Class: Lithic::Models::AccountHolder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolder
- Defined in:
- lib/lithic/models/account_holder.rb
Overview
Defined Under Namespace
Modules: ExemptionType, Status, StatusReason, UserType Classes: BeneficialOwnerIndividual, BusinessEntity, ControlPerson, Individual, VerificationApplication
Instance Attribute Summary collapse
-
#account_token ⇒ String?
Globally unique identifier for the account.
-
#beneficial_owner_individuals ⇒ Array<Lithic::Models::AccountHolder::BeneficialOwnerIndividual>?
Only present when user_type == “BUSINESS”.
-
#business_account_token ⇒ String?
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses.
-
#business_entity ⇒ Lithic::Models::AccountHolder::BusinessEntity?
Only present when user_type == “BUSINESS”.
-
#control_person ⇒ Lithic::Models::AccountHolder::ControlPerson?
Only present when user_type == “BUSINESS”.
-
#created ⇒ Time
Timestamp of when the account holder was created.
-
#email ⇒ String?
(Deprecated. Use control_person.email when user_type == “BUSINESS”. Use individual.phone_number when user_type == “INDIVIDUAL”.) Primary email of Account Holder.
-
#exemption_type ⇒ Symbol, ...
The type of KYC exemption for a KYC-Exempt Account Holder.
-
#external_id ⇒ String?
Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem.
-
#individual ⇒ Lithic::Models::AccountHolder::Individual?
Only present when user_type == “INDIVIDUAL”.
-
#naics_code ⇒ String?
Only present when user_type == “BUSINESS”.
-
#nature_of_business ⇒ String?
Only present when user_type == “BUSINESS”.
-
#phone_number ⇒ String?
(Deprecated. Use control_person.phone_number when user_type == “BUSINESS”. Use individual.phone_number when user_type == “INDIVIDUAL”.) Primary phone of Account Holder, entered in E.164 format.
-
#required_documents ⇒ Array<Lithic::Models::RequiredDocument>?
Only present for “KYB_BASIC” workflow.
-
#status ⇒ Symbol, ...
(Deprecated. Use verification_application.status instead).
-
#status_reasons ⇒ Array<Symbol, Lithic::Models::AccountHolder::StatusReason>?
(Deprecated. Use verification_application.status_reasons).
-
#token ⇒ String
Globally unique identifier for the account holder.
-
#user_type ⇒ Symbol, ...
The type of Account Holder.
-
#verification_application ⇒ Lithic::Models::AccountHolder::VerificationApplication?
Information about the most recent identity verification attempt.
-
#website_url ⇒ String?
Only present when user_type == “BUSINESS”.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(address:, dob:, email:, entity_token:, first_name:, last_name:, phone_number:) ⇒ Object
constructor
Only present when user_type == “INDIVIDUAL”.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address:, dob:, email:, entity_token:, first_name:, last_name:, phone_number:) ⇒ Object
Only present when user_type == “INDIVIDUAL”. Information about the individual for which the account is being opened and KYC is being run.
|
|
# File 'lib/lithic/models/account_holder.rb', line 249
|
Instance Attribute Details
#account_token ⇒ String?
Globally unique identifier for the account.
23 |
# File 'lib/lithic/models/account_holder.rb', line 23 optional :account_token, String |
#beneficial_owner_individuals ⇒ Array<Lithic::Models::AccountHolder::BeneficialOwnerIndividual>?
Only present when user_type == “BUSINESS”. You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See [FinCEN requirements](www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf) (Section I) for more background on individuals that should be included.
34 35 |
# File 'lib/lithic/models/account_holder.rb', line 34 optional :beneficial_owner_individuals, -> { Lithic::Internal::Type::ArrayOf[Lithic::AccountHolder::BeneficialOwnerIndividual] } |
#business_account_token ⇒ String?
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Pass the account_token of the enrolled business associated with the AUTHORIZED_USER in this field.
43 |
# File 'lib/lithic/models/account_holder.rb', line 43 optional :business_account_token, String |
#business_entity ⇒ Lithic::Models::AccountHolder::BusinessEntity?
Only present when user_type == “BUSINESS”. Information about the business for which the account is being opened and KYB is being run.
50 |
# File 'lib/lithic/models/account_holder.rb', line 50 optional :business_entity, -> { Lithic::AccountHolder::BusinessEntity } |
#control_person ⇒ Lithic::Models::AccountHolder::ControlPerson?
Only present when user_type == “BUSINESS”. An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above.
61 |
# File 'lib/lithic/models/account_holder.rb', line 61 optional :control_person, -> { Lithic::AccountHolder::ControlPerson } |
#created ⇒ Time
Timestamp of when the account holder was created.
17 |
# File 'lib/lithic/models/account_holder.rb', line 17 required :created, Time |
#email ⇒ String?
(Deprecated. Use control_person.email when user_type == “BUSINESS”. Use individual.phone_number when user_type == “INDIVIDUAL”.) Primary email of Account Holder.
69 |
# File 'lib/lithic/models/account_holder.rb', line 69 optional :email, String |
#exemption_type ⇒ Symbol, ...
The type of KYC exemption for a KYC-Exempt Account Holder.
75 |
# File 'lib/lithic/models/account_holder.rb', line 75 optional :exemption_type, enum: -> { Lithic::AccountHolder::ExemptionType } |
#external_id ⇒ String?
Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem.
82 |
# File 'lib/lithic/models/account_holder.rb', line 82 optional :external_id, String |
#individual ⇒ Lithic::Models::AccountHolder::Individual?
Only present when user_type == “INDIVIDUAL”. Information about the individual for which the account is being opened and KYC is being run.
89 |
# File 'lib/lithic/models/account_holder.rb', line 89 optional :individual, -> { Lithic::AccountHolder::Individual } |
#naics_code ⇒ String?
Only present when user_type == “BUSINESS”. 6-digit North American Industry Classification System (NAICS) code for the business.
96 |
# File 'lib/lithic/models/account_holder.rb', line 96 optional :naics_code, String |
#nature_of_business ⇒ String?
Only present when user_type == “BUSINESS”. User-submitted description of the business.
103 |
# File 'lib/lithic/models/account_holder.rb', line 103 optional :nature_of_business, String |
#phone_number ⇒ String?
(Deprecated. Use control_person.phone_number when user_type == “BUSINESS”. Use individual.phone_number when user_type == “INDIVIDUAL”.) Primary phone of Account Holder, entered in E.164 format.
111 |
# File 'lib/lithic/models/account_holder.rb', line 111 optional :phone_number, String |
#required_documents ⇒ Array<Lithic::Models::RequiredDocument>?
Only present for “KYB_BASIC” workflow. A list of documents required for the account holder to be approved.
118 |
# File 'lib/lithic/models/account_holder.rb', line 118 optional :required_documents, -> { Lithic::Internal::Type::ArrayOf[Lithic::RequiredDocument] } |
#status ⇒ Symbol, ...
(Deprecated. Use verification_application.status instead)
KYC and KYB evaluation states.
Note:
-
‘PENDING_REVIEW` is only applicable for the `KYB_BASIC` workflow.
130 |
# File 'lib/lithic/models/account_holder.rb', line 130 optional :status, enum: -> { Lithic::AccountHolder::Status } |
#status_reasons ⇒ Array<Symbol, Lithic::Models::AccountHolder::StatusReason>?
(Deprecated. Use verification_application.status_reasons)
Reason for the evaluation status.
138 139 |
# File 'lib/lithic/models/account_holder.rb', line 138 optional :status_reasons, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::AccountHolder::StatusReason] } |
#token ⇒ String
Globally unique identifier for the account holder.
11 |
# File 'lib/lithic/models/account_holder.rb', line 11 required :token, String |
#user_type ⇒ Symbol, ...
The type of Account Holder. If the type is “INDIVIDUAL”, the “individual” attribute will be present. If the type is “BUSINESS” then the “business_entity”, “control_person”, “beneficial_owner_individuals”, “naics_code”, “nature_of_business”, and “website_url” attributes will be present.
148 |
# File 'lib/lithic/models/account_holder.rb', line 148 optional :user_type, enum: -> { Lithic::AccountHolder::UserType } |
#verification_application ⇒ Lithic::Models::AccountHolder::VerificationApplication?
Information about the most recent identity verification attempt
154 |
# File 'lib/lithic/models/account_holder.rb', line 154 optional :verification_application, -> { Lithic::AccountHolder::VerificationApplication } |
#website_url ⇒ String?
Only present when user_type == “BUSINESS”. Business’s primary website.
160 |
# File 'lib/lithic/models/account_holder.rb', line 160 optional :website_url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/account_holder.rb', line 416
|