Class: Lithic::Models::AccountHolder::BeneficialOwnerIndividual

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holder.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, created:, account_token: nil, beneficial_owner_individuals: nil, business_account_token: nil, business_entity: nil, control_person: nil, email: nil, exemption_type: nil, external_id: nil, individual: nil, naics_code: nil, nature_of_business: nil, phone_number: nil, required_documents: nil, status: nil, status_reasons: nil, user_type: nil, verification_application: nil, website_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AccountHolder for more details.

Parameters:

  • token (String)

    Globally unique identifier for the account holder.

  • created (Time)

    Timestamp of when the account holder was created.

  • account_token (String) (defaults to: nil)

    Globally unique identifier for the account.

  • beneficial_owner_individuals (Array<Lithic::Models::AccountHolder::BeneficialOwnerIndividual>) (defaults to: nil)

    Only present when user_type == “BUSINESS”.

  • business_account_token (String) (defaults to: nil)

    Only applicable for customers using the KYC-Exempt workflow to enroll authorized

  • business_entity (Lithic::Models::AccountHolder::BusinessEntity) (defaults to: nil)

    Only present when user_type == “BUSINESS”. Information about the business for wh

  • control_person (Lithic::Models::AccountHolder::ControlPerson) (defaults to: nil)

    Only present when user_type == “BUSINESS”.

  • email (String) (defaults to: nil)

    (Deprecated. Use control_person.email when user_type == “BUSINESS”. Use individu

  • exemption_type (Symbol, Lithic::Models::AccountHolder::ExemptionType) (defaults to: nil)

    The type of KYC exemption for a KYC-Exempt Account Holder.

  • external_id (String) (defaults to: nil)

    Customer-provided token that indicates a relationship with an object outside of

  • individual (Lithic::Models::AccountHolder::Individual) (defaults to: nil)

    Only present when user_type == “INDIVIDUAL”. Information about the individual fo

  • naics_code (String) (defaults to: nil)

    Only present when user_type == “BUSINESS”. 6-digit North American Industry Class

  • nature_of_business (String) (defaults to: nil)

    Only present when user_type == “BUSINESS”. User-submitted description of the bus

  • phone_number (String) (defaults to: nil)

    (Deprecated. Use control_person.phone_number when user_type == “BUSINESS”. Use i

  • required_documents (Array<Lithic::Models::RequiredDocument>) (defaults to: nil)

    Only present for “KYB_BASIC” workflow. A list of documents required for the acco

  • status (Symbol, Lithic::Models::AccountHolder::Status) (defaults to: nil)

    (Deprecated. Use verification_application.status instead)

  • status_reasons (Array<Symbol, Lithic::Models::AccountHolder::StatusReason>) (defaults to: nil)

    (Deprecated. Use verification_application.status_reasons)

  • user_type (Symbol, Lithic::Models::AccountHolder::UserType) (defaults to: nil)

    The type of Account Holder. If the type is “INDIVIDUAL”, the “individual” attrib

  • verification_application (Lithic::Models::AccountHolder::VerificationApplication) (defaults to: nil)

    Information about the most recent identity verification attempt

  • website_url (String) (defaults to: nil)

    Only present when user_type == “BUSINESS”. Business’s primary website.



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/lithic/models/account_holder.rb', line 206

class BeneficialOwnerIndividual < Lithic::Internal::Type::BaseModel
  # @!attribute address
  #   Individual's current address
  #
  #   @return [Lithic::Models::Address]
  required :address, -> { Lithic::Address }

  # @!attribute dob
  #   Individual's date of birth, as an RFC 3339 date.
  #
  #   @return [String]
  required :dob, String

  # @!attribute email
  #   Individual's email address.
  #
  #   @return [String]
  required :email, String

  # @!attribute entity_token
  #   Globally unique identifier for the entity.
  #
  #   @return [String]
  required :entity_token, String

  # @!attribute first_name
  #   Individual's first name, as it appears on government-issued identity documents.
  #
  #   @return [String]
  required :first_name, String

  # @!attribute last_name
  #   Individual's last name, as it appears on government-issued identity documents.
  #
  #   @return [String]
  required :last_name, String

  # @!attribute phone_number
  #   Individual's phone number, entered in E.164 format.
  #
  #   @return [String]
  required :phone_number, String

  # @!method initialize(address:, dob:, email:, entity_token:, first_name:, last_name:, phone_number:)
  #   Information about an individual associated with an account holder. A subset of
  #   the information provided via KYC. For example, we do not return the government
  #   id.
  #
  #   @param address [Lithic::Models::Address] Individual's current address
  #
  #   @param dob [String] Individual's date of birth, as an RFC 3339 date.
  #
  #   @param email [String] Individual's email address.
  #
  #   @param entity_token [String] Globally unique identifier for the entity.
  #
  #   @param first_name [String] Individual's first name, as it appears on government-issued identity documents.
  #
  #   @param last_name [String] Individual's last name, as it appears on government-issued identity documents.
  #
  #   @param phone_number [String] Individual's phone number, entered in E.164 format.
end

Instance Attribute Details

#addressLithic::Models::Address

Individual’s current address



211
# File 'lib/lithic/models/account_holder.rb', line 211

required :address, -> { Lithic::Address }

#dobString

Individual’s date of birth, as an RFC 3339 date.

Returns:

  • (String)


217
# File 'lib/lithic/models/account_holder.rb', line 217

required :dob, String

#emailString

Individual’s email address.

Returns:

  • (String)


223
# File 'lib/lithic/models/account_holder.rb', line 223

required :email, String

#entity_tokenString

Globally unique identifier for the entity.

Returns:

  • (String)


229
# File 'lib/lithic/models/account_holder.rb', line 229

required :entity_token, String

#first_nameString

Individual’s first name, as it appears on government-issued identity documents.

Returns:

  • (String)


235
# File 'lib/lithic/models/account_holder.rb', line 235

required :first_name, String

#last_nameString

Individual’s last name, as it appears on government-issued identity documents.

Returns:

  • (String)


241
# File 'lib/lithic/models/account_holder.rb', line 241

required :last_name, String

#phone_numberString

Individual’s phone number, entered in E.164 format.

Returns:

  • (String)


247
# File 'lib/lithic/models/account_holder.rb', line 247

required :phone_number, String