Class: Lithic::Models::AccountHolder::BusinessEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolder::BusinessEntity
- Defined in:
- lib/lithic/models/account_holder.rb,
sig/lithic/models/account_holder.rbs
Overview
Instance Attribute Summary collapse
-
#address ⇒ Lithic::Models::Address
Business's physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
#dba_business_name ⇒ String
Any name that the business operates under that is not its legal business name (if applicable).
-
#entity_token ⇒ String
Globally unique identifier for the entity.
-
#government_id ⇒ String
Government-issued identification number.
-
#legal_business_name ⇒ String
Legal (formal) business name.
-
#parent_company ⇒ String?
Parent company name (if applicable).
-
#phone_numbers ⇒ Array<String>
One or more of the business's phone number(s), entered as a list in E.164 format.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
245 |
# File 'sig/lithic/models/account_holder.rbs', line 245
def initialize: (
|
Instance Attribute Details
#address ⇒ Lithic::Models::Address
Business's physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
276 |
# File 'lib/lithic/models/account_holder.rb', line 276 required :address, -> { Lithic::Address } |
#dba_business_name ⇒ String
Any name that the business operates under that is not its legal business name (if applicable).
283 |
# File 'lib/lithic/models/account_holder.rb', line 283 required :dba_business_name, String |
#entity_token ⇒ String
Globally unique identifier for the entity.
289 |
# File 'lib/lithic/models/account_holder.rb', line 289 required :entity_token, String |
#government_id ⇒ String
Government-issued identification number. US Federal Employer Identification Numbers (EIN) are currently supported, entered as full nine-digits, with or without hyphens.
297 |
# File 'lib/lithic/models/account_holder.rb', line 297 required :government_id, String |
#legal_business_name ⇒ String
Legal (formal) business name.
303 |
# File 'lib/lithic/models/account_holder.rb', line 303 required :legal_business_name, String |
#parent_company ⇒ String?
Parent company name (if applicable).
316 |
# File 'lib/lithic/models/account_holder.rb', line 316 optional :parent_company, String |
#phone_numbers ⇒ Array<String>
One or more of the business's phone number(s), entered as a list in E.164 format.
310 |
# File 'lib/lithic/models/account_holder.rb', line 310 required :phone_numbers, Lithic::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
255 |
# File 'sig/lithic/models/account_holder.rbs', line 255
def to_hash: -> {
|