Module: Lithic::Models::AccountHolderCreateParams::Body

Extended by:
Internal::Type::Union
Defined in:
lib/lithic/models/account_holder_create_params.rb

Defined Under Namespace

Classes: KYBDelegated

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(body:, request_options: {}) ⇒ Object



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/lithic/models/account_holder_create_params.rb', line 19

module Body
  extend Lithic::Internal::Type::Union

  variant -> { Lithic::KYB }

  variant -> { Lithic::AccountHolderCreateParams::Body::KYBDelegated }

  variant -> { Lithic::KYC }

  variant -> { Lithic::KYCExempt }

  class KYBDelegated < Lithic::Internal::Type::BaseModel
    # @!attribute business_entity
    #   Information for business for which the account is being opened.
    #
    #   @return [Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BusinessEntity]
    required :business_entity, -> { Lithic::AccountHolderCreateParams::Body::KYBDelegated::BusinessEntity }

    # @!attribute beneficial_owner_individuals
    #   You can submit a list of all direct and indirect individuals with 25% or more
    #   ownership in the company. A maximum of 4 beneficial owners can be submitted. If
    #   no individual owns 25% of the company you do not need to send beneficial owner
    #   information. See
    #   [FinCEN requirements](https://www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf)
    #   (Section I) for more background on individuals that should be included.
    #
    #   @return [Array<Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BeneficialOwnerIndividual>, nil]
    optional :beneficial_owner_individuals,
             -> { Lithic::Internal::Type::ArrayOf[Lithic::AccountHolderCreateParams::Body::KYBDelegated::BeneficialOwnerIndividual] }

    # @!attribute control_person
    #   An individual with significant responsibility for managing the legal entity
    #   (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating
    #   Officer, Managing Member, General Partner, President, Vice President, or
    #   Treasurer). This can be an executive, or someone who will have program-wide
    #   access to the cards that Lithic will provide. In some cases, this individual
    #   could also be a beneficial owner listed above. See
    #   [FinCEN requirements](https://www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf)
    #   (Section II) for more background.
    #
    #   @return [Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::ControlPerson, nil]
    optional :control_person, -> { Lithic::AccountHolderCreateParams::Body::KYBDelegated::ControlPerson }

    # @!attribute external_id
    #   A user provided id that can be used to link an account holder with an external
    #   system
    #
    #   @return [String, nil]
    optional :external_id, String

    # @!attribute naics_code
    #   6-digit North American Industry Classification System (NAICS) code for the
    #   business.
    #
    #   @return [String, nil]
    optional :naics_code, String

    # @!attribute nature_of_business
    #   Short description of the company's line of business (i.e., what does the company
    #   do?). Values longer than 255 characters will be truncated before KYB
    #   verification
    #
    #   @return [String, nil]
    optional :nature_of_business, String

    # @!attribute tos_timestamp
    #   An RFC 3339 timestamp indicating when the account holder accepted the applicable
    #   legal agreements (e.g., cardholder terms) as agreed upon during API customer's
    #   implementation with Lithic.
    #
    #   @return [String, nil]
    optional :tos_timestamp, String

    # @!attribute website_url
    #   Company website URL.
    #
    #   @return [String, nil]
    optional :website_url, String

    # @!attribute workflow
    #   Specifies the type of KYB workflow to run.
    #
    #   @return [Symbol, Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::Workflow, nil]
    optional :workflow, enum: -> { Lithic::AccountHolderCreateParams::Body::KYBDelegated::Workflow }

    # @!method initialize(business_entity:, beneficial_owner_individuals: nil, control_person: nil, external_id: nil, naics_code: nil, nature_of_business: nil, tos_timestamp: nil, website_url: nil, workflow: nil)
    #   Some parameter documentations has been truncated, see
    #   {Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated} for more
    #   details.
    #
    #   @param business_entity [Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BusinessEntity] Information for business for which the account is being opened.
    #
    #   @param beneficial_owner_individuals [Array<Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BeneficialOwnerIndividual>] You can submit a list of all direct and indirect individuals with 25% or more ow
    #
    #   @param control_person [Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::ControlPerson] An individual with significant responsibility for managing the legal entity (e.g
    #
    #   @param external_id [String] A user provided id that can be used to link an account holder with an external s
    #
    #   @param naics_code [String] 6-digit North American Industry Classification System (NAICS) code for the busin
    #
    #   @param nature_of_business [String] Short description of the company's line of business (i.e., what does the company
    #
    #   @param tos_timestamp [String] An RFC 3339 timestamp indicating when the account holder accepted the applicable
    #
    #   @param website_url [String] Company website URL.
    #
    #   @param workflow [Symbol, Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::Workflow] Specifies the type of KYB workflow to run.

    # @see Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated#business_entity
    class BusinessEntity < Lithic::Internal::Type::BaseModel
      # @!attribute address
      #   Business's physical address - PO boxes, UPS drops, and FedEx drops are not
      #   acceptable; APO/FPO are acceptable.
      #
      #   @return [Lithic::Models::Address]
      required :address, -> { Lithic::Address }

      # @!attribute legal_business_name
      #   Legal (formal) business name.
      #
      #   @return [String]
      required :legal_business_name, String

      # @!attribute dba_business_name
      #   Any name that the business operates under that is not its legal business name
      #   (if applicable).
      #
      #   @return [String, nil]
      optional :dba_business_name, String

      # @!attribute government_id
      #   Government-issued identification number. US Federal Employer Identification
      #   Numbers (EIN) are currently supported, entered as full nine-digits, with or
      #   without hyphens.
      #
      #   @return [String, nil]
      optional :government_id, String

      # @!attribute parent_company
      #   Parent company name (if applicable).
      #
      #   @return [String, nil]
      optional :parent_company, String

      # @!attribute phone_numbers
      #   One or more of the business's phone number(s), entered as a list in E.164
      #   format.
      #
      #   @return [Array<String>, nil]
      optional :phone_numbers, Lithic::Internal::Type::ArrayOf[String]

      # @!method initialize(address:, legal_business_name:, dba_business_name: nil, government_id: nil, parent_company: nil, phone_numbers: nil)
      #   Some parameter documentations has been truncated, see
      #   {Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BusinessEntity}
      #   for more details.
      #
      #   Information for business for which the account is being opened.
      #
      #   @param address [Lithic::Models::Address] Business's physical address - PO boxes, UPS drops, and FedEx drops are not accep
      #
      #   @param legal_business_name [String] Legal (formal) business name.
      #
      #   @param dba_business_name [String] Any name that the business operates under that is not its legal business name (i
      #
      #   @param government_id [String] Government-issued identification number. US Federal Employer Identification Numb
      #
      #   @param parent_company [String] Parent company name (if applicable).
      #
      #   @param phone_numbers [Array<String>] One or more of the business's phone number(s), entered as a list in E.164 format
    end

    class BeneficialOwnerIndividual < Lithic::Internal::Type::BaseModel
      # @!attribute first_name
      #   Individual's first name, as it appears on government-issued identity documents.
      #
      #   @return [String]
      required :first_name, String

      # @!attribute last_name
      #   Individual's last name, as it appears on government-issued identity documents.
      #
      #   @return [String]
      required :last_name, String

      # @!attribute address
      #   Individual's current address - PO boxes, UPS drops, and FedEx drops are not
      #   acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
      #
      #   @return [Lithic::Models::Address, nil]
      optional :address, -> { Lithic::Address }

      # @!attribute dob
      #   Individual's date of birth, as an RFC 3339 date.
      #
      #   @return [String, nil]
      optional :dob, String

      # @!attribute email
      #   Individual's email address. If utilizing Lithic for chargeback processing, this
      #   customer email address may be used to communicate dispute status and resolution.
      #
      #   @return [String, nil]
      optional :email, String

      # @!attribute government_id
      #   Government-issued identification number (required for identity verification and
      #   compliance with banking regulations). Social Security Numbers (SSN) and
      #   Individual Taxpayer Identification Numbers (ITIN) are currently supported,
      #   entered as full nine-digits, with or without hyphens
      #
      #   @return [String, nil]
      optional :government_id, String

      # @!attribute phone_number
      #   Individual's phone number, entered in E.164 format.
      #
      #   @return [String, nil]
      optional :phone_number, String

      # @!method initialize(first_name:, last_name:, address: nil, dob: nil, email: nil, government_id: nil, phone_number: nil)
      #   Some parameter documentations has been truncated, see
      #   {Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BeneficialOwnerIndividual}
      #   for more details.
      #
      #   Individuals associated with a KYB_DELEGATED application. Only first and last
      #   name are required.
      #
      #   @param first_name [String] Individual's first name, as it appears on government-issued identity documents.
      #
      #   @param last_name [String] Individual's last name, as it appears on government-issued identity documents.
      #
      #   @param address [Lithic::Models::Address] Individual's current address - PO boxes, UPS drops, and FedEx drops are not acce
      #
      #   @param dob [String] Individual's date of birth, as an RFC 3339 date.
      #
      #   @param email [String] Individual's email address.
      #
      #   @param government_id [String] Government-issued identification number (required for identity verification and
      #
      #   @param phone_number [String] Individual's phone number, entered in E.164 format.
    end

    # @see Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated#control_person
    class ControlPerson < Lithic::Internal::Type::BaseModel
      # @!attribute first_name
      #   Individual's first name, as it appears on government-issued identity documents.
      #
      #   @return [String]
      required :first_name, String

      # @!attribute last_name
      #   Individual's last name, as it appears on government-issued identity documents.
      #
      #   @return [String]
      required :last_name, String

      # @!attribute address
      #   Individual's current address - PO boxes, UPS drops, and FedEx drops are not
      #   acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
      #
      #   @return [Lithic::Models::Address, nil]
      optional :address, -> { Lithic::Address }

      # @!attribute dob
      #   Individual's date of birth, as an RFC 3339 date.
      #
      #   @return [String, nil]
      optional :dob, String

      # @!attribute email
      #   Individual's email address. If utilizing Lithic for chargeback processing, this
      #   customer email address may be used to communicate dispute status and resolution.
      #
      #   @return [String, nil]
      optional :email, String

      # @!attribute government_id
      #   Government-issued identification number (required for identity verification and
      #   compliance with banking regulations). Social Security Numbers (SSN) and
      #   Individual Taxpayer Identification Numbers (ITIN) are currently supported,
      #   entered as full nine-digits, with or without hyphens
      #
      #   @return [String, nil]
      optional :government_id, String

      # @!attribute phone_number
      #   Individual's phone number, entered in E.164 format.
      #
      #   @return [String, nil]
      optional :phone_number, String

      # @!method initialize(first_name:, last_name:, address: nil, dob: nil, email: nil, government_id: nil, phone_number: nil)
      #   Some parameter documentations has been truncated, see
      #   {Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::ControlPerson}
      #   for more details.
      #
      #   An individual with significant responsibility for managing the legal entity
      #   (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating
      #   Officer, Managing Member, General Partner, President, Vice President, or
      #   Treasurer). This can be an executive, or someone who will have program-wide
      #   access to the cards that Lithic will provide. In some cases, this individual
      #   could also be a beneficial owner listed above. See
      #   [FinCEN requirements](https://www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf)
      #   (Section II) for more background.
      #
      #   @param first_name [String] Individual's first name, as it appears on government-issued identity documents.
      #
      #   @param last_name [String] Individual's last name, as it appears on government-issued identity documents.
      #
      #   @param address [Lithic::Models::Address] Individual's current address - PO boxes, UPS drops, and FedEx drops are not acce
      #
      #   @param dob [String] Individual's date of birth, as an RFC 3339 date.
      #
      #   @param email [String] Individual's email address.
      #
      #   @param government_id [String] Government-issued identification number (required for identity verification and
      #
      #   @param phone_number [String] Individual's phone number, entered in E.164 format.
    end

    # Specifies the type of KYB workflow to run.
    #
    # @see Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated#workflow
    module Workflow
      extend Lithic::Internal::Type::Enum

      KYB_DELEGATED = :KYB_DELEGATED

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @!method self.variants
  #   @return [Array(Lithic::Models::KYB, Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated, Lithic::Models::KYC, Lithic::Models::KYCExempt)]
end