Class: Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holder_create_params.rb

Defined Under Namespace

Modules: Workflow Classes: BeneficialOwnerIndividual, BusinessEntity, ControlPerson

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(first_name:, last_name:, address: nil, dob: nil, email: nil, government_id: nil, phone_number: nil) ⇒ Object

Some parameter documentations has been truncated, see ControlPerson for more details.

An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See [FinCEN requirements](www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf) (Section II) for more background.

Parameters:

  • first_name (String)

    Individual’s first name, as it appears on government-issued identity documents.

  • last_name (String)

    Individual’s last name, as it appears on government-issued identity documents.

  • address (Lithic::Models::Address) (defaults to: nil)

    Individual’s current address - PO boxes, UPS drops, and FedEx drops are not acce

  • dob (String) (defaults to: nil)

    Individual’s date of birth, as an RFC 3339 date.

  • email (String) (defaults to: nil)

    Individual’s email address.

  • government_id (String) (defaults to: nil)

    Government-issued identification number (required for identity verification and

  • phone_number (String) (defaults to: nil)

    Individual’s phone number, entered in E.164 format.



# File 'lib/lithic/models/account_holder_create_params.rb', line 104

Instance Attribute Details

#beneficial_owner_individualsArray<Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BeneficialOwnerIndividual>?

You can submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See [FinCEN requirements](www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf) (Section I) for more background on individuals that should be included.



46
47
# File 'lib/lithic/models/account_holder_create_params.rb', line 46

optional :beneficial_owner_individuals,
-> { Lithic::Internal::Type::ArrayOf[Lithic::AccountHolderCreateParams::Body::KYBDelegated::BeneficialOwnerIndividual] }

#business_entityLithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BusinessEntity

Information for business for which the account is being opened.



35
# File 'lib/lithic/models/account_holder_create_params.rb', line 35

required :business_entity, -> { Lithic::AccountHolderCreateParams::Body::KYBDelegated::BusinessEntity }

#control_personLithic::Models::AccountHolderCreateParams::Body::KYBDelegated::ControlPerson?

An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See [FinCEN requirements](www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf) (Section II) for more background.



60
# File 'lib/lithic/models/account_holder_create_params.rb', line 60

optional :control_person, -> { Lithic::AccountHolderCreateParams::Body::KYBDelegated::ControlPerson }

#external_idString?

A user provided id that can be used to link an account holder with an external system

Returns:

  • (String, nil)


67
# File 'lib/lithic/models/account_holder_create_params.rb', line 67

optional :external_id, String

#naics_codeString?

6-digit North American Industry Classification System (NAICS) code for the business.

Returns:

  • (String, nil)


74
# File 'lib/lithic/models/account_holder_create_params.rb', line 74

optional :naics_code, String

#nature_of_businessString?

Short description of the company’s line of business (i.e., what does the company do?). Values longer than 255 characters will be truncated before KYB verification

Returns:

  • (String, nil)


82
# File 'lib/lithic/models/account_holder_create_params.rb', line 82

optional :nature_of_business, String

#tos_timestampString?

An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer’s implementation with Lithic.

Returns:

  • (String, nil)


90
# File 'lib/lithic/models/account_holder_create_params.rb', line 90

optional :tos_timestamp, String

#website_urlString?

Company website URL.

Returns:

  • (String, nil)


96
# File 'lib/lithic/models/account_holder_create_params.rb', line 96

optional :website_url, String

#workflowSymbol, ...

Specifies the type of KYB workflow to run.



102
# File 'lib/lithic/models/account_holder_create_params.rb', line 102

optional :workflow, enum: -> { Lithic::AccountHolderCreateParams::Body::KYBDelegated::Workflow }