Class: Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BeneficialOwnerIndividual
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolderCreateParams::Body::KYBDelegated::BeneficialOwnerIndividual
- Defined in:
- lib/lithic/models/account_holder_create_params.rb
Instance Attribute Summary collapse
-
#address ⇒ Lithic::Models::Address?
Individual’s current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
#dob ⇒ String?
Individual’s date of birth, as an RFC 3339 date.
-
#email ⇒ String?
Individual’s email address.
-
#first_name ⇒ String
Individual’s first name, as it appears on government-issued identity documents.
-
#government_id ⇒ String?
Government-issued identification number (required for identity verification and compliance with banking regulations).
-
#last_name ⇒ String
Individual’s last name, as it appears on government-issued identity documents.
-
#phone_number ⇒ String?
Individual’s phone number, entered in E.164 format.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Lithic::Internal::Type::BaseModel
Instance Attribute Details
#address ⇒ Lithic::Models::Address?
Individual’s current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
208 |
# File 'lib/lithic/models/account_holder_create_params.rb', line 208 optional :address, -> { Lithic::Address } |
#dob ⇒ String?
Individual’s date of birth, as an RFC 3339 date.
214 |
# File 'lib/lithic/models/account_holder_create_params.rb', line 214 optional :dob, String |
#email ⇒ String?
Individual’s email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.
221 |
# File 'lib/lithic/models/account_holder_create_params.rb', line 221 optional :email, String |
#first_name ⇒ String
Individual’s first name, as it appears on government-issued identity documents.
195 |
# File 'lib/lithic/models/account_holder_create_params.rb', line 195 required :first_name, String |
#government_id ⇒ String?
Government-issued identification number (required for identity verification and compliance with banking regulations). Social Security Numbers (SSN) and Individual Taxpayer Identification Numbers (ITIN) are currently supported, entered as full nine-digits, with or without hyphens
230 |
# File 'lib/lithic/models/account_holder_create_params.rb', line 230 optional :government_id, String |
#last_name ⇒ String
Individual’s last name, as it appears on government-issued identity documents.
201 |
# File 'lib/lithic/models/account_holder_create_params.rb', line 201 required :last_name, String |
#phone_number ⇒ String?
Individual’s phone number, entered in E.164 format.
236 |
# File 'lib/lithic/models/account_holder_create_params.rb', line 236 optional :phone_number, String |