Class: Lithic::Models::AccountHolderCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holder_create_response.rb

Overview

Defined Under Namespace

Modules: Status, StatusReason

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, account_token:, status:, status_reasons:, created: nil, external_id: nil, required_documents: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AccountHolderCreateResponse for more details.

Parameters:

  • token (String)

    Globally unique identifier for the account holder.

  • account_token (String)

    Globally unique identifier for the account.

  • status (Symbol, Lithic::Models::AccountHolderCreateResponse::Status)

    KYC and KYB evaluation states.

  • status_reasons (Array<Symbol, Lithic::Models::AccountHolderCreateResponse::StatusReason>)

    Reason for the evaluation status.

  • created (Time) (defaults to: nil)

    Timestamp of when the account holder was created.

  • external_id (String) (defaults to: nil)

    Customer-provided token that indicates a relationship with an object outside of

  • required_documents (Array<Lithic::Models::RequiredDocument>) (defaults to: nil)

    Only present for “KYB_BASIC” workflow. A list of documents required for the acco



# File 'lib/lithic/models/account_holder_create_response.rb', line 56

Instance Attribute Details

#account_tokenString

Globally unique identifier for the account.

Returns:

  • (String)


17
# File 'lib/lithic/models/account_holder_create_response.rb', line 17

required :account_token, String

#createdTime?

Timestamp of when the account holder was created.

Returns:

  • (Time, nil)


40
# File 'lib/lithic/models/account_holder_create_response.rb', line 40

optional :created, Time

#external_idString?

Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem.

Returns:

  • (String, nil)


47
# File 'lib/lithic/models/account_holder_create_response.rb', line 47

optional :external_id, String

#required_documentsArray<Lithic::Models::RequiredDocument>?

Only present for “KYB_BASIC” workflow. A list of documents required for the account holder to be approved.

Returns:



54
# File 'lib/lithic/models/account_holder_create_response.rb', line 54

optional :required_documents, -> { Lithic::Internal::Type::ArrayOf[Lithic::RequiredDocument] }

#statusSymbol, Lithic::Models::AccountHolderCreateResponse::Status

KYC and KYB evaluation states.

Note:

  • ‘PENDING_REVIEW` is only applicable for the `KYB_BASIC` workflow.



27
# File 'lib/lithic/models/account_holder_create_response.rb', line 27

required :status, enum: -> { Lithic::Models::AccountHolderCreateResponse::Status }

#status_reasonsArray<Symbol, Lithic::Models::AccountHolderCreateResponse::StatusReason>

Reason for the evaluation status.



33
34
# File 'lib/lithic/models/account_holder_create_response.rb', line 33

required :status_reasons,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::Models::AccountHolderCreateResponse::StatusReason] }

#tokenString

Globally unique identifier for the account holder.

Returns:

  • (String)


11
# File 'lib/lithic/models/account_holder_create_response.rb', line 11

required :token, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/account_holder_create_response.rb', line 90