Class: Lithic::Models::AccountHolderListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/account_holder_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(begin_: nil, email: nil, end_: nil, ending_before: nil, external_id: nil, first_name: nil, last_name: nil, legal_business_name: nil, limit: nil, phone_number: nil, starting_after: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AccountHolderListParams for more details.

Parameters:

  • begin_ (Time) (defaults to: nil)

    Date string in RFC 3339 format. Only entries created after the specified time wi

  • email (String) (defaults to: nil)

    Email address of the account holder. The query must be an exact match, case inse

  • end_ (Time) (defaults to: nil)

    Date string in RFC 3339 format. Only entries created before the specified time w

  • ending_before (String) (defaults to: nil)

    A cursor representing an item’s token before which a page of results should end.

  • external_id (String) (defaults to: nil)

    If applicable, represents the external_id associated with the account_holder.

  • first_name (String) (defaults to: nil)

    (Individual Account Holders only) The first name of the account holder. The quer

  • last_name (String) (defaults to: nil)

    (Individual Account Holders only) The last name of the account holder. The query

  • legal_business_name (String) (defaults to: nil)

    (Business Account Holders only) The legal business name of the account holder. T

  • limit (Integer) (defaults to: nil)

    The number of account_holders to limit the response to.

  • phone_number (String) (defaults to: nil)

    Phone number of the account holder. The query must be an exact match.

  • starting_after (String) (defaults to: nil)

    A cursor representing an item’s token after which a page of results should begin

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/account_holder_list_params.rb', line 84

Instance Attribute Details

#begin_Time?

Date string in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.

Returns:

  • (Time, nil)


15
# File 'lib/lithic/models/account_holder_list_params.rb', line 15

optional :begin_, Time

#emailString?

Email address of the account holder. The query must be an exact match, case insensitive.

Returns:

  • (String, nil)


22
# File 'lib/lithic/models/account_holder_list_params.rb', line 22

optional :email, String

#end_Time?

Date string in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.

Returns:

  • (Time, nil)


29
# File 'lib/lithic/models/account_holder_list_params.rb', line 29

optional :end_, Time

#ending_beforeString?

A cursor representing an item’s token before which a page of results should end. Used to retrieve the previous page of results before this item.

Returns:

  • (String, nil)


36
# File 'lib/lithic/models/account_holder_list_params.rb', line 36

optional :ending_before, String

#external_idString?

If applicable, represents the external_id associated with the account_holder.

Returns:

  • (String, nil)


42
# File 'lib/lithic/models/account_holder_list_params.rb', line 42

optional :external_id, String

#first_nameString?

(Individual Account Holders only) The first name of the account holder. The query is case insensitive and supports partial matches.

Returns:

  • (String, nil)


49
# File 'lib/lithic/models/account_holder_list_params.rb', line 49

optional :first_name, String

#last_nameString?

(Individual Account Holders only) The last name of the account holder. The query is case insensitive and supports partial matches.

Returns:

  • (String, nil)


56
# File 'lib/lithic/models/account_holder_list_params.rb', line 56

optional :last_name, String

(Business Account Holders only) The legal business name of the account holder. The query is case insensitive and supports partial matches.

Returns:

  • (String, nil)


63
# File 'lib/lithic/models/account_holder_list_params.rb', line 63

optional :legal_business_name, String

#limitInteger?

The number of account_holders to limit the response to.

Returns:

  • (Integer, nil)


69
# File 'lib/lithic/models/account_holder_list_params.rb', line 69

optional :limit, Integer

#phone_numberString?

Phone number of the account holder. The query must be an exact match.

Returns:

  • (String, nil)


75
# File 'lib/lithic/models/account_holder_list_params.rb', line 75

optional :phone_number, String

#starting_afterString?

A cursor representing an item’s token after which a page of results should begin. Used to retrieve the next page of results after this item.

Returns:

  • (String, nil)


82
# File 'lib/lithic/models/account_holder_list_params.rb', line 82

optional :starting_after, String