Class: Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::BeneficialOwnerIndividual

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/lithic/models/account_holder_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(beneficial_owner_individuals: nil, business_entity: nil, control_person: nil, external_id: nil, naics_code: nil, nature_of_business: nil, website_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest for more details.

The KYB request payload for updating a business.

Parameters:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/lithic/models/account_holder_update_params.rb', line 123

class BeneficialOwnerIndividual < Lithic::Internal::Type::BaseModel
  # @!attribute entity_token
  #   Globally unique identifier for an entity.
  #
  #   @return [String]
  required :entity_token, String

  # @!attribute address
  #   Individual's current address - PO boxes, UPS drops, and FedEx drops are not
  #   acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
  #
  #   @return [Lithic::Models::AddressUpdate, nil]
  optional :address, -> { Lithic::AddressUpdate }

  # @!attribute dob
  #   Individual's date of birth, as an RFC 3339 date.
  #
  #   @return [String, nil]
  optional :dob, String

  # @!attribute email
  #   Individual's email address. If utilizing Lithic for chargeback processing, this
  #   customer email address may be used to communicate dispute status and resolution.
  #
  #   @return [String, nil]
  optional :email, String

  # @!attribute first_name
  #   Individual's first name, as it appears on government-issued identity documents.
  #
  #   @return [String, nil]
  optional :first_name, String

  # @!attribute last_name
  #   Individual's last name, as it appears on government-issued identity documents.
  #
  #   @return [String, nil]
  optional :last_name, String

  # @!attribute phone_number
  #   Individual's phone number, entered in E.164 format.
  #
  #   @return [String, nil]
  optional :phone_number, String

  request_only do
    # @!attribute government_id
    #   Government-issued identification number (required for identity verification and
    #   compliance with banking regulations). Social Security Numbers (SSN) and
    #   Individual Taxpayer Identification Numbers (ITIN) are currently supported,
    #   entered as full nine-digits, with or without hyphens
    #
    #   @return [String, nil]
    optional :government_id, String
  end

  # @!method initialize(entity_token:, address: nil, dob: nil, email: nil, first_name: nil, government_id: nil, last_name: nil, phone_number: nil)
  #   Some parameter documentations has been truncated, see
  #   {Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::BeneficialOwnerIndividual}
  #   for more details.
  #
  #   Individuals associated with a KYB application. Phone number is optional.
  #
  #   @param entity_token [String] Globally unique identifier for an entity.
  #
  #   @param address [Lithic::Models::AddressUpdate] Individual's current address - PO boxes, UPS drops, and FedEx drops are not acce
  #
  #   @param dob [String] Individual's date of birth, as an RFC 3339 date.
  #
  #   @param email [String] Individual's email address. If utilizing Lithic for chargeback processing, this
  #
  #   @param first_name [String] Individual's first name, as it appears on government-issued identity documents.
  #
  #   @param government_id [String] Government-issued identification number (required for identity verification and
  #
  #   @param last_name [String] Individual's last name, as it appears on government-issued identity documents.
  #
  #   @param phone_number [String] Individual's phone number, entered in E.164 format.
end

Instance Attribute Details

#addressLithic::Models::AddressUpdate?

Individual’s current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.



135
# File 'lib/lithic/models/account_holder_update_params.rb', line 135

optional :address, -> { Lithic::AddressUpdate }

#dobString?

Individual’s date of birth, as an RFC 3339 date.

Returns:

  • (String, nil)


141
# File 'lib/lithic/models/account_holder_update_params.rb', line 141

optional :dob, String

#emailString?

Individual’s email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.

Returns:

  • (String, nil)


148
# File 'lib/lithic/models/account_holder_update_params.rb', line 148

optional :email, String

#entity_tokenString

Globally unique identifier for an entity.

Returns:

  • (String)


128
# File 'lib/lithic/models/account_holder_update_params.rb', line 128

required :entity_token, String

#first_nameString?

Individual’s first name, as it appears on government-issued identity documents.

Returns:

  • (String, nil)


154
# File 'lib/lithic/models/account_holder_update_params.rb', line 154

optional :first_name, String

#last_nameString?

Individual’s last name, as it appears on government-issued identity documents.

Returns:

  • (String, nil)


160
# File 'lib/lithic/models/account_holder_update_params.rb', line 160

optional :last_name, String

#phone_numberString?

Individual’s phone number, entered in E.164 format.

Returns:

  • (String, nil)


166
# File 'lib/lithic/models/account_holder_update_params.rb', line 166

optional :phone_number, String