Class: Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::ControlPerson

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holder_update_params.rb,
sig/lithic/models/account_holder_update_params.rbs

Overview

See Also:

  • Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest#control_person

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



272
# File 'sig/lithic/models/account_holder_update_params.rbs', line 272

def initialize: (

Instance Attribute Details

#addressLithic::Models::AddressUpdate?

Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.



288
# File 'lib/lithic/models/account_holder_update_params.rb', line 288

optional :address, -> { Lithic::AddressUpdate }

#dobString?

Individual's date of birth, as an RFC 3339 date.

Parameters:

  • (String)

Returns:

  • (String, nil)


294
# File 'lib/lithic/models/account_holder_update_params.rb', line 294

optional :dob, String

#emailString?

Individual's email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.

Parameters:

  • (String)

Returns:

  • (String, nil)


301
# File 'lib/lithic/models/account_holder_update_params.rb', line 301

optional :email, String

#entity_tokenString

Globally unique identifier for an entity.

Parameters:

  • value (String)

Returns:

  • (String)


281
# File 'lib/lithic/models/account_holder_update_params.rb', line 281

required :entity_token, String

#first_nameString?

Individual's first name, as it appears on government-issued identity documents.

Parameters:

  • (String)

Returns:

  • (String, nil)


307
# File 'lib/lithic/models/account_holder_update_params.rb', line 307

optional :first_name, String

#government_idString? (readonly)

Returns the value of attribute government_id.

Returns:

  • (String, nil)


268
269
270
# File 'sig/lithic/models/account_holder_update_params.rbs', line 268

def government_id
  @government_id
end

#last_nameString?

Individual's last name, as it appears on government-issued identity documents.

Parameters:

  • (String)

Returns:

  • (String, nil)


313
# File 'lib/lithic/models/account_holder_update_params.rb', line 313

optional :last_name, String

#phone_numberString?

Individual's phone number, entered in E.164 format.

Parameters:

  • (String)

Returns:

  • (String, nil)


319
# File 'lib/lithic/models/account_holder_update_params.rb', line 319

optional :phone_number, String

Instance Method Details

#government_id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


270
# File 'sig/lithic/models/account_holder_update_params.rbs', line 270

def government_id=: (String) -> String

#to_hash{

Returns:

  • ({)


283
# File 'sig/lithic/models/account_holder_update_params.rbs', line 283

def to_hash: -> {