Class: Lithic::Models::AccountHolderUpdateParams::Body::KYCPatchRequest::Individual

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holder_update_params.rb,
sig/lithic/models/account_holder_update_params.rbs

Overview

See Also:

  • Lithic::Models::AccountHolderUpdateParams::Body::KYCPatchRequest#individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



366
# File 'sig/lithic/models/account_holder_update_params.rbs', line 366

def initialize: (

Instance Attribute Details

#address ⇒ Lithic::Models::AddressUpdate?

Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.



403
# File 'lib/lithic/models/account_holder_update_params.rb', line 403

optional :address, -> { Lithic::AddressUpdate }

#dob ⇒ String?

Individual's date of birth, as an RFC 3339 date.

Parameters:

  • (String)

Returns:

  • (String, nil)


409
# File 'lib/lithic/models/account_holder_update_params.rb', line 409

optional :dob, String

#email ⇒ String?

Individual's email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.

Parameters:

  • (String)

Returns:

  • (String, nil)


416
# File 'lib/lithic/models/account_holder_update_params.rb', line 416

optional :email, String

#entity_token ⇒ String

Globally unique identifier for an entity.

Parameters:

  • value (String)

Returns:

  • (String)


396
# File 'lib/lithic/models/account_holder_update_params.rb', line 396

required :entity_token, String

#first_name ⇒ String?

Individual's first name, as it appears on government-issued identity documents.

Parameters:

  • (String)

Returns:

  • (String, nil)


422
# File 'lib/lithic/models/account_holder_update_params.rb', line 422

optional :first_name, String

#government_id ⇒ String? (readonly)

Returns the value of attribute government_id.

Returns:

  • (String, nil)


362
363
364
# File 'sig/lithic/models/account_holder_update_params.rbs', line 362

def government_id
  @government_id
end

#last_name ⇒ String?

Individual's last name, as it appears on government-issued identity documents.

Parameters:

  • (String)

Returns:

  • (String, nil)


428
# File 'lib/lithic/models/account_holder_update_params.rb', line 428

optional :last_name, String

#phone_number ⇒ String?

Individual's phone number, entered in E.164 format.

Parameters:

  • (String)

Returns:

  • (String, nil)


434
# File 'lib/lithic/models/account_holder_update_params.rb', line 434

optional :phone_number, String

Instance Method Details

#government_id= ⇒ String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


364
# File 'sig/lithic/models/account_holder_update_params.rbs', line 364

def government_id=: (String) -> String

#to_hash ⇒ {

Returns:

  • ({)


377
# File 'sig/lithic/models/account_holder_update_params.rbs', line 377

def to_hash: -> {