Class: Lithic::Models::AccountHolderUpdateParams::Body::PatchRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holder_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address: nil, business_account_token: nil, email: nil, first_name: nil, last_name: nil, legal_business_name: nil, phone_number: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AccountHolderUpdateParams::Body::PatchRequest for more details.

The legacy request for updating an account holder.

Parameters:

  • address (Lithic::Models::AddressUpdate) (defaults to: nil)

    Allowed for: KYC-Exempt, BYO-KYC, BYO-KYB.

  • business_account_token (String) (defaults to: nil)

    Allowed for: KYC-Exempt, BYO-KYC. The token of the business account to which the

  • email (String) (defaults to: nil)

    Allowed for all Account Holders. Account holder’s email address. The primary pur

  • first_name (String) (defaults to: nil)

    Allowed for KYC-Exempt, BYO-KYC. Account holder’s first name.

  • last_name (String) (defaults to: nil)

    Allowed for KYC-Exempt, BYO-KYC. Account holder’s last name.

  • legal_business_name (String) (defaults to: nil)

    Allowed for BYO-KYB. Legal business name of the account holder.

  • phone_number (String) (defaults to: nil)

    Allowed for all Account Holders. Account holder’s phone number, entered in E.164



# File 'lib/lithic/models/account_holder_update_params.rb', line 521

Instance Attribute Details

#addressLithic::Models::AddressUpdate?

Allowed for: KYC-Exempt, BYO-KYC, BYO-KYB.



478
# File 'lib/lithic/models/account_holder_update_params.rb', line 478

optional :address, -> { Lithic::AddressUpdate }

#business_account_tokenString?

Allowed for: KYC-Exempt, BYO-KYC. The token of the business account to which the account holder is associated.

Returns:

  • (String, nil)


485
# File 'lib/lithic/models/account_holder_update_params.rb', line 485

optional :business_account_token, String

#emailString?

Allowed for all Account Holders. Account holder’s email address. The primary purpose of this field is for cardholder identification and verification during the digital wallet tokenization process.

Returns:

  • (String, nil)


493
# File 'lib/lithic/models/account_holder_update_params.rb', line 493

optional :email, String

#first_nameString?

Allowed for KYC-Exempt, BYO-KYC. Account holder’s first name.

Returns:

  • (String, nil)


499
# File 'lib/lithic/models/account_holder_update_params.rb', line 499

optional :first_name, String

#last_nameString?

Allowed for KYC-Exempt, BYO-KYC. Account holder’s last name.

Returns:

  • (String, nil)


505
# File 'lib/lithic/models/account_holder_update_params.rb', line 505

optional :last_name, String

Allowed for BYO-KYB. Legal business name of the account holder.

Returns:

  • (String, nil)


511
# File 'lib/lithic/models/account_holder_update_params.rb', line 511

optional :legal_business_name, String

#phone_numberString?

Allowed for all Account Holders. Account holder’s phone number, entered in E.164 format. The primary purpose of this field is for cardholder identification and verification during the digital wallet tokenization process.

Returns:

  • (String, nil)


519
# File 'lib/lithic/models/account_holder_update_params.rb', line 519

optional :phone_number, String