Class: Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holder_update_response.rb

Defined Under Namespace

Modules: ExemptionType, Status, StatusReason, UserType Classes: BeneficialOwnerIndividual, ControlPerson, Individual, VerificationApplication

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address1:, city:, country:, postal_code:, state:, address2: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::Individual::Address for more details.

Individual’s current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.

Parameters:

  • address1 (String)

    Valid deliverable address (no PO boxes).

  • city (String)

    Name of city.

  • country (String)

    Valid country code. Only USA is currently supported, entered in uppercase ISO 31

  • postal_code (String)

    Valid postal code. Only USA ZIP codes are currently supported, entered as a five

  • state (String)

    Valid state code. Only USA state codes are currently supported, entered in upper

  • address2 (String) (defaults to: nil)

    Unit or apartment number (if applicable).



# File 'lib/lithic/models/account_holder_update_response.rb', line 321

Instance Attribute Details

#account_tokenString?

Globally unique identifier for the account.

Returns:

  • (String, nil)


24
# File 'lib/lithic/models/account_holder_update_response.rb', line 24

optional :account_token, String

#beneficial_owner_individualsArray<Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::BeneficialOwnerIndividual>?

Only present when user_type == “BUSINESS”. You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See [FinCEN requirements](www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf) (Section I) for more background on individuals that should be included.



35
36
# File 'lib/lithic/models/account_holder_update_response.rb', line 35

optional :beneficial_owner_individuals,
-> { Lithic::Internal::Type::ArrayOf[Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::BeneficialOwnerIndividual] }

#business_account_tokenString?

Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Pass the account_token of the enrolled business associated with the AUTHORIZED_USER in this field.

Returns:

  • (String, nil)


44
# File 'lib/lithic/models/account_holder_update_response.rb', line 44

optional :business_account_token, String, nil?: true

#business_entityLithic::Models::KYBBusinessEntity?

Only present when user_type == “BUSINESS”. Information about the business for which the account is being opened and KYB is being run.



51
# File 'lib/lithic/models/account_holder_update_response.rb', line 51

optional :business_entity, -> { Lithic::KYBBusinessEntity }

#control_personLithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::ControlPerson?

Only present when user_type == “BUSINESS”.

An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer,

Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access

to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above.



67
68
# File 'lib/lithic/models/account_holder_update_response.rb', line 67

optional :control_person,
-> { Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::ControlPerson }

#createdTime?

Timestamp of when the account holder was created.

Returns:

  • (Time, nil)


74
# File 'lib/lithic/models/account_holder_update_response.rb', line 74

optional :created, Time

#emailString?

(Deprecated. Use control_person.email when user_type == “BUSINESS”. Use individual.phone_number when user_type == “INDIVIDUAL”.) Primary email of Account Holder.

Returns:

  • (String, nil)


82
# File 'lib/lithic/models/account_holder_update_response.rb', line 82

optional :email, String

#exemption_typeSymbol, ...

The type of KYC exemption for a KYC-Exempt Account Holder. “None” if the account holder is not KYC-Exempt.



89
90
# File 'lib/lithic/models/account_holder_update_response.rb', line 89

optional :exemption_type,
enum: -> { Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::ExemptionType }

#external_idString?

Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem.

Returns:

  • (String, nil)


97
# File 'lib/lithic/models/account_holder_update_response.rb', line 97

optional :external_id, String

#individualLithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::Individual?

Only present when user_type == “INDIVIDUAL”. Information about the individual for which the account is being opened and KYC is being run.



104
# File 'lib/lithic/models/account_holder_update_response.rb', line 104

optional :individual, -> { Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::Individual }

#naics_codeString?

Only present when user_type == “BUSINESS”. 6-digit North American Industry Classification System (NAICS) code for the business.

Returns:

  • (String, nil)


111
# File 'lib/lithic/models/account_holder_update_response.rb', line 111

optional :naics_code, String

#nature_of_businessString?

Only present when user_type == “BUSINESS”. User-submitted description of the business.

Returns:

  • (String, nil)


118
# File 'lib/lithic/models/account_holder_update_response.rb', line 118

optional :nature_of_business, String

#phone_numberString?

(Deprecated. Use control_person.phone_number when user_type == “BUSINESS”. Use individual.phone_number when user_type == “INDIVIDUAL”.) Primary phone of Account Holder, entered in E.164 format.

Returns:

  • (String, nil)


126
# File 'lib/lithic/models/account_holder_update_response.rb', line 126

optional :phone_number, String

#required_documentsArray<Lithic::Models::RequiredDocument>?

Only present for “KYB_BASIC” and “KYC_ADVANCED” workflows. A list of documents required for the account holder to be approved.

Returns:



133
# File 'lib/lithic/models/account_holder_update_response.rb', line 133

optional :required_documents, -> { Lithic::Internal::Type::ArrayOf[Lithic::RequiredDocument] }

#statusSymbol, ...

(Deprecated. Use verification_application.status instead) KYC and KYB evaluation states.

Note: ‘PENDING_RESUBMIT` and `PENDING_DOCUMENT` are only applicable for the `ADVANCED` workflow.



143
# File 'lib/lithic/models/account_holder_update_response.rb', line 143

optional :status, enum: -> { Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::Status }

#status_reasonsArray<Symbol, Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::StatusReason>?

(Deprecated. Use verification_application.status_reasons) Reason for the evaluation status.



150
151
# File 'lib/lithic/models/account_holder_update_response.rb', line 150

optional :status_reasons,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::StatusReason] }

#tokenString?

Globally unique identifier for the account holder.

Returns:

  • (String, nil)


18
# File 'lib/lithic/models/account_holder_update_response.rb', line 18

optional :token, String

#user_typeSymbol, ...

The type of Account Holder. If the type is “INDIVIDUAL”, the “individual” attribute will be present.

If the type is “BUSINESS” then the “business_entity”, “control_person”, “beneficial_owner_individuals”, “naics_code”, “nature_of_business”, and “website_url” attributes will be present.



162
163
# File 'lib/lithic/models/account_holder_update_response.rb', line 162

optional :user_type,
enum: -> { Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::UserType }

#verification_applicationLithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::VerificationApplication?

Information about the most recent identity verification attempt



169
170
# File 'lib/lithic/models/account_holder_update_response.rb', line 169

optional :verification_application,
-> { Lithic::Models::AccountHolderUpdateResponse::KYBKYCPatchResponse::VerificationApplication }

#website_urlString?

Only present when user_type == “BUSINESS”. Business’s primary website.

Returns:

  • (String, nil)


176
# File 'lib/lithic/models/account_holder_update_response.rb', line 176

optional :website_url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/account_holder_update_response.rb', line 486