Class: Lithic::Models::AccountHolderUpdateResponse::PatchResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holder_update_response.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token: nil, address: nil, business_account_token: nil, email: nil, first_name: nil, last_name: nil, legal_business_name: nil, phone_number: nil) ⇒ Object

Parameters:

  • token (String) (defaults to: nil)

    The token for the account holder that was updated

  • address (Lithic::Models::AccountHolderUpdateResponse::PatchResponse::Address) (defaults to: nil)

    The address for the account holder

  • business_account_token (String, nil) (defaults to: nil)

    The token for the business account that the account holder is associated with

  • email (String) (defaults to: nil)

    The email for the account holder

  • first_name (String) (defaults to: nil)

    The first name for the account holder

  • last_name (String) (defaults to: nil)

    The last name for the account holder

  • legal_business_name (String) (defaults to: nil)

    The legal business name for the account holder

  • phone_number (String) (defaults to: nil)

    The phone_number for the account holder



# File 'lib/lithic/models/account_holder_update_response.rb', line 849

Instance Attribute Details

#addressLithic::Models::AccountHolderUpdateResponse::PatchResponse::Address?

The address for the account holder



811
# File 'lib/lithic/models/account_holder_update_response.rb', line 811

optional :address, -> { Lithic::Models::AccountHolderUpdateResponse::PatchResponse::Address }

#business_account_tokenString?

The token for the business account that the account holder is associated with

Returns:

  • (String, nil)


817
# File 'lib/lithic/models/account_holder_update_response.rb', line 817

optional :business_account_token, String, nil?: true

#emailString?

The email for the account holder

Returns:

  • (String, nil)


823
# File 'lib/lithic/models/account_holder_update_response.rb', line 823

optional :email, String

#first_nameString?

The first name for the account holder

Returns:

  • (String, nil)


829
# File 'lib/lithic/models/account_holder_update_response.rb', line 829

optional :first_name, String

#last_nameString?

The last name for the account holder

Returns:

  • (String, nil)


835
# File 'lib/lithic/models/account_holder_update_response.rb', line 835

optional :last_name, String

The legal business name for the account holder

Returns:

  • (String, nil)


841
# File 'lib/lithic/models/account_holder_update_response.rb', line 841

optional :legal_business_name, String

#phone_numberString?

The phone_number for the account holder

Returns:

  • (String, nil)


847
# File 'lib/lithic/models/account_holder_update_response.rb', line 847

optional :phone_number, String

#tokenString?

The token for the account holder that was updated

Returns:

  • (String, nil)


805
# File 'lib/lithic/models/account_holder_update_response.rb', line 805

optional :token, String