Class: Lithic::Models::AccountHolders::AccountHolderEntity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holders/account_holder_entity.rb

Overview

Defined Under Namespace

Modules: Status, Type Classes: Address

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address1:, city:, country:, postal_code:, state:, address2: nil) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

Individual’s current address

Parameters:

  • address1 (String)

    Valid deliverable address (no PO boxes).

  • city (String)

    Name of city.

  • country (String)

    Valid country code. Only USA is currently supported, entered in uppercase ISO 31

  • postal_code (String)

    Valid postal code. Only USA ZIP codes are currently supported, entered as a five

  • state (String)

    Valid state code. Only USA state codes are currently supported, entered in upper

  • address2 (String) (defaults to: nil)

    Unit or apartment number (if applicable).



# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 68

Instance Attribute Details

#account_holder_tokenString

Globally unique identifier for the account holder

Returns:

  • (String)


18
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 18

required :account_holder_token, String

#addressLithic::Models::AccountHolders::AccountHolderEntity::Address

Individual’s current address



24
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 24

required :address, -> { Lithic::AccountHolders::AccountHolderEntity::Address }

#dobString?

Individual’s date of birth, as an RFC 3339 date

Returns:

  • (String, nil)


30
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 30

required :dob, String, nil?: true

#emailString?

Individual’s email address

Returns:

  • (String, nil)


36
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 36

required :email, String, nil?: true

#first_nameString?

Individual’s first name, as it appears on government-issued identity documents

Returns:

  • (String, nil)


42
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 42

required :first_name, String, nil?: true

#last_nameString?

Individual’s last name, as it appears on government-issued identity documents

Returns:

  • (String, nil)


48
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 48

required :last_name, String, nil?: true

#phone_numberString?

Individual’s phone number, entered in E.164 format

Returns:

  • (String, nil)


54
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 54

required :phone_number, String, nil?: true

#statusSymbol, Lithic::Models::AccountHolders::AccountHolderEntity::Status

The status of the entity



60
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 60

required :status, enum: -> { Lithic::AccountHolders::AccountHolderEntity::Status }

#tokenString

Globally unique identifier for the entity

Returns:

  • (String)


12
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 12

required :token, String

#typeSymbol, Lithic::Models::AccountHolders::AccountHolderEntity::Type

The type of entity



66
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 66

required :type, enum: -> { Lithic::AccountHolders::AccountHolderEntity::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 162