Class: Lithic::Models::AccountHolders::EntityCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/account_holders/entity_create_params.rb

Overview

Defined Under Namespace

Modules: Type Classes: Address

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address1:, city:, country:, postal_code:, state:, address2: nil) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

Individual’s current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.

Parameters:

  • address1 (String)

    Valid deliverable address (no PO boxes).

  • city (String)

    Name of city.

  • country (String)

    Valid country code. Only USA is currently supported, entered in uppercase ISO 31

  • postal_code (String)

    Valid postal code. Only USA ZIP codes are currently supported, entered as a five

  • state (String)

    Valid state code. Only USA state codes are currently supported, entered in upper

  • address2 (String) (defaults to: nil)

    Unit or apartment number (if applicable).



# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 133

Instance Attribute Details

#account_holder_tokenString

Returns:

  • (String)


14
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 14

required :account_holder_token, String

#addressLithic::Models::AccountHolders::EntityCreateParams::Address

Individual’s current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.



21
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 21

required :address, -> { Lithic::AccountHolders::EntityCreateParams::Address }

#dobString

Individual’s date of birth, as an RFC 3339 date.

Returns:

  • (String)


27
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 27

required :dob, String

#emailString

Individual’s email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.

Returns:

  • (String)


34
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 34

required :email, String

#first_nameString

Individual’s first name, as it appears on government-issued identity documents.

Returns:

  • (String)


40
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 40

required :first_name, String

#government_idString

Government-issued identification number (required for identity verification and compliance with banking regulations). Social Security Numbers (SSN) and Individual Taxpayer Identification Numbers (ITIN) are currently supported, entered as full nine-digits, with or without hyphens

Returns:

  • (String)


49
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 49

required :government_id, String

#last_nameString

Individual’s last name, as it appears on government-issued identity documents.

Returns:

  • (String)


55
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 55

required :last_name, String

#phone_numberString

Individual’s phone number, entered in E.164 format.

Returns:

  • (String)


61
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 61

required :phone_number, String

#typeSymbol, Lithic::Models::AccountHolders::EntityCreateParams::Type

The type of entity to create on the account holder



67
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 67

required :type, enum: -> { Lithic::AccountHolders::EntityCreateParams::Type }