Class: Lithic::Models::AccountHolders::EntityCreateParams::Address

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holders/entity_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_holder_token:, address:, dob:, email:, first_name:, government_id:, last_name:, phone_number:, type:, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AccountHolders::EntityCreateParams for more details.

Parameters:

  • account_holder_token (String)
  • address (Lithic::Models::AccountHolders::EntityCreateParams::Address)

    Individual’s current address - PO boxes, UPS drops, and FedEx drops are not acce

  • dob (String)

    Individual’s date of birth, as an RFC 3339 date.

  • email (String)

    Individual’s email address. If utilizing Lithic for chargeback processing, this

  • first_name (String)

    Individual’s first name, as it appears on government-issued identity documents.

  • government_id (String)

    Government-issued identification number (required for identity verification and

  • last_name (String)

    Individual’s last name, as it appears on government-issued identity documents.

  • phone_number (String)

    Individual’s phone number, entered in E.164 format.

  • type (Symbol, Lithic::Models::AccountHolders::EntityCreateParams::Type)

    The type of entity to create on the account holder

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 93

class Address < Lithic::Internal::Type::BaseModel
  # @!attribute address1
  #   Valid deliverable address (no PO boxes).
  #
  #   @return [String]
  required :address1, String

  # @!attribute city
  #   Name of city.
  #
  #   @return [String]
  required :city, String

  # @!attribute country
  #   Valid country code. Only USA is currently supported, entered in uppercase ISO
  #   3166-1 alpha-3 three-character format.
  #
  #   @return [String]
  required :country, String

  # @!attribute postal_code
  #   Valid postal code. Only USA ZIP codes are currently supported, entered as a
  #   five-digit ZIP or nine-digit ZIP+4.
  #
  #   @return [String]
  required :postal_code, String

  # @!attribute state
  #   Valid state code. Only USA state codes are currently supported, entered in
  #   uppercase ISO 3166-2 two-character format.
  #
  #   @return [String]
  required :state, String

  # @!attribute address2
  #   Unit or apartment number (if applicable).
  #
  #   @return [String, nil]
  optional :address2, String

  # @!method initialize(address1:, city:, country:, postal_code:, state:, address2: nil)
  #   Some parameter documentations has been truncated, see
  #   {Lithic::Models::AccountHolders::EntityCreateParams::Address} for more details.
  #
  #   Individual's current address - PO boxes, UPS drops, and FedEx drops are not
  #   acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
  #
  #   @param address1 [String] Valid deliverable address (no PO boxes).
  #
  #   @param city [String] Name of city.
  #
  #   @param country [String] Valid country code. Only USA is currently supported, entered in uppercase ISO 31
  #
  #   @param postal_code [String] Valid postal code. Only USA ZIP codes are currently supported, entered as a five
  #
  #   @param state [String] Valid state code. Only USA state codes are currently supported, entered in upper
  #
  #   @param address2 [String] Unit or apartment number (if applicable).
end

Instance Attribute Details

#address1String

Valid deliverable address (no PO boxes).

Returns:

  • (String)


98
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 98

required :address1, String

#address2String?

Unit or apartment number (if applicable).

Returns:

  • (String, nil)


131
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 131

optional :address2, String

#cityString

Name of city.

Returns:

  • (String)


104
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 104

required :city, String

#countryString

Valid country code. Only USA is currently supported, entered in uppercase ISO 3166-1 alpha-3 three-character format.

Returns:

  • (String)


111
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 111

required :country, String

#postal_codeString

Valid postal code. Only USA ZIP codes are currently supported, entered as a five-digit ZIP or nine-digit ZIP+4.

Returns:

  • (String)


118
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 118

required :postal_code, String

#stateString

Valid state code. Only USA state codes are currently supported, entered in uppercase ISO 3166-2 two-character format.

Returns:

  • (String)


125
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 125

required :state, String