Class: Lithic::Models::AccountHolders::EntityCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_holders/entity_create_response.rb

Overview

Defined Under Namespace

Modules: Status, StatusReason

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, account_holder_token:, created:, required_documents:, status:, status_reasons:) ⇒ Object

Response body for creating a new beneficial owner or replacing the control person entity on an existing KYB account holder.

Parameters:



# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 45

Instance Attribute Details

#account_holder_tokenString

Globally unique identifier for the account holder

Returns:

  • (String)


18
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 18

required :account_holder_token, String

#createdTime

Timestamp of when the entity was created

Returns:

  • (Time)


24
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 24

required :created, Time

#required_documentsArray<Lithic::Models::RequiredDocument>

A list of documents required for the entity to be approved



30
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 30

required :required_documents, -> { Lithic::Internal::Type::ArrayOf[Lithic::RequiredDocument] }

#statusSymbol, Lithic::Models::AccountHolders::EntityCreateResponse::Status

Entity verification status



36
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 36

required :status, enum: -> { Lithic::Models::AccountHolders::EntityCreateResponse::Status }

#status_reasonsArray<Symbol, Lithic::Models::AccountHolders::EntityCreateResponse::StatusReason>

Reason for the evaluation status



42
43
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 42

required :status_reasons,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::Models::AccountHolders::EntityCreateResponse::StatusReason] }

#tokenString

Globally unique identifier for the entity

Returns:

  • (String)


12
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 12

required :token, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 72