Class: Lithic::Models::AccountSpendLimits::AvailableSpendLimit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_spend_limits.rb,
sig/lithic/models/account_spend_limits.rbs

Overview

See Also:

  • Lithic::Models::AccountSpendLimits#available_spend_limit

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



53
# File 'sig/lithic/models/account_spend_limits.rbs', line 53

def initialize: (

Instance Attribute Details

#dailyInteger?

The available spend limit (in cents) relative to the daily limit configured on the Account (e.g. 100000 would be a $1,000 limit).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


34
# File 'lib/lithic/models/account_spend_limits.rb', line 34

optional :daily, Integer

#lifetimeInteger?

The available spend limit (in cents) relative to the lifetime limit configured on the Account.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


41
# File 'lib/lithic/models/account_spend_limits.rb', line 41

optional :lifetime, Integer

#monthlyInteger?

The available spend limit (in cents) relative to the monthly limit configured on the Account.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


48
# File 'lib/lithic/models/account_spend_limits.rb', line 48

optional :monthly, Integer

Instance Method Details

#to_hash{ daily: Integer, lifetime: Integer, monthly: Integer }

Returns:

  • ({ daily: Integer, lifetime: Integer, monthly: Integer })


59
# File 'sig/lithic/models/account_spend_limits.rbs', line 59

def to_hash: -> { daily: Integer, lifetime: Integer, monthly: Integer }