Class: Lithic::Models::AccountUpdateParams::VerificationAddress Deprecated

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/account_update_params.rb

Overview

Deprecated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address1: nil, address2: nil, city: nil, country: nil, postal_code: nil, state: nil) ⇒ Object

Address used during Address Verification Service (AVS) checks during transactions if enabled via Auth Rules. This field is deprecated as AVS checks are no longer supported by Auth Rules. The field will be removed from the schema in a future release.

Parameters:

  • address1 (String) (defaults to: nil)
  • address2 (String) (defaults to: nil)
  • city (String) (defaults to: nil)
  • country (String) (defaults to: nil)
  • postal_code (String) (defaults to: nil)
  • state (String) (defaults to: nil)


# File 'lib/lithic/models/account_update_params.rb', line 205

Instance Attribute Details

#address1String?

Returns:

  • (String, nil)


178
# File 'lib/lithic/models/account_update_params.rb', line 178

optional :address1, String

#address2String?

Returns:

  • (String, nil)


183
# File 'lib/lithic/models/account_update_params.rb', line 183

optional :address2, String

#cityString?

Returns:

  • (String, nil)


188
# File 'lib/lithic/models/account_update_params.rb', line 188

optional :city, String

#countryString?

Returns:

  • (String, nil)


193
# File 'lib/lithic/models/account_update_params.rb', line 193

optional :country, String

#postal_codeString?

Returns:

  • (String, nil)


198
# File 'lib/lithic/models/account_update_params.rb', line 198

optional :postal_code, String

#stateString?

Returns:

  • (String, nil)


203
# File 'lib/lithic/models/account_update_params.rb', line 203

optional :state, String