Module: Lithic::Models::AuthRules::AuthRule::Type
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/auth_rules/auth_rule.rb,
sig/lithic/models/auth_rules/auth_rule.rbs
Overview
The type of Auth Rule. For certain rule types, this determines the event stream
during which it will be evaluated. For rules that can be applied to one of
several event streams, the effective one is defined by the separate
event_stream field.
CONDITIONAL_BLOCK: Deprecated. UseCONDITIONAL_ACTIONinstead. AUTHORIZATION event stream.VELOCITY_LIMIT: AUTHORIZATION event stream.MERCHANT_LOCK: AUTHORIZATION event stream.CONDITIONAL_ACTION: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, CARD_TRANSACTION_UPDATE, or ACH_PAYMENT_UPDATE event stream.TYPESCRIPT_CODE: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, CARD_TRANSACTION_UPDATE, or ACH_PAYMENT_UPDATE event stream.OTHER: A rule whose type is not exposed through this API. Rules of this type are read-only;OTHERcannot be used when creating a rule.
Constant Summary collapse
- CONDITIONAL_BLOCK =
:CONDITIONAL_BLOCK- VELOCITY_LIMIT =
:VELOCITY_LIMIT- MERCHANT_LOCK =
:MERCHANT_LOCK- CONDITIONAL_ACTION =
:CONDITIONAL_ACTION- TYPESCRIPT_CODE =
:TYPESCRIPT_CODE- OTHER =
:OTHER
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::AuthRules::AuthRule::type_]
233 |
# File 'sig/lithic/models/auth_rules/auth_rule.rbs', line 233
def self?.values: -> ::Array[Lithic::Models::AuthRules::AuthRule::type_]
|