Class: Lithic::Models::AuthRules::BacktestStats
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::BacktestStats
- Defined in:
- lib/lithic/models/auth_rules/backtest_stats.rb,
sig/lithic/models/auth_rules/backtest_stats.rbs
Defined Under Namespace
Classes: Example
Instance Attribute Summary collapse
-
#approved ⇒ Integer?
The total number of historical transactions approved by this rule during the backtest period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode.
-
#challenged ⇒ Integer?
The total number of historical transactions challenged by this rule during the backtest period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode.
-
#declined ⇒ Integer?
The total number of historical transactions declined by this rule during the backtest period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode.
-
#examples ⇒ Array<Lithic::Models::AuthRules::BacktestStats::Example>?
Example events and their outcomes.
-
#version ⇒ Integer?
readonly
Returns the value of attribute version.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
- #version ⇒ Integer readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
36 |
# File 'sig/lithic/models/auth_rules/backtest_stats.rbs', line 36
def initialize: (
|
Instance Attribute Details
#approved ⇒ Integer?
The total number of historical transactions approved by this rule during the backtest period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode.
13 |
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 13 optional :approved, Integer |
#challenged ⇒ Integer?
The total number of historical transactions challenged by this rule during the backtest period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. Currently applicable only for 3DS Auth Rules.
22 |
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 22 optional :challenged, Integer |
#declined ⇒ Integer?
The total number of historical transactions declined by this rule during the backtest period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode.
30 |
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 30 optional :declined, Integer |
#examples ⇒ Array<Lithic::Models::AuthRules::BacktestStats::Example>?
Example events and their outcomes.
36 |
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 36 optional :examples, -> { Lithic::Internal::Type::ArrayOf[Lithic::AuthRules::BacktestStats::Example] } |
#version ⇒ Integer? (readonly)
Returns the value of attribute version.
32 33 34 |
# File 'sig/lithic/models/auth_rules/backtest_stats.rbs', line 32 def version @version end |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/lithic/models/auth_rules/backtest_stats.rbs', line 44
def to_hash: -> {
|
#version= ⇒ Integer (readonly)
34 |
# File 'sig/lithic/models/auth_rules/backtest_stats.rbs', line 34
def version=: (Integer) -> Integer
|