Class: Lithic::Models::AuthRules::BacktestStats::Example

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/backtest_stats.rb

Defined Under Namespace

Modules: Decision

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(decision: nil, event_token: nil, timestamp: nil, transaction_token: nil) ⇒ Object

Parameters:

  • decision (Symbol, Lithic::Models::AuthRules::BacktestStats::Example::Decision) (defaults to: nil)

    The decision made by the rule for this event.

  • event_token (String) (defaults to: nil)

    The event token.

  • timestamp (Time) (defaults to: nil)

    The timestamp of the event.

  • transaction_token (String, nil) (defaults to: nil)

    The token of the transaction associated with the event



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 61

class Example < Lithic::Internal::Type::BaseModel
  # @!attribute decision
  #   The decision made by the rule for this event.
  #
  #   @return [Symbol, Lithic::Models::AuthRules::BacktestStats::Example::Decision, nil]
  optional :decision, enum: -> { Lithic::AuthRules::BacktestStats::Example::Decision }

  # @!attribute event_token
  #   The event token.
  #
  #   @return [String, nil]
  optional :event_token, String

  # @!attribute timestamp
  #   The timestamp of the event.
  #
  #   @return [Time, nil]
  optional :timestamp, Time

  # @!attribute transaction_token
  #   The token of the transaction associated with the event
  #
  #   @return [String, nil]
  optional :transaction_token, String, nil?: true

  # @!method initialize(decision: nil, event_token: nil, timestamp: nil, transaction_token: nil)
  #   @param decision [Symbol, Lithic::Models::AuthRules::BacktestStats::Example::Decision] The decision made by the rule for this event.
  #
  #   @param event_token [String] The event token.
  #
  #   @param timestamp [Time] The timestamp of the event.
  #
  #   @param transaction_token [String, nil] The token of the transaction associated with the event

  # The decision made by the rule for this event.
  #
  # @see Lithic::Models::AuthRules::BacktestStats::Example#decision
  module Decision
    extend Lithic::Internal::Type::Enum

    APPROVED = :APPROVED
    DECLINED = :DECLINED
    CHALLENGED = :CHALLENGED

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#decisionSymbol, ...

The decision made by the rule for this event.



66
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 66

optional :decision, enum: -> { Lithic::AuthRules::BacktestStats::Example::Decision }

#event_tokenString?

The event token.

Returns:

  • (String, nil)


72
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 72

optional :event_token, String

#timestampTime?

The timestamp of the event.

Returns:

  • (Time, nil)


78
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 78

optional :timestamp, Time

#transaction_tokenString?

The token of the transaction associated with the event

Returns:

  • (String, nil)


84
# File 'lib/lithic/models/auth_rules/backtest_stats.rb', line 84

optional :transaction_token, String, nil?: true