Class: Lithic::Models::AuthRules::CardTransactionUpdateAction::CreateCaseAction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/card_transaction_update_action.rb,
sig/lithic/models/auth_rules/card_transaction_update_action.rbs

Defined Under Namespace

Modules: Scope, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(queue_token:, scope:, type:) ⇒ Object

Parameters:

  • The token of the queue to create the case in

  • The scope of the case to create

  • Create a case for the transaction



# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 71

Instance Attribute Details

#queue_token ⇒ String

The token of the queue to create the case in

Parameters:

Returns:



57
# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 57

required :queue_token, String

#scope ⇒ Symbol, Lithic::Models::AuthRules::CardTransactionUpdateAction::CreateCaseAction::Scope

The scope of the case to create

Parameters:

Returns:



63
# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 63

required :scope, enum: -> { Lithic::AuthRules::CardTransactionUpdateAction::CreateCaseAction::Scope }

#type ⇒ Symbol, Lithic::Models::AuthRules::CardTransactionUpdateAction::CreateCaseAction::Type

Create a case for the transaction

Parameters:

Returns:



69
# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 69

required :type, enum: -> { Lithic::AuthRules::CardTransactionUpdateAction::CreateCaseAction::Type }

Class Method Details

.values ⇒ Array<Symbol>

Returns:



# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 88

Instance Method Details

#to_hash ⇒ {

Returns:



68
# File 'sig/lithic/models/auth_rules/card_transaction_update_action.rbs', line 68

def to_hash: -> {