Class: Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/conditional_3ds_action_parameters.rb,
sig/lithic/models/auth_rules/conditional_3ds_action_parameters.rbs

Defined Under Namespace

Modules: Attribute

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(attribute:, operation:, value:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition for more details.

Parameters:



# File 'lib/lithic/models/auth_rules/conditional_3ds_action_parameters.rb', line 80

Instance Attribute Details

#attributeSymbol, Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition::Attribute

The attribute to target.

The following attributes may be targeted:

  • MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.
  • COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.
  • CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.
  • MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).
  • DESCRIPTOR: Short description of card acceptor.
  • TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder. Use an integer value.
  • RISK_SCORE: Mastercard only: Assessment by the network of the authentication risk level, with a higher value indicating a higher amount of risk. Use an integer value.
  • MESSAGE_CATEGORY: The category of the authentication being processed.
  • ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values are MATCH, MATCH_ADDRESS_ONLY, MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.

Parameters:

  • value (Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition::attribute)

Returns:



66
# File 'lib/lithic/models/auth_rules/conditional_3ds_action_parameters.rb', line 66

required :attribute, enum: -> { Lithic::AuthRules::Conditional3DSActionParameters::Condition::Attribute }

#operationSymbol, Lithic::Models::AuthRules::ConditionalOperation

The operation to apply to the attribute

Parameters:

  • value (Lithic::Models::AuthRules::conditional_operation)

Returns:



72
# File 'lib/lithic/models/auth_rules/conditional_3ds_action_parameters.rb', line 72

required :operation, enum: -> { Lithic::AuthRules::ConditionalOperation }

#valueString, ...

A regex string, to be used with MATCHES or DOES_NOT_MATCH

Parameters:

  • value (Lithic::Models::AuthRules::conditional_value)

Returns:

  • (String, Integer, Float, Array<String>, Time)


78
# File 'lib/lithic/models/auth_rules/conditional_3ds_action_parameters.rb', line 78

required :value, union: -> { Lithic::AuthRules::ConditionalValue }

Instance Method Details

#to_hash{

Returns:

  • ({)


56
# File 'sig/lithic/models/auth_rules/conditional_3ds_action_parameters.rbs', line 56

def to_hash: -> {