Module: Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition::Attribute

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/auth_rules/conditional_3ds_action_parameters.rb,
sig/lithic/models/auth_rules/conditional_3ds_action_parameters.rbs

Overview

The attribute to target.

The following attributes may be targeted:

  • MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.
  • COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.
  • CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.
  • MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).
  • DESCRIPTOR: Short description of card acceptor.
  • TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder. Use an integer value.
  • RISK_SCORE: Mastercard only: Assessment by the network of the authentication risk level, with a higher value indicating a higher amount of risk. Use an integer value.
  • MESSAGE_CATEGORY: The category of the authentication being processed.
  • ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values are MATCH, MATCH_ADDRESS_ONLY, MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.

See Also:

  • Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition#attribute

Constant Summary collapse

MCC =

Returns:

  • (:MCC)
:MCC
COUNTRY =

Returns:

  • (:COUNTRY)
:COUNTRY
CURRENCY =

Returns:

  • (:CURRENCY)
:CURRENCY
MERCHANT_ID =

Returns:

  • (:MERCHANT_ID)
:MERCHANT_ID
DESCRIPTOR =

Returns:

  • (:DESCRIPTOR)
:DESCRIPTOR
TRANSACTION_AMOUNT =

Returns:

  • (:TRANSACTION_AMOUNT)
:TRANSACTION_AMOUNT
RISK_SCORE =

Returns:

  • (:RISK_SCORE)
:RISK_SCORE
MESSAGE_CATEGORY =

Returns:

  • (:MESSAGE_CATEGORY)
:MESSAGE_CATEGORY
ADDRESS_MATCH =

Returns:

  • (:ADDRESS_MATCH)
:ADDRESS_MATCH

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/conditional_3ds_action_parameters.rb', line 131

Instance Method Details

#self?.values::Array[Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition::attribute]

Returns:

  • (::Array[Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition::attribute])


86
# File 'sig/lithic/models/auth_rules/conditional_3ds_action_parameters.rbs', line 86

def self?.values: -> ::Array[Lithic::Models::AuthRules::Conditional3DSActionParameters::Condition::attribute]