Class: Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/conditional_ach_action_parameters.rb,
sig/lithic/models/auth_rules/conditional_ach_action_parameters.rbs

Defined Under Namespace

Modules: Attribute

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(attribute:, operation:, value:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition for more details.

Parameters:



# File 'lib/lithic/models/auth_rules/conditional_ach_action_parameters.rb', line 215

Instance Attribute Details

#attributeSymbol, Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition::Attribute

The attribute to target.

The following attributes may be targeted:

  • COMPANY_NAME: The name of the company initiating the ACH transaction.
  • COMPANY_ID: The company ID (also known as Standard Entry Class (SEC) Company ID) of the entity initiating the ACH transaction.
  • TIMESTAMP: The timestamp of the ACH transaction in ISO 8601 format.
  • TRANSACTION_AMOUNT: The amount of the ACH transaction in minor units (cents). Use an integer value.
  • SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.
  • MEMO: Optional memo or description field included with the ACH transaction.

Parameters:

  • value (Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition::attribute)

Returns:



201
# File 'lib/lithic/models/auth_rules/conditional_ach_action_parameters.rb', line 201

required :attribute, enum: -> { Lithic::AuthRules::ConditionalACHActionParameters::Condition::Attribute }

#operationSymbol, Lithic::Models::AuthRules::ConditionalOperation

The operation to apply to the attribute

Parameters:

  • value (Lithic::Models::AuthRules::conditional_operation)

Returns:



207
# File 'lib/lithic/models/auth_rules/conditional_ach_action_parameters.rb', line 207

required :operation, enum: -> { Lithic::AuthRules::ConditionalOperation }

#valueString, ...

A regex string, to be used with MATCHES or DOES_NOT_MATCH

Parameters:

  • value (Lithic::Models::AuthRules::conditional_value)

Returns:

  • (String, Integer, Float, Array<String>, Time)


213
# File 'lib/lithic/models/auth_rules/conditional_ach_action_parameters.rb', line 213

required :value, union: -> { Lithic::AuthRules::ConditionalValue }

Instance Method Details

#to_hash{

Returns:

  • ({)


263
# File 'sig/lithic/models/auth_rules/conditional_ach_action_parameters.rbs', line 263

def to_hash: -> {