Module: Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition::Attribute

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/auth_rules/conditional_ach_action_parameters.rb,
sig/lithic/models/auth_rules/conditional_ach_action_parameters.rbs

Overview

The attribute to target.

The following attributes may be targeted:

  • COMPANY_NAME: The name of the company initiating the ACH transaction.
  • COMPANY_ID: The company ID (also known as Standard Entry Class (SEC) Company ID) of the entity initiating the ACH transaction.
  • TIMESTAMP: The timestamp of the ACH transaction in ISO 8601 format.
  • TRANSACTION_AMOUNT: The amount of the ACH transaction in minor units (cents). Use an integer value.
  • SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.
  • MEMO: Optional memo or description field included with the ACH transaction.

See Also:

  • Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition#attribute

Constant Summary collapse

COMPANY_NAME =

Returns:

  • (:COMPANY_NAME)
:COMPANY_NAME
COMPANY_ID =

Returns:

  • (:COMPANY_ID)
:COMPANY_ID
TIMESTAMP =

Returns:

  • (:TIMESTAMP)
:TIMESTAMP
TRANSACTION_AMOUNT =

Returns:

  • (:TRANSACTION_AMOUNT)
:TRANSACTION_AMOUNT
SEC_CODE =

Returns:

  • (:SEC_CODE)
:SEC_CODE
MEMO =

Returns:

  • (:MEMO)
:MEMO

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/conditional_ach_action_parameters.rb', line 253

Instance Method Details

#self?.values::Array[Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition::attribute]

Returns:

  • (::Array[Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition::attribute])


287
# File 'sig/lithic/models/auth_rules/conditional_ach_action_parameters.rbs', line 287

def self?.values: -> ::Array[Lithic::Models::AuthRules::ConditionalACHActionParameters::Condition::attribute]