Class: Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action
- Defined in:
- lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb,
sig/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#mode ⇒ Symbol, Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::Mode
The mode of the hold adjustment, determining how the value is interpreted:.
-
#type ⇒ Symbol, Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::Type
The type of adjustment to apply.
-
#value ⇒ Integer
The value used for the hold adjustment, interpreted based on the mode.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(mode:, type:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Action for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mode:, type:, value:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action for more details.
The hold adjustment to apply if the conditions are met.
|
|
# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 49
|
Instance Attribute Details
#mode ⇒ Symbol, Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::Mode
The mode of the hold adjustment, determining how the value is interpreted:
REPLACE_WITH_AMOUNT: The value is the approved hold amount in cents.ADD_PERCENTAGE: The value adjusts the hold amount by a percentage. 1000 represents a 10% increase, 0 represents no change.ADD_AMOUNT: The value is added to the hold amount in cents.
35 |
# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 35 required :mode, enum: -> { Lithic::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::Mode } |
#type ⇒ Symbol, Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::Type
The type of adjustment to apply
41 |
# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 41 required :type, enum: -> { Lithic::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::Type } |
#value ⇒ Integer
The value used for the hold adjustment, interpreted based on the mode
47 |
# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 47 required :value, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 77
|
Instance Method Details
#to_hash ⇒ {
45 |
# File 'sig/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rbs', line 45
def to_hash: -> {
|