Module: Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::Mode

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb,
sig/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rbs

Overview

The mode of the hold adjustment, determining how the value is interpreted:

  • REPLACE_WITH_AMOUNT: The value is the approved hold amount in cents.
  • ADD_PERCENTAGE: The value adjusts the hold amount by a percentage. 1000 represents a 10% increase, 0 represents no change.
  • ADD_AMOUNT: The value is added to the hold amount in cents.

See Also:

  • Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action#mode

Constant Summary collapse

REPLACE_WITH_AMOUNT =

Returns:

  • (:REPLACE_WITH_AMOUNT)
:REPLACE_WITH_AMOUNT
ADD_PERCENTAGE =

Returns:

  • (:ADD_PERCENTAGE)
:ADD_PERCENTAGE
ADD_AMOUNT =

Returns:

  • (:ADD_AMOUNT)
:ADD_AMOUNT

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::mode]

Returns:

  • (::Array[Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::mode])


60
# File 'sig/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rbs', line 60

def self?.values: -> ::Array[Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Action::mode]