Class: Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Adjustment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb

Overview

See Also:

Defined Under Namespace

Modules: Mode, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mode:, type:, value:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Adjustment for more details.

The hold adjustment to apply if the conditions are met

Parameters:



# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 51

Instance Attribute Details

#modeSymbol, Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Adjustment::Mode

The mode of the hold adjustment, determining how the value is interpreted:

  • ‘REPLACE_WITH_AMOUNT`: The value is the approved hold amount in cents.

  • ‘ADD_PERCENTAGE`: The value adjusts the hold amount by a percentage. 1000 represents a 10% increase, 0 represents no change.

  • ‘ADD_AMOUNT`: The value is added to the hold amount in cents.



35
36
# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 35

required :mode,
enum: -> { Lithic::AuthRules::ConditionalAuthorizationAdjustmentParameters::Adjustment::Mode }

#typeSymbol, Lithic::Models::AuthRules::ConditionalAuthorizationAdjustmentParameters::Adjustment::Type

The type of adjustment to apply



42
43
# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 42

required :type,
enum: -> { Lithic::AuthRules::ConditionalAuthorizationAdjustmentParameters::Adjustment::Type }

#valueInteger

The value used for the hold adjustment, interpreted based on the mode

Returns:

  • (Integer)


49
# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 49

required :value, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/conditional_authorization_adjustment_parameters.rb', line 79