Class: Lithic::Models::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Parameters

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb,
sig/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rbs

Overview

See Also:

  • Lithic::Models::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition#parameters

Defined Under Namespace

Modules: Interval, Scope, Unit

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters: nil, interval: nil, period: nil, scope: nil, unit: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Parameters for more details.

Additional parameters for certain attributes. Required when attribute is SPEND_VELOCITY_COUNT or SPEND_VELOCITY_AMOUNT (require scope, period, and optional filters); AMOUNT_Z_SCORE, AVG_TRANSACTION_AMOUNT, STDEV_TRANSACTION_AMOUNT, IS_NEW_COUNTRY, IS_NEW_MCC, IS_FIRST_TRANSACTION, CONSECUTIVE_DECLINES, TIME_SINCE_LAST_TRANSACTION, or DISTINCT_COUNTRY_COUNT (require scope, and additionally interval for the statistical attributes); or TRAVEL_SPEED or DISTANCE_FROM_LAST_TRANSACTION (require unit). Not used for other attributes.

`TRAVEL_

Parameters:



# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 352

Instance Attribute Details

#filtersLithic::Models::AuthRules::SpendVelocityFilters?



315
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 315

optional :filters, -> { Lithic::AuthRules::SpendVelocityFilters }

#intervalSymbol, ...

The time window for statistical attributes (AMOUNT_Z_SCORE, AVG_TRANSACTION_AMOUNT, STDEV_TRANSACTION_AMOUNT). Use LIFETIME for all-time history or a specific window (7D, 30D, 90D).



323
324
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 323

optional :interval,
enum: -> { Lithic::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Parameters::Interval }

#periodLithic::Models::AuthRules::VelocityLimitPeriod::TrailingWindowObject, ...

The time period over which to calculate the spend velocity.



330
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 330

optional :period, union: -> { Lithic::AuthRules::VelocityLimitPeriod }

#scopeSymbol, ...

The entity scope to evaluate the attribute against. GLOBAL is only valid for spend velocity attributes.



337
338
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 337

optional :scope,
enum: -> { Lithic::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Parameters::Scope }

#unitSymbol, ...

The unit for impossible travel attributes. Required when attribute is TRAVEL_SPEED or DISTANCE_FROM_LAST_TRANSACTION.

For TRAVEL_SPEED: MPH (miles per hour) or KPH (kilometers per hour).

For DISTANCE_FROM_LAST_TRANSACTION: MILES or KILOMETERS.



349
350
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 349

optional :unit,
enum: -> { Lithic::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Parameters::Unit }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 391

Instance Method Details

#to_hash{

Returns:

  • ({)


175
# File 'sig/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rbs', line 175

def to_hash: -> {