Class: Lithic::Models::AuthRules::ConditionalTokenizationActionParameters::Condition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::ConditionalTokenizationActionParameters::Condition
- Defined in:
- lib/lithic/models/auth_rules/conditional_tokenization_action_parameters.rb,
sig/lithic/models/auth_rules/conditional_tokenization_action_parameters.rbs
Defined Under Namespace
Modules: Attribute
Instance Attribute Summary collapse
-
#attribute ⇒ Symbol, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters::Condition::Attribute
The attribute to target.
-
#operation ⇒ Symbol, Lithic::Models::AuthRules::ConditionalOperation
The operation to apply to the attribute.
-
#value ⇒ String, ...
A regex string, to be used with
MATCHESorDOES_NOT_MATCH.
Instance Method Summary collapse
-
#initialize(attribute:, operation:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Condition for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attribute:, operation:, value:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::ConditionalTokenizationActionParameters::Condition for more details.
|
|
# File 'lib/lithic/models/auth_rules/conditional_tokenization_action_parameters.rb', line 220
|
Instance Attribute Details
#attribute ⇒ Symbol, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters::Condition::Attribute
The attribute to target.
The following attributes may be targeted:
TIMESTAMP: The timestamp of the tokenization request in ISO 8601 format.TOKENIZATION_CHANNEL: The channel through which the tokenization request was initiated. Valid values areDIGITAL_WALLET,MERCHANT.TOKENIZATION_SOURCE: The source of the tokenization request. Valid values areACCOUNT_ON_FILE,MANUAL_PROVISION,PUSH_PROVISION,CHIP_DIP,CONTACTLESS_TAP,TOKEN,UNKNOWN.TOKEN_REQUESTOR_NAME: The name of the entity requesting the token. Valid values areALT_ID,AMAZON_ONE,AMERICAN_EXPRESS_TOKEN_SERVICE,ANDROID_PAY,APPLE_PAY,FACEBOOK,FITBIT_PAY,GARMIN_PAY,GOOGLE_PAY,GOOGLE_VCN,ISSUER_HCE,MICROSOFT_PAY,NETFLIX,SAMSUNG_PAY,UNKNOWN,VISA_CHECKOUT.-
WALLET_ACCOUNT_SCORE: Risk score for the account in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2medium risk). Use an integer value.
-
WALLET_DEVICE_SCORE: Risk score for the device in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2medium risk). Use an integer value.
WALLET_RECOMMENDED_DECISION: The decision recommended by the digital wallet provider. Valid values include APPROVE, DECLINE, REQUIRE_ADDITIONAL_AUTHENTICATION.-
WALLET_RECOMMENDATION_REASONS: List of reasons provided by the digital wallet provider for the recommended decision. Valid values are:- Common:
ACCOUNT_CARD_TOO_NEW,ACCOUNT_RECENTLY_CHANGED,ACCOUNT_TOO_NEW,ACCOUNT_TOO_NEW_SINCE_LAUNCH,DEVICE_RECENTLY_LOST,HAS_SUSPENDED_TOKENS,HIGH_RISK,INACTIVE_ACCOUNT,LOW_ACCOUNT_SCORE,LOW_DEVICE_SCORE,OUTSIDE_HOME_TERRITORY,SUSPICIOUS_ACTIVITY,TOO_MANY_DIFFERENT_CARDHOLDERS,TOO_MANY_RECENT_ATTEMPTS,TOO_MANY_RECENT_TOKENS,UNABLE_TO_ASSESS - Visa only:
ACCOUNT_DATA_RECENTLY_CHANGED,ACCOUNT_PAN_PAIRING_TOO_NEW,LOW_TRANSACTION_VOLUME,USER_ACCOUNT_DEVICE_TOO_NEW,WALLET_ACCOUNT_TOO_NEW - Amex only:
DEVICE_USING_VPN_PROXY,EXCESSIVE_BILLING_NAME_ATTEMPTS_MODERATE,EXCESSIVE_BILLING_NAME_ATTEMPTS_SEVERE,EXCESSIVE_CARD_PROVISION_ATTEMPTS_MODERATE,EXCESSIVE_CARD_PROVISION_ATTEMPTS_SEVERE,EXCESSIVE_WALLET_RESETS,EXCESSIVE_ZIP_ATTEMPTS_MODERATE,EXCESSIVE_ZIP_ATTEMPTS_SEVERE,USER_ID_CARD_PAIRING_TOO_NEW,USER_ID_DEVICE_ID_PAIRING_TOO_NEW,USER_ID_OS_ID_PAIRING_TOO_NEW,USER_ID_TOO_NEW
- Common:
TOKEN_REQUESTOR_ID: Unique identifier for the entity requesting the token.WALLET_TOKEN_STATUS: The current status of the wallet token.CARD_STATE: The state of the card being tokenized. Valid values areCLOSED,OPEN,PAUSED,PENDING_ACTIVATION,PENDING_FULFILLMENT.
205 206 |
# File 'lib/lithic/models/auth_rules/conditional_tokenization_action_parameters.rb', line 205 required :attribute, enum: -> { Lithic::AuthRules::ConditionalTokenizationActionParameters::Condition::Attribute } |
#operation ⇒ Symbol, Lithic::Models::AuthRules::ConditionalOperation
The operation to apply to the attribute
212 |
# File 'lib/lithic/models/auth_rules/conditional_tokenization_action_parameters.rb', line 212 required :operation, enum: -> { Lithic::AuthRules::ConditionalOperation } |
#value ⇒ String, ...
A regex string, to be used with MATCHES or DOES_NOT_MATCH
218 |
# File 'lib/lithic/models/auth_rules/conditional_tokenization_action_parameters.rb', line 218 required :value, union: -> { Lithic::AuthRules::ConditionalValue } |
Instance Method Details
#to_hash ⇒ {
201 |
# File 'sig/lithic/models/auth_rules/conditional_tokenization_action_parameters.rbs', line 201
def to_hash: -> {
|