Class: Lithic::Models::AuthRules::MerchantLockParameters
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::MerchantLockParameters
- Defined in:
- lib/lithic/models/auth_rules/merchant_lock_parameters.rb,
sig/lithic/models/auth_rules/merchant_lock_parameters.rbs
Defined Under Namespace
Classes: Merchant
Instance Attribute Summary collapse
-
#merchants ⇒ Array<Lithic::Models::AuthRules::MerchantLockParameters::Merchant>
A list of merchant locks defining specific merchants or groups of merchants (based on descriptors or IDs) that the lock applies to.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
12 |
# File 'sig/lithic/models/auth_rules/merchant_lock_parameters.rbs', line 12
def initialize: (
|
Instance Attribute Details
#merchants ⇒ Array<Lithic::Models::AuthRules::MerchantLockParameters::Merchant>
A list of merchant locks defining specific merchants or groups of merchants (based on descriptors or IDs) that the lock applies to.
12 13 |
# File 'lib/lithic/models/auth_rules/merchant_lock_parameters.rb', line 12 required :merchants, -> { Lithic::Internal::Type::ArrayOf[Lithic::AuthRules::MerchantLockParameters::Merchant] } |
Instance Method Details
#to_hash ⇒ {
16 |
# File 'sig/lithic/models/auth_rules/merchant_lock_parameters.rbs', line 16
def to_hash: -> {
|