Class: Lithic::Models::AuthRules::ReportStats

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/report_stats.rb

Defined Under Namespace

Modules: State Classes: Example

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Lithic::Internal::Type::BaseModel

Instance Attribute Details

#action_countsHash{Symbol=>Integer}

A mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn’t trigger any action, it’s counted under NO_ACTION key.

Returns:

  • (Hash{Symbol=>Integer})


14
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 14

required :action_counts, Lithic::Internal::Type::HashOf[Integer]

#examplesArray<Lithic::Models::AuthRules::ReportStats::Example>

Example events and their outcomes for this version.



20
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 20

required :examples, -> { Lithic::Internal::Type::ArrayOf[Lithic::AuthRules::ReportStats::Example] }

#stateSymbol, Lithic::Models::AuthRules::ReportStats::State

The evaluation mode of this version during the reported period.



26
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 26

required :state, enum: -> { Lithic::AuthRules::ReportStats::State }

#versionInteger

The rule version number.

Returns:

  • (Integer)


32
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 32

required :version, Integer