Class: Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization
- Defined in:
- lib/lithic/models/auth_rules/report_stats.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#code ⇒ Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Code
The detailed result code explaining the specific reason for the decline.
- #type ⇒ Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Type
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(code:, type:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, type:) ⇒ Object
|
|
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 112
|
Instance Attribute Details
#code ⇒ Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Code
The detailed result code explaining the specific reason for the decline
103 104 |
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 103 required :code, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Code } |
#type ⇒ Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Type
109 110 |
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 109 required :type, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 181
|