Class: Lithic::Models::AuthRules::RuleFeature::ACHPaymentFeature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::RuleFeature::ACHPaymentFeature
- Defined in:
- lib/lithic/models/auth_rules/rule_feature.rb,
sig/lithic/models/auth_rules/rule_feature.rbs
Instance Attribute Summary collapse
-
#name ⇒ String?
The variable name for this feature in the rule function signature.
- #type ⇒ Symbol, :ACH_PAYMENT
Instance Method Summary collapse
-
#initialize ⇒ ACHPaymentFeature
constructor
A new instance of ACHPaymentFeature.
- #to_hash ⇒ { type: :ACH_PAYMENT, name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ ACHPaymentFeature
Returns a new instance of ACHPaymentFeature.
104 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 104
def initialize: (?name: String, ?type: :ACH_PAYMENT) -> void
|
Instance Attribute Details
#name ⇒ String?
The variable name for this feature in the rule function signature
181 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 181 optional :name, String |
#type ⇒ Symbol, :ACH_PAYMENT
175 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 175 required :type, const: :ACH_PAYMENT |
Instance Method Details
#to_hash ⇒ { type: :ACH_PAYMENT, name: String }
106 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 106
def to_hash: -> { type: :ACH_PAYMENT, name: String }
|