Class: Lithic::Models::AuthRules::RuleFeature::ACHReceiptFeature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::RuleFeature::ACHReceiptFeature
- Defined in:
- lib/lithic/models/auth_rules/rule_feature.rb,
sig/lithic/models/auth_rules/rule_feature.rbs
Instance Attribute Summary collapse
-
#name ⇒ String?
The variable name for this feature in the rule function signature.
- #type ⇒ Symbol, :ACH_RECEIPT
Instance Method Summary collapse
-
#initialize ⇒ ACHReceiptFeature
constructor
A new instance of ACHReceiptFeature.
- #to_hash ⇒ { type: :ACH_RECEIPT, name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ ACHReceiptFeature
Returns a new instance of ACHReceiptFeature.
75 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 75
def initialize: (?name: String, ?type: :ACH_RECEIPT) -> void
|
Instance Attribute Details
#name ⇒ String?
The variable name for this feature in the rule function signature
145 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 145 optional :name, String |
#type ⇒ Symbol, :ACH_RECEIPT
139 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 139 required :type, const: :ACH_RECEIPT |
Instance Method Details
#to_hash ⇒ { type: :ACH_RECEIPT, name: String }
77 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 77
def to_hash: -> { type: :ACH_RECEIPT, name: String }
|