Class: Lithic::Models::AuthRules::RuleFeature::CardTransactionFeature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::RuleFeature::CardTransactionFeature
- Defined in:
- lib/lithic/models/auth_rules/rule_feature.rb,
sig/lithic/models/auth_rules/rule_feature.rbs
Instance Attribute Summary collapse
-
#name ⇒ String?
The variable name for this feature in the rule function signature.
- #type ⇒ Symbol, :CARD_TRANSACTION
Instance Method Summary collapse
-
#initialize ⇒ CardTransactionFeature
constructor
A new instance of CardTransactionFeature.
- #to_hash ⇒ { type: :CARD_TRANSACTION, name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ CardTransactionFeature
Returns a new instance of CardTransactionFeature.
90 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 90
def initialize: (?name: String, ?type: :CARD_TRANSACTION) -> void
|
Instance Attribute Details
#name ⇒ String?
The variable name for this feature in the rule function signature
163 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 163 optional :name, String |
#type ⇒ Symbol, :CARD_TRANSACTION
157 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 157 required :type, const: :CARD_TRANSACTION |
Instance Method Details
#to_hash ⇒ { type: :CARD_TRANSACTION, name: String }
92 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 92
def to_hash: -> { type: :CARD_TRANSACTION, name: String }
|