Class: Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/rule_feature.rb,
sig/lithic/models/auth_rules/rule_feature.rbs

Defined Under Namespace

Modules: Scope Classes: Filters

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(period:, scope:, filters: nil, name: nil, type: :PAYMENT_VELOCITY) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature for more details.

Parameters:



# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 346

Instance Attribute Details

#filtersLithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters?

Optional filters applied when aggregating ACH payment velocity. Payments not matching the provided filters are excluded from the calculated velocity.



338
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 338

optional :filters, -> { Lithic::AuthRules::RuleFeature::PaymentVelocityFeature::Filters }

#nameString?

The variable name for this feature in the rule function signature

Parameters:

  • (String)

Returns:

  • (String, nil)


344
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 344

optional :name, String

#periodLithic::Models::AuthRules::VelocityLimitPeriod::TrailingWindowObject, ...

Velocity over the current day since 00:00 / 12 AM in Eastern Time



320
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 320

required :period, union: -> { Lithic::AuthRules::VelocityLimitPeriod }

#scopeSymbol, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Scope

The scope over which the ACH payment velocity is aggregated.

Parameters:

  • value (Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::scope)

Returns:



326
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 326

required :scope, enum: -> { Lithic::AuthRules::RuleFeature::PaymentVelocityFeature::Scope }

#typeSymbol, :PAYMENT_VELOCITY

Parameters:

  • value (:PAYMENT_VELOCITY)

Returns:

  • (Symbol, :PAYMENT_VELOCITY)


331
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 331

required :type, const: :PAYMENT_VELOCITY

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 370

Instance Method Details

#to_hash{

Returns:

  • ({)


254
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 254

def to_hash: -> {