Class: Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters
- Defined in:
- lib/lithic/models/auth_rules/rule_feature.rb,
sig/lithic/models/auth_rules/rule_feature.rbs
Overview
Defined Under Namespace
Modules: IncludePaymentType, IncludePolarity, IncludeStatus, Result
Instance Attribute Summary collapse
-
#exclude_tags ⇒ Hash{Symbol=>String}?
Exclude payments matching any of the provided tag key-value pairs.
-
#include_payment_types ⇒ Array<Symbol, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludePaymentType>?
Payment types to include in the velocity calculation.
-
#include_polarities ⇒ Array<Symbol, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludePolarity>?
Payment polarities to include in the velocity calculation.
-
#include_statuses ⇒ Array<Symbol, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludeStatus>?
Payment statuses to include in the velocity calculation.
-
#include_tags ⇒ Hash{Symbol=>String}?
Only include payments matching all of the provided tag key-value pairs.
-
#result ⇒ Symbol, ...
Only include payments with the given result.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
300 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 300
def initialize: (
|
Instance Attribute Details
#exclude_tags ⇒ Hash{Symbol=>String}?
Exclude payments matching any of the provided tag key-value pairs.
380 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 380 optional :exclude_tags, Lithic::Internal::Type::HashOf[String], nil?: true |
#include_payment_types ⇒ Array<Symbol, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludePaymentType>?
Payment types to include in the velocity calculation.
386 387 388 389 390 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 386 optional :include_payment_types, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludePaymentType] }, nil?: true |
#include_polarities ⇒ Array<Symbol, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludePolarity>?
Payment polarities to include in the velocity calculation.
396 397 398 399 400 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 396 optional :include_polarities, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludePolarity] }, nil?: true |
#include_statuses ⇒ Array<Symbol, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludeStatus>?
Payment statuses to include in the velocity calculation.
406 407 408 409 410 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 406 optional :include_statuses, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::IncludeStatus] }, nil?: true |
#include_tags ⇒ Hash{Symbol=>String}?
Only include payments matching all of the provided tag key-value pairs.
416 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 416 optional :include_tags, Lithic::Internal::Type::HashOf[String], nil?: true |
#result ⇒ Symbol, ...
Only include payments with the given result.
422 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 422 optional :result, enum: -> { Lithic::AuthRules::RuleFeature::PaymentVelocityFeature::Filters::Result } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 446
|
Instance Method Details
#to_hash ⇒ {
309 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 309
def to_hash: -> {
|