Class: Lithic::Models::AuthRules::RuleFeature::SpendVelocityFeature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::RuleFeature::SpendVelocityFeature
- Defined in:
- lib/lithic/models/auth_rules/rule_feature.rb
Defined Under Namespace
Modules: Scope
Instance Attribute Summary collapse
- #filters ⇒ Lithic::Models::AuthRules::VelocityLimitFilters?
-
#name ⇒ String?
The variable name for this feature in the rule function signature.
-
#period ⇒ Lithic::Models::AuthRules::VelocityLimitPeriod::TrailingWindowObject, ...
Velocity over the current day since 00:00 / 12 AM in Eastern Time.
-
#scope ⇒ Symbol, Lithic::Models::AuthRules::RuleFeature::SpendVelocityFeature::Scope
The scope the velocity is calculated for.
- #type ⇒ Symbol, :SPEND_VELOCITY
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(period:, scope:, filters: nil, name: nil, type: :SPEND_VELOCITY) ⇒ Object
|
|
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 201
|
Instance Attribute Details
#filters ⇒ Lithic::Models::AuthRules::VelocityLimitFilters?
193 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 193 optional :filters, -> { Lithic::AuthRules::VelocityLimitFilters } |
#name ⇒ String?
The variable name for this feature in the rule function signature
199 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 199 optional :name, String |
#period ⇒ Lithic::Models::AuthRules::VelocityLimitPeriod::TrailingWindowObject, ...
Velocity over the current day since 00:00 / 12 AM in Eastern Time
177 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 177 required :period, union: -> { Lithic::AuthRules::VelocityLimitPeriod } |
#scope ⇒ Symbol, Lithic::Models::AuthRules::RuleFeature::SpendVelocityFeature::Scope
The scope the velocity is calculated for
183 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 183 required :scope, enum: -> { Lithic::AuthRules::RuleFeature::SpendVelocityFeature::Scope } |
#type ⇒ Symbol, :SPEND_VELOCITY
188 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 188 required :type, const: :SPEND_VELOCITY |