Class: Lithic::Models::AuthRules::RuleFeature::TransactionHistorySignalsFeature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::RuleFeature::TransactionHistorySignalsFeature
- Defined in:
- lib/lithic/models/auth_rules/rule_feature.rb
Defined Under Namespace
Modules: Scope
Instance Attribute Summary collapse
-
#name ⇒ String?
The variable name for this feature in the rule function signature.
-
#scope ⇒ Symbol, Lithic::Models::AuthRules::RuleFeature::TransactionHistorySignalsFeature::Scope
The entity scope to load transaction history signals for.
- #type ⇒ Symbol, :TRANSACTION_HISTORY_SIGNALS
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(scope:, name: nil, type: :TRANSACTION_HISTORY_SIGNALS) ⇒ Object
|
|
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 250
|
Instance Attribute Details
#name ⇒ String?
The variable name for this feature in the rule function signature
248 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 248 optional :name, String |
#scope ⇒ Symbol, Lithic::Models::AuthRules::RuleFeature::TransactionHistorySignalsFeature::Scope
The entity scope to load transaction history signals for.
237 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 237 required :scope, enum: -> { Lithic::AuthRules::RuleFeature::TransactionHistorySignalsFeature::Scope } |
#type ⇒ Symbol, :TRANSACTION_HISTORY_SIGNALS
242 |
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 242 required :type, const: :TRANSACTION_HISTORY_SIGNALS |