Class: Lithic::Models::AuthRules::SpendVelocityFilters

Inherits:
VelocityLimitFilters show all
Defined in:
lib/lithic/models/auth_rules/spend_velocity_filters.rb

Instance Attribute Summary collapse

Attributes inherited from VelocityLimitFilters

#exclude_countries, #exclude_mccs, #include_countries, #include_mccs, #include_pan_entry_modes

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(exclude_tags: nil, include_tags: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::SpendVelocityFilters for more details.

Parameters:

  • exclude_tags (Hash{Symbol=>String}, nil) (defaults to: nil)

    Tag key-value pairs to exclude from the velocity calculation. Transactions match

  • include_tags (Hash{Symbol=>String}, nil) (defaults to: nil)

    Tag key-value pairs to include in the velocity calculation. Only transactions ma



# File 'lib/lithic/models/auth_rules/spend_velocity_filters.rb', line 23

Instance Attribute Details

#exclude_tagsHash{Symbol=>String}?

Tag key-value pairs to exclude from the velocity calculation. Transactions matching all specified tag key-value pairs will be excluded from the calculated velocity.

Returns:

  • (Hash{Symbol=>String}, nil)


13
# File 'lib/lithic/models/auth_rules/spend_velocity_filters.rb', line 13

optional :exclude_tags, Lithic::Internal::Type::HashOf[String], nil?: true

#include_tagsHash{Symbol=>String}?

Tag key-value pairs to include in the velocity calculation. Only transactions matching all specified tag key-value pairs will be included in the calculated velocity.

Returns:

  • (Hash{Symbol=>String}, nil)


21
# File 'lib/lithic/models/auth_rules/spend_velocity_filters.rb', line 21

optional :include_tags, Lithic::Internal::Type::HashOf[String], nil?: true