Module: Lithic::Models::AuthRules::V2CreateParams::Body

Extended by:
Internal::Type::Union
Defined in:
lib/lithic/models/auth_rules/v2_create_params.rb

Defined Under Namespace

Classes: AccountLevelRule, CardLevelRule, ProgramLevelRule

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 147

Instance Method Details

#initialize(body:, request_options: {}) ⇒ Object



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 20

module Body
  extend Lithic::Internal::Type::Union

  variant -> { Lithic::AuthRules::V2CreateParams::Body::AccountLevelRule }

  variant -> { Lithic::AuthRules::V2CreateParams::Body::CardLevelRule }

  variant -> { Lithic::AuthRules::V2CreateParams::Body::ProgramLevelRule }

  class AccountLevelRule < Lithic::Internal::Type::BaseModel
    # @!attribute parameters
    #   Parameters for the Auth Rule
    #
    #   @return [Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters]
    required :parameters, union: -> { Lithic::AuthRules::V2CreateParams::Body::AccountLevelRule::Parameters }

    # @!attribute type
    #   The type of Auth Rule. For certain rule types, this determines the event stream
    #   during which it will be evaluated. For rules that can be applied to one of
    #   several event streams, the effective one is defined by the separate
    #   `event_stream` field.
    #
    #   - `CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead.
    #     AUTHORIZATION event stream.
    #   - `VELOCITY_LIMIT`: AUTHORIZATION event stream.
    #   - `MERCHANT_LOCK`: AUTHORIZATION event stream.
    #   - `CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #     ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #   - `TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #     ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::AccountLevelRule::Type]
    required :type, enum: -> { Lithic::AuthRules::V2CreateParams::Body::AccountLevelRule::Type }

    # @!attribute account_tokens
    #   Account tokens to which the Auth Rule applies.
    #
    #   @return [Array<String>, nil]
    optional :account_tokens, Lithic::Internal::Type::ArrayOf[String]

    # @!attribute business_account_tokens
    #   Business Account tokens to which the Auth Rule applies.
    #
    #   @return [Array<String>, nil]
    optional :business_account_tokens, Lithic::Internal::Type::ArrayOf[String]

    # @!attribute event_stream
    #   The event stream during which the rule will be evaluated.
    #
    #   @return [Symbol, Lithic::Models::AuthRules::EventStream, nil]
    optional :event_stream, enum: -> { Lithic::AuthRules::EventStream }

    # @!attribute name
    #   Auth Rule Name
    #
    #   @return [String, nil]
    optional :name, String, nil?: true

    # @!method initialize(parameters:, type:, account_tokens: nil, business_account_tokens: nil, event_stream: nil, name: nil)
    #   Some parameter documentations has been truncated, see
    #   {Lithic::Models::AuthRules::V2CreateParams::Body::AccountLevelRule} for more
    #   details.
    #
    #   @param parameters [Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters] Parameters for the Auth Rule
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::AccountLevelRule::Type] The type of Auth Rule. For certain rule types, this determines the event stream
    #
    #   @param account_tokens [Array<String>] Account tokens to which the Auth Rule applies.
    #
    #   @param business_account_tokens [Array<String>] Business Account tokens to which the Auth Rule applies.
    #
    #   @param event_stream [Symbol, Lithic::Models::AuthRules::EventStream] The event stream during which the rule will be evaluated.
    #
    #   @param name [String, nil] Auth Rule Name

    # Parameters for the Auth Rule
    #
    # @see Lithic::Models::AuthRules::V2CreateParams::Body::AccountLevelRule#parameters
    module Parameters
      extend Lithic::Internal::Type::Union

      # Deprecated: Use CONDITIONAL_ACTION instead.
      variant -> { Lithic::AuthRules::ConditionalBlockParameters }

      variant -> { Lithic::AuthRules::VelocityLimitParams }

      variant -> { Lithic::AuthRules::MerchantLockParameters }

      variant -> { Lithic::AuthRules::Conditional3DSActionParameters }

      variant -> { Lithic::AuthRules::ConditionalAuthorizationActionParameters }

      variant -> { Lithic::AuthRules::ConditionalACHActionParameters }

      variant -> { Lithic::AuthRules::ConditionalTokenizationActionParameters }

      # Parameters for defining a TypeScript code rule
      variant -> { Lithic::AuthRules::TypescriptCodeParameters }

      # @!method self.variants
      #   @return [Array(Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters)]
    end

    # The type of Auth Rule. For certain rule types, this determines the event stream
    # during which it will be evaluated. For rules that can be applied to one of
    # several event streams, the effective one is defined by the separate
    # `event_stream` field.
    #
    # - `CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead.
    #   AUTHORIZATION event stream.
    # - `VELOCITY_LIMIT`: AUTHORIZATION event stream.
    # - `MERCHANT_LOCK`: AUTHORIZATION event stream.
    # - `CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #   ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    # - `TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #   ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #
    # @see Lithic::Models::AuthRules::V2CreateParams::Body::AccountLevelRule#type
    module Type
      extend Lithic::Internal::Type::Enum

      CONDITIONAL_BLOCK = :CONDITIONAL_BLOCK
      VELOCITY_LIMIT = :VELOCITY_LIMIT
      MERCHANT_LOCK = :MERCHANT_LOCK
      CONDITIONAL_ACTION = :CONDITIONAL_ACTION
      TYPESCRIPT_CODE = :TYPESCRIPT_CODE

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class CardLevelRule < Lithic::Internal::Type::BaseModel
    # @!attribute card_tokens
    #   Card tokens to which the Auth Rule applies.
    #
    #   @return [Array<String>]
    required :card_tokens, Lithic::Internal::Type::ArrayOf[String]

    # @!attribute parameters
    #   Parameters for the Auth Rule
    #
    #   @return [Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters]
    required :parameters, union: -> { Lithic::AuthRules::V2CreateParams::Body::CardLevelRule::Parameters }

    # @!attribute type
    #   The type of Auth Rule. For certain rule types, this determines the event stream
    #   during which it will be evaluated. For rules that can be applied to one of
    #   several event streams, the effective one is defined by the separate
    #   `event_stream` field.
    #
    #   - `CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead.
    #     AUTHORIZATION event stream.
    #   - `VELOCITY_LIMIT`: AUTHORIZATION event stream.
    #   - `MERCHANT_LOCK`: AUTHORIZATION event stream.
    #   - `CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #     ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #   - `TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #     ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule::Type]
    required :type, enum: -> { Lithic::AuthRules::V2CreateParams::Body::CardLevelRule::Type }

    # @!attribute event_stream
    #   The event stream during which the rule will be evaluated.
    #
    #   @return [Symbol, Lithic::Models::AuthRules::EventStream, nil]
    optional :event_stream, enum: -> { Lithic::AuthRules::EventStream }

    # @!attribute name
    #   Auth Rule Name
    #
    #   @return [String, nil]
    optional :name, String, nil?: true

    # @!method initialize(card_tokens:, parameters:, type:, event_stream: nil, name: nil)
    #   Some parameter documentations has been truncated, see
    #   {Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule} for more
    #   details.
    #
    #   @param card_tokens [Array<String>] Card tokens to which the Auth Rule applies.
    #
    #   @param parameters [Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters] Parameters for the Auth Rule
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule::Type] The type of Auth Rule. For certain rule types, this determines the event stream
    #
    #   @param event_stream [Symbol, Lithic::Models::AuthRules::EventStream] The event stream during which the rule will be evaluated.
    #
    #   @param name [String, nil] Auth Rule Name

    # Parameters for the Auth Rule
    #
    # @see Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule#parameters
    module Parameters
      extend Lithic::Internal::Type::Union

      # Deprecated: Use CONDITIONAL_ACTION instead.
      variant -> { Lithic::AuthRules::ConditionalBlockParameters }

      variant -> { Lithic::AuthRules::VelocityLimitParams }

      variant -> { Lithic::AuthRules::MerchantLockParameters }

      variant -> { Lithic::AuthRules::Conditional3DSActionParameters }

      variant -> { Lithic::AuthRules::ConditionalAuthorizationActionParameters }

      variant -> { Lithic::AuthRules::ConditionalACHActionParameters }

      variant -> { Lithic::AuthRules::ConditionalTokenizationActionParameters }

      # Parameters for defining a TypeScript code rule
      variant -> { Lithic::AuthRules::TypescriptCodeParameters }

      # @!method self.variants
      #   @return [Array(Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters)]
    end

    # The type of Auth Rule. For certain rule types, this determines the event stream
    # during which it will be evaluated. For rules that can be applied to one of
    # several event streams, the effective one is defined by the separate
    # `event_stream` field.
    #
    # - `CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead.
    #   AUTHORIZATION event stream.
    # - `VELOCITY_LIMIT`: AUTHORIZATION event stream.
    # - `MERCHANT_LOCK`: AUTHORIZATION event stream.
    # - `CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #   ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    # - `TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #   ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #
    # @see Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule#type
    module Type
      extend Lithic::Internal::Type::Enum

      CONDITIONAL_BLOCK = :CONDITIONAL_BLOCK
      VELOCITY_LIMIT = :VELOCITY_LIMIT
      MERCHANT_LOCK = :MERCHANT_LOCK
      CONDITIONAL_ACTION = :CONDITIONAL_ACTION
      TYPESCRIPT_CODE = :TYPESCRIPT_CODE

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class ProgramLevelRule < Lithic::Internal::Type::BaseModel
    # @!attribute parameters
    #   Parameters for the Auth Rule
    #
    #   @return [Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters]
    required :parameters, union: -> { Lithic::AuthRules::V2CreateParams::Body::ProgramLevelRule::Parameters }

    # @!attribute program_level
    #   Whether the Auth Rule applies to all authorizations on the card program.
    #
    #   @return [Boolean]
    required :program_level, Lithic::Internal::Type::Boolean

    # @!attribute type
    #   The type of Auth Rule. For certain rule types, this determines the event stream
    #   during which it will be evaluated. For rules that can be applied to one of
    #   several event streams, the effective one is defined by the separate
    #   `event_stream` field.
    #
    #   - `CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead.
    #     AUTHORIZATION event stream.
    #   - `VELOCITY_LIMIT`: AUTHORIZATION event stream.
    #   - `MERCHANT_LOCK`: AUTHORIZATION event stream.
    #   - `CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #     ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #   - `TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #     ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule::Type]
    required :type, enum: -> { Lithic::AuthRules::V2CreateParams::Body::ProgramLevelRule::Type }

    # @!attribute event_stream
    #   The event stream during which the rule will be evaluated.
    #
    #   @return [Symbol, Lithic::Models::AuthRules::EventStream, nil]
    optional :event_stream, enum: -> { Lithic::AuthRules::EventStream }

    # @!attribute excluded_account_tokens
    #   Account tokens to which the Auth Rule does not apply.
    #
    #   @return [Array<String>, nil]
    optional :excluded_account_tokens, Lithic::Internal::Type::ArrayOf[String]

    # @!attribute excluded_business_account_tokens
    #   Business account tokens to which the Auth Rule does not apply.
    #
    #   @return [Array<String>, nil]
    optional :excluded_business_account_tokens, Lithic::Internal::Type::ArrayOf[String]

    # @!attribute excluded_card_tokens
    #   Card tokens to which the Auth Rule does not apply.
    #
    #   @return [Array<String>, nil]
    optional :excluded_card_tokens, Lithic::Internal::Type::ArrayOf[String]

    # @!attribute name
    #   Auth Rule Name
    #
    #   @return [String, nil]
    optional :name, String, nil?: true

    # @!method initialize(parameters:, program_level:, type:, event_stream: nil, excluded_account_tokens: nil, excluded_business_account_tokens: nil, excluded_card_tokens: nil, name: nil)
    #   Some parameter documentations has been truncated, see
    #   {Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule} for more
    #   details.
    #
    #   @param parameters [Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters] Parameters for the Auth Rule
    #
    #   @param program_level [Boolean] Whether the Auth Rule applies to all authorizations on the card program.
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule::Type] The type of Auth Rule. For certain rule types, this determines the event stream
    #
    #   @param event_stream [Symbol, Lithic::Models::AuthRules::EventStream] The event stream during which the rule will be evaluated.
    #
    #   @param excluded_account_tokens [Array<String>] Account tokens to which the Auth Rule does not apply.
    #
    #   @param excluded_business_account_tokens [Array<String>] Business account tokens to which the Auth Rule does not apply.
    #
    #   @param excluded_card_tokens [Array<String>] Card tokens to which the Auth Rule does not apply.
    #
    #   @param name [String, nil] Auth Rule Name

    # Parameters for the Auth Rule
    #
    # @see Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule#parameters
    module Parameters
      extend Lithic::Internal::Type::Union

      # Deprecated: Use CONDITIONAL_ACTION instead.
      variant -> { Lithic::AuthRules::ConditionalBlockParameters }

      variant -> { Lithic::AuthRules::VelocityLimitParams }

      variant -> { Lithic::AuthRules::MerchantLockParameters }

      variant -> { Lithic::AuthRules::Conditional3DSActionParameters }

      variant -> { Lithic::AuthRules::ConditionalAuthorizationActionParameters }

      variant -> { Lithic::AuthRules::ConditionalACHActionParameters }

      variant -> { Lithic::AuthRules::ConditionalTokenizationActionParameters }

      # Parameters for defining a TypeScript code rule
      variant -> { Lithic::AuthRules::TypescriptCodeParameters }

      # @!method self.variants
      #   @return [Array(Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters)]
    end

    # The type of Auth Rule. For certain rule types, this determines the event stream
    # during which it will be evaluated. For rules that can be applied to one of
    # several event streams, the effective one is defined by the separate
    # `event_stream` field.
    #
    # - `CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead.
    #   AUTHORIZATION event stream.
    # - `VELOCITY_LIMIT`: AUTHORIZATION event stream.
    # - `MERCHANT_LOCK`: AUTHORIZATION event stream.
    # - `CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #   ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    # - `TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION,
    #   ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
    #
    # @see Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule#type
    module Type
      extend Lithic::Internal::Type::Enum

      CONDITIONAL_BLOCK = :CONDITIONAL_BLOCK
      VELOCITY_LIMIT = :VELOCITY_LIMIT
      MERCHANT_LOCK = :MERCHANT_LOCK
      CONDITIONAL_ACTION = :CONDITIONAL_ACTION
      TYPESCRIPT_CODE = :TYPESCRIPT_CODE

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @!method self.variants
  #   @return [Array(Lithic::Models::AuthRules::V2CreateParams::Body::AccountLevelRule, Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule, Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule)]
end