Class: Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_create_params.rb

Defined Under Namespace

Modules: Parameters, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(parameters:, program_level:, type:, event_stream: nil, excluded_account_tokens: nil, excluded_business_account_tokens: nil, excluded_card_tokens: nil, name: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule for more details.

Parameters:



# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 350

Instance Attribute Details

#event_streamSymbol, ...

The event stream during which the rule will be evaluated.

Returns:



324
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 324

optional :event_stream, enum: -> { Lithic::AuthRules::EventStream }

#excluded_account_tokensArray<String>?

Account tokens to which the Auth Rule does not apply.

Returns:

  • (Array<String>, nil)


330
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 330

optional :excluded_account_tokens, Lithic::Internal::Type::ArrayOf[String]

#excluded_business_account_tokensArray<String>?

Business account tokens to which the Auth Rule does not apply.

Returns:

  • (Array<String>, nil)


336
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 336

optional :excluded_business_account_tokens, Lithic::Internal::Type::ArrayOf[String]

#excluded_card_tokensArray<String>?

Card tokens to which the Auth Rule does not apply.

Returns:

  • (Array<String>, nil)


342
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 342

optional :excluded_card_tokens, Lithic::Internal::Type::ArrayOf[String]

#nameString?

Auth Rule Name

Returns:

  • (String, nil)


348
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 348

optional :name, String, nil?: true

#program_levelBoolean

Whether the Auth Rule applies to all authorizations on the card program.

Returns:

  • (Boolean)


298
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 298

required :program_level, Lithic::Internal::Type::Boolean

#typeSymbol, Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule::Type

The type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate ‘event_stream` field.

  • ‘CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead. AUTHORIZATION event stream.

  • ‘VELOCITY_LIMIT`: AUTHORIZATION event stream.

  • ‘MERCHANT_LOCK`: AUTHORIZATION event stream.

  • ‘CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, CARD_TRANSACTION_UPDATE, or ACH_PAYMENT_UPDATE event stream.

  • ‘TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, CARD_TRANSACTION_UPDATE, or ACH_PAYMENT_UPDATE event stream.



318
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 318

required :type, enum: -> { Lithic::AuthRules::V2CreateParams::Body::ProgramLevelRule::Type }