Class: Lithic::Models::AuthRules::V2ListResultsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2ListResultsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/auth_rules/v2_list_results_params.rb
Overview
Instance Attribute Summary collapse
-
#auth_rule_token ⇒ String?
Filter by Auth Rule token.
-
#begin_ ⇒ Time?
Date string in RFC 3339 format.
-
#end_ ⇒ Time?
Date string in RFC 3339 format.
-
#ending_before ⇒ String?
A cursor representing an item’s token before which a page of results should end.
-
#event_token ⇒ String?
Filter by event token.
-
#has_actions ⇒ Boolean?
Filter by whether the rule evaluation produced any actions.
-
#page_size ⇒ Integer?
Page size (for pagination).
-
#starting_after ⇒ String?
A cursor representing an item’s token after which a page of results should begin.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(auth_rule_token: nil, begin_: nil, end_: nil, ending_before: nil, event_token: nil, has_actions: nil, page_size: nil, starting_after: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see V2ListResultsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(auth_rule_token: nil, begin_: nil, end_: nil, ending_before: nil, event_token: nil, has_actions: nil, page_size: nil, starting_after: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2ListResultsParams for more details.
|
|
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 64
|
Instance Attribute Details
#auth_rule_token ⇒ String?
Filter by Auth Rule token
15 |
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 15 optional :auth_rule_token, String |
#begin_ ⇒ Time?
Date string in RFC 3339 format. Only events evaluated after the specified time will be included. UTC time zone.
22 |
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 22 optional :begin_, Time |
#end_ ⇒ Time?
Date string in RFC 3339 format. Only events evaluated before the specified time will be included. UTC time zone.
29 |
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 29 optional :end_, Time |
#ending_before ⇒ String?
A cursor representing an item’s token before which a page of results should end. Used to retrieve the previous page of results before this item.
36 |
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 36 optional :ending_before, String |
#event_token ⇒ String?
Filter by event token
42 |
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 42 optional :event_token, String |
#has_actions ⇒ Boolean?
Filter by whether the rule evaluation produced any actions. When not provided, all results are returned.
49 |
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 49 optional :has_actions, Lithic::Internal::Type::Boolean |
#page_size ⇒ Integer?
Page size (for pagination).
55 |
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 55 optional :page_size, Integer |
#starting_after ⇒ String?
A cursor representing an item’s token after which a page of results should begin. Used to retrieve the next page of results after this item.
62 |
# File 'lib/lithic/models/auth_rules/v2_list_results_params.rb', line 62 optional :starting_after, String |