Module: Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action

Extended by:
Internal::Type::Union
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb

Defined Under Namespace

Classes: CreateCaseAction, TagAction

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1224

Instance Method Details

#initialize(token:, actions:, auth_rule_token:, evaluation_time:, event_token:, mode:, rule_version:, transaction_token:, event_stream: :ACH_PAYMENT_UPDATE) ⇒ Object

Parameters:



1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1174

module Action
  extend Lithic::Internal::Type::Union

  variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::TagAction }

  variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction }

  class TagAction < Lithic::Internal::Type::BaseModel
    # @!attribute key
    #   The key of the tag to apply to the payment
    #
    #   @return [String]
    required :key, String

    # @!attribute type
    #   Tag the payment with key-value metadata
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::TagAction::Type]
    required :type,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::TagAction::Type }

    # @!attribute value
    #   The value of the tag to apply to the payment
    #
    #   @return [String]
    required :value, String

    # @!attribute explanation
    #   Optional explanation for why this action was taken
    #
    #   @return [String, nil]
    optional :explanation, String

    # @!method initialize(key:, type:, value:, explanation: nil)
    #   @param key [String] The key of the tag to apply to the payment
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::TagAction::Type] Tag the payment with key-value metadata
    #
    #   @param value [String] The value of the tag to apply to the payment
    #
    #   @param explanation [String] Optional explanation for why this action was taken

    # Tag the payment with key-value metadata
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::TagAction#type
    module Type
      extend Lithic::Internal::Type::Enum

      TAG = :TAG

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class CreateCaseAction < Lithic::Internal::Type::BaseModel
    # @!attribute queue_token
    #   The token of the queue to create the case in
    #
    #   @return [String]
    required :queue_token, String

    # @!attribute scope
    #   The scope of the case to create
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction::Scope]
    required :scope,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction::Scope }

    # @!attribute type
    #   Create a case for the payment
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction::Type]
    required :type,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction::Type }

    # @!attribute explanation
    #   Optional explanation for why this action was taken
    #
    #   @return [String, nil]
    optional :explanation, String

    # @!method initialize(queue_token:, scope:, type:, explanation: nil)
    #   @param queue_token [String] The token of the queue to create the case in
    #
    #   @param scope [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction::Scope] The scope of the case to create
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction::Type] Create a case for the payment
    #
    #   @param explanation [String] Optional explanation for why this action was taken

    # The scope of the case to create
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction#scope
    module Scope
      extend Lithic::Internal::Type::Enum

      FINANCIAL_ACCOUNT = :FINANCIAL_ACCOUNT

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # Create a case for the payment
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction#type
    module Type
      extend Lithic::Internal::Type::Enum

      CREATE_CASE = :CREATE_CASE

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @!method self.variants
  #   @return [Array(Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::TagAction, Lithic::Models::AuthRules::V2ListResultsResponse::ACHPaymentUpdateResult::Action::CreateCaseAction)]
end