Class: Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb

Defined Under Namespace

Modules: Action, EventStream, Mode

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Lithic::Internal::Type::BaseModel

Instance Attribute Details

#auth_rule_tokenString

The Auth Rule token

Returns:

  • (String)


629
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 629

required :auth_rule_token, String

#evaluation_timeTime

Timestamp of the rule evaluation

Returns:

  • (Time)


635
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 635

required :evaluation_time, Time

#event_streamSymbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::EventStream

The event stream during which the rule was evaluated



641
642
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 641

required :event_stream,
enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::EventStream }

#event_tokenString

Token of the event that triggered the evaluation

Returns:

  • (String)


648
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 648

required :event_token, String

#modeSymbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Mode

The state of the Auth Rule



654
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 654

required :mode, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Mode }

#rule_versionInteger

Version of the rule that was evaluated

Returns:

  • (Integer)


660
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 660

required :rule_version, Integer

#tokenString

Globally unique identifier for the evaluation

Returns:

  • (String)


616
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 616

required :token, String

#transaction_tokenString?

The token of the transaction that triggered the rule evaluation

Returns:

  • (String, nil)


666
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 666

required :transaction_token, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 851