Module: Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action

Extended by:
Internal::Type::Union
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb

Defined Under Namespace

Classes: ApproveActionACH, ReturnAction

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 717

Instance Method Details

#initialize(token:, actions:, auth_rule_token:, evaluation_time:, event_stream:, event_token:, mode:, rule_version:, transaction_token:) ⇒ Object

Parameters:



683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 683

module Action
  extend Lithic::Internal::Type::Union

  variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH }

  variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction }

  class ApproveActionACH < Lithic::Internal::Type::BaseModel
    # @!attribute type
    #   Approve the ACH transaction
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH::Type]
    required :type,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH::Type }

    # @!attribute explanation
    #   Optional explanation for why this action was taken
    #
    #   @return [String, nil]
    optional :explanation, String

    # @!method initialize(type:, explanation: nil)
    #   @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH::Type] Approve the ACH transaction
    #
    #   @param explanation [String] Optional explanation for why this action was taken

    # Approve the ACH transaction
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH#type
    module Type
      extend Lithic::Internal::Type::Enum

      APPROVE = :APPROVE

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class ReturnAction < Lithic::Internal::Type::BaseModel
    # @!attribute code
    #   NACHA return code to use when returning the transaction. Note that the list of
    #   available return codes is subject to an allowlist configured at the program
    #   level
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction::Code]
    required :code,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction::Code }

    # @!attribute type
    #   Return the ACH transaction
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction::Type]
    required :type,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction::Type }

    # @!attribute explanation
    #   Optional explanation for why this action was taken
    #
    #   @return [String, nil]
    optional :explanation, String

    # @!method initialize(code:, type:, explanation: nil)
    #   Some parameter documentations has been truncated, see
    #   {Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction}
    #   for more details.
    #
    #   @param code [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction::Code] NACHA return code to use when returning the transaction. Note that the list of a
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction::Type] Return the ACH transaction
    #
    #   @param explanation [String] Optional explanation for why this action was taken

    # NACHA return code to use when returning the transaction. Note that the list of
    # available return codes is subject to an allowlist configured at the program
    # level
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction#code
    module Code
      extend Lithic::Internal::Type::Enum

      R01 = :R01
      R02 = :R02
      R03 = :R03
      R04 = :R04
      R05 = :R05
      R06 = :R06
      R07 = :R07
      R08 = :R08
      R09 = :R09
      R10 = :R10
      R11 = :R11
      R12 = :R12
      R13 = :R13
      R14 = :R14
      R15 = :R15
      R16 = :R16
      R17 = :R17
      R18 = :R18
      R19 = :R19
      R20 = :R20
      R21 = :R21
      R22 = :R22
      R23 = :R23
      R24 = :R24
      R25 = :R25
      R26 = :R26
      R27 = :R27
      R28 = :R28
      R29 = :R29
      R30 = :R30
      R31 = :R31
      R32 = :R32
      R33 = :R33
      R34 = :R34
      R35 = :R35
      R36 = :R36
      R37 = :R37
      R38 = :R38
      R39 = :R39
      R40 = :R40
      R41 = :R41
      R42 = :R42
      R43 = :R43
      R44 = :R44
      R45 = :R45
      R46 = :R46
      R47 = :R47
      R50 = :R50
      R51 = :R51
      R52 = :R52
      R53 = :R53
      R61 = :R61
      R62 = :R62
      R67 = :R67
      R68 = :R68
      R69 = :R69
      R70 = :R70
      R71 = :R71
      R72 = :R72
      R73 = :R73
      R74 = :R74
      R75 = :R75
      R76 = :R76
      R77 = :R77
      R80 = :R80
      R81 = :R81
      R82 = :R82
      R83 = :R83
      R84 = :R84
      R85 = :R85

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # Return the ACH transaction
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction#type
    module Type
      extend Lithic::Internal::Type::Enum

      RETURN = :RETURN

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @!method self.variants
  #   @return [Array(Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction)]
end