Class: Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb,
sig/lithic/models/auth_rules/v2_list_results_response.rbs

Defined Under Namespace

Modules: Mode Classes: Action

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



323
# File 'sig/lithic/models/auth_rules/v2_list_results_response.rbs', line 323

def initialize: (

Instance Attribute Details

#actions ⇒ Array<Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action>

Actions returned by the rule evaluation



271
272
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 271

required :actions,
-> { Lithic::Internal::Type::ArrayOf[Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action] }

#auth_rule_token ⇒ String

The Auth Rule token

Parameters:

  • value (String)

Returns:

  • (String)


278
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 278

required :auth_rule_token, String

#evaluation_time ⇒ Time

Timestamp of the rule evaluation

Parameters:

  • value (Time)

Returns:

  • (Time)


284
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 284

required :evaluation_time, Time

#event_stream ⇒ Symbol, :THREE_DS_AUTHENTICATION

The event stream during which the rule was evaluated

Parameters:

  • value (:THREE_DS_AUTHENTICATION)

Returns:

  • (Symbol, :THREE_DS_AUTHENTICATION)


290
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 290

required :event_stream, const: :THREE_DS_AUTHENTICATION

#event_token ⇒ String

Token of the event that triggered the evaluation

Parameters:

  • value (String)

Returns:

  • (String)


296
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 296

required :event_token, String

#mode ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Mode

The state of the Auth Rule

Parameters:

  • value (Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::mode)

Returns:



302
303
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 302

required :mode,
enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Mode }

#rule_version ⇒ Integer

Version of the rule that was evaluated

Parameters:

  • value (Integer)

Returns:

  • (Integer)


309
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 309

required :rule_version, Integer

#token ⇒ String

Globally unique identifier for the evaluation

Parameters:

  • value (String)

Returns:

  • (String)


265
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 265

required :token, String

#transaction_token ⇒ String?

The token of the transaction that triggered the rule evaluation

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


315
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 315

required :transaction_token, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 361

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


335
# File 'sig/lithic/models/auth_rules/v2_list_results_response.rbs', line 335

def to_hash: -> {