Class: Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action
- Defined in:
- lib/lithic/models/auth_rules/v2_list_results_response.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#explanation ⇒ String?
Optional explanation for why this action was taken.
- #type ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action::Type
Instance Method Summary collapse
- #initialize(type:, explanation: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, explanation: nil) ⇒ Object
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 331 class Action < Lithic::Internal::Type::BaseModel # @!attribute type # # @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action::Type] required :type, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action::Type } # @!attribute explanation # Optional explanation for why this action was taken # # @return [String, nil] optional :explanation, String # @!method initialize(type:, explanation: nil) # @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action::Type] # # @param explanation [String] Optional explanation for why this action was taken # @see Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action#type module Type extend Lithic::Internal::Type::Enum DECLINE = :DECLINE CHALLENGE = :CHALLENGE # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#explanation ⇒ String?
Optional explanation for why this action was taken
342 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 342 optional :explanation, String |
#type ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action::Type
335 336 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 335 required :type, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action::Type } |