Class: Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb

Defined Under Namespace

Modules: Action, Mode

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Lithic::Internal::Type::BaseModel

Instance Attribute Details

#auth_rule_tokenString

The Auth Rule token

Returns:

  • (String)


38
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 38

required :auth_rule_token, String

#evaluation_timeTime

Timestamp of the rule evaluation

Returns:

  • (Time)


44
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 44

required :evaluation_time, Time

#event_streamSymbol, :AUTHORIZATION

The event stream during which the rule was evaluated

Returns:

  • (Symbol, :AUTHORIZATION)


50
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 50

required :event_stream, const: :AUTHORIZATION

#event_tokenString

Token of the event that triggered the evaluation

Returns:

  • (String)


56
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 56

required :event_token, String

#modeSymbol, Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Mode

The state of the Auth Rule



62
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 62

required :mode, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Mode }

#rule_versionInteger

Version of the rule that was evaluated

Returns:

  • (Integer)


68
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 68

required :rule_version, Integer

#tokenString

Globally unique identifier for the evaluation

Returns:

  • (String)


25
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 25

required :token, String

#transaction_tokenString?

The token of the transaction that triggered the rule evaluation

Returns:

  • (String, nil)


74
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 74

required :transaction_token, String, nil?: true