Module: Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action

Extended by:
Internal::Type::Union
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb

Defined Under Namespace

Classes: ChallengeActionAuthorization, DeclineActionAuthorization

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 203

Instance Method Details

#initialize(token:, actions:, auth_rule_token:, evaluation_time:, event_token:, mode:, rule_version:, transaction_token:, event_stream: :AUTHORIZATION) ⇒ Object

Parameters:



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 95

module Action
  extend Lithic::Internal::Type::Union

  variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization }

  variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::ChallengeActionAuthorization }

  class DeclineActionAuthorization < Lithic::Internal::Type::BaseModel
    # @!attribute code
    #   The detailed result code explaining the specific reason for the decline
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization::Code]
    required :code,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization::Code }

    # @!attribute type
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization::Type]
    required :type,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization::Type }

    # @!attribute explanation
    #   Optional explanation for why this action was taken
    #
    #   @return [String, nil]
    optional :explanation, String

    # @!method initialize(code:, type:, explanation: nil)
    #   @param code [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization::Code] The detailed result code explaining the specific reason for the decline
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization::Type]
    #
    #   @param explanation [String] Optional explanation for why this action was taken

    # The detailed result code explaining the specific reason for the decline
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization#code
    module Code
      extend Lithic::Internal::Type::Enum

      ACCOUNT_DAILY_SPEND_LIMIT_EXCEEDED = :ACCOUNT_DAILY_SPEND_LIMIT_EXCEEDED
      ACCOUNT_DELINQUENT = :ACCOUNT_DELINQUENT
      ACCOUNT_INACTIVE = :ACCOUNT_INACTIVE
      ACCOUNT_LIFETIME_SPEND_LIMIT_EXCEEDED = :ACCOUNT_LIFETIME_SPEND_LIMIT_EXCEEDED
      ACCOUNT_MONTHLY_SPEND_LIMIT_EXCEEDED = :ACCOUNT_MONTHLY_SPEND_LIMIT_EXCEEDED
      ACCOUNT_PAUSED = :ACCOUNT_PAUSED
      ACCOUNT_UNDER_REVIEW = :ACCOUNT_UNDER_REVIEW
      ADDRESS_INCORRECT = :ADDRESS_INCORRECT
      APPROVED = :APPROVED
      AUTH_RULE_ALLOWED_COUNTRY = :AUTH_RULE_ALLOWED_COUNTRY
      AUTH_RULE_ALLOWED_MCC = :AUTH_RULE_ALLOWED_MCC
      AUTH_RULE_BLOCKED_COUNTRY = :AUTH_RULE_BLOCKED_COUNTRY
      AUTH_RULE_BLOCKED_MCC = :AUTH_RULE_BLOCKED_MCC
      AUTH_RULE = :AUTH_RULE
      CARD_CLOSED = :CARD_CLOSED
      CARD_CRYPTOGRAM_VALIDATION_FAILURE = :CARD_CRYPTOGRAM_VALIDATION_FAILURE
      CARD_EXPIRED = :CARD_EXPIRED
      CARD_EXPIRY_DATE_INCORRECT = :CARD_EXPIRY_DATE_INCORRECT
      CARD_INVALID = :CARD_INVALID
      CARD_NOT_ACTIVATED = :CARD_NOT_ACTIVATED
      CARD_PAUSED = :CARD_PAUSED
      CARD_PIN_INCORRECT = :CARD_PIN_INCORRECT
      CARD_RESTRICTED = :CARD_RESTRICTED
      CARD_SECURITY_CODE_INCORRECT = :CARD_SECURITY_CODE_INCORRECT
      CARD_SPEND_LIMIT_EXCEEDED = :CARD_SPEND_LIMIT_EXCEEDED
      CONTACT_CARD_ISSUER = :CONTACT_CARD_ISSUER
      CUSTOMER_ASA_TIMEOUT = :CUSTOMER_ASA_TIMEOUT
      CUSTOM_ASA_RESULT = :CUSTOM_ASA_RESULT
      DECLINED = :DECLINED
      DO_NOT_HONOR = :DO_NOT_HONOR
      DRIVER_NUMBER_INVALID = :DRIVER_NUMBER_INVALID
      FORMAT_ERROR = :FORMAT_ERROR
      INSUFFICIENT_FUNDING_SOURCE_BALANCE = :INSUFFICIENT_FUNDING_SOURCE_BALANCE
      INSUFFICIENT_FUNDS = :INSUFFICIENT_FUNDS
      LITHIC_SYSTEM_ERROR = :LITHIC_SYSTEM_ERROR
      LITHIC_SYSTEM_RATE_LIMIT = :LITHIC_SYSTEM_RATE_LIMIT
      MALFORMED_ASA_RESPONSE = :MALFORMED_ASA_RESPONSE
      MERCHANT_INVALID = :MERCHANT_INVALID
      MERCHANT_LOCKED_CARD_ATTEMPTED_ELSEWHERE = :MERCHANT_LOCKED_CARD_ATTEMPTED_ELSEWHERE
      MERCHANT_NOT_PERMITTED = :MERCHANT_NOT_PERMITTED
      OVER_REVERSAL_ATTEMPTED = :OVER_REVERSAL_ATTEMPTED
      PIN_BLOCKED = :PIN_BLOCKED
      PROGRAM_CARD_SPEND_LIMIT_EXCEEDED = :PROGRAM_CARD_SPEND_LIMIT_EXCEEDED
      PROGRAM_SUSPENDED = :PROGRAM_SUSPENDED
      PROGRAM_USAGE_RESTRICTION = :PROGRAM_USAGE_RESTRICTION
      REVERSAL_UNMATCHED = :REVERSAL_UNMATCHED
      SECURITY_VIOLATION = :SECURITY_VIOLATION
      SINGLE_USE_CARD_REATTEMPTED = :SINGLE_USE_CARD_REATTEMPTED
      SUSPECTED_FRAUD = :SUSPECTED_FRAUD
      TRANSACTION_INVALID = :TRANSACTION_INVALID
      TRANSACTION_NOT_PERMITTED_TO_ACQUIRER_OR_TERMINAL = :TRANSACTION_NOT_PERMITTED_TO_ACQUIRER_OR_TERMINAL
      TRANSACTION_NOT_PERMITTED_TO_ISSUER_OR_CARDHOLDER = :TRANSACTION_NOT_PERMITTED_TO_ISSUER_OR_CARDHOLDER
      TRANSACTION_PREVIOUSLY_COMPLETED = :TRANSACTION_PREVIOUSLY_COMPLETED
      UNAUTHORIZED_MERCHANT = :UNAUTHORIZED_MERCHANT
      VEHICLE_NUMBER_INVALID = :VEHICLE_NUMBER_INVALID
      CARDHOLDER_CHALLENGED = :CARDHOLDER_CHALLENGED
      CARDHOLDER_CHALLENGE_FAILED = :CARDHOLDER_CHALLENGE_FAILED

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization#type
    module Type
      extend Lithic::Internal::Type::Enum

      DECLINE = :DECLINE

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class ChallengeActionAuthorization < Lithic::Internal::Type::BaseModel
    # @!attribute type
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::ChallengeActionAuthorization::Type]
    required :type,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::ChallengeActionAuthorization::Type }

    # @!attribute explanation
    #   Optional explanation for why this action was taken
    #
    #   @return [String, nil]
    optional :explanation, String

    # @!method initialize(type:, explanation: nil)
    #   @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::ChallengeActionAuthorization::Type]
    #
    #   @param explanation [String] Optional explanation for why this action was taken

    # @see Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::ChallengeActionAuthorization#type
    module Type
      extend Lithic::Internal::Type::Enum

      CHALLENGE = :CHALLENGE

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @!method self.variants
  #   @return [Array(Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::DeclineActionAuthorization, Lithic::Models::AuthRules::V2ListResultsResponse::AuthorizationResult::Action::ChallengeActionAuthorization)]
end