Module: Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action

Extended by:
Internal::Type::Union
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb

Defined Under Namespace

Classes: CreateCaseAction, TagAction

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1013

Instance Method Details

#initialize(token:, actions:, auth_rule_token:, evaluation_time:, event_token:, mode:, rule_version:, transaction_token:, event_stream: :CARD_TRANSACTION_UPDATE) ⇒ Object

Parameters:



963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 963

module Action
  extend Lithic::Internal::Type::Union

  variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::TagAction }

  variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction }

  class TagAction < Lithic::Internal::Type::BaseModel
    # @!attribute key
    #   The key of the tag to apply to the transaction
    #
    #   @return [String]
    required :key, String

    # @!attribute type
    #   Tag the transaction with key-value metadata
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::TagAction::Type]
    required :type,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::TagAction::Type }

    # @!attribute value
    #   The value of the tag to apply to the transaction
    #
    #   @return [String]
    required :value, String

    # @!attribute explanation
    #   Optional explanation for why this action was taken
    #
    #   @return [String, nil]
    optional :explanation, String

    # @!method initialize(key:, type:, value:, explanation: nil)
    #   @param key [String] The key of the tag to apply to the transaction
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::TagAction::Type] Tag the transaction with key-value metadata
    #
    #   @param value [String] The value of the tag to apply to the transaction
    #
    #   @param explanation [String] Optional explanation for why this action was taken

    # Tag the transaction with key-value metadata
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::TagAction#type
    module Type
      extend Lithic::Internal::Type::Enum

      TAG = :TAG

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class CreateCaseAction < Lithic::Internal::Type::BaseModel
    # @!attribute queue_token
    #   The token of the queue to create the case in
    #
    #   @return [String]
    required :queue_token, String

    # @!attribute scope
    #   The scope of the case to create
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Scope]
    required :scope,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Scope }

    # @!attribute type
    #   Create a case for the transaction
    #
    #   @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Type]
    required :type,
             enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Type }

    # @!attribute explanation
    #   Optional explanation for why this action was taken
    #
    #   @return [String, nil]
    optional :explanation, String

    # @!method initialize(queue_token:, scope:, type:, explanation: nil)
    #   @param queue_token [String] The token of the queue to create the case in
    #
    #   @param scope [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Scope] The scope of the case to create
    #
    #   @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Type] Create a case for the transaction
    #
    #   @param explanation [String] Optional explanation for why this action was taken

    # The scope of the case to create
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction#scope
    module Scope
      extend Lithic::Internal::Type::Enum

      CARD = :CARD
      ACCOUNT = :ACCOUNT

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # Create a case for the transaction
    #
    # @see Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction#type
    module Type
      extend Lithic::Internal::Type::Enum

      CREATE_CASE = :CREATE_CASE

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @!method self.variants
  #   @return [Array(Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::TagAction, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction)]
end