Class: Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction
- Defined in:
- lib/lithic/models/auth_rules/v2_list_results_response.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#explanation ⇒ String?
Optional explanation for why this action was taken.
-
#queue_token ⇒ String
The token of the queue to create the case in.
-
#scope ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Scope
The scope of the case to create.
-
#type ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Type
Create a case for the transaction.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(queue_token:, scope:, type:, explanation: nil) ⇒ Object
|
|
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1045
|
Instance Attribute Details
#explanation ⇒ String?
Optional explanation for why this action was taken
1043 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1043 optional :explanation, String |
#queue_token ⇒ String
The token of the queue to create the case in
1023 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1023 required :queue_token, String |
#scope ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Scope
The scope of the case to create
1029 1030 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1029 required :scope, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Scope } |
#type ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Type
Create a case for the transaction
1036 1037 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1036 required :type, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::CardTransactionUpdateResult::Action::CreateCaseAction::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 1063
|