Class: Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb

Defined Under Namespace

Modules: Action, Mode

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Lithic::Internal::Type::BaseModel

Instance Attribute Details

#auth_rule_tokenString

The Auth Rule token

Returns:

  • (String)


393
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 393

required :auth_rule_token, String

#evaluation_timeTime

Timestamp of the rule evaluation

Returns:

  • (Time)


399
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 399

required :evaluation_time, Time

#event_streamSymbol, :TOKENIZATION

The event stream during which the rule was evaluated

Returns:

  • (Symbol, :TOKENIZATION)


405
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 405

required :event_stream, const: :TOKENIZATION

#event_tokenString

Token of the event that triggered the evaluation

Returns:

  • (String)


411
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 411

required :event_token, String

#modeSymbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Mode

The state of the Auth Rule



417
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 417

required :mode, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Mode }

#rule_versionInteger

Version of the rule that was evaluated

Returns:

  • (Integer)


423
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 423

required :rule_version, Integer

#tokenString

Globally unique identifier for the evaluation

Returns:

  • (String)


380
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 380

required :token, String

#transaction_tokenString?

The token of the transaction that triggered the rule evaluation

Returns:

  • (String, nil)


429
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 429

required :transaction_token, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 584