Module: Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/lithic/models/auth_rules/v2_list_results_response.rb
Defined Under Namespace
Classes: DeclineActionTokenization, RequireTfaAction
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 517
|
Instance Method Details
#initialize(token:, actions:, auth_rule_token:, evaluation_time:, event_token:, mode:, rule_version:, transaction_token:, event_stream: :TOKENIZATION) ⇒ Object
450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 450 module Action extend Lithic::Internal::Type::Union variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization } variant -> { Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction } class DeclineActionTokenization < Lithic::Internal::Type::BaseModel # @!attribute type # Decline the tokenization request # # @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization::Type] required :type, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization::Type } # @!attribute explanation # Optional explanation for why this action was taken # # @return [String, nil] optional :explanation, String # @!attribute reason # Reason code for declining the tokenization request # # @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization::Reason, nil] optional :reason, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization::Reason } # @!method initialize(type:, explanation: nil, reason: nil) # @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization::Type] Decline the tokenization request # # @param explanation [String] Optional explanation for why this action was taken # # @param reason [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization::Reason] Reason code for declining the tokenization request # Decline the tokenization request # # @see Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization#type module Type extend Lithic::Internal::Type::Enum DECLINE = :DECLINE # @!method self.values # @return [Array<Symbol>] end # Reason code for declining the tokenization request # # @see Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization#reason module Reason extend Lithic::Internal::Type::Enum ACCOUNT_SCORE_1 = :ACCOUNT_SCORE_1 DEVICE_SCORE_1 = :DEVICE_SCORE_1 ALL_WALLET_DECLINE_REASONS_PRESENT = :ALL_WALLET_DECLINE_REASONS_PRESENT WALLET_RECOMMENDED_DECISION_RED = :WALLET_RECOMMENDED_DECISION_RED CVC_MISMATCH = :CVC_MISMATCH CARD_EXPIRY_MONTH_MISMATCH = :CARD_EXPIRY_MONTH_MISMATCH CARD_EXPIRY_YEAR_MISMATCH = :CARD_EXPIRY_YEAR_MISMATCH CARD_INVALID_STATE = :CARD_INVALID_STATE CUSTOMER_RED_PATH = :CUSTOMER_RED_PATH INVALID_CUSTOMER_RESPONSE = :INVALID_CUSTOMER_RESPONSE NETWORK_FAILURE = :NETWORK_FAILURE GENERIC_DECLINE = :GENERIC_DECLINE DIGITAL_CARD_ART_REQUIRED = :DIGITAL_CARD_ART_REQUIRED # @!method self.values # @return [Array<Symbol>] end end class RequireTfaAction < Lithic::Internal::Type::BaseModel # @!attribute type # Require two-factor authentication for the tokenization request # # @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction::Type] required :type, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction::Type } # @!attribute explanation # Optional explanation for why this action was taken # # @return [String, nil] optional :explanation, String # @!attribute reason # Reason code for requiring two-factor authentication # # @return [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction::Reason, nil] optional :reason, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction::Reason } # @!method initialize(type:, explanation: nil, reason: nil) # @param type [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction::Type] Require two-factor authentication for the tokenization request # # @param explanation [String] Optional explanation for why this action was taken # # @param reason [Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction::Reason] Reason code for requiring two-factor authentication # Require two-factor authentication for the tokenization request # # @see Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction#type module Type extend Lithic::Internal::Type::Enum REQUIRE_TFA = :REQUIRE_TFA # @!method self.values # @return [Array<Symbol>] end # Reason code for requiring two-factor authentication # # @see Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction#reason module Reason extend Lithic::Internal::Type::Enum WALLET_RECOMMENDED_TFA = :WALLET_RECOMMENDED_TFA SUSPICIOUS_ACTIVITY = :SUSPICIOUS_ACTIVITY DEVICE_RECENTLY_LOST = :DEVICE_RECENTLY_LOST TOO_MANY_RECENT_ATTEMPTS = :TOO_MANY_RECENT_ATTEMPTS TOO_MANY_RECENT_TOKENS = :TOO_MANY_RECENT_TOKENS TOO_MANY_DIFFERENT_CARDHOLDERS = :TOO_MANY_DIFFERENT_CARDHOLDERS OUTSIDE_HOME_TERRITORY = :OUTSIDE_HOME_TERRITORY HAS_SUSPENDED_TOKENS = :HAS_SUSPENDED_TOKENS HIGH_RISK = :HIGH_RISK ACCOUNT_SCORE_LOW = :ACCOUNT_SCORE_LOW DEVICE_SCORE_LOW = :DEVICE_SCORE_LOW CARD_STATE_TFA = :CARD_STATE_TFA HARDCODED_TFA = :HARDCODED_TFA CUSTOMER_RULE_TFA = :CUSTOMER_RULE_TFA DEVICE_HOST_CARD_EMULATION = :DEVICE_HOST_CARD_EMULATION # @!method self.values # @return [Array<Symbol>] end end # @!method self.variants # @return [Array(Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction)] end |