Class: Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_retrieve_features_response.rb

Defined Under Namespace

Modules: Scope Classes: Value

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters:, period:, scope:, value:) ⇒ Object



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/lithic/models/auth_rules/v2_retrieve_features_response.rb', line 26

class Feature < Lithic::Internal::Type::BaseModel
  # @!attribute filters
  #
  #   @return [Lithic::Models::AuthRules::VelocityLimitFilters]
  required :filters, -> { Lithic::AuthRules::VelocityLimitFilters }

  # @!attribute period
  #   Velocity over the current day since 00:00 / 12 AM in Eastern Time
  #
  #   @return [Lithic::Models::AuthRules::VelocityLimitPeriod::TrailingWindowObject, Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowDay, Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowWeek, Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowMonth, Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowYear]
  required :period, union: -> { Lithic::AuthRules::VelocityLimitPeriod }

  # @!attribute scope
  #   The scope the velocity is calculated for
  #
  #   @return [Symbol, Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Scope]
  required :scope, enum: -> { Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Scope }

  # @!attribute value
  #
  #   @return [Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Value]
  required :value, -> { Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Value }

  # @!method initialize(filters:, period:, scope:, value:)
  #   @param filters [Lithic::Models::AuthRules::VelocityLimitFilters]
  #
  #   @param period [Lithic::Models::AuthRules::VelocityLimitPeriod::TrailingWindowObject, Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowDay, Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowWeek, Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowMonth, Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowYear] Velocity over the current day since 00:00 / 12 AM in Eastern Time
  #
  #   @param scope [Symbol, Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Scope] The scope the velocity is calculated for
  #
  #   @param value [Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Value]

  # The scope the velocity is calculated for
  #
  # @see Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature#scope
  module Scope
    extend Lithic::Internal::Type::Enum

    CARD = :CARD
    ACCOUNT = :ACCOUNT

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature#value
  class Value < Lithic::Internal::Type::BaseModel
    # @!attribute amount
    #   Amount (in cents) for the given Auth Rule that is used as input for calculating
    #   the rule. For Velocity Limit rules this would be the calculated Velocity. For
    #   Conditional Rules using CARD*TRANSACTION_COUNT*\* this will be 0
    #
    #   @return [Integer]
    required :amount, Integer

    # @!attribute count
    #   Number of velocity impacting transactions matching the given scope, period and
    #   filters
    #
    #   @return [Integer]
    required :count, Integer

    # @!method initialize(amount:, count:)
    #   Some parameter documentations has been truncated, see
    #   {Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Value} for more
    #   details.
    #
    #   @param amount [Integer] Amount (in cents) for the given Auth Rule that is used as input for calculating
    #
    #   @param count [Integer] Number of velocity impacting transactions matching the given scope, period and f
  end
end

Instance Attribute Details

#filtersLithic::Models::AuthRules::VelocityLimitFilters



30
# File 'lib/lithic/models/auth_rules/v2_retrieve_features_response.rb', line 30

required :filters, -> { Lithic::AuthRules::VelocityLimitFilters }

#scopeSymbol, Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Scope

The scope the velocity is calculated for



42
# File 'lib/lithic/models/auth_rules/v2_retrieve_features_response.rb', line 42

required :scope, enum: -> { Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Scope }

#valueLithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Value



47
# File 'lib/lithic/models/auth_rules/v2_retrieve_features_response.rb', line 47

required :value, -> { Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Value }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_retrieve_features_response.rb', line 67