Class: Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Value

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_retrieve_features_response.rb,
sig/lithic/models/auth_rules/v2_retrieve_features_response.rbs

Overview

See Also:

  • Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature#value

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, count:) ⇒ Value

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2RetrieveFeaturesResponse::Feature::Value for more details.

Parameters:

  • amount (Integer)

    Amount (in cents) for the given Auth Rule that is used as input for calculating

  • count (Integer)

    Number of velocity impacting transactions matching the given scope, period and f

  • amount: (Integer)
  • count: (Integer)


# File 'lib/lithic/models/auth_rules/v2_retrieve_features_response.rb', line 88

Instance Attribute Details

#amountInteger

Amount (in cents) for the given Auth Rule that is used as input for calculating the rule. For Velocity Limit rules this would be the calculated Velocity. For Conditional Rules using CARDTRANSACTION_COUNT* this will be 0

Parameters:

  • value (Integer)

Returns:

  • (Integer)


79
# File 'lib/lithic/models/auth_rules/v2_retrieve_features_response.rb', line 79

required :amount, Integer

#countInteger

Number of velocity impacting transactions matching the given scope, period and filters

Parameters:

  • value (Integer)

Returns:

  • (Integer)


86
# File 'lib/lithic/models/auth_rules/v2_retrieve_features_response.rb', line 86

required :count, Integer

Instance Method Details

#to_hash{ amount: Integer, count: Integer }

Returns:

  • ({ amount: Integer, count: Integer })


76
# File 'sig/lithic/models/auth_rules/v2_retrieve_features_response.rbs', line 76

def to_hash: -> { amount: Integer, count: Integer }