Class: Lithic::Models::AuthRules::V2UpdateParams::Body::AccountLevelRule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_update_params.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_tokens: nil, business_account_tokens: nil, name: nil, state: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2UpdateParams::Body::AccountLevelRule for more details.

Parameters:

  • account_tokens (Array<String>) (defaults to: nil)

    Account tokens to which the Auth Rule applies.

  • business_account_tokens (Array<String>) (defaults to: nil)

    Business Account tokens to which the Auth Rule applies.

  • name (String, nil) (defaults to: nil)

    Auth Rule Name

  • state (Symbol, Lithic::Models::AuthRules::V2UpdateParams::Body::AccountLevelRule::State) (defaults to: nil)

    The desired state of the Auth Rule.



# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 64

Instance Attribute Details

#account_tokensArray<String>?

Account tokens to which the Auth Rule applies.

Returns:

  • (Array<String>, nil)


40
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 40

optional :account_tokens, Lithic::Internal::Type::ArrayOf[String]

#business_account_tokensArray<String>?

Business Account tokens to which the Auth Rule applies.

Returns:

  • (Array<String>, nil)


46
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 46

optional :business_account_tokens, Lithic::Internal::Type::ArrayOf[String]

#nameString?

Auth Rule Name

Returns:

  • (String, nil)


52
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 52

optional :name, String, nil?: true

#stateSymbol, ...

The desired state of the Auth Rule.

Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.



62
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 62

optional :state, enum: -> { Lithic::AuthRules::V2UpdateParams::Body::AccountLevelRule::State }