Module: Lithic::Models::AuthRules::V2UpdateParams::Body::AccountLevelRule::State

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/auth_rules/v2_update_params.rb,
sig/lithic/models/auth_rules/v2_update_params.rbs

Overview

The desired state of the Auth Rule.

Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.

See Also:

  • Lithic::Models::AuthRules::V2UpdateParams::Body::AccountLevelRule#state

Constant Summary collapse

INACTIVE =

Returns:

  • (:INACTIVE)
:INACTIVE

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Lithic::Models::AuthRules::V2UpdateParams::Body::AccountLevelRule::state]

Returns:

  • (::Array[Lithic::Models::AuthRules::V2UpdateParams::Body::AccountLevelRule::state])


85
# File 'sig/lithic/models/auth_rules/v2_update_params.rbs', line 85

def self?.values: -> ::Array[Lithic::Models::AuthRules::V2UpdateParams::Body::AccountLevelRule::state]