Class: Lithic::Models::AuthRules::V2UpdateParams::Body::ProgramLevelRule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_update_params.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(excluded_account_tokens: nil, excluded_business_account_tokens: nil, excluded_card_tokens: nil, name: nil, program_level: nil, state: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2UpdateParams::Body::ProgramLevelRule for more details.

Parameters:

  • excluded_account_tokens (Array<String>) (defaults to: nil)

    Account tokens to which the Auth Rule does not apply.

  • excluded_business_account_tokens (Array<String>) (defaults to: nil)

    Business account tokens to which the Auth Rule does not apply.

  • excluded_card_tokens (Array<String>) (defaults to: nil)

    Card tokens to which the Auth Rule does not apply.

  • name (String, nil) (defaults to: nil)

    Auth Rule Name

  • program_level (Boolean) (defaults to: nil)

    Whether the Auth Rule applies to all authorizations on the card program.

  • state (Symbol, Lithic::Models::AuthRules::V2UpdateParams::Body::ProgramLevelRule::State) (defaults to: nil)

    The desired state of the Auth Rule.



# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 186

Instance Attribute Details

#excluded_account_tokensArray<String>?

Account tokens to which the Auth Rule does not apply.

Returns:

  • (Array<String>, nil)


150
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 150

optional :excluded_account_tokens, Lithic::Internal::Type::ArrayOf[String]

#excluded_business_account_tokensArray<String>?

Business account tokens to which the Auth Rule does not apply.

Returns:

  • (Array<String>, nil)


156
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 156

optional :excluded_business_account_tokens, Lithic::Internal::Type::ArrayOf[String]

#excluded_card_tokensArray<String>?

Card tokens to which the Auth Rule does not apply.

Returns:

  • (Array<String>, nil)


162
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 162

optional :excluded_card_tokens, Lithic::Internal::Type::ArrayOf[String]

#nameString?

Auth Rule Name

Returns:

  • (String, nil)


168
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 168

optional :name, String, nil?: true

#program_levelBoolean?

Whether the Auth Rule applies to all authorizations on the card program.

Returns:

  • (Boolean, nil)


174
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 174

optional :program_level, Lithic::Internal::Type::Boolean

#stateSymbol, ...

The desired state of the Auth Rule.

Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.



184
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 184

optional :state, enum: -> { Lithic::AuthRules::V2UpdateParams::Body::ProgramLevelRule::State }