Module: Lithic::Models::AuthRules::VelocityLimitFilters::IncludePanEntryMode

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/auth_rules/velocity_limit_filters.rb

Constant Summary collapse

AUTO_ENTRY =
:AUTO_ENTRY
BAR_CODE =
:BAR_CODE
CONTACTLESS =
:CONTACTLESS
CREDENTIAL_ON_FILE =
:CREDENTIAL_ON_FILE
ECOMMERCE =
:ECOMMERCE
ERROR_KEYED =
:ERROR_KEYED
ERROR_MAGNETIC_STRIPE =
:ERROR_MAGNETIC_STRIPE
ICC =
:ICC
KEY_ENTERED =
:KEY_ENTERED
MAGNETIC_STRIPE =
:MAGNETIC_STRIPE
MANUAL =
:MANUAL
OCR =
:OCR
SECURE_CARDLESS =
:SECURE_CARDLESS
UNSPECIFIED =
:UNSPECIFIED
UNKNOWN =
:UNKNOWN

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/velocity_limit_filters.rb', line 81

Instance Method Details

#initialize(exclude_countries: nil, exclude_mccs: nil, include_countries: nil, include_mccs: nil, include_pan_entry_modes: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::VelocityLimitFilters for more details.

Parameters:

  • exclude_countries (Array<String>, nil) (defaults to: nil)

    ISO-3166-1 alpha-3 Country Codes to exclude from the velocity calculation. Trans

  • exclude_mccs (Array<String>, nil) (defaults to: nil)

    Merchant Category Codes to exclude from the velocity calculation. Transactions m

  • include_countries (Array<String>, nil) (defaults to: nil)

    ISO-3166-1 alpha-3 Country Codes to include in the velocity calculation. Transac

  • include_mccs (Array<String>, nil) (defaults to: nil)

    Merchant Category Codes to include in the velocity calculation. Transactions not

  • include_pan_entry_modes (Array<Symbol, Lithic::Models::AuthRules::VelocityLimitFilters::IncludePanEntryMode>, nil) (defaults to: nil)

    PAN entry modes to include in the velocity calculation. Transactions not matchin



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/lithic/models/auth_rules/velocity_limit_filters.rb', line 62

module IncludePanEntryMode
  extend Lithic::Internal::Type::Enum

  AUTO_ENTRY = :AUTO_ENTRY
  BAR_CODE = :BAR_CODE
  CONTACTLESS = :CONTACTLESS
  CREDENTIAL_ON_FILE = :CREDENTIAL_ON_FILE
  ECOMMERCE = :ECOMMERCE
  ERROR_KEYED = :ERROR_KEYED
  ERROR_MAGNETIC_STRIPE = :ERROR_MAGNETIC_STRIPE
  ICC = :ICC
  KEY_ENTERED = :KEY_ENTERED
  MAGNETIC_STRIPE = :MAGNETIC_STRIPE
  MANUAL = :MANUAL
  OCR = :OCR
  SECURE_CARDLESS = :SECURE_CARDLESS
  UNSPECIFIED = :UNSPECIFIED
  UNKNOWN = :UNKNOWN

  # @!method self.values
  #   @return [Array<Symbol>]
end