Class: Lithic::Models::AuthRules::VelocityLimitParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/velocity_limit_params.rb

Defined Under Namespace

Modules: Scope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(period:, scope:, filters: nil, limit_amount: nil, limit_count: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::VelocityLimitParams for more details.

Parameters:



# File 'lib/lithic/models/auth_rules/velocity_limit_params.rb', line 42

Instance Attribute Details

#filtersLithic::Models::AuthRules::VelocityLimitFilters?



22
# File 'lib/lithic/models/auth_rules/velocity_limit_params.rb', line 22

optional :filters, -> { Lithic::AuthRules::VelocityLimitFilters }

#limit_amountInteger?

The maximum amount of spend velocity allowed in the period in minor units (the smallest unit of a currency, e.g. cents for USD). Transactions exceeding this limit will be declined.

Returns:

  • (Integer, nil)


30
# File 'lib/lithic/models/auth_rules/velocity_limit_params.rb', line 30

optional :limit_amount, Integer, nil?: true

#limit_countInteger?

The number of spend velocity impacting transactions may not exceed this limit in the period. Transactions exceeding this limit will be declined. A spend velocity impacting transaction is a transaction that has been authorized, and optionally settled, or a force post (a transaction that settled without prior authorization).

Returns:

  • (Integer, nil)


40
# File 'lib/lithic/models/auth_rules/velocity_limit_params.rb', line 40

optional :limit_count, Integer, nil?: true

#scopeSymbol, Lithic::Models::AuthRules::VelocityLimitParams::Scope

The scope the velocity is calculated for



17
# File 'lib/lithic/models/auth_rules/velocity_limit_params.rb', line 17

required :scope, enum: -> { Lithic::AuthRules::VelocityLimitParams::Scope }