Class: Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowYear
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowYear
- Defined in:
- lib/lithic/models/auth_rules/velocity_limit_period.rb,
sig/lithic/models/auth_rules/velocity_limit_period.rbs
Instance Attribute Summary collapse
-
#day_of_month ⇒ Integer?
The day of the month to start from.
-
#month ⇒ Integer?
The month to start from.
- #type ⇒ Symbol, :YEAR
Instance Method Summary collapse
-
#initialize(day_of_month: nil, month: nil, type: :YEAR) ⇒ Object
constructor
Some parameter documentations has been truncated, see FixedWindowYear for more details.
- #to_hash ⇒ { type: :YEAR, day_of_month: Integer, month: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(day_of_month: nil, month: nil, type: :YEAR) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowYear for more details.
Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified
month and day_of_month. This validates the month and day of the year to
start from is a real date. In the event that February 29th is selected, in
non-leap years, the window will start from February 28th.
|
|
# File 'lib/lithic/models/auth_rules/velocity_limit_period.rb', line 132
|
Instance Attribute Details
#day_of_month ⇒ Integer?
The day of the month to start from. Defaults to the 1st of the month if not specified.
123 |
# File 'lib/lithic/models/auth_rules/velocity_limit_period.rb', line 123 optional :day_of_month, Integer |
#month ⇒ Integer?
The month to start from. 1 is January and 12 is December. Defaults to January if not specified.
130 |
# File 'lib/lithic/models/auth_rules/velocity_limit_period.rb', line 130 optional :month, Integer |
#type ⇒ Symbol, :YEAR
116 |
# File 'lib/lithic/models/auth_rules/velocity_limit_period.rb', line 116 required :type, const: :YEAR |
Instance Method Details
#to_hash ⇒ { type: :YEAR, day_of_month: Integer, month: Integer }
84 |
# File 'sig/lithic/models/auth_rules/velocity_limit_period.rbs', line 84
def to_hash: -> { type: :YEAR, day_of_month: Integer, month: Integer }
|