Class: Lithic::Models::BlockchainRecipient

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/blockchain_recipient.rb,
sig/lithic/models/blockchain_recipient.rbs

Overview

See Also:

  • Lithic::Resources::BlockchainRecipients#create

Defined Under Namespace

Modules: State, VerificationState

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, account_token:, address_tag:, chain:, created:, external_id:, name:, owner:, owner_type:, program_id:, state:, updated:, verification_state:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::BlockchainRecipient for more details.

Parameters:

  • token (String)

    A globally unique identifier for this blockchain recipient

  • account_token (String, nil)

    The financial account the blockchain recipient belongs to, or null when the reci

  • address_tag (String, nil)

    An optional tag or memo used by some chains to identify the destination of a tra

  • chain (String)

    The blockchain network that the address belongs to

  • created (Time)

    An ISO 8601 string representing when this blockchain recipient was created

  • external_id (String, nil)

    The identifier the recipient is registered under with the payment provider

  • name (String, nil)

    The nickname for this blockchain recipient

  • owner (String)

    Legal name of the business or individual who owns the blockchain address

  • owner_type (Symbol, Lithic::Models::OwnerType)

    Owner Type

  • program_id (String)

    Globally unique identifier for the program the blockchain recipient is associate

  • state (Symbol, Lithic::Models::BlockchainRecipient::State)

    Account State

  • updated (Time)

    An ISO 8601 string representing when this blockchain recipient was last updated

  • verification_state (Symbol, Lithic::Models::BlockchainRecipient::VerificationState)

    Verification State



# File 'lib/lithic/models/blockchain_recipient.rb', line 88

Instance Attribute Details

#account_tokenString?

The financial account the blockchain recipient belongs to, or null when the recipient is registered against the program rather than a financial account

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


18
# File 'lib/lithic/models/blockchain_recipient.rb', line 18

required :account_token, String, nil?: true

#address_tagString?

An optional tag or memo used by some chains to identify the destination of a transfer within a shared address

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


25
# File 'lib/lithic/models/blockchain_recipient.rb', line 25

required :address_tag, String, nil?: true

#chainString

The blockchain network that the address belongs to

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/lithic/models/blockchain_recipient.rb', line 31

required :chain, String

#createdTime

An ISO 8601 string representing when this blockchain recipient was created

Parameters:

  • value (Time)

Returns:

  • (Time)


37
# File 'lib/lithic/models/blockchain_recipient.rb', line 37

required :created, Time

#external_idString?

The identifier the recipient is registered under with the payment provider

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


43
# File 'lib/lithic/models/blockchain_recipient.rb', line 43

required :external_id, String, nil?: true

#nameString?

The nickname for this blockchain recipient

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


49
# File 'lib/lithic/models/blockchain_recipient.rb', line 49

required :name, String, nil?: true

#ownerString

Legal name of the business or individual who owns the blockchain address

Parameters:

  • value (String)

Returns:

  • (String)


55
# File 'lib/lithic/models/blockchain_recipient.rb', line 55

required :owner, String

#owner_typeSymbol, Lithic::Models::OwnerType

Owner Type

Parameters:

  • value (Lithic::Models::owner_type)

Returns:



61
# File 'lib/lithic/models/blockchain_recipient.rb', line 61

required :owner_type, enum: -> { Lithic::OwnerType }

#program_idString

Globally unique identifier for the program the blockchain recipient is associated with

Parameters:

  • value (String)

Returns:

  • (String)


68
# File 'lib/lithic/models/blockchain_recipient.rb', line 68

required :program_id, String

#stateSymbol, Lithic::Models::BlockchainRecipient::State

Account State

Parameters:

  • value (Lithic::Models::BlockchainRecipient::state)

Returns:



74
# File 'lib/lithic/models/blockchain_recipient.rb', line 74

required :state, enum: -> { Lithic::BlockchainRecipient::State }

#tokenString

A globally unique identifier for this blockchain recipient

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/lithic/models/blockchain_recipient.rb', line 11

required :token, String

#updatedTime

An ISO 8601 string representing when this blockchain recipient was last updated

Parameters:

  • value (Time)

Returns:

  • (Time)


80
# File 'lib/lithic/models/blockchain_recipient.rb', line 80

required :updated, Time

#verification_stateSymbol, Lithic::Models::BlockchainRecipient::VerificationState

Verification State

Parameters:

  • value (Lithic::Models::BlockchainRecipient::verification_state)

Returns:



86
# File 'lib/lithic/models/blockchain_recipient.rb', line 86

required :verification_state, enum: -> { Lithic::BlockchainRecipient::VerificationState }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/blockchain_recipient.rb', line 128

Instance Method Details

#to_hash{

Returns:

  • ({)


63
# File 'sig/lithic/models/blockchain_recipient.rbs', line 63

def to_hash: -> {