Class: Lithic::Models::BlockchainRecipientCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/blockchain_recipient_create_params.rb,
sig/lithic/models/blockchain_recipient_create_params.rbs

Overview

See Also:

  • Lithic::Resources::BlockchainRecipients#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_token:, address:, chain:, owner:, owner_type:, address_tag: nil, name: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::BlockchainRecipientCreateParams for more details.

Parameters:

  • account_token (String)

    The financial account the blockchain recipient belongs to

  • address (String)

    The blockchain address funds will be withdrawn to

  • chain (String)

    The blockchain network that the address belongs to

  • owner (String)

    Legal name of the business or individual who owns the blockchain address

  • owner_type (Symbol, Lithic::Models::OwnerType)

    Owner Type

  • address_tag (String) (defaults to: nil)

    An optional tag or memo used by some chains to identify the destination of a tra

  • name (String) (defaults to: nil)

    The nickname for this blockchain recipient

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 53

Instance Attribute Details

#account_tokenString

The financial account the blockchain recipient belongs to

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 14

required :account_token, String

#addressString

The blockchain address funds will be withdrawn to

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 20

required :address, String

#address_tagString?

An optional tag or memo used by some chains to identify the destination of a transfer within a shared address

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 45

optional :address_tag, String

#chainString

The blockchain network that the address belongs to

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 26

required :chain, String

#nameString?

The nickname for this blockchain recipient

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 51

optional :name, String

#ownerString

Legal name of the business or individual who owns the blockchain address

Parameters:

  • value (String)

Returns:

  • (String)


32
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 32

required :owner, String

#owner_typeSymbol, Lithic::Models::OwnerType

Owner Type

Parameters:

  • value (Lithic::Models::owner_type)

Returns:



38
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 38

required :owner_type, enum: -> { Lithic::OwnerType }

Instance Method Details

#to_hash{

Returns:

  • ({)


48
# File 'sig/lithic/models/blockchain_recipient_create_params.rbs', line 48

def to_hash: -> {