Class: Lithic::Models::BookTransferResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/book_transfer_response.rb,
sig/lithic/models/book_transfer_response.rbs

Overview

See Also:

  • Lithic::Resources::BookTransfers#create

Defined Under Namespace

Modules: Category, Result, Status Classes: Event, TransactionSeries

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, category:, created:, currency:, events:, from_financial_account_token:, pending_amount:, result:, settled_amount:, status:, to_financial_account_token:, updated:, external_id: nil, external_resource: nil, transaction_series: nil, family: :TRANSFER) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::BookTransferResponse for more details.

Book transfer transaction

Parameters:

  • token (String)

    Unique identifier for the transaction

  • category (Symbol, Lithic::Models::BookTransferResponse::Category)
  • created (Time)

    ISO 8601 timestamp of when the transaction was created

  • currency (String)

    3-character alphabetic ISO 4217 code for the settling currency of the transactio

  • events (Array<Lithic::Models::BookTransferResponse::Event>)

    A list of all financial events that have modified this transfer

  • from_financial_account_token (String)

    Globally unique identifier for the financial account or card that will send the

  • pending_amount (Integer)

    Pending amount of the transaction in the currency's smallest unit (e.g., cents),

  • result (Symbol, Lithic::Models::BookTransferResponse::Result)
  • settled_amount (Integer)

    Amount of the transaction that has been settled in the currency's smallest unit

  • status (Symbol, Lithic::Models::BookTransferResponse::Status)

    The status of the transaction

  • to_financial_account_token (String)

    Globally unique identifier for the financial account or card that will receive t

  • updated (Time)

    ISO 8601 timestamp of when the transaction was last updated

  • external_id (String, nil) (defaults to: nil)

    External ID defined by the customer

  • external_resource (Lithic::Models::ExternalResource, nil) (defaults to: nil)

    External resource associated with the management operation

  • transaction_series (Lithic::Models::BookTransferResponse::TransactionSeries, nil) (defaults to: nil)

    A series of transactions that are grouped together

  • family (Symbol, :TRANSFER) (defaults to: :TRANSFER)

    TRANSFER - Book Transfer Transaction



# File 'lib/lithic/models/book_transfer_response.rb', line 109

Instance Attribute Details

#categorySymbol, Lithic::Models::BookTransferResponse::Category

Parameters:

  • value (Lithic::Models::BookTransferResponse::category)

Returns:



16
# File 'lib/lithic/models/book_transfer_response.rb', line 16

required :category, enum: -> { Lithic::BookTransferResponse::Category }

#createdTime

ISO 8601 timestamp of when the transaction was created

Parameters:

  • value (Time)

Returns:

  • (Time)


22
# File 'lib/lithic/models/book_transfer_response.rb', line 22

required :created, Time

#currencyString

3-character alphabetic ISO 4217 code for the settling currency of the transaction

Parameters:

  • value (String)

Returns:

  • (String)


29
# File 'lib/lithic/models/book_transfer_response.rb', line 29

required :currency, String

#eventsArray<Lithic::Models::BookTransferResponse::Event>

A list of all financial events that have modified this transfer

Parameters:

  • value (::Array[Lithic::BookTransferResponse::Event])

Returns:



35
# File 'lib/lithic/models/book_transfer_response.rb', line 35

required :events, -> { Lithic::Internal::Type::ArrayOf[Lithic::BookTransferResponse::Event] }

#external_idString?

External ID defined by the customer

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


95
# File 'lib/lithic/models/book_transfer_response.rb', line 95

optional :external_id, String, nil?: true

#external_resourceLithic::Models::ExternalResource?

External resource associated with the management operation

Parameters:

Returns:



101
# File 'lib/lithic/models/book_transfer_response.rb', line 101

optional :external_resource, -> { Lithic::ExternalResource }, nil?: true

#familySymbol, :TRANSFER

TRANSFER - Book Transfer Transaction

Parameters:

  • value (:TRANSFER)

Returns:

  • (Symbol, :TRANSFER)


41
# File 'lib/lithic/models/book_transfer_response.rb', line 41

required :family, const: :TRANSFER

#from_financial_account_tokenString

Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case

Parameters:

  • value (String)

Returns:

  • (String)


48
# File 'lib/lithic/models/book_transfer_response.rb', line 48

required :from_financial_account_token, String

#pending_amountInteger

Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees.

The value of this field will go to zero over time once the financial transaction is settled.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


58
# File 'lib/lithic/models/book_transfer_response.rb', line 58

required :pending_amount, Integer

#resultSymbol, Lithic::Models::BookTransferResponse::Result

Parameters:

  • value (Lithic::Models::BookTransferResponse::result)

Returns:



63
# File 'lib/lithic/models/book_transfer_response.rb', line 63

required :result, enum: -> { Lithic::BookTransferResponse::Result }

#settled_amountInteger

Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents)

Parameters:

  • value (Integer)

Returns:

  • (Integer)


70
# File 'lib/lithic/models/book_transfer_response.rb', line 70

required :settled_amount, Integer

#statusSymbol, Lithic::Models::BookTransferResponse::Status

The status of the transaction

Parameters:

  • value (Lithic::Models::BookTransferResponse::status)

Returns:



76
# File 'lib/lithic/models/book_transfer_response.rb', line 76

required :status, enum: -> { Lithic::BookTransferResponse::Status }

#to_financial_account_tokenString

Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case

Parameters:

  • value (String)

Returns:

  • (String)


83
# File 'lib/lithic/models/book_transfer_response.rb', line 83

required :to_financial_account_token, String

#tokenString

Unique identifier for the transaction

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/lithic/models/book_transfer_response.rb', line 11

required :token, String

#transaction_seriesLithic::Models::BookTransferResponse::TransactionSeries?

A series of transactions that are grouped together

Parameters:

  • value (Lithic::BookTransferResponse::TransactionSeries, nil)

Returns:



107
# File 'lib/lithic/models/book_transfer_response.rb', line 107

optional :transaction_series, -> { Lithic::BookTransferResponse::TransactionSeries }, nil?: true

#updatedTime

ISO 8601 timestamp of when the transaction was last updated

Parameters:

  • value (Time)

Returns:

  • (Time)


89
# File 'lib/lithic/models/book_transfer_response.rb', line 89

required :updated, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/book_transfer_response.rb', line 161

Instance Method Details

#to_hash{

Returns:

  • ({)


75
# File 'sig/lithic/models/book_transfer_response.rbs', line 75

def to_hash: -> {