Class: Lithic::Models::BookTransferResponse::Event
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::BookTransferResponse::Event
- Defined in:
- lib/lithic/models/book_transfer_response.rb,
sig/lithic/models/book_transfer_response.rbs
Defined Under Namespace
Modules: DetailedResult, Result, Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
#created ⇒ Time
Date and time when the financial event occurred.
- #detailed_results ⇒ Array<Symbol, Lithic::Models::BookTransferResponse::Event::DetailedResult>
-
#memo ⇒ String
Memo for the transfer.
-
#result ⇒ Symbol, Lithic::Models::BookTransferResponse::Event::Result
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
#subtype ⇒ String
The program specific subtype code for the specified category/type.
-
#token ⇒ String
Globally unique identifier.
-
#type ⇒ Symbol, Lithic::Models::BookTransferResponse::Event::Type
Type of the book transfer.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
152 |
# File 'sig/lithic/models/book_transfer_response.rbs', line 152
def initialize: (
|
Instance Attribute Details
#amount ⇒ Integer
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
178 |
# File 'lib/lithic/models/book_transfer_response.rb', line 178 required :amount, Integer |
#created ⇒ Time
Date and time when the financial event occurred. UTC time zone.
184 |
# File 'lib/lithic/models/book_transfer_response.rb', line 184 required :created, Time |
#detailed_results ⇒ Array<Symbol, Lithic::Models::BookTransferResponse::Event::DetailedResult>
189 190 |
# File 'lib/lithic/models/book_transfer_response.rb', line 189 required :detailed_results, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::BookTransferResponse::Event::DetailedResult] } |
#memo ⇒ String
Memo for the transfer.
196 |
# File 'lib/lithic/models/book_transfer_response.rb', line 196 required :memo, String |
#result ⇒ Symbol, Lithic::Models::BookTransferResponse::Event::Result
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
203 |
# File 'lib/lithic/models/book_transfer_response.rb', line 203 required :result, enum: -> { Lithic::BookTransferResponse::Event::Result } |
#subtype ⇒ String
The program specific subtype code for the specified category/type.
209 |
# File 'lib/lithic/models/book_transfer_response.rb', line 209 required :subtype, String |
#token ⇒ String
Globally unique identifier.
171 |
# File 'lib/lithic/models/book_transfer_response.rb', line 171 required :token, String |
#type ⇒ Symbol, Lithic::Models::BookTransferResponse::Event::Type
Type of the book transfer
215 |
# File 'lib/lithic/models/book_transfer_response.rb', line 215 required :type, enum: -> { Lithic::BookTransferResponse::Event::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/book_transfer_response.rb', line 245
|
Instance Method Details
#to_hash ⇒ {
163 |
# File 'sig/lithic/models/book_transfer_response.rbs', line 163
def to_hash: -> {
|