Class: Lithic::Models::CardAuthorization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs

Defined Under Namespace

Modules: AccountType, Network, Status, TransactionInitiator Classes: Amounts, Avs, Card, FleetInfo, LatestChallenge, Merchant, NameValidation, NetworkSpecificData, Pos, ServiceLocation

Constant Summary collapse

Lithic =

Returns:

  • (:CardholderAuthentication)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(business_application_identifier: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardAuthorization::NetworkSpecificData::Visa for more details.

Parameters:

  • business_application_identifier (String, nil) (defaults to: nil)

    Identifies the purpose or category of a transaction, used to classify and proces



# File 'lib/lithic/models/card_authorization.rb', line 245

Instance Attribute Details

#account_typeSymbol, ...



156
# File 'lib/lithic/models/card_authorization.rb', line 156

optional :account_type, enum: -> { Lithic::CardAuthorization::AccountType }

#acquirer_feeInteger

Fee (in cents) assessed by the merchant and paid for by the cardholder. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


18
# File 'lib/lithic/models/card_authorization.rb', line 18

required :acquirer_fee, Integer

#amountInteger

Deprecated.

Deprecated, use amounts. Authorization amount of the transaction (in cents), including any acquirer fees. The contents of this field are identical to authorization_amount.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


28
# File 'lib/lithic/models/card_authorization.rb', line 28

required :amount, Integer

#amountsLithic::Models::CardAuthorization::Amounts

Structured amounts for this authorization. The cardholder and merchant amounts reflect the original network authorization values. For programs with hold adjustments enabled (e.g., automated fuel dispensers or tipping MCCs), the hold amount may exceed the cardholder and merchant amounts to account for anticipated final transaction amounts such as tips or fuel fill-ups

Parameters:

  • value (Lithic::CardAuthorization::Amounts)

Returns:



38
# File 'lib/lithic/models/card_authorization.rb', line 38

required :amounts, -> { Lithic::CardAuthorization::Amounts }

#authorization_amountInteger

Deprecated.

Deprecated, use amounts. The base transaction amount (in cents) plus the acquirer fee field. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


48
# File 'lib/lithic/models/card_authorization.rb', line 48

required :authorization_amount, Integer

#avsLithic::Models::CardAuthorization::Avs

Parameters:

  • value (Lithic::CardAuthorization::Avs)

Returns:



53
# File 'lib/lithic/models/card_authorization.rb', line 53

required :avs, -> { Lithic::CardAuthorization::Avs }

#cardLithic::Models::CardAuthorization::Card

Card object in ASA

Parameters:

  • value (Lithic::CardAuthorization::Card)

Returns:



59
# File 'lib/lithic/models/card_authorization.rb', line 59

required :card, -> { Lithic::CardAuthorization::Card }

#cardholder_authenticationLithic::Models::CardholderAuthentication?



161
# File 'lib/lithic/models/card_authorization.rb', line 161

optional :cardholder_authentication, -> { Lithic::CardholderAuthentication }

#cardholder_currencyString

Deprecated.

Deprecated, use amounts. 3-character alphabetic ISO 4217 code for cardholder's billing currency.

Parameters:

  • value (String)

Returns:

  • (String)


68
# File 'lib/lithic/models/card_authorization.rb', line 68

required :cardholder_currency, String

#cash_amountInteger

The amount of cash requested by the cardholder, in the cardholder billing currency's smallest unit. For purchase-with-cashback transactions this is the cashback portion only; for ATM transactions this is the full amount. This amount includes all acquirer fees.

If no cash was requested, the value of this field will be 0, and the field will always be present.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


80
# File 'lib/lithic/models/card_authorization.rb', line 80

required :cash_amount, Integer

#cashbackInteger?

Deprecated, use cash_amount.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


167
# File 'lib/lithic/models/card_authorization.rb', line 167

optional :cashback, Integer

#conversion_rateFloat?

Deprecated.

Deprecated, use amounts. If the transaction was requested in a currency other than the settlement currency, this field will be populated to indicate the rate used to translate the merchant_amount to the amount (i.e., merchant_amount x conversion_rate = amount). Note that the merchant_amount is in the local currency and the amount is in the settlement currency.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


179
# File 'lib/lithic/models/card_authorization.rb', line 179

optional :conversion_rate, Float

#createdTime

Date and time when the transaction first occurred in UTC.

Parameters:

  • value (Time)

Returns:

  • (Time)


86
# File 'lib/lithic/models/card_authorization.rb', line 86

required :created, Time

#event_tokenString?

The event token associated with the authorization. This field is only set for programs enrolled into the beta.

Parameters:

  • (String)

Returns:

  • (String, nil)


186
# File 'lib/lithic/models/card_authorization.rb', line 186

optional :event_token, String

#fleet_infoLithic::Models::CardAuthorization::FleetInfo?

Optional Object containing information if the Card is a part of a Fleet managed program

Parameters:

  • value (Lithic::CardAuthorization::FleetInfo, nil)

Returns:



193
# File 'lib/lithic/models/card_authorization.rb', line 193

optional :fleet_info, -> { Lithic::CardAuthorization::FleetInfo }, nil?: true

#latest_challengeLithic::Models::CardAuthorization::LatestChallenge?

The latest Authorization Challenge that was issued to the cardholder for this merchant.



200
# File 'lib/lithic/models/card_authorization.rb', line 200

optional :latest_challenge, -> { Lithic::CardAuthorization::LatestChallenge }

#merchantLithic::Models::CardAuthorization::Merchant

Merchant information including full location details.

Parameters:

  • value (Lithic::CardAuthorization::Merchant)

Returns:



92
# File 'lib/lithic/models/card_authorization.rb', line 92

required :merchant, -> { Lithic::CardAuthorization::Merchant }

#merchant_amountInteger

Deprecated.

Deprecated, use amounts. The amount that the merchant will receive, denominated in merchant_currency and in the smallest currency unit. Note the amount includes acquirer_fee, similar to authorization_amount. It will be different from authorization_amount if the merchant is taking payment in a different currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


104
# File 'lib/lithic/models/card_authorization.rb', line 104

required :merchant_amount, Integer

#merchant_currencyString

Deprecated.

3-character alphabetic ISO 4217 code for the local currency of the transaction.

Parameters:

  • value (String)

Returns:

  • (String)


112
# File 'lib/lithic/models/card_authorization.rb', line 112

required :merchant_currency, String

#name_validationLithic::Models::CardAuthorization::NameValidation?

Network name validation data, present when the card network requested name validation for this transaction. Contains the cardholder name provided by the network and Lithic's computed match result against KYC data on file.

Parameters:

  • value (Lithic::CardAuthorization::NameValidation, nil)

Returns:



120
# File 'lib/lithic/models/card_authorization.rb', line 120

required :name_validation, -> { Lithic::CardAuthorization::NameValidation }, nil?: true

#networkSymbol, ...

Card network of the authorization.



206
# File 'lib/lithic/models/card_authorization.rb', line 206

optional :network, enum: -> { Lithic::CardAuthorization::Network }

#network_risk_scoreInteger?

Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


216
# File 'lib/lithic/models/card_authorization.rb', line 216

optional :network_risk_score, Integer, nil?: true

#network_specific_dataLithic::Models::CardAuthorization::NetworkSpecificData?

Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.

Parameters:

  • value (Lithic::CardAuthorization::NetworkSpecificData, nil)

Returns:



227
# File 'lib/lithic/models/card_authorization.rb', line 227

optional :network_specific_data, -> { Lithic::CardAuthorization::NetworkSpecificData }, nil?: true

#posLithic::Models::CardAuthorization::Pos?



232
# File 'lib/lithic/models/card_authorization.rb', line 232

optional :pos, -> { Lithic::CardAuthorization::Pos }

#service_locationLithic::Models::CardAuthorization::ServiceLocation?

Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.

Parameters:

  • value (Lithic::CardAuthorization::ServiceLocation, nil)

Returns:



128
# File 'lib/lithic/models/card_authorization.rb', line 128

required :service_location, -> { Lithic::CardAuthorization::ServiceLocation }, nil?: true

#settled_amountInteger

Deprecated.

Deprecated, use amounts. Amount (in cents) of the transaction that has been settled, including any acquirer fees.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


137
# File 'lib/lithic/models/card_authorization.rb', line 137

required :settled_amount, Integer

#statusSymbol, Lithic::Models::CardAuthorization::Status

The type of authorization request that this request is for. Note that CREDIT_AUTHORIZATION and FINANCIAL_CREDIT_AUTHORIZATION is only available to users with credit decisioning via ASA enabled.

Parameters:

  • value (Lithic::Models::CardAuthorization::status)

Returns:



145
# File 'lib/lithic/models/card_authorization.rb', line 145

required :status, enum: -> { Lithic::CardAuthorization::Status }

#tokenString

The provisional transaction group uuid associated with the authorization

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/lithic/models/card_authorization.rb', line 10

required :token, String

#token_infoLithic::Models::TokenInfo?

Parameters:

Returns:



237
# File 'lib/lithic/models/card_authorization.rb', line 237

optional :token_info, -> { Lithic::TokenInfo }, nil?: true

#transaction_initiatorSymbol, Lithic::Models::CardAuthorization::TransactionInitiator

The entity that initiated the transaction.

Parameters:

  • value (Lithic::Models::CardAuthorization::transaction_initiator)

Returns:



151
# File 'lib/lithic/models/card_authorization.rb', line 151

required :transaction_initiator, enum: -> { Lithic::CardAuthorization::TransactionInitiator }

#ttlTime?

Deprecated: approximate time-to-live for the authorization.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


243
# File 'lib/lithic/models/card_authorization.rb', line 243

optional :ttl, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/card_authorization.rb', line 484

Instance Method Details

#to_hash{

Returns:

  • ({)


163
# File 'sig/lithic/models/card_authorization.rbs', line 163

def to_hash: -> {