Class: Lithic::Models::CardAuthorization::Amounts::Settlement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorization::Amounts::Settlement
- Defined in:
- lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Amount in the smallest unit of the applicable currency (e.g., cents).
-
#currency ⇒ String
3-character alphabetic ISO 4217 currency.
Instance Method Summary collapse
-
#initialize ⇒ Settlement
constructor
A new instance of Settlement.
- #to_hash ⇒ { amount: Integer, currency: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Settlement
Returns a new instance of Settlement.
282 |
# File 'sig/lithic/models/card_authorization.rbs', line 282
def initialize: (amount: Integer, currency: String) -> void
|
Instance Attribute Details
#amount ⇒ Integer
Amount in the smallest unit of the applicable currency (e.g., cents)
421 |
# File 'lib/lithic/models/card_authorization.rb', line 421 required :amount, Integer |
#currency ⇒ String
3-character alphabetic ISO 4217 currency
427 |
# File 'lib/lithic/models/card_authorization.rb', line 427 required :currency, String |
Instance Method Details
#to_hash ⇒ { amount: Integer, currency: String }
284 |
# File 'sig/lithic/models/card_authorization.rbs', line 284
def to_hash: -> { amount: Integer, currency: String }
|