Class: Lithic::Models::CardAuthorization::Card
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorization::Card
- Defined in:
- lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs
Overview
Defined Under Namespace
Modules: SpendLimitDuration, State, Type
Instance Attribute Summary collapse
-
#last_four ⇒ String
Last four digits of the card number.
-
#memo ⇒ String
Customizable name to identify the card.
-
#spend_limit ⇒ Integer
Amount (in cents) to limit approved authorizations.
-
#spend_limit_duration ⇒ Symbol, Lithic::Models::CardAuthorization::Card::SpendLimitDuration
Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
- #state ⇒ Symbol, Lithic::Models::CardAuthorization::Card::State
-
#token ⇒ String
Globally unique identifier for the card.
- #type ⇒ Symbol, Lithic::Models::CardAuthorization::Card::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, last_four:, memo:, spend_limit:, spend_limit_duration:, state:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Card for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, last_four:, memo:, spend_limit:, spend_limit_duration:, state:, type:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardAuthorization::Card for more details.
Card object in ASA
|
|
# File 'lib/lithic/models/card_authorization.rb', line 540
|
Instance Attribute Details
#last_four ⇒ String
Last four digits of the card number
501 |
# File 'lib/lithic/models/card_authorization.rb', line 501 required :last_four, String |
#memo ⇒ String
Customizable name to identify the card
507 |
# File 'lib/lithic/models/card_authorization.rb', line 507 required :memo, String |
#spend_limit ⇒ Integer
Amount (in cents) to limit approved authorizations. Purchase requests above the spend limit will be declined (refunds and credits will be approved).
Note that while spend limits are enforced based on authorized and settled volume on a card, they are not recommended to be used for balance or reconciliation-level accuracy. Spend limits also cannot block force posted charges (i.e., when a merchant sends a clearing message without a prior authorization).
520 |
# File 'lib/lithic/models/card_authorization.rb', line 520 required :spend_limit, Integer |
#spend_limit_duration ⇒ Symbol, Lithic::Models::CardAuthorization::Card::SpendLimitDuration
Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
528 |
# File 'lib/lithic/models/card_authorization.rb', line 528 required :spend_limit_duration, enum: -> { Lithic::CardAuthorization::Card::SpendLimitDuration } |
#state ⇒ Symbol, Lithic::Models::CardAuthorization::Card::State
533 |
# File 'lib/lithic/models/card_authorization.rb', line 533 required :state, enum: -> { Lithic::CardAuthorization::Card::State } |
#token ⇒ String
Globally unique identifier for the card.
495 |
# File 'lib/lithic/models/card_authorization.rb', line 495 required :token, String |
#type ⇒ Symbol, Lithic::Models::CardAuthorization::Card::Type
538 |
# File 'lib/lithic/models/card_authorization.rb', line 538 required :type, enum: -> { Lithic::CardAuthorization::Card::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/card_authorization.rb', line 573
|
Instance Method Details
#to_hash ⇒ {
370 |
# File 'sig/lithic/models/card_authorization.rbs', line 370
def to_hash: -> {
|