Module: Lithic::Models::CardAuthorization::Card::SpendLimitDuration
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs
Overview
Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
Constant Summary collapse
- ANNUALLY =
:ANNUALLY- FOREVER =
:FOREVER- MONTHLY =
:MONTHLY- TRANSACTION =
:TRANSACTION
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::CardAuthorization::Card::spend_limit_duration]
391 |
# File 'sig/lithic/models/card_authorization.rbs', line 391
def self?.values: -> ::Array[Lithic::Models::CardAuthorization::Card::spend_limit_duration]
|