Class: Lithic::Models::CardAuthorization::LatestChallenge

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs

Overview

See Also:

  • Lithic::Models::CardAuthorization#latest_challenge

Defined Under Namespace

Modules: Method, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, created:, method_:, phone_number:, status:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardAuthorization::LatestChallenge for more details.

The latest Authorization Challenge that was issued to the cardholder for this merchant.

Parameters:



# File 'lib/lithic/models/card_authorization.rb', line 936

Instance Attribute Details

#completed_atTime?

The date and time when the Authorization Challenge was completed in UTC. Filled only if the challenge has been completed.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


900
# File 'lib/lithic/models/card_authorization.rb', line 900

required :completed_at, Time, nil?: true

#createdTime

The date and time when the Authorization Challenge was created in UTC

Parameters:

  • value (Time)

Returns:

  • (Time)


906
# File 'lib/lithic/models/card_authorization.rb', line 906

required :created, Time

#method_Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Method

The method used to deliver the challenge to the cardholder

  • SMS - Challenge was delivered via SMS
  • OUT_OF_BAND - Challenge was delivered via an out-of-band method

Parameters:

  • value (Lithic::Models::CardAuthorization::LatestChallenge::method_)

Returns:



915
# File 'lib/lithic/models/card_authorization.rb', line 915

required :method_, enum: -> { Lithic::CardAuthorization::LatestChallenge::Method }, api_name: :method

#phone_numberString?

The phone number used for sending the Authorization Challenge. Present only when the challenge method is SMS.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


922
# File 'lib/lithic/models/card_authorization.rb', line 922

required :phone_number, String, nil?: true

#statusSymbol, Lithic::Models::CardAuthorization::LatestChallenge::Status

The status of the Authorization Challenge

  • COMPLETED - Challenge was successfully completed by the cardholder
  • DECLINED - Challenge was declined by the cardholder
  • PENDING - Challenge is still open
  • EXPIRED - Challenge has expired without being completed
  • ERROR - There was an error processing the challenge

Parameters:

  • value (Lithic::Models::CardAuthorization::LatestChallenge::status)

Returns:



934
# File 'lib/lithic/models/card_authorization.rb', line 934

required :status, enum: -> { Lithic::CardAuthorization::LatestChallenge::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/card_authorization.rb', line 965

Instance Method Details

#to_hash{

Returns:

  • ({)


688
# File 'sig/lithic/models/card_authorization.rbs', line 688

def to_hash: -> {