Class: Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent
- Inherits:
-
CardAuthorization
- Object
- Internal::Type::BaseModel
- CardAuthorization
- Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent
- Defined in:
- lib/lithic/models/card_authorization_approval_request_webhook_event.rb
Instance Attribute Summary collapse
Attributes inherited from CardAuthorization
#account_type, #acquirer_fee, #amount, #amounts, #authorization_amount, #avs, #card, #cardholder_authentication, #cardholder_currency, #cash_amount, #cashback, #conversion_rate, #created, #event_token, #fleet_info, #latest_challenge, #merchant, #merchant_amount, #merchant_currency, #network, #network_risk_score, #network_specific_data, #pos, #service_location, #settled_amount, #status, #token, #token_info, #transaction_initiator, #ttl
Instance Method Summary collapse
-
#initialize(event_type: :"card_authorization.approval_request") ⇒ Object
constructor
The Auth Stream Access request payload that was sent to the ASA responder.
Methods inherited from CardAuthorization
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_type: :"card_authorization.approval_request") ⇒ Object
The Auth Stream Access request payload that was sent to the ASA responder.
|
|
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 11
|
Instance Attribute Details
#event_type ⇒ Symbol, :"card_authorization.approval_request"
9 |
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 9 required :event_type, const: :"card_authorization.approval_request" |