Class: Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Avs
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Avs
- Defined in:
- lib/lithic/models/card_authorization_approval_request_webhook_event.rb
Overview
Defined Under Namespace
Modules: AddressOnFileMatch
Instance Attribute Summary collapse
-
#address ⇒ String
Cardholder address.
-
#address_on_file_match ⇒ Symbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Avs::AddressOnFileMatch
Lithic’s evaluation result comparing the transaction’s address data with the cardholder KYC data if it exists.
-
#zipcode ⇒ String
Cardholder ZIP code.
Instance Method Summary collapse
-
#initialize(address:, address_on_file_match:, zipcode:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Avs for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address:, address_on_file_match:, zipcode:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Avs for more details.
|
|
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 461
|
Instance Attribute Details
#address ⇒ String
Cardholder address
443 |
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 443 required :address, String |
#address_on_file_match ⇒ Symbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Avs::AddressOnFileMatch
Lithic’s evaluation result comparing the transaction’s address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
452 453 |
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 452 required :address_on_file_match, enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Avs::AddressOnFileMatch } |
#zipcode ⇒ String
Cardholder ZIP code
459 |
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 459 required :zipcode, String |