Class: Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Card

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/card_authorization_approval_request_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: SpendLimitDuration, State, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, last_four:, memo:, spend_limit:, spend_limit_duration:, state:, type:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Card for more details.

Card object in ASA

Parameters:



# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 544

Instance Attribute Details

#last_fourString

Last four digits of the card number

Returns:

  • (String)


504
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 504

required :last_four, String

#memoString

Customizable name to identify the card

Returns:

  • (String)


510
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 510

required :memo, String

#spend_limitInteger

Amount (in cents) to limit approved authorizations. Purchase requests above the spend limit will be declined (refunds and credits will be approved).

Note that while spend limits are enforced based on authorized and settled volume on a card, they are not recommended to be used for balance or reconciliation-level accuracy. Spend limits also cannot block force posted charges (i.e., when a merchant sends a clearing message without a prior authorization).

Returns:

  • (Integer)


523
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 523

required :spend_limit, Integer

#spend_limit_durationSymbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Card::SpendLimitDuration

Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.



531
532
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 531

required :spend_limit_duration,
enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Card::SpendLimitDuration }

#stateSymbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Card::State



537
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 537

required :state, enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Card::State }

#tokenString

Globally unique identifier for the card.

Returns:

  • (String)


498
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 498

required :token, String

#typeSymbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Card::Type



542
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 542

required :type, enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Card::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 578