Class: Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::FleetInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/card_authorization_approval_request_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: FleetPromptCode, FleetRestrictionCode

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(fleet_prompt_code:, fleet_restriction_code:, driver_number: nil, vehicle_number: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::FleetInfo for more details.

Optional Object containing information if the Card is a part of a Fleet managed program

Parameters:



# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 765

Instance Attribute Details

#driver_numberString?

Number representing the driver

Returns:

  • (String, nil)


757
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 757

optional :driver_number, String, nil?: true

#fleet_prompt_codeSymbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::FleetInfo::FleetPromptCode

Code indicating what the driver was prompted to enter at time of purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis



741
742
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 741

required :fleet_prompt_code,
enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::FleetInfo::FleetPromptCode }

#fleet_restriction_codeSymbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::FleetInfo::FleetRestrictionCode

Code indicating which restrictions, if any, there are on purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis



750
751
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 750

required :fleet_restriction_code,
enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::FleetInfo::FleetRestrictionCode }

#vehicle_numberString?

Number associated with the vehicle

Returns:

  • (String, nil)


763
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 763

optional :vehicle_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 793