Class: Lithic::Models::CardAuthorizationChallengeWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorizationChallengeWebhookEvent
- Defined in:
- lib/lithic/models/card_authorization_challenge_webhook_event.rb
Defined Under Namespace
Classes: Challenge
Instance Attribute Summary collapse
-
#authorization ⇒ Lithic::Models::CardAuthorization
The authorization that triggered the challenge.
-
#challenge ⇒ Lithic::Models::CardAuthorizationChallengeWebhookEvent::Challenge
Details of the Authorization Challenge issued during card authorization.
-
#event_type ⇒ Symbol, :"card_authorization.challenge"
The type of event that occurred.
Instance Method Summary collapse
- #initialize(authorization:, challenge:, event_type: :"card_authorization.challenge") ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization:, challenge:, event_type: :"card_authorization.challenge") ⇒ Object
|
|
# File 'lib/lithic/models/card_authorization_challenge_webhook_event.rb', line 24
|
Instance Attribute Details
#authorization ⇒ Lithic::Models::CardAuthorization
The authorization that triggered the challenge
10 |
# File 'lib/lithic/models/card_authorization_challenge_webhook_event.rb', line 10 required :authorization, -> { Lithic::CardAuthorization } |
#challenge ⇒ Lithic::Models::CardAuthorizationChallengeWebhookEvent::Challenge
Details of the Authorization Challenge issued during card authorization
16 |
# File 'lib/lithic/models/card_authorization_challenge_webhook_event.rb', line 16 required :challenge, -> { Lithic::CardAuthorizationChallengeWebhookEvent::Challenge } |
#event_type ⇒ Symbol, :"card_authorization.challenge"
The type of event that occurred.
22 |
# File 'lib/lithic/models/card_authorization_challenge_webhook_event.rb', line 22 required :event_type, const: :"card_authorization.challenge" |