Class: Lithic::Models::CardConvertPhysicalParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardConvertPhysicalParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/card_convert_physical_params.rb,
sig/lithic/models/card_convert_physical_params.rbs
Overview
Defined Under Namespace
Modules: ShippingMethod
Instance Attribute Summary collapse
- #card_token ⇒ String
-
#carrier ⇒ Lithic::Models::Carrier?
If omitted, the previous carrier will be used.
-
#product_id ⇒ String?
Specifies the configuration (e.g. physical card art) that the card should be manufactured with, and only applies to cards of type
PHYSICAL. -
#shipping_address ⇒ Lithic::Models::ShippingAddress
The shipping address this card will be sent to.
-
#shipping_method ⇒ Symbol, ...
Shipping method for the card.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(card_token:, shipping_address:, carrier: nil, product_id: nil, shipping_method: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardConvertPhysicalParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(card_token:, shipping_address:, carrier: nil, product_id: nil, shipping_method: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardConvertPhysicalParams for more details.
|
|
# File 'lib/lithic/models/card_convert_physical_params.rb', line 56
|
Instance Attribute Details
#card_token ⇒ String
13 |
# File 'lib/lithic/models/card_convert_physical_params.rb', line 13 required :card_token, String |
#carrier ⇒ Lithic::Models::Carrier?
If omitted, the previous carrier will be used.
25 |
# File 'lib/lithic/models/card_convert_physical_params.rb', line 25 optional :carrier, -> { Lithic::Carrier } |
#product_id ⇒ String?
Specifies the configuration (e.g. physical card art) that the card should be
manufactured with, and only applies to cards of type PHYSICAL. This must be
configured with Lithic before use.
33 |
# File 'lib/lithic/models/card_convert_physical_params.rb', line 33 optional :product_id, String |
#shipping_address ⇒ Lithic::Models::ShippingAddress
The shipping address this card will be sent to.
19 |
# File 'lib/lithic/models/card_convert_physical_params.rb', line 19 required :shipping_address, -> { Lithic::ShippingAddress } |
#shipping_method ⇒ Symbol, ...
Shipping method for the card. Only applies to cards of type PHYSICAL. Use of
options besides STANDARD require additional permissions.
STANDARD- USPS regular mail or similar international option, with no trackingSTANDARD_WITH_TRACKING- USPS regular mail or similar international option, with trackingPRIORITY- USPS Priority, 1-3 day shipping, with trackingEXPRESS- FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking2_DAY- FedEx or UPS depending on card manufacturer, 2-day shipping, with trackingEXPEDITED- FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with trackingBULK- Card will be shipped as part of a bulk fulfillment order. The shipping method and timeline are inherited from the parent bulk order.
54 |
# File 'lib/lithic/models/card_convert_physical_params.rb', line 54 optional :shipping_method, enum: -> { Lithic::CardConvertPhysicalParams::ShippingMethod } |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/lithic/models/card_convert_physical_params.rbs', line 44
def to_hash: -> {
|