Class: Lithic::Models::CardCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/card_create_params.rb,
sig/lithic/models/card_create_params.rbs
Overview
Defined Under Namespace
Modules: ReplacementSubstatus, ShippingMethod, State, Type
Constant Summary collapse
- Lithic =
Instance Attribute Summary collapse
-
#account_token ⇒ String?
Globally unique identifier for the account that the card will be associated with.
-
#bulk_order_token ⇒ String?
Globally unique identifier for an existing bulk order to associate this card with.
-
#card_program_token ⇒ String?
For card programs with more than one BIN range.
- #carrier ⇒ Lithic::Models::Carrier?
-
#digital_card_art_token ⇒ String?
Specifies the digital card art to be displayed in the user’s digital wallet after tokenization.
-
#exp_month ⇒ String?
Two digit (MM) expiry month.
-
#exp_year ⇒ String?
Four digit (yyyy) expiry year.
- #idempotency_key ⇒ String?
-
#memo ⇒ String?
Friendly name to identify the card.
-
#pin ⇒ String?
Encrypted PIN block (in base64).
-
#product_id ⇒ String?
Only applicable to cards of type
PHYSICAL. -
#replacement_account_token ⇒ String?
Restricted field limited to select use cases.
-
#replacement_comment ⇒ String?
Additional context or information related to the card that this card will replace.
-
#replacement_for ⇒ String?
Globally unique identifier for the card that this card will replace.
-
#replacement_substatus ⇒ Symbol, ...
Card state substatus values for the card that this card will replace:.
- #shipping_address ⇒ Lithic::Models::ShippingAddress?
-
#shipping_method ⇒ Symbol, ...
Shipping method for the card.
-
#spend_limit ⇒ Integer?
Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit).
-
#spend_limit_duration ⇒ Symbol, ...
Spend limit duration values:.
-
#state ⇒ Symbol, ...
Card state values:.
-
#type ⇒ Symbol, Lithic::Models::CardCreateParams::Type
Card types:.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, account_token: nil, bulk_order_token: nil, card_program_token: nil, carrier: nil, digital_card_art_token: nil, exp_month: nil, exp_year: nil, memo: nil, pin: nil, product_id: nil, replacement_account_token: nil, replacement_comment: nil, replacement_for: nil, replacement_substatus: nil, shipping_address: nil, shipping_method: nil, spend_limit: nil, spend_limit_duration: nil, state: nil, idempotency_key: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, account_token: nil, bulk_order_token: nil, card_program_token: nil, carrier: nil, digital_card_art_token: nil, exp_month: nil, exp_year: nil, memo: nil, pin: nil, product_id: nil, replacement_account_token: nil, replacement_comment: nil, replacement_for: nil, replacement_substatus: nil, shipping_address: nil, shipping_method: nil, spend_limit: nil, spend_limit_duration: nil, state: nil, idempotency_key: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardCreateParams for more details.
|
|
# File 'lib/lithic/models/card_create_params.rb', line 237
|
Instance Attribute Details
#account_token ⇒ String?
Globally unique identifier for the account that the card will be associated with. Required for programs enrolling users using the /account_holders endpoint. See Managing Your Program for more information.
38 |
# File 'lib/lithic/models/card_create_params.rb', line 38 optional :account_token, String |
#bulk_order_token ⇒ String?
Globally unique identifier for an existing bulk order to associate this card with. When specified, the card will be added to the bulk order for batch shipment. Only applicable to cards of type PHYSICAL
46 |
# File 'lib/lithic/models/card_create_params.rb', line 46 optional :bulk_order_token, String |
#card_program_token ⇒ String?
For card programs with more than one BIN range. This must be configured with
Lithic before use. Identifies the card program/BIN range under which to create
the card. If omitted, will utilize the program's default card_program_token.
In Sandbox, use 00000000-0000-0000-1000-000000000000 and
00000000-0000-0000-2000-000000000000 to test creating cards on specific card
programs.
57 |
# File 'lib/lithic/models/card_create_params.rb', line 57 optional :card_program_token, String |
#carrier ⇒ Lithic::Models::Carrier?
62 |
# File 'lib/lithic/models/card_create_params.rb', line 62 optional :carrier, -> { Lithic::Carrier } |
#digital_card_art_token ⇒ String?
Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. This artwork must be approved by Mastercard and configured by Lithic to use. See Flexible Card Art Guide.
71 |
# File 'lib/lithic/models/card_create_params.rb', line 71 optional :digital_card_art_token, String |
#exp_month ⇒ String?
Two digit (MM) expiry month. If neither exp_month nor exp_year is provided,
an expiration date five years in the future will be generated. Five years is the
maximum expiration date.
79 |
# File 'lib/lithic/models/card_create_params.rb', line 79 optional :exp_month, String |
#exp_year ⇒ String?
Four digit (yyyy) expiry year. If neither exp_month nor exp_year is
provided, an expiration date five years in the future will be generated. Five
years is the maximum expiration date.
87 |
# File 'lib/lithic/models/card_create_params.rb', line 87 optional :exp_year, String |
#idempotency_key ⇒ String?
235 |
# File 'lib/lithic/models/card_create_params.rb', line 235 optional :idempotency_key, String |
#memo ⇒ String?
Friendly name to identify the card.
93 |
# File 'lib/lithic/models/card_create_params.rb', line 93 optional :memo, String |
#pin ⇒ String?
Encrypted PIN block (in base64). Applies to cards of type PHYSICAL and
VIRTUAL. See
Encrypted PIN Block.
101 |
# File 'lib/lithic/models/card_create_params.rb', line 101 optional :pin, String |
#product_id ⇒ String?
Only applicable to cards of type PHYSICAL. This must be configured with Lithic
before use. Specifies the configuration (i.e., physical card art) that the card
should be manufactured with.
109 |
# File 'lib/lithic/models/card_create_params.rb', line 109 optional :product_id, String |
#replacement_account_token ⇒ String?
Restricted field limited to select use cases. Lithic will reach out directly if
this field should be used. Globally unique identifier for the replacement card's
account. If this field is specified, replacement_for must also be specified.
If replacement_for is specified and this field is omitted, the replacement
card's account will be inferred from the card being replaced.
119 |
# File 'lib/lithic/models/card_create_params.rb', line 119 optional :replacement_account_token, String |
#replacement_comment ⇒ String?
Additional context or information related to the card that this card will replace.
126 |
# File 'lib/lithic/models/card_create_params.rb', line 126 optional :replacement_comment, String |
#replacement_for ⇒ String?
Globally unique identifier for the card that this card will replace. If the card
type is PHYSICAL it will be replaced by a PHYSICAL card. If the card type is
VIRTUAL it will be replaced by a VIRTUAL card.
134 |
# File 'lib/lithic/models/card_create_params.rb', line 134 optional :replacement_for, String |
#replacement_substatus ⇒ Symbol, ...
Card state substatus values for the card that this card will replace:
LOST- The physical card is no longer in the cardholder's possession due to being lost or never received by the cardholder.COMPROMISED- Card information has been exposed, potentially leading to unauthorized access. This may involve physical card theft, cloning, or online data breaches.DAMAGED- The physical card is not functioning properly, such as having chip failures or a demagnetized magnetic stripe.END_USER_REQUEST- The cardholder requested the closure of the card for reasons unrelated to fraud or damage, such as switching to a different product or closing the account.ISSUER_REQUEST- The issuer closed the card for reasons unrelated to fraud or damage, such as account inactivity, product or policy changes, or technology upgrades.NOT_ACTIVE- The card hasn’t had any transaction activity for a specified period, applicable to statuses likePAUSEDorCLOSED.SUSPICIOUS_ACTIVITY- The card has one or more suspicious transactions or activities that require review. This can involve prompting the cardholder to confirm legitimate use or report confirmed fraud.INTERNAL_REVIEW- The card is temporarily paused pending further internal review.EXPIRED- The card has expired and has been closed without being reissued.UNDELIVERABLE- The card cannot be delivered to the cardholder and has been returned.OTHER- The reason for the status does not fall into any of the above categories. A comment should be provided to specify the reason.
166 |
# File 'lib/lithic/models/card_create_params.rb', line 166 optional :replacement_substatus, enum: -> { Lithic::CardCreateParams::ReplacementSubstatus } |
#shipping_address ⇒ Lithic::Models::ShippingAddress?
171 |
# File 'lib/lithic/models/card_create_params.rb', line 171 optional :shipping_address, -> { Lithic::ShippingAddress } |
#shipping_method ⇒ Symbol, ...
Shipping method for the card. Only applies to cards of type PHYSICAL. Use of
options besides STANDARD require additional permissions.
STANDARD- USPS regular mail or similar international option, with no trackingSTANDARD_WITH_TRACKING- USPS regular mail or similar international option, with trackingPRIORITY- USPS Priority, 1-3 day shipping, with trackingEXPRESS- FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking2_DAY- FedEx or UPS depending on card manufacturer, 2-day shipping, with trackingEXPEDITED- FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with trackingBULK- Card will be shipped as part of a bulk fulfillment order. The shipping method and timeline are inherited from the parent bulk order.
192 |
# File 'lib/lithic/models/card_create_params.rb', line 192 optional :shipping_method, enum: -> { Lithic::CardCreateParams::ShippingMethod } |
#spend_limit ⇒ Integer?
Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined. Note that a spend limit of 0 is effectively no limit, and should only be used to reset or remove a prior limit. Only a limit of 1 or above will result in declined transactions due to checks against the card limit.
202 |
# File 'lib/lithic/models/card_create_params.rb', line 202 optional :spend_limit, Integer |
#spend_limit_duration ⇒ Symbol, ...
Spend limit duration values:
ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
219 |
# File 'lib/lithic/models/card_create_params.rb', line 219 optional :spend_limit_duration, enum: -> { Lithic::SpendLimitDuration } |
#state ⇒ Symbol, ...
Card state values:
OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.
230 |
# File 'lib/lithic/models/card_create_params.rb', line 230 optional :state, enum: -> { Lithic::CardCreateParams::State } |
#type ⇒ Symbol, Lithic::Models::CardCreateParams::Type
Card types:
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- [Deprecated] Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- [Deprecated] Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
29 |
# File 'lib/lithic/models/card_create_params.rb', line 29 required :type, enum: -> { Lithic::CardCreateParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/card_create_params.rb', line 311
|
Instance Method Details
#to_hash ⇒ {
150 |
# File 'sig/lithic/models/card_create_params.rbs', line 150
def to_hash: -> {
|