Module: Lithic::Models::CardCreateParams::ShippingMethod

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/card_create_params.rb,
sig/lithic/models/card_create_params.rbs

Overview

Shipping method for the card. Only applies to cards of type PHYSICAL. Use of options besides STANDARD require additional permissions.

  • STANDARD - USPS regular mail or similar international option, with no tracking
  • STANDARD_WITH_TRACKING - USPS regular mail or similar international option, with tracking
  • PRIORITY - USPS Priority, 1-3 day shipping, with tracking
  • EXPRESS - FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking
  • 2_DAY - FedEx or UPS depending on card manufacturer, 2-day shipping, with tracking
  • EXPEDITED - FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with tracking
  • BULK - Card will be shipped as part of a bulk fulfillment order. The shipping method and timeline are inherited from the parent bulk order.

Constant Summary collapse

SHIPPING_METHOD_2_DAY =

Returns:

  • (:"2_DAY")
:"2_DAY"
BULK =

Returns:

  • (:BULK)
:BULK
EXPEDITED =

Returns:

  • (:EXPEDITED)
:EXPEDITED
EXPRESS =

Returns:

  • (:EXPRESS)
:EXPRESS
PRIORITY =

Returns:

  • (:PRIORITY)
:PRIORITY
STANDARD =

Returns:

  • (:STANDARD)
:STANDARD
STANDARD_WITH_TRACKING =

Returns:

  • (:STANDARD_WITH_TRACKING)
:STANDARD_WITH_TRACKING

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Lithic::Models::CardCreateParams::shipping_method]

Returns:

  • (::Array[Lithic::Models::CardCreateParams::shipping_method])


247
# File 'sig/lithic/models/card_create_params.rbs', line 247

def self?.values: -> ::Array[Lithic::Models::CardCreateParams::shipping_method]