Module: Lithic::Models::CardCreateParams::Type
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/card_create_params.rb,
sig/lithic/models/card_create_params.rbs
Overview
Card types:
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- [Deprecated] Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- [Deprecated] Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
Constant Summary collapse
- MERCHANT_LOCKED =
:MERCHANT_LOCKED- PHYSICAL =
:PHYSICAL- SINGLE_USE =
:SINGLE_USE- VIRTUAL =
:VIRTUAL- UNLOCKED =
:UNLOCKED- DIGITAL_WALLET =
:DIGITAL_WALLET
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::CardCreateParams::type_]
193 |
# File 'sig/lithic/models/card_create_params.rbs', line 193
def self?.values: -> ::Array[Lithic::Models::CardCreateParams::type_]
|