Class: Lithic::Models::CardProvisionParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/card_provision_params.rb,
sig/lithic/models/card_provision_params.rbs

Overview

See Also:

  • Lithic::Resources::Cards#provision

Defined Under Namespace

Modules: DigitalWallet

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_token:, certificate: nil, client_device_id: nil, client_wallet_account_id: nil, digital_wallet: nil, nonce: nil, nonce_signature: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardProvisionParams for more details.

Parameters:

  • card_token (String)
  • certificate (String) (defaults to: nil) —

    Only applicable if digital_wallet is APPLE_PAY. Omit to receive only `activa

  • client_device_id (String) (defaults to: nil) —

    Only applicable if digital_wallet is GOOGLE_PAY or SAMSUNG_PAY. Stable dev

  • client_wallet_account_id (String) (defaults to: nil) —

    Only applicable if digital_wallet is GOOGLE_PAY or SAMSUNG_PAY. Consumer I

  • digital_wallet (Symbol, Lithic::Models::CardProvisionParams::DigitalWallet) (defaults to: nil) —

    Name of digital wallet provider.

  • nonce (String) (defaults to: nil) —

    Only applicable if digital_wallet is APPLE_PAY. Omit to receive only `activa

  • nonce_signature (String) (defaults to: nil) —

    Only applicable if digital_wallet is APPLE_PAY. Omit to receive only `activa

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/card_provision_params.rb', line 64


Instance Attribute Details

#card_token ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/lithic/models/card_provision_params.rb', line 13

required :card_token, String

#certificate ⇒ String?

Only applicable if digital_wallet is APPLE_PAY. Omit to receive only activationData in the response. Apple's public leaf certificate. Base64 encoded in PEM format with headers (-----BEGIN CERTIFICATE-----) and trailers omitted. Provided by the device's wallet.

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/lithic/models/card_provision_params.rb', line 22

optional :certificate, String

#client_device_id ⇒ String?

Only applicable if digital_wallet is GOOGLE_PAY or SAMSUNG_PAY. Stable device identification set by the wallet provider. Required for both wallets regardless of network, though the value is only used for cards on the Visa network and is ignored on Amex and Mastercard.

Parameters:

  • (String)

Returns:

  • (String, nil)


31
# File 'lib/lithic/models/card_provision_params.rb', line 31

optional :client_device_id, String

#client_wallet_account_id ⇒ String?

Only applicable if digital_wallet is GOOGLE_PAY or SAMSUNG_PAY. Consumer ID that identifies the wallet account holder entity. Required for both wallets regardless of network, though the value is only used for cards on the Visa network and is ignored on Amex and Mastercard.

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/lithic/models/card_provision_params.rb', line 40

optional :client_wallet_account_id, String

#digital_wallet ⇒ Symbol, ...

Name of digital wallet provider.



46
# File 'lib/lithic/models/card_provision_params.rb', line 46

optional :digital_wallet, enum: -> { Lithic::CardProvisionParams::DigitalWallet }

#nonce ⇒ String?

Only applicable if digital_wallet is APPLE_PAY. Omit to receive only activationData in the response. Base64 cryptographic nonce provided by the device's wallet.

Parameters:

  • (String)

Returns:

  • (String, nil)


54
# File 'lib/lithic/models/card_provision_params.rb', line 54

optional :nonce, String

#nonce_signature ⇒ String?

Only applicable if digital_wallet is APPLE_PAY. Omit to receive only activationData in the response. Base64 cryptographic nonce provided by the device's wallet.

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/lithic/models/card_provision_params.rb', line 62

optional :nonce_signature, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


58
# File 'sig/lithic/models/card_provision_params.rbs', line 58

def to_hash: -> {