Class: Lithic::Models::CardRenewParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/card_renew_params.rb,
sig/lithic/models/card_renew_params.rbs

Overview

See Also:

  • Lithic::Resources::Cards#renew

Defined Under Namespace

Modules: ShippingMethod

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_token:, shipping_address:, carrier: nil, exp_month: nil, exp_year: nil, product_id: nil, shipping_method: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardRenewParams for more details.

Parameters:

  • card_token (String)
  • shipping_address (Lithic::Models::ShippingAddress)

    The shipping address this card will be sent to.

  • carrier (Lithic::Models::Carrier) (defaults to: nil)

    If omitted, the previous carrier will be used.

  • exp_month (String) (defaults to: nil)

    Two digit (MM) expiry month. If neither exp_month nor exp_year is provided,

  • exp_year (String) (defaults to: nil)

    Four digit (yyyy) expiry year. If neither exp_month nor exp_year is provided

  • product_id (String) (defaults to: nil)

    Specifies the configuration (e.g. physical card art) that the card should be man

  • shipping_method (Symbol, Lithic::Models::CardRenewParams::ShippingMethod) (defaults to: nil)

    Shipping method for the card. Only applies to cards of type PHYSICAL.

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/card_renew_params.rb', line 72

Instance Attribute Details

#card_tokenString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/lithic/models/card_renew_params.rb', line 13

required :card_token, String

#carrierLithic::Models::Carrier?

If omitted, the previous carrier will be used.

Parameters:

Returns:



25
# File 'lib/lithic/models/card_renew_params.rb', line 25

optional :carrier, -> { Lithic::Carrier }

#exp_monthString?

Two digit (MM) expiry month. If neither exp_month nor exp_year is provided, an expiration date five years in the future will be generated. Five years is the maximum expiration date.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/lithic/models/card_renew_params.rb', line 33

optional :exp_month, String

#exp_yearString?

Four digit (yyyy) expiry year. If neither exp_month nor exp_year is provided, an expiration date five years in the future will be generated. Five years is the maximum expiration date.

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/lithic/models/card_renew_params.rb', line 41

optional :exp_year, String

#product_idString?

Specifies the configuration (e.g. physical card art) that the card should be manufactured with, and only applies to cards of type PHYSICAL. This must be configured with Lithic before use.

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/lithic/models/card_renew_params.rb', line 49

optional :product_id, String

#shipping_addressLithic::Models::ShippingAddress

The shipping address this card will be sent to.



19
# File 'lib/lithic/models/card_renew_params.rb', line 19

required :shipping_address, -> { Lithic::ShippingAddress }

#shipping_methodSymbol, ...

Shipping method for the card. Only applies to cards of type PHYSICAL. Use of options besides STANDARD require additional permissions.

  • STANDARD - USPS regular mail or similar international option, with no tracking
  • STANDARD_WITH_TRACKING - USPS regular mail or similar international option, with tracking
  • PRIORITY - USPS Priority, 1-3 day shipping, with tracking
  • EXPRESS - FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking
  • 2_DAY - FedEx or UPS depending on card manufacturer, 2-day shipping, with tracking
  • EXPEDITED - FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with tracking
  • BULK - Card will be shipped as part of a bulk fulfillment order. The shipping method and timeline are inherited from the parent bulk order.


70
# File 'lib/lithic/models/card_renew_params.rb', line 70

optional :shipping_method, enum: -> { Lithic::CardRenewParams::ShippingMethod }

Instance Method Details

#to_hash{

Returns:

  • ({)


56
# File 'sig/lithic/models/card_renew_params.rbs', line 56

def to_hash: -> {