Module: Lithic::Models::CardRenewParams::ShippingMethod
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/card_renew_params.rb,
sig/lithic/models/card_renew_params.rbs
Overview
Shipping method for the card. Only applies to cards of type PHYSICAL. Use of
options besides STANDARD require additional permissions.
STANDARD- USPS regular mail or similar international option, with no trackingSTANDARD_WITH_TRACKING- USPS regular mail or similar international option, with trackingPRIORITY- USPS Priority, 1-3 day shipping, with trackingEXPRESS- FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking2_DAY- FedEx or UPS depending on card manufacturer, 2-day shipping, with trackingEXPEDITED- FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with trackingBULK- Card will be shipped as part of a bulk fulfillment order. The shipping method and timeline are inherited from the parent bulk order.
Constant Summary collapse
- SHIPPING_METHOD_2_DAY =
:"2_DAY"- BULK =
:BULK- EXPEDITED =
:EXPEDITED- EXPRESS =
:EXPRESS- PRIORITY =
:PRIORITY- STANDARD =
:STANDARD- STANDARD_WITH_TRACKING =
:STANDARD_WITH_TRACKING
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/card_renew_params.rb', line 119
|
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::CardRenewParams::shipping_method]
87 |
# File 'sig/lithic/models/card_renew_params.rbs', line 87
def self?.values: -> ::Array[Lithic::Models::CardRenewParams::shipping_method]
|