Class: Lithic::Models::CardShippedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/card_shipped_webhook_event.rb

Defined Under Namespace

Modules: ShippingMethod

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bulk_order_token:, card_token:, shipping_method:, tracking_number:, event_type: :"card.shipped") ⇒ Object

Parameters:

  • bulk_order_token (String, nil)

    The token of the bulk order associated with this card shipment, if applicable.

  • card_token (String)

    The token of the card that was shipped.

  • shipping_method (Symbol, Lithic::Models::CardShippedWebhookEvent::ShippingMethod)

    The specific shipping method used to ship the card.

  • tracking_number (String, nil)

    The tracking number of the shipment.

  • event_type (Symbol, :"card.shipped") (defaults to: :"card.shipped")

    The type of event that occurred.



# File 'lib/lithic/models/card_shipped_webhook_event.rb', line 36

Instance Attribute Details

#bulk_order_tokenString?

The token of the bulk order associated with this card shipment, if applicable.

Returns:

  • (String, nil)


10
# File 'lib/lithic/models/card_shipped_webhook_event.rb', line 10

required :bulk_order_token, String, nil?: true

#card_tokenString

The token of the card that was shipped.

Returns:

  • (String)


16
# File 'lib/lithic/models/card_shipped_webhook_event.rb', line 16

required :card_token, String

#event_typeSymbol, :"card.shipped"

The type of event that occurred.

Returns:

  • (Symbol, :"card.shipped")


22
# File 'lib/lithic/models/card_shipped_webhook_event.rb', line 22

required :event_type, const: :"card.shipped"

#shipping_methodSymbol, Lithic::Models::CardShippedWebhookEvent::ShippingMethod

The specific shipping method used to ship the card.



28
# File 'lib/lithic/models/card_shipped_webhook_event.rb', line 28

required :shipping_method, enum: -> { Lithic::CardShippedWebhookEvent::ShippingMethod }

#tracking_numberString?

The tracking number of the shipment.

Returns:

  • (String, nil)


34
# File 'lib/lithic/models/card_shipped_webhook_event.rb', line 34

required :tracking_number, String, nil?: true