Class: Lithic::Models::CardUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/card_update_params.rb

Overview

Defined Under Namespace

Modules: PinStatus, State, Substatus

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_token:, comment: nil, digital_card_art_token: nil, memo: nil, network_program_token: nil, pin: nil, pin_status: nil, spend_limit: nil, spend_limit_duration: nil, state: nil, substatus: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardUpdateParams for more details.

Parameters:

  • card_token (String)
  • comment (String) (defaults to: nil)

    Additional context or information related to the card.

  • digital_card_art_token (String) (defaults to: nil)

    Specifies the digital card art to be displayed in the user’s digital wallet afte

  • memo (String) (defaults to: nil)

    Friendly name to identify the card.

  • network_program_token (String) (defaults to: nil)

    Globally unique identifier for the card’s network program. Currently applicable

  • pin (String) (defaults to: nil)

    Encrypted PIN block (in base64). Only applies to cards of type ‘PHYSICAL` and `V

  • pin_status (Symbol, Lithic::Models::CardUpdateParams::PinStatus) (defaults to: nil)

    Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect

  • spend_limit (Integer) (defaults to: nil)

    Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,00

  • spend_limit_duration (Symbol, Lithic::Models::SpendLimitDuration) (defaults to: nil)

    Spend limit duration values:

  • state (Symbol, Lithic::Models::CardUpdateParams::State) (defaults to: nil)

    Card state values:

  • substatus (Symbol, Lithic::Models::CardUpdateParams::Substatus) (defaults to: nil)

    Card state substatus values:

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/card_update_params.rb', line 130

Instance Attribute Details

#card_tokenString

Returns:

  • (String)


13
# File 'lib/lithic/models/card_update_params.rb', line 13

required :card_token, String

#commentString?

Additional context or information related to the card.

Returns:

  • (String, nil)


19
# File 'lib/lithic/models/card_update_params.rb', line 19

optional :comment, String

#digital_card_art_tokenString?

Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. This artwork must be approved by Mastercard and configured by Lithic to use. See [Flexible Card Art Guide](docs.lithic.com/docs/about-digital-wallets#flexible-card-art).

Returns:

  • (String, nil)


28
# File 'lib/lithic/models/card_update_params.rb', line 28

optional :digital_card_art_token, String

#memoString?

Friendly name to identify the card.

Returns:

  • (String, nil)


34
# File 'lib/lithic/models/card_update_params.rb', line 34

optional :memo, String

#network_program_tokenString?

Globally unique identifier for the card’s network program. Currently applicable to Visa cards participating in Account Level Management only.

Returns:

  • (String, nil)


41
# File 'lib/lithic/models/card_update_params.rb', line 41

optional :network_program_token, String

#pinString?

Encrypted PIN block (in base64). Only applies to cards of type ‘PHYSICAL` and `VIRTUAL`. Changing PIN also resets PIN status to `OK`. See [Encrypted PIN Block](docs.lithic.com/docs/cards#encrypted-pin-block).

Returns:

  • (String, nil)


49
# File 'lib/lithic/models/card_update_params.rb', line 49

optional :pin, String

#pin_statusSymbol, ...

Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts). Can only be set to ‘OK` to unblock a card.



56
# File 'lib/lithic/models/card_update_params.rb', line 56

optional :pin_status, enum: -> { Lithic::CardUpdateParams::PinStatus }

#spend_limitInteger?

Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined. Note that a spend limit of 0 is effectively no limit, and should only be used to reset or remove a prior limit. Only a limit of 1 or above will result in declined transactions due to checks against the card limit.

Returns:

  • (Integer, nil)


66
# File 'lib/lithic/models/card_update_params.rb', line 66

optional :spend_limit, Integer

#spend_limit_durationSymbol, ...

Spend limit duration values:

  • ‘ANNUALLY` - Card will authorize transactions up to spend limit for the trailing year.

  • ‘FOREVER` - Card will authorize only up to spend limit for the entire lifetime of the card.

  • ‘MONTHLY` - Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.

  • ‘TRANSACTION` - Card will authorize multiple transactions if each individual transaction is under the spend limit.

Returns:



83
# File 'lib/lithic/models/card_update_params.rb', line 83

optional :spend_limit_duration, enum: -> { Lithic::SpendLimitDuration }

#stateSymbol, ...

Card state values:

  • ‘CLOSED` - Card will no longer approve authorizations. Closing a card cannot be undone.

  • ‘OPEN` - Card will approve authorizations (if they match card and account parameters).

  • ‘PAUSED` - Card will decline authorizations, but can be resumed at a later time.

Returns:



96
# File 'lib/lithic/models/card_update_params.rb', line 96

optional :state, enum: -> { Lithic::CardUpdateParams::State }

#substatusSymbol, ...

Card state substatus values:

  • ‘LOST` - The physical card is no longer in the cardholder’s possession due to being lost or never received by the cardholder.

  • ‘COMPROMISED` - Card information has been exposed, potentially leading to unauthorized access. This may involve physical card theft, cloning, or online data breaches.

  • ‘DAMAGED` - The physical card is not functioning properly, such as having chip failures or a demagnetized magnetic stripe.

  • ‘END_USER_REQUEST` - The cardholder requested the closure of the card for reasons unrelated to fraud or damage, such as switching to a different product or closing the account.

  • ‘ISSUER_REQUEST` - The issuer closed the card for reasons unrelated to fraud or damage, such as account inactivity, product or policy changes, or technology upgrades.

  • ‘NOT_ACTIVE` - The card hasn’t had any transaction activity for a specified period, applicable to statuses like `PAUSED` or `CLOSED`.

  • ‘SUSPICIOUS_ACTIVITY` - The card has one or more suspicious transactions or activities that require review. This can involve prompting the cardholder to confirm legitimate use or report confirmed fraud.

  • ‘INTERNAL_REVIEW` - The card is temporarily paused pending further internal review.

  • ‘EXPIRED` - The card has expired and has been closed without being reissued.

  • ‘UNDELIVERABLE` - The card cannot be delivered to the cardholder and has been returned.

  • ‘OTHER` - The reason for the status does not fall into any of the above categories. A comment should be provided to specify the reason.



128
# File 'lib/lithic/models/card_update_params.rb', line 128

optional :substatus, enum: -> { Lithic::CardUpdateParams::Substatus }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/card_update_params.rb', line 165