Module: Lithic::Models::CardholderAuthentication::LiabilityShift

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/cardholder_authentication.rb,
sig/lithic/models/cardholder_authentication.rbs

Overview

Indicates whether chargeback liability shift applies to the transaction. Possible enum values:

  • 3DS_AUTHENTICATED: The transaction was fully authenticated through a 3-D Secure flow, chargeback liability shift applies.
  • NONE: Chargeback liability shift has not shifted to the issuer, i.e. the merchant is liable.
  • TOKEN_AUTHENTICATED: The transaction was a tokenized payment with validated cryptography, possibly recurring. Chargeback liability shift to the issuer applies.

See Also:

  • Lithic::Models::CardholderAuthentication#liability_shift

Constant Summary collapse

LIABILITY_SHIFT_3DS_AUTHENTICATED =

Returns:

  • (:"3DS_AUTHENTICATED")
:"3DS_AUTHENTICATED"
TOKEN_AUTHENTICATED =

Returns:

  • (:TOKEN_AUTHENTICATED)
:TOKEN_AUTHENTICATED
NONE =

Returns:

  • (:NONE)
:NONE

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/cardholder_authentication.rb', line 127

Instance Method Details

#self?.values::Array[Lithic::Models::CardholderAuthentication::liability_shift]

Returns:

  • (::Array[Lithic::Models::CardholderAuthentication::liability_shift])


94
# File 'sig/lithic/models/cardholder_authentication.rbs', line 94

def self?.values: -> ::Array[Lithic::Models::CardholderAuthentication::liability_shift]