Class: Lithic::Models::Cards::FinancialTransactionListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/cards/financial_transaction_list_params.rb

Overview

Defined Under Namespace

Modules: Category, Result, Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_token:, begin_: nil, category: nil, end_: nil, ending_before: nil, result: nil, starting_after: nil, status: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Cards::FinancialTransactionListParams for more details.

Parameters:

  • card_token (String)
  • begin_ (Time) (defaults to: nil)

    Date string in RFC 3339 format. Only entries created after the specified time wi

  • category (Symbol, Lithic::Models::Cards::FinancialTransactionListParams::Category) (defaults to: nil)

    Financial Transaction category to be returned.

  • end_ (Time) (defaults to: nil)

    Date string in RFC 3339 format. Only entries created before the specified time w

  • ending_before (String) (defaults to: nil)

    A cursor representing an item’s token before which a page of results should end.

  • result (Symbol, Lithic::Models::Cards::FinancialTransactionListParams::Result) (defaults to: nil)

    Financial Transaction result to be returned.

  • starting_after (String) (defaults to: nil)

    A cursor representing an item’s token after which a page of results should begin

  • status (Symbol, Lithic::Models::Cards::FinancialTransactionListParams::Status) (defaults to: nil)

    Financial Transaction status to be returned.

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 62

Instance Attribute Details

#begin_Time?

Date string in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.

Returns:

  • (Time, nil)


21
# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 21

optional :begin_, Time

#card_tokenString

Returns:

  • (String)


14
# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 14

required :card_token, String

#categorySymbol, ...

Financial Transaction category to be returned.



27
# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 27

optional :category, enum: -> { Lithic::Cards::FinancialTransactionListParams::Category }

#end_Time?

Date string in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.

Returns:

  • (Time, nil)


34
# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 34

optional :end_, Time

#ending_beforeString?

A cursor representing an item’s token before which a page of results should end. Used to retrieve the previous page of results before this item.

Returns:

  • (String, nil)


41
# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 41

optional :ending_before, String

#resultSymbol, ...

Financial Transaction result to be returned.



47
# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 47

optional :result, enum: -> { Lithic::Cards::FinancialTransactionListParams::Result }

#starting_afterString?

A cursor representing an item’s token after which a page of results should begin. Used to retrieve the next page of results after this item.

Returns:

  • (String, nil)


54
# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 54

optional :starting_after, String

#statusSymbol, ...

Financial Transaction status to be returned.



60
# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 60

optional :status, enum: -> { Lithic::Cards::FinancialTransactionListParams::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/cards/financial_transaction_list_params.rb', line 91