Class: Lithic::Models::Carrier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Carrier
- Defined in:
- lib/lithic/models/carrier.rb,
sig/lithic/models/carrier.rbs
Instance Attribute Summary collapse
-
#qr_code_url ⇒ String?
QR code URL to display on the card carrier.
Instance Method Summary collapse
-
#initialize(qr_code_url: nil) ⇒ Carrier
constructor
Some parameter documentations has been truncated, see Carrier for more details.
- #to_hash ⇒ { qr_code_url: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(qr_code_url: nil) ⇒ Carrier
Some parameter documentations has been truncated, see Lithic::Models::Carrier for more details.
|
|
# File 'lib/lithic/models/carrier.rb', line 14
|
Instance Attribute Details
#qr_code_url ⇒ String?
QR code URL to display on the card carrier. The qr_code_url field requires
your domain to be allowlisted by Lithic before use. Contact Support to configure
your QR code domain
12 |
# File 'lib/lithic/models/carrier.rb', line 12 optional :qr_code_url, String |
Instance Method Details
#to_hash ⇒ { qr_code_url: String }
12 |
# File 'sig/lithic/models/carrier.rbs', line 12
def to_hash: -> { qr_code_url: String }
|