Class: Lithic::Models::ClaimCreatedWebhookEvent::DisputedTransaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/claim_created_webhook_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, account_holder_token:, account_token:, card_tokens:, created:, disputed_transactions:, outstanding_requirements:, reason:, status:, submitted:, updated:, event_type: :"claim.created") ⇒ Object

Parameters:

  • token (String)

    Unique identifier for the claim, in UUID format

  • account_holder_token (String, nil)

    Token for the account holder that filed the claim

  • account_token (String, nil)

    Token for the account associated with the claim

  • card_tokens (Array<String>)

    Tokens for the cards associated with the disputed transactions

  • created (Time)

    When the claim was created

  • disputed_transactions (Array<Lithic::Models::ClaimCreatedWebhookEvent::DisputedTransaction>)

    Transactions included in this claim

  • outstanding_requirements (Array<Symbol, Lithic::Models::ClaimCreatedWebhookEvent::OutstandingRequirement>)

    Requirements that must be fulfilled before the claim can be submitted

  • reason (Symbol, Lithic::Models::ClaimCreatedWebhookEvent::Reason)

    Dispute reason code provided when creating the claim

  • status (Symbol, Lithic::Models::ClaimCreatedWebhookEvent::Status)

    Current lifecycle status of the claim

  • submitted (Time, nil)

    When the claim was submitted. Null until the claim reaches ‘SUBMITTED` status

  • updated (Time)

    When the claim was last updated

  • event_type (Symbol, :"claim.created") (defaults to: :"claim.created")

    The type of event that occurred.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/lithic/models/claim_created_webhook_event.rb', line 105

class DisputedTransaction < Lithic::Internal::Type::BaseModel
  # @!attribute event_tokens
  #   Tokens for the specific events within the transaction being disputed. Lithic
  #   creates one dispute per event token
  #
  #   @return [Array<String>]
  required :event_tokens, Lithic::Internal::Type::ArrayOf[String]

  # @!attribute transaction_token
  #   Token for the transaction being disputed, in UUID format
  #
  #   @return [String]
  required :transaction_token, String

  # @!method initialize(event_tokens:, transaction_token:)
  #   Some parameter documentations has been truncated, see
  #   {Lithic::Models::ClaimCreatedWebhookEvent::DisputedTransaction} for more
  #   details.
  #
  #   A transaction included in a claim, along with the specific events being
  #   disputed.
  #
  #   @param event_tokens [Array<String>] Tokens for the specific events within the transaction being disputed. Lithic cre
  #
  #   @param transaction_token [String] Token for the transaction being disputed, in UUID format
end

Instance Attribute Details

#event_tokensArray<String>

Tokens for the specific events within the transaction being disputed. Lithic creates one dispute per event token

Returns:

  • (Array<String>)


111
# File 'lib/lithic/models/claim_created_webhook_event.rb', line 111

required :event_tokens, Lithic::Internal::Type::ArrayOf[String]

#transaction_tokenString

Token for the transaction being disputed, in UUID format

Returns:

  • (String)


117
# File 'lib/lithic/models/claim_created_webhook_event.rb', line 117

required :transaction_token, String