Class: Lithic::Models::ClaimDocumentRejectedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ClaimDocumentRejectedWebhookEvent
- Defined in:
- lib/lithic/models/claim_document_rejected_webhook_event.rb
Defined Under Namespace
Modules: FailureReason, Status Classes: UploadConstraints
Instance Attribute Summary collapse
-
#created ⇒ Time
When the document was created.
-
#download_url ⇒ String?
Presigned URL for downloading the uploaded document.
-
#download_url_expires_at ⇒ Time?
When the download URL expires.
-
#event_type ⇒ Symbol, :"claim_document.rejected"
The type of event that occurred.
-
#failure_reason ⇒ Symbol, ...
Reason the document failed validation.
-
#name ⇒ String
Name provided when the upload intent was created.
-
#requirement_id ⇒ String?
Identifier of the document requirement this document satisfies.
-
#status ⇒ Symbol, Lithic::Models::ClaimDocumentRejectedWebhookEvent::Status
Current validation status of the document.
-
#token ⇒ String
Unique identifier for the document, in UUID format.
-
#updated ⇒ Time
When the document was last updated.
-
#upload_constraints ⇒ Lithic::Models::ClaimDocumentRejectedWebhookEvent::UploadConstraints?
Constraints that an uploaded file must satisfy.
-
#upload_url ⇒ String?
Presigned URL for uploading the file via HTTP PUT.
-
#upload_url_expires_at ⇒ Time?
When the upload URL expires.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, created:, download_url:, download_url_expires_at:, failure_reason:, name:, requirement_id:, status:, updated:, upload_constraints:, upload_url:, upload_url_expires_at:, event_type: :"claim_document.rejected") ⇒ Object
constructor
Some parameter documentations has been truncated, see ClaimDocumentRejectedWebhookEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, created:, download_url:, download_url_expires_at:, failure_reason:, name:, requirement_id:, status:, updated:, upload_constraints:, upload_url:, upload_url_expires_at:, event_type: :"claim_document.rejected") ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::ClaimDocumentRejectedWebhookEvent for more details.
|
|
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 91
|
Instance Attribute Details
#created ⇒ Time
When the document was created
16 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 16 required :created, Time |
#download_url ⇒ String?
Presigned URL for downloading the uploaded document. Available once the document is being validated or has been accepted (‘VALIDATING` or `ACCEPTED`)
23 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 23 required :download_url, String, nil?: true |
#download_url_expires_at ⇒ Time?
When the download URL expires
29 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 29 required :download_url_expires_at, Time, nil?: true |
#event_type ⇒ Symbol, :"claim_document.rejected"
The type of event that occurred.
35 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 35 required :event_type, const: :"claim_document.rejected" |
#failure_reason ⇒ Symbol, ...
Reason the document failed validation. Null unless ‘status` is `REJECTED`
41 42 43 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 41 required :failure_reason, enum: -> { Lithic::ClaimDocumentRejectedWebhookEvent::FailureReason }, nil?: true |
#name ⇒ String
Name provided when the upload intent was created
49 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 49 required :name, String |
#requirement_id ⇒ String?
Identifier of the document requirement this document satisfies. Null for supplemental documents not tied to a specific requirement
56 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 56 required :requirement_id, String, nil?: true |
#status ⇒ Symbol, Lithic::Models::ClaimDocumentRejectedWebhookEvent::Status
Current validation status of the document
62 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 62 required :status, enum: -> { Lithic::ClaimDocumentRejectedWebhookEvent::Status } |
#token ⇒ String
Unique identifier for the document, in UUID format
10 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 10 required :token, String |
#updated ⇒ Time
When the document was last updated
68 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 68 required :updated, Time |
#upload_constraints ⇒ Lithic::Models::ClaimDocumentRejectedWebhookEvent::UploadConstraints?
Constraints that an uploaded file must satisfy.
74 75 76 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 74 required :upload_constraints, -> { Lithic::ClaimDocumentRejectedWebhookEvent::UploadConstraints }, nil?: true |
#upload_url ⇒ String?
Presigned URL for uploading the file via HTTP PUT. Null after the upload window expires or after the document has been validated
83 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 83 required :upload_url, String, nil?: true |
#upload_url_expires_at ⇒ Time?
When the upload URL expires
89 |
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 89 required :upload_url_expires_at, Time, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/claim_document_rejected_webhook_event.rb', line 133
|