Class: Lithic::Models::ClaimDocumentUploadedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/claim_document_uploaded_webhook_event.rb

Defined Under Namespace

Modules: FailureReason, Status Classes: UploadConstraints

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, created:, download_url:, download_url_expires_at:, failure_reason:, name:, requirement_id:, status:, updated:, upload_constraints:, upload_url:, upload_url_expires_at:, event_type: :"claim_document.uploaded") ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ClaimDocumentUploadedWebhookEvent for more details.

Parameters:

  • token (String)

    Unique identifier for the document, in UUID format

  • created (Time)

    When the document was created

  • download_url (String, nil)

    Presigned URL for downloading the uploaded document. Available once the document

  • download_url_expires_at (Time, nil)

    When the download URL expires

  • failure_reason (Symbol, Lithic::Models::ClaimDocumentUploadedWebhookEvent::FailureReason, nil)

    Reason the document failed validation. Null unless ‘status` is `REJECTED`

  • name (String)

    Name provided when the upload intent was created

  • requirement_id (String, nil)

    Identifier of the document requirement this document satisfies. Null for supplem

  • status (Symbol, Lithic::Models::ClaimDocumentUploadedWebhookEvent::Status)

    Current validation status of the document

  • updated (Time)

    When the document was last updated

  • upload_constraints (Lithic::Models::ClaimDocumentUploadedWebhookEvent::UploadConstraints, nil)

    Constraints that an uploaded file must satisfy.

  • upload_url (String, nil)

    Presigned URL for uploading the file via HTTP PUT. Null after the upload window

  • upload_url_expires_at (Time, nil)

    When the upload URL expires

  • event_type (Symbol, :"claim_document.uploaded") (defaults to: :"claim_document.uploaded")

    The type of event that occurred.



# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 91

Instance Attribute Details

#createdTime

When the document was created

Returns:

  • (Time)


16
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 16

required :created, Time

#download_urlString?

Presigned URL for downloading the uploaded document. Available once the document is being validated or has been accepted (‘VALIDATING` or `ACCEPTED`)

Returns:

  • (String, nil)


23
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 23

required :download_url, String, nil?: true

#download_url_expires_atTime?

When the download URL expires

Returns:

  • (Time, nil)


29
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 29

required :download_url_expires_at, Time, nil?: true

#event_typeSymbol, :"claim_document.uploaded"

The type of event that occurred.

Returns:

  • (Symbol, :"claim_document.uploaded")


35
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 35

required :event_type, const: :"claim_document.uploaded"

#failure_reasonSymbol, ...

Reason the document failed validation. Null unless ‘status` is `REJECTED`



41
42
43
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 41

required :failure_reason,
enum: -> { Lithic::ClaimDocumentUploadedWebhookEvent::FailureReason },
nil?: true

#nameString

Name provided when the upload intent was created

Returns:

  • (String)


49
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 49

required :name, String

#requirement_idString?

Identifier of the document requirement this document satisfies. Null for supplemental documents not tied to a specific requirement

Returns:

  • (String, nil)


56
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 56

required :requirement_id, String, nil?: true

#statusSymbol, Lithic::Models::ClaimDocumentUploadedWebhookEvent::Status

Current validation status of the document



62
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 62

required :status, enum: -> { Lithic::ClaimDocumentUploadedWebhookEvent::Status }

#tokenString

Unique identifier for the document, in UUID format

Returns:

  • (String)


10
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 10

required :token, String

#updatedTime

When the document was last updated

Returns:

  • (Time)


68
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 68

required :updated, Time

#upload_constraintsLithic::Models::ClaimDocumentUploadedWebhookEvent::UploadConstraints?

Constraints that an uploaded file must satisfy.



74
75
76
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 74

required :upload_constraints,
-> { Lithic::ClaimDocumentUploadedWebhookEvent::UploadConstraints },
nil?: true

#upload_urlString?

Presigned URL for uploading the file via HTTP PUT. Null after the upload window expires or after the document has been validated

Returns:

  • (String, nil)


83
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 83

required :upload_url, String, nil?: true

#upload_url_expires_atTime?

When the upload URL expires

Returns:

  • (Time, nil)


89
# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 89

required :upload_url_expires_at, Time, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/claim_document_uploaded_webhook_event.rb', line 133