Class: Lithic::Models::ClaimUpdatedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ClaimUpdatedWebhookEvent
- Defined in:
- lib/lithic/models/claim_updated_webhook_event.rb
Defined Under Namespace
Modules: OutstandingRequirement, Reason, Status Classes: DisputedTransaction
Instance Attribute Summary collapse
-
#account_holder_token ⇒ String?
Token for the account holder that filed the claim.
-
#account_token ⇒ String?
Token for the account associated with the claim.
-
#card_tokens ⇒ Array<String>
Tokens for the cards associated with the disputed transactions.
-
#created ⇒ Time
When the claim was created.
-
#disputed_transactions ⇒ Array<Lithic::Models::ClaimUpdatedWebhookEvent::DisputedTransaction>
Transactions included in this claim.
-
#event_type ⇒ Symbol, :"claim.updated"
The type of event that occurred.
-
#outstanding_requirements ⇒ Array<Symbol, Lithic::Models::ClaimUpdatedWebhookEvent::OutstandingRequirement>
Requirements that must be fulfilled before the claim can be submitted.
-
#reason ⇒ Symbol, Lithic::Models::ClaimUpdatedWebhookEvent::Reason
Dispute reason code provided when creating the claim.
-
#status ⇒ Symbol, Lithic::Models::ClaimUpdatedWebhookEvent::Status
Current lifecycle status of the claim.
-
#submitted ⇒ Time?
When the claim was submitted.
-
#token ⇒ String
Unique identifier for the claim, in UUID format.
-
#updated ⇒ Time
When the claim was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(event_tokens:, transaction_token:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DisputedTransaction for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_tokens:, transaction_token:) ⇒ Object
Some parameter documentations has been truncated, see DisputedTransaction for more details.
A transaction included in a claim, along with the specific events being disputed.
|
|
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 119
|
Instance Attribute Details
#account_holder_token ⇒ String?
Token for the account holder that filed the claim
16 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 16 required :account_holder_token, String, nil?: true |
#account_token ⇒ String?
Token for the account associated with the claim
22 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 22 required :account_token, String, nil?: true |
#card_tokens ⇒ Array<String>
Tokens for the cards associated with the disputed transactions
28 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 28 required :card_tokens, Lithic::Internal::Type::ArrayOf[String] |
#created ⇒ Time
When the claim was created
34 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 34 required :created, Time |
#disputed_transactions ⇒ Array<Lithic::Models::ClaimUpdatedWebhookEvent::DisputedTransaction>
Transactions included in this claim
40 41 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 40 required :disputed_transactions, -> { Lithic::Internal::Type::ArrayOf[Lithic::ClaimUpdatedWebhookEvent::DisputedTransaction] } |
#event_type ⇒ Symbol, :"claim.updated"
The type of event that occurred.
47 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 47 required :event_type, const: :"claim.updated" |
#outstanding_requirements ⇒ Array<Symbol, Lithic::Models::ClaimUpdatedWebhookEvent::OutstandingRequirement>
Requirements that must be fulfilled before the claim can be submitted
53 54 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 53 required :outstanding_requirements, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::ClaimUpdatedWebhookEvent::OutstandingRequirement] } |
#reason ⇒ Symbol, Lithic::Models::ClaimUpdatedWebhookEvent::Reason
Dispute reason code provided when creating the claim
60 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 60 required :reason, enum: -> { Lithic::ClaimUpdatedWebhookEvent::Reason } |
#status ⇒ Symbol, Lithic::Models::ClaimUpdatedWebhookEvent::Status
Current lifecycle status of the claim
66 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 66 required :status, enum: -> { Lithic::ClaimUpdatedWebhookEvent::Status } |
#submitted ⇒ Time?
When the claim was submitted. Null until the claim reaches ‘SUBMITTED` status
72 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 72 required :submitted, Time, nil?: true |
#token ⇒ String
Unique identifier for the claim, in UUID format
10 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 10 required :token, String |
#updated ⇒ Time
When the claim was last updated
78 |
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 78 required :updated, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/claim_updated_webhook_event.rb', line 138
|