Class: Lithic::Models::DigitalWalletTokenizationApprovalRequestWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb

Defined Under Namespace

Modules: EventType, IssuerDecision, TokenizationChannel, TokenizationSource Classes: CustomerTokenizationDecision

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_token:, card_token:, created:, digital_wallet_token_metadata:, event_type:, issuer_decision:, tokenization_channel:, tokenization_token:, wallet_decisioning_info:, customer_tokenization_decision: nil, device: nil, rule_results: nil, tokenization_decline_reasons: nil, tokenization_source: nil, tokenization_tfa_reasons: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::DigitalWalletTokenizationApprovalRequestWebhookEvent for more details.

Payload for digital wallet tokenization approval requests. Used for both the decisioning responder request (sent to the customer’s endpoint for a real-time decision) and the subsequent webhook event (sent after the decision is made). Fields like customer_tokenization_decision, tokenization_decline_reasons, tokenization_tfa_reasons, and rule_results are only populated in the webhook event, not in the initial decisioning request.

Parameters:



# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 107

Instance Attribute Details

#account_tokenString

Unique identifier for the user tokenizing a card

Returns:

  • (String)


10
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 10

required :account_token, String

#card_tokenString

Unique identifier for the card being tokenized

Returns:

  • (String)


16
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 16

required :card_token, String

#createdTime

Indicate when the request was received from Mastercard or Visa

Returns:

  • (Time)


22
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 22

required :created, Time

#customer_tokenization_decisionLithic::Models::DigitalWalletTokenizationApprovalRequestWebhookEvent::CustomerTokenizationDecision?

Contains the metadata for the customer tokenization decision.



66
67
68
69
70
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 66

optional :customer_tokenization_decision,
-> {
  Lithic::DigitalWalletTokenizationApprovalRequestWebhookEvent::CustomerTokenizationDecision
},
nil?: true

#deviceLithic::Models::Device?

Returns:



75
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 75

optional :device, -> { Lithic::Device }

#digital_wallet_token_metadataLithic::Models::TokenMetadata

Contains the metadata for the digital wallet being tokenized.



28
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 28

required :digital_wallet_token_metadata, -> { Lithic::TokenMetadata }

#event_typeSymbol, Lithic::Models::DigitalWalletTokenizationApprovalRequestWebhookEvent::EventType

The name of this event



34
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 34

required :event_type, enum: -> { Lithic::DigitalWalletTokenizationApprovalRequestWebhookEvent::EventType }

#issuer_decisionSymbol, Lithic::Models::DigitalWalletTokenizationApprovalRequestWebhookEvent::IssuerDecision

Whether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.



41
42
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 41

required :issuer_decision,
enum: -> { Lithic::DigitalWalletTokenizationApprovalRequestWebhookEvent::IssuerDecision }

#rule_resultsArray<Lithic::Models::TokenizationRuleResult>?

Results from rules that were evaluated for this tokenization. Only populated in webhook events, not in the initial decisioning request



82
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 82

optional :rule_results, -> { Lithic::Internal::Type::ArrayOf[Lithic::TokenizationRuleResult] }

#tokenization_channelSymbol, Lithic::Models::DigitalWalletTokenizationApprovalRequestWebhookEvent::TokenizationChannel

The channel through which the tokenization was made.



48
49
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 48

required :tokenization_channel,
enum: -> { Lithic::DigitalWalletTokenizationApprovalRequestWebhookEvent::TokenizationChannel }

#tokenization_decline_reasonsArray<Symbol, Lithic::Models::TokenizationDeclineReason>?

List of reasons why the tokenization was declined. Only populated in webhook events, not in the initial decisioning request

Returns:



89
90
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 89

optional :tokenization_decline_reasons,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::TokenizationDeclineReason] }

#tokenization_sourceSymbol, ...

The source of the tokenization.



96
97
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 96

optional :tokenization_source,
enum: -> { Lithic::DigitalWalletTokenizationApprovalRequestWebhookEvent::TokenizationSource }

#tokenization_tfa_reasonsArray<Symbol, Lithic::Models::TokenizationTfaReason>?

List of reasons why two-factor authentication was required. Only populated in webhook events, not in the initial decisioning request

Returns:



104
105
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 104

optional :tokenization_tfa_reasons,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::TokenizationTfaReason] }

#tokenization_tokenString

Unique identifier for the digital wallet token attempt

Returns:

  • (String)


55
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 55

required :tokenization_token, String

#wallet_decisioning_infoLithic::Models::WalletDecisioningInfo



60
# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 60

required :wallet_decisioning_info, -> { Lithic::WalletDecisioningInfo }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/digital_wallet_tokenization_approval_request_webhook_event.rb', line 157