Class: Lithic::Models::Dispute

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/dispute.rb,
sig/lithic/models/dispute.rbs

Overview

See Also:

  • Lithic::Resources::Disputes#create

Direct Known Subclasses

DisputeUpdatedWebhookEvent

Defined Under Namespace

Modules: Reason, ResolutionReason, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, amount:, arbitration_date:, created:, customer_filed_date:, customer_note:, network_claim_ids:, network_filed_date:, network_reason_code:, prearbitration_date:, primary_claim_id:, reason:, representment_date:, resolution_date:, resolution_note:, resolution_reason:, status:, transaction_token:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Dispute for more details.

Dispute.

Parameters:

  • token (String)

    Globally unique identifier.

  • amount (Integer)

    Amount under dispute. May be different from the original transaction amount.

  • arbitration_date (Time, nil)

    Date dispute entered arbitration.

  • created (Time)

    Timestamp of when first Dispute was reported.

  • customer_filed_date (Time, nil)

    Date that the dispute was filed by the customer making the dispute.

  • customer_note (String, nil)

    End customer description of the reason for the dispute.

  • network_claim_ids (Array<String>, nil)

    Unique identifiers for the dispute from the network.

  • network_filed_date (Time, nil)

    Date that the dispute was submitted to the network.

  • network_reason_code (String, nil)

    Network reason code used to file the dispute.

  • prearbitration_date (Time, nil)

    Date dispute entered pre-arbitration.

  • primary_claim_id (String, nil)

    Unique identifier for the dispute from the network. If there are multiple, this

  • reason (Symbol, Lithic::Models::Dispute::Reason)

    Dispute reason:

  • representment_date (Time, nil)

    Date the representment was received.

  • resolution_date (Time, nil)

    Date that the dispute was resolved.

  • resolution_note (String, nil)

    Note by Dispute team on the case resolution.

  • resolution_reason (Symbol, Lithic::Models::Dispute::ResolutionReason, nil)

    Reason for the dispute resolution:

  • status (Symbol, Lithic::Models::Dispute::Status)

    Status types:

  • transaction_token (String)

    The transaction that is being disputed. A transaction can only be disputed once



# File 'lib/lithic/models/dispute.rb', line 163

Instance Attribute Details

#amountInteger

Amount under dispute. May be different from the original transaction amount.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


17
# File 'lib/lithic/models/dispute.rb', line 17

required :amount, Integer

#arbitration_dateTime?

Date dispute entered arbitration.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


23
# File 'lib/lithic/models/dispute.rb', line 23

required :arbitration_date, Time, nil?: true

#createdTime

Timestamp of when first Dispute was reported.

Parameters:

  • value (Time)

Returns:

  • (Time)


29
# File 'lib/lithic/models/dispute.rb', line 29

required :created, Time

#customer_filed_dateTime?

Date that the dispute was filed by the customer making the dispute.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


35
# File 'lib/lithic/models/dispute.rb', line 35

required :customer_filed_date, Time, nil?: true

#customer_noteString?

End customer description of the reason for the dispute.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


41
# File 'lib/lithic/models/dispute.rb', line 41

required :customer_note, String, nil?: true

#network_claim_idsArray<String>?

Unique identifiers for the dispute from the network.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


47
# File 'lib/lithic/models/dispute.rb', line 47

required :network_claim_ids, Lithic::Internal::Type::ArrayOf[String], nil?: true

#network_filed_dateTime?

Date that the dispute was submitted to the network.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


53
# File 'lib/lithic/models/dispute.rb', line 53

required :network_filed_date, Time, nil?: true

#network_reason_codeString?

Network reason code used to file the dispute.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


59
# File 'lib/lithic/models/dispute.rb', line 59

required :network_reason_code, String, nil?: true

#prearbitration_dateTime?

Date dispute entered pre-arbitration.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


65
# File 'lib/lithic/models/dispute.rb', line 65

required :prearbitration_date, Time, nil?: true

#primary_claim_idString?

Unique identifier for the dispute from the network. If there are multiple, this will be the first claim id set by the network

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


72
# File 'lib/lithic/models/dispute.rb', line 72

required :primary_claim_id, String, nil?: true

#reasonSymbol, Lithic::Models::Dispute::Reason

Dispute reason:

  • ATM_CASH_MISDISPENSE: ATM cash misdispense.
  • CANCELLED: Transaction was cancelled by the customer.
  • DUPLICATED: The transaction was a duplicate.
  • FRAUD_CARD_NOT_PRESENT: Fraudulent transaction, card not present.
  • FRAUD_CARD_PRESENT: Fraudulent transaction, card present.
  • FRAUD_OTHER: Fraudulent transaction, other types such as questionable merchant activity.
  • GOODS_SERVICES_NOT_AS_DESCRIBED: The goods or services were not as described.
  • GOODS_SERVICES_NOT_RECEIVED: The goods or services were not received.
  • INCORRECT_AMOUNT: The transaction amount was incorrect.
  • MISSING_AUTH: The transaction was missing authorization.
  • OTHER: Other reason.
  • PROCESSING_ERROR: Processing error.
  • REFUND_NOT_PROCESSED: The refund was not processed.
  • RECURRING_TRANSACTION_NOT_CANCELLED: The recurring transaction was not cancelled.

Parameters:

  • value (Lithic::Models::Dispute::reason)

Returns:



96
# File 'lib/lithic/models/dispute.rb', line 96

required :reason, enum: -> { Lithic::Dispute::Reason }

#representment_dateTime?

Date the representment was received.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


102
# File 'lib/lithic/models/dispute.rb', line 102

required :representment_date, Time, nil?: true

#resolution_dateTime?

Date that the dispute was resolved.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


108
# File 'lib/lithic/models/dispute.rb', line 108

required :resolution_date, Time, nil?: true

#resolution_noteString?

Note by Dispute team on the case resolution.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


114
# File 'lib/lithic/models/dispute.rb', line 114

required :resolution_note, String, nil?: true

#resolution_reasonSymbol, ...

Reason for the dispute resolution:

  • CASE_LOST: This case was lost at final arbitration.
  • NETWORK_REJECTED: Network rejected.
  • NO_DISPUTE_RIGHTS_3DS: No dispute rights, 3DS.
  • NO_DISPUTE_RIGHTS_BELOW_THRESHOLD: No dispute rights, below threshold.
  • NO_DISPUTE_RIGHTS_CONTACTLESS: No dispute rights, contactless.
  • NO_DISPUTE_RIGHTS_HYBRID: No dispute rights, hybrid.
  • NO_DISPUTE_RIGHTS_MAX_CHARGEBACKS: No dispute rights, max chargebacks.
  • NO_DISPUTE_RIGHTS_OTHER: No dispute rights, other.
  • PAST_FILING_DATE: Past filing date.
  • PREARBITRATION_REJECTED: Prearbitration rejected.
  • PROCESSOR_REJECTED_OTHER: Processor rejected, other.
  • REFUNDED: Refunded.
  • REFUNDED_AFTER_CHARGEBACK: Refunded after chargeback.
  • WITHDRAWN: Withdrawn.
  • WON_ARBITRATION: Won arbitration.
  • WON_FIRST_CHARGEBACK: Won first chargeback.
  • WON_PREARBITRATION: Won prearbitration.

Parameters:

  • value (Lithic::Models::Dispute::resolution_reason, nil)

Returns:



138
# File 'lib/lithic/models/dispute.rb', line 138

required :resolution_reason, enum: -> { Lithic::Dispute::ResolutionReason }, nil?: true

#statusSymbol, Lithic::Models::Dispute::Status

Status types:

  • NEW - New dispute case is opened.
  • PENDING_CUSTOMER - Lithic is waiting for customer to provide more information.
  • SUBMITTED - Dispute is submitted to the card network.
  • REPRESENTMENT - Case has entered second presentment.
  • PREARBITRATION - Case has entered prearbitration.
  • ARBITRATION - Case has entered arbitration.
  • CASE_WON - Case was won and credit will be issued.
  • CASE_CLOSED - Case was lost or withdrawn.

Parameters:

  • value (Lithic::Models::Dispute::status)

Returns:



154
# File 'lib/lithic/models/dispute.rb', line 154

required :status, enum: -> { Lithic::Dispute::Status }

#tokenString

Globally unique identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/lithic/models/dispute.rb', line 11

required :token, String

#transaction_tokenString

The transaction that is being disputed. A transaction can only be disputed once but may have multiple dispute cases.

Parameters:

  • value (String)

Returns:

  • (String)


161
# File 'lib/lithic/models/dispute.rb', line 161

required :transaction_token, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/dispute.rb', line 244

Instance Method Details

#to_hash{

Returns:

  • ({)


83
# File 'sig/lithic/models/dispute.rbs', line 83

def to_hash: -> {