Class: Lithic::Models::DisputeV2::Event::Financial
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::DisputeV2::Event::Financial
- Defined in:
- lib/lithic/models/dispute_v2.rb,
sig/lithic/models/dispute_v2.rbs
Defined Under Namespace
Classes: Data
Instance Attribute Summary collapse
-
#created ⇒ Time
When the event occurred.
-
#data ⇒ Lithic::Models::DisputeV2::Event::Financial::Data
Details specific to financial events.
-
#token ⇒ String
Unique identifier for the event, in UUID format.
-
#type ⇒ Symbol, :FINANCIAL
Type of event.
Instance Method Summary collapse
-
#initialize(token:, created:, data:, type: :FINANCIAL) ⇒ Object
constructor
Event tracking a funds movement between issuer and acquirer.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, created:, data:, type: :FINANCIAL) ⇒ Object
Event tracking a funds movement between issuer and acquirer
|
|
# File 'lib/lithic/models/dispute_v2.rb', line 320
|
Instance Attribute Details
#created ⇒ Time
When the event occurred
306 |
# File 'lib/lithic/models/dispute_v2.rb', line 306 required :created, Time |
#data ⇒ Lithic::Models::DisputeV2::Event::Financial::Data
Details specific to financial events
312 |
# File 'lib/lithic/models/dispute_v2.rb', line 312 required :data, -> { Lithic::DisputeV2::Event::Financial::Data } |
#token ⇒ String
Unique identifier for the event, in UUID format
300 |
# File 'lib/lithic/models/dispute_v2.rb', line 300 required :token, String |
#type ⇒ Symbol, :FINANCIAL
Type of event. Always FINANCIAL
318 |
# File 'lib/lithic/models/dispute_v2.rb', line 318 required :type, const: :FINANCIAL |
Instance Method Details
#to_hash ⇒ {
241 |
# File 'sig/lithic/models/dispute_v2.rbs', line 241
def to_hash: -> {
|