Class: Lithic::Models::DisputeV2::LiabilityAllocation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::DisputeV2::LiabilityAllocation
- Defined in:
- lib/lithic/models/dispute_v2.rb,
sig/lithic/models/dispute_v2.rbs
Overview
Instance Attribute Summary collapse
-
#denied_amount ⇒ Integer
The amount that has been denied to the cardholder.
-
#original_amount ⇒ Integer
The initial amount disputed.
-
#recovered_amount ⇒ Integer
The amount that has been recovered from the merchant through the dispute process.
-
#remaining_amount ⇒ Integer
Any disputed amount that is still outstanding, i.e.
-
#written_off_amount ⇒ Integer
The amount the issuer has chosen to write off.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
405 |
# File 'sig/lithic/models/dispute_v2.rbs', line 405
def initialize: (
|
Instance Attribute Details
#denied_amount ⇒ Integer
The amount that has been denied to the cardholder
483 |
# File 'lib/lithic/models/dispute_v2.rb', line 483 required :denied_amount, Integer |
#original_amount ⇒ Integer
The initial amount disputed
489 |
# File 'lib/lithic/models/dispute_v2.rb', line 489 required :original_amount, Integer |
#recovered_amount ⇒ Integer
The amount that has been recovered from the merchant through the dispute process
495 |
# File 'lib/lithic/models/dispute_v2.rb', line 495 required :recovered_amount, Integer |
#remaining_amount ⇒ Integer
Any disputed amount that is still outstanding, i.e. has not been recovered, written off, or denied
502 |
# File 'lib/lithic/models/dispute_v2.rb', line 502 required :remaining_amount, Integer |
#written_off_amount ⇒ Integer
The amount the issuer has chosen to write off
508 |
# File 'lib/lithic/models/dispute_v2.rb', line 508 required :written_off_amount, Integer |
Instance Method Details
#to_hash ⇒ {
413 |
# File 'sig/lithic/models/dispute_v2.rbs', line 413
def to_hash: -> {
|