Class: Lithic::Models::DisputesV2ListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/disputes_v2_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_token: nil, begin_: nil, card_token: nil, disputed_transaction_token: nil, end_: nil, ending_before: nil, page_size: nil, starting_after: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::DisputesV2ListParams for more details.

Parameters:

  • account_token (String) (defaults to: nil)

    Filter by account token.

  • begin_ (Time) (defaults to: nil)

    RFC 3339 timestamp for filtering by created date, inclusive.

  • card_token (String) (defaults to: nil)

    Filter by card token.

  • disputed_transaction_token (String) (defaults to: nil)

    Filter by the token of the transaction being disputed. Corresponds with transact

  • end_ (Time) (defaults to: nil)

    RFC 3339 timestamp for filtering by created date, inclusive.

  • ending_before (String) (defaults to: nil)

    A cursor representing an item’s token before which a page of results should end.

  • page_size (Integer) (defaults to: nil)

    Number of items to return.

  • starting_after (String) (defaults to: nil)

    A cursor representing an item’s token after which a page of results should begin

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/disputes_v2_list_params.rb', line 61

Instance Attribute Details

#account_tokenString?

Filter by account token.

Returns:

  • (String, nil)


14
# File 'lib/lithic/models/disputes_v2_list_params.rb', line 14

optional :account_token, String

#begin_Time?

RFC 3339 timestamp for filtering by created date, inclusive.

Returns:

  • (Time, nil)


20
# File 'lib/lithic/models/disputes_v2_list_params.rb', line 20

optional :begin_, Time

#card_tokenString?

Filter by card token.

Returns:

  • (String, nil)


26
# File 'lib/lithic/models/disputes_v2_list_params.rb', line 26

optional :card_token, String

#disputed_transaction_tokenString?

Filter by the token of the transaction being disputed. Corresponds with transaction_series.related_transaction_token in the Dispute.

Returns:

  • (String, nil)


33
# File 'lib/lithic/models/disputes_v2_list_params.rb', line 33

optional :disputed_transaction_token, String

#end_Time?

RFC 3339 timestamp for filtering by created date, inclusive.

Returns:

  • (Time, nil)


39
# File 'lib/lithic/models/disputes_v2_list_params.rb', line 39

optional :end_, Time

#ending_beforeString?

A cursor representing an item’s token before which a page of results should end. Used to retrieve the previous page of results before this item.

Returns:

  • (String, nil)


46
# File 'lib/lithic/models/disputes_v2_list_params.rb', line 46

optional :ending_before, String

#page_sizeInteger?

Number of items to return.

Returns:

  • (Integer, nil)


52
# File 'lib/lithic/models/disputes_v2_list_params.rb', line 52

optional :page_size, Integer

#starting_afterString?

A cursor representing an item’s token after which a page of results should begin. Used to retrieve the next page of results after this item.

Returns:

  • (String, nil)


59
# File 'lib/lithic/models/disputes_v2_list_params.rb', line 59

optional :starting_after, String