Class: Lithic::Models::EmbedSessionGeneratedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/embed_session_generated_webhook_event.rb,
sig/lithic/models/embed_session_generated_webhook_event.rbs

Defined Under Namespace

Modules: SessionType Classes: DeviceDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ip_address:) ⇒ Object

Details about the request that generated the embed session

Parameters:

  • ip_address (String)

    The IP address recorded for the request that generated the event



# File 'lib/lithic/models/embed_session_generated_webhook_event.rb', line 42

Instance Attribute Details

#account_tokenString

The token of the account associated with the card

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/lithic/models/embed_session_generated_webhook_event.rb', line 10

required :account_token, String

#card_tokenString

The token of the card associated with the embed session

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/lithic/models/embed_session_generated_webhook_event.rb', line 16

required :card_token, String

#device_detailsLithic::Models::EmbedSessionGeneratedWebhookEvent::DeviceDetails

Details about the request that generated the embed session

Parameters:

  • value (Lithic::EmbedSessionGeneratedWebhookEvent::DeviceDetails)

Returns:



22
# File 'lib/lithic/models/embed_session_generated_webhook_event.rb', line 22

required :device_details, -> { Lithic::EmbedSessionGeneratedWebhookEvent::DeviceDetails }

#event_typeSymbol, :"embed.session_generated"

The type of event

Parameters:

  • value (:"embed.session_generated")

Returns:

  • (Symbol, :"embed.session_generated")


28
# File 'lib/lithic/models/embed_session_generated_webhook_event.rb', line 28

required :event_type, const: :"embed.session_generated"

#session_idString

The identifier shared by webhook events for the same embed session.

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/lithic/models/embed_session_generated_webhook_event.rb', line 34

required :session_id, String

#session_typeSymbol, Lithic::Models::EmbedSessionGeneratedWebhookEvent::SessionType

The type of embed session that was generated

Parameters:

  • value (Lithic::Models::EmbedSessionGeneratedWebhookEvent::session_type)

Returns:



40
# File 'lib/lithic/models/embed_session_generated_webhook_event.rb', line 40

required :session_type, enum: -> { Lithic::EmbedSessionGeneratedWebhookEvent::SessionType }

Instance Method Details

#to_hash{

Returns:

  • ({)


35
# File 'sig/lithic/models/embed_session_generated_webhook_event.rbs', line 35

def to_hash: -> {