Class: Lithic::Models::EmbedSessionGeneratedWebhookEvent::DeviceDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::EmbedSessionGeneratedWebhookEvent::DeviceDetails
- Defined in:
- lib/lithic/models/embed_session_generated_webhook_event.rb,
sig/lithic/models/embed_session_generated_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#ip_address ⇒ String
The IP address recorded for the request that generated the event.
Instance Method Summary collapse
-
#initialize ⇒ DeviceDetails
constructor
A new instance of DeviceDetails.
- #to_hash ⇒ { ip_address: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ DeviceDetails
Returns a new instance of DeviceDetails.
49 |
# File 'sig/lithic/models/embed_session_generated_webhook_event.rbs', line 49
def initialize: (ip_address: String) -> void
|
Instance Attribute Details
#ip_address ⇒ String
The IP address recorded for the request that generated the event
61 |
# File 'lib/lithic/models/embed_session_generated_webhook_event.rb', line 61 required :ip_address, String |
Instance Method Details
#to_hash ⇒ { ip_address: String }
51 |
# File 'sig/lithic/models/embed_session_generated_webhook_event.rbs', line 51
def to_hash: -> { ip_address: String }
|