Class: Lithic::Models::EmbedViewedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/embed_viewed_webhook_event.rb,
sig/lithic/models/embed_viewed_webhook_event.rbs

Defined Under Namespace

Modules: EmbedType Classes: DeviceDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ip_address:) ⇒ Object

Details about the request that revealed the card detail

Parameters:

  • ip_address (String)

    The IP address recorded for the request that generated the event



# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 42

Instance Attribute Details

#account_tokenString

The token of the account associated with the card

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 10

required :account_token, String

#card_tokenString

The token of the card whose details were revealed

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 16

required :card_token, String

#device_detailsLithic::Models::EmbedViewedWebhookEvent::DeviceDetails

Details about the request that revealed the card detail

Parameters:

  • value (Lithic::EmbedViewedWebhookEvent::DeviceDetails)

Returns:



22
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 22

required :device_details, -> { Lithic::EmbedViewedWebhookEvent::DeviceDetails }

#embed_typeSymbol, Lithic::Models::EmbedViewedWebhookEvent::EmbedType

The type of card detail that was revealed

Parameters:

  • value (Lithic::Models::EmbedViewedWebhookEvent::embed_type)

Returns:



28
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 28

required :embed_type, enum: -> { Lithic::EmbedViewedWebhookEvent::EmbedType }

#event_typeSymbol, :"embed.viewed"

The type of event

Parameters:

  • value (:"embed.viewed")

Returns:

  • (Symbol, :"embed.viewed")


34
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 34

required :event_type, const: :"embed.viewed"

#session_idString

The identifier shared by webhook events for the same embed session.

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 40

required :session_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


35
# File 'sig/lithic/models/embed_viewed_webhook_event.rbs', line 35

def to_hash: -> {