Class: Lithic::Models::Event

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/event.rb,
sig/lithic/models/event.rbs

Overview

See Also:

  • Lithic::Resources::Events#retrieve

Defined Under Namespace

Modules: EventType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, created:, event_type:, payload:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Event for more details.

A single event that affects the transaction state and lifecycle.

Parameters:

  • token (String)

    Globally unique identifier.

  • created (Time)

    An RFC 3339 timestamp for when the event was created. UTC time zone.

  • event_type (Symbol, Lithic::Models::Event::EventType)

    The type of event that occurred. Possible values:

  • payload (Hash{Symbol=>Object})


# File 'lib/lithic/models/event.rb', line 144

Instance Attribute Details

#createdTime

An RFC 3339 timestamp for when the event was created. UTC time zone.

If no timezone is specified, UTC will be used.

Parameters:

  • value (Time)

Returns:

  • (Time)


19
# File 'lib/lithic/models/event.rb', line 19

required :created, Time

#event_typeSymbol, Lithic::Models::Event::EventType

The type of event that occurred. Possible values:

  • account_holder_document.updated: Occurs when an account holder's document upload status has been updated
  • account_holder.created: Occurs when a new account_holder is created.
  • account_holder.updated: Occurs when an account_holder is updated.
  • account_holder.verification: Occurs when an asynchronous account_holder's verification is completed.
  • auth_rules.backtest_report.created: Auth Rules backtest report created.
  • balance.updated: Financial Account Balance Update
  • book_transfer_transaction.created: Occurs when a book transfer transaction is created.
  • book_transfer_transaction.updated: Occurs when a book transfer transaction is updated.
  • card_authorization.challenge: Occurs when an Out of Band challenge is issued during card authorization. The card program should issue its own challenge to the cardholder and then respond via /v1/card_authorizations/event_token/challenge_response.
  • card_authorization.challenge_response: Occurs when a cardholder responds to a challenge during card authorization.
  • card_transaction.enhanced_data.created: Occurs when L2/L3 enhanced commercial data is processed for a transaction event.
  • card_transaction.enhanced_data.updated: Occurs when L2/L3 enhanced commercial data is reprocessed for a transaction event.
  • card_transaction.updated: Occurs when a card transaction happens.
  • card.converted: Occurs when a card is converted from virtual to physical cards.
  • card.created: Occurs when a new card is created.
  • card.reissued: Occurs when a card is reissued.
  • card.renewed: Occurs when a card is renewed.
  • card.shipped: Occurs when a card is shipped.
  • card.updated: Occurs when a card is updated.
  • claim_document.accepted: Occurs when a claim document passes validation and is accepted.
  • claim_document.rejected: Occurs when a claim document fails validation and is rejected.
  • claim_document.uploaded: Occurs when a claim document is uploaded and begins validation.
  • claim.created: Occurs when a dispute intake claim is created.
  • claim.updated: Occurs when a dispute intake claim is updated, such as a status change or a change to its outstanding requirements.
  • digital_wallet.tokenization_result: Occurs when a tokenization request succeeded or failed.

This event will be deprecated in the future. We recommend using tokenization.result instead.

  • digital_wallet.tokenization_two_factor_authentication_code: Occurs when a tokenization request 2FA code is sent to the Lithic customer for self serve delivery.

This event will be deprecated in the future. We recommend using tokenization.two_factor_authentication_code instead.

  • digital_wallet.tokenization_two_factor_authentication_code_sent: Occurs when a tokenization request 2FA code is sent to our downstream messaging providers for delivery.

This event will be deprecated in the future. We recommend using tokenization.two_factor_authentication_code_sent instead.

  • digital_wallet.tokenization_updated: Occurs when a tokenization's status has changed.

This event will be deprecated in the future. We recommend using tokenization.updated instead.

  • dispute_evidence.upload_failed: Occurs when a dispute evidence upload fails.
  • dispute_transaction.created: Occurs when a new dispute transaction is created
  • dispute_transaction.updated: Occurs when a dispute transaction is updated
  • dispute.updated: Occurs when a dispute is updated.
  • external_bank_account.created: Occurs when an external bank account is created.
  • external_bank_account.updated: Occurs when an external bank account is updated.
  • external_payment.created: Occurs when an external payment is created.
  • external_payment.updated: Occurs when an external payment is updated.
  • financial_account.created: Occurs when a financial account is created.
  • financial_account.updated: Occurs when a financial account is updated.
  • funding_event.created: Occurs when a funding event is created.
  • internal_transaction.created: Occurs when an internal adjustment is created.
  • internal_transaction.updated: Occurs when an internal adjustment is updated.
  • loan_tape.created: Occurs when a loan tape is created.
  • loan_tape.updated: Occurs when a loan tape is updated.
  • management_operation.created: Occurs when an management operation is created.
  • management_operation.updated: Occurs when an management operation is updated.
  • network_total.created: Occurs when a network total is created.
  • network_total.updated: Occurs when a network total is updated.
  • payment_transaction.created: Occurs when a payment transaction is created.
  • payment_transaction.updated: Occurs when a payment transaction is updated.
  • settlement_report.updated: Occurs when a settlement report is created or updated.
  • statements.created: Occurs when a statement has been created
  • three_ds_authentication.challenge: The three_ds_authentication.challenge event. Upon receiving this request, the Card Program should issue its own challenge to the cardholder. After a cardholder challenge is successfully completed, the Card Program needs to respond back to Lithic by call to /v1/three_ds_decisioning/challenge_response. Then the cardholder must navigate back to the merchant checkout flow to complete the transaction. Some merchants will include an app_requestor_url for app-based purchases; Lithic recommends triggering a redirect to that URL after the cardholder completes an app-based challenge.
  • three_ds_authentication.created: Occurs when a 3DS authentication is created.
  • three_ds_authentication.updated: Occurs when a 3DS authentication is updated (eg. challenge is completed).
  • tokenization.approval_request: Occurs when a tokenization approval request is made.
  • tokenization.result: Occurs when a tokenization request succeeded or failed.
  • tokenization.two_factor_authentication_code: Occurs when a tokenization request 2FA code is sent to the Lithic customer for self serve delivery.
  • tokenization.two_factor_authentication_code_sent: Occurs when a tokenization request 2FA code is sent to our downstream messaging providers for delivery.
  • tokenization.updated: Occurs when a tokenization's status has changed.

Parameters:

  • value (Lithic::Models::Event::event_type)

Returns:



137
# File 'lib/lithic/models/event.rb', line 137

required :event_type, enum: -> { Lithic::Event::EventType }

#payloadHash{Symbol=>Object}

Parameters:

  • value (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object})


142
# File 'lib/lithic/models/event.rb', line 142

required :payload, Lithic::Internal::Type::HashOf[Lithic::Internal::Type::Unknown]

#tokenString

Globally unique identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/lithic/models/event.rb', line 11

required :token, String

Instance Method Details

#to_hash{

Returns:

  • ({)


27
# File 'sig/lithic/models/event.rbs', line 27

def to_hash: -> {