Module: Lithic::Models::Events::SubscriptionListAttemptsParams::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/events/subscription_list_attempts_params.rb

Constant Summary collapse

FAILED =
:FAILED
PENDING =
:PENDING
SENDING =
:SENDING
SUCCESS =
:SUCCESS

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/events/subscription_list_attempts_params.rb', line 83

Instance Method Details

#initialize(event_subscription_token:, begin_: nil, end_: nil, ending_before: nil, page_size: nil, starting_after: nil, status: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Events::SubscriptionListAttemptsParams for more details.

Parameters:

  • event_subscription_token (String)
  • begin_ (Time) (defaults to: nil)

    Date string in RFC 3339 format. Only entries created after the specified time wi

  • end_ (Time) (defaults to: nil)

    Date string in RFC 3339 format. Only entries created before the specified time w

  • ending_before (String) (defaults to: nil)

    A cursor representing an item’s token before which a page of results should end.

  • page_size (Integer) (defaults to: nil)

    Page size (for pagination).

  • starting_after (String) (defaults to: nil)

    A cursor representing an item’s token after which a page of results should begin

  • status (Symbol, Lithic::Models::Events::SubscriptionListAttemptsParams::Status) (defaults to: nil)
  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


75
76
77
78
79
80
81
82
83
84
85
# File 'lib/lithic/models/events/subscription_list_attempts_params.rb', line 75

module Status
  extend Lithic::Internal::Type::Enum

  FAILED = :FAILED
  PENDING = :PENDING
  SENDING = :SENDING
  SUCCESS = :SUCCESS

  # @!method self.values
  #   @return [Array<Symbol>]
end