Module: Lithic::Models::ExternalBankAccountCreateParams::Body
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/lithic/models/external_bank_account_create_params.rb
Defined Under Namespace
Classes: BankVerifiedCreateBankAccountAPIRequest, ExternallyVerified, Unverified
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified, Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified, Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 185
|
.variants ⇒ Array(Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified, Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified, Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest)
|
|
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 478
|
Instance Method Details
#initialize(body:, request_options: {}) ⇒ Object
19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 19 module Body extend Lithic::Internal::Type::Union discriminator :verification_method variant :EXTERNALLY_VERIFIED, -> { Lithic::ExternalBankAccountCreateParams::Body::ExternallyVerified } variant :UNVERIFIED, -> { Lithic::ExternalBankAccountCreateParams::Body::Unverified } variant -> { Lithic::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest } class BankVerifiedCreateBankAccountAPIRequest < Lithic::Internal::Type::BaseModel # @!attribute account_number # Account Number # # @return [String] required :account_number, String # @!attribute country # The country that the bank account is located in using ISO 3166-1. We will only # accept USA bank accounts e.g., USA # # @return [String] required :country, String # @!attribute currency # currency of the external account 3-character alphabetic ISO 4217 code # # @return [String] required :currency, String # @!attribute financial_account_token # The financial account token of the operating account to fund the micro deposits # # @return [String] required :financial_account_token, String # @!attribute owner # Legal Name of the business or individual who owns the external account. This # will appear in statements # # @return [String] required :owner, String # @!attribute owner_type # Owner Type # # @return [Symbol, Lithic::Models::OwnerType] required :owner_type, enum: -> { Lithic::OwnerType } # @!attribute routing_number # Routing Number # # @return [String] required :routing_number, String # @!attribute type # Account Type # # @return [Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest::Type] required :type, enum: -> { Lithic::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest::Type } # @!attribute verification_method # Verification Method # # @return [Symbol, Lithic::Models::VerificationMethod] required :verification_method, enum: -> { Lithic::VerificationMethod } # @!attribute account_token # Indicates which Lithic account the external account is associated with. For # external accounts that are associated with the program, account_token field # returned will be null # # @return [String, nil] optional :account_token, String # @!attribute address # Address # # @return [Lithic::Models::ExternalBankAccountAddress, nil] optional :address, -> { Lithic::ExternalBankAccountAddress } # @!attribute company_id # Optional field that helps identify bank accounts in receipts # # @return [String, nil] optional :company_id, String # @!attribute dob # Date of Birth of the Individual that owns the external bank account # # @return [Date, nil] optional :dob, Date # @!attribute doing_business_as # Doing Business As # # @return [String, nil] optional :doing_business_as, String # @!attribute name # The nickname for this External Bank Account # # @return [String, nil] optional :name, String # @!attribute user_defined_id # User Defined ID # # @return [String, nil] optional :user_defined_id, String # @!attribute verification_enforcement # # @return [Boolean, nil] optional :verification_enforcement, Lithic::Internal::Type::Boolean # @!method initialize(account_number:, country:, currency:, financial_account_token:, owner:, owner_type:, routing_number:, type:, verification_method:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_enforcement: nil) # Some parameter documentations has been truncated, see # {Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest} # for more details. # # @param account_number [String] Account Number # # @param country [String] The country that the bank account is located in using ISO 3166-1. We will only a # # @param currency [String] currency of the external account 3-character alphabetic ISO 4217 code # # @param financial_account_token [String] The financial account token of the operating account to fund the micro deposits # # @param owner [String] Legal Name of the business or individual who owns the external account. This wil # # @param owner_type [Symbol, Lithic::Models::OwnerType] Owner Type # # @param routing_number [String] Routing Number # # @param type [Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest::Type] Account Type # # @param verification_method [Symbol, Lithic::Models::VerificationMethod] Verification Method # # @param account_token [String] Indicates which Lithic account the external account is associated with. For exte # # @param address [Lithic::Models::ExternalBankAccountAddress] Address # # @param company_id [String] Optional field that helps identify bank accounts in receipts # # @param dob [Date] Date of Birth of the Individual that owns the external bank account # # @param doing_business_as [String] Doing Business As # # @param name [String] The nickname for this External Bank Account # # @param user_defined_id [String] User Defined ID # # @param verification_enforcement [Boolean] # Account Type # # @see Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest#type module Type extend Lithic::Internal::Type::Enum CHECKING = :CHECKING SAVINGS = :SAVINGS # @!method self.values # @return [Array<Symbol>] end end class ExternallyVerified < Lithic::Internal::Type::BaseModel # @!attribute account_number # Account Number # # @return [String] required :account_number, String # @!attribute country # The country that the bank account is located in using ISO 3166-1. We will only # accept USA bank accounts e.g., USA # # @return [String] required :country, String # @!attribute currency # currency of the external account 3-character alphabetic ISO 4217 code # # @return [String] required :currency, String # @!attribute owner # Legal Name of the business or individual who owns the external account. This # will appear in statements # # @return [String] required :owner, String # @!attribute owner_type # Owner Type # # @return [Symbol, Lithic::Models::OwnerType] required :owner_type, enum: -> { Lithic::OwnerType } # @!attribute routing_number # Routing Number # # @return [String] required :routing_number, String # @!attribute type # Account Type # # @return [Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type] required :type, enum: -> { Lithic::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type } # @!attribute verification_method # Verification Method # # @return [Symbol, :EXTERNALLY_VERIFIED] required :verification_method, const: :EXTERNALLY_VERIFIED # @!attribute account_token # Indicates which Lithic account the external account is associated with. For # external accounts that are associated with the program, account_token field # returned will be null # # @return [String, nil] optional :account_token, String # @!attribute address # Address # # @return [Lithic::Models::ExternalBankAccountAddress, nil] optional :address, -> { Lithic::ExternalBankAccountAddress } # @!attribute company_id # Optional field that helps identify bank accounts in receipts # # @return [String, nil] optional :company_id, String # @!attribute dob # Date of Birth of the Individual that owns the external bank account # # @return [Date, nil] optional :dob, Date # @!attribute doing_business_as # Doing Business As # # @return [String, nil] optional :doing_business_as, String # @!attribute name # The nickname for this External Bank Account # # @return [String, nil] optional :name, String # @!attribute user_defined_id # User Defined ID # # @return [String, nil] optional :user_defined_id, String # @!method initialize(account_number:, country:, currency:, owner:, owner_type:, routing_number:, type:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_method: :EXTERNALLY_VERIFIED) # Some parameter documentations has been truncated, see # {Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified} for # more details. # # @param account_number [String] Account Number # # @param country [String] The country that the bank account is located in using ISO 3166-1. We will only a # # @param currency [String] currency of the external account 3-character alphabetic ISO 4217 code # # @param owner [String] Legal Name of the business or individual who owns the external account. This wil # # @param owner_type [Symbol, Lithic::Models::OwnerType] Owner Type # # @param routing_number [String] Routing Number # # @param type [Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type] Account Type # # @param account_token [String] Indicates which Lithic account the external account is associated with. For exte # # @param address [Lithic::Models::ExternalBankAccountAddress] Address # # @param company_id [String] Optional field that helps identify bank accounts in receipts # # @param dob [Date] Date of Birth of the Individual that owns the external bank account # # @param doing_business_as [String] Doing Business As # # @param name [String] The nickname for this External Bank Account # # @param user_defined_id [String] User Defined ID # # @param verification_method [Symbol, :EXTERNALLY_VERIFIED] Verification Method # Account Type # # @see Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified#type module Type extend Lithic::Internal::Type::Enum CHECKING = :CHECKING SAVINGS = :SAVINGS # @!method self.values # @return [Array<Symbol>] end end class Unverified < Lithic::Internal::Type::BaseModel # @!attribute account_number # Account Number # # @return [String] required :account_number, String # @!attribute country # The country that the bank account is located in using ISO 3166-1. We will only # accept USA bank accounts e.g., USA # # @return [String] required :country, String # @!attribute currency # currency of the external account 3-character alphabetic ISO 4217 code # # @return [String] required :currency, String # @!attribute owner # Legal Name of the business or individual who owns the external account. This # will appear in statements # # @return [String] required :owner, String # @!attribute owner_type # Owner Type # # @return [Symbol, Lithic::Models::OwnerType] required :owner_type, enum: -> { Lithic::OwnerType } # @!attribute routing_number # Routing Number # # @return [String] required :routing_number, String # @!attribute type # Account Type # # @return [Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified::Type] required :type, enum: -> { Lithic::ExternalBankAccountCreateParams::Body::Unverified::Type } # @!attribute verification_method # Verification Method # # @return [Symbol, :UNVERIFIED] required :verification_method, const: :UNVERIFIED # @!attribute account_token # Indicates which Lithic account the external account is associated with. For # external accounts that are associated with the program, account_token field # returned will be null # # @return [String, nil] optional :account_token, String # @!attribute address # Address # # @return [Lithic::Models::ExternalBankAccountAddress, nil] optional :address, -> { Lithic::ExternalBankAccountAddress } # @!attribute company_id # Optional field that helps identify bank accounts in receipts # # @return [String, nil] optional :company_id, String # @!attribute dob # Date of Birth of the Individual that owns the external bank account # # @return [Date, nil] optional :dob, Date # @!attribute doing_business_as # Doing Business As # # @return [String, nil] optional :doing_business_as, String # @!attribute name # The nickname for this External Bank Account # # @return [String, nil] optional :name, String # @!attribute user_defined_id # User Defined ID # # @return [String, nil] optional :user_defined_id, String # @!method initialize(account_number:, country:, currency:, owner:, owner_type:, routing_number:, type:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_method: :UNVERIFIED) # Some parameter documentations has been truncated, see # {Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified} for more # details. # # @param account_number [String] Account Number # # @param country [String] The country that the bank account is located in using ISO 3166-1. We will only a # # @param currency [String] currency of the external account 3-character alphabetic ISO 4217 code # # @param owner [String] Legal Name of the business or individual who owns the external account. This wil # # @param owner_type [Symbol, Lithic::Models::OwnerType] Owner Type # # @param routing_number [String] Routing Number # # @param type [Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified::Type] Account Type # # @param account_token [String] Indicates which Lithic account the external account is associated with. For exte # # @param address [Lithic::Models::ExternalBankAccountAddress] Address # # @param company_id [String] Optional field that helps identify bank accounts in receipts # # @param dob [Date] Date of Birth of the Individual that owns the external bank account # # @param doing_business_as [String] Doing Business As # # @param name [String] The nickname for this External Bank Account # # @param user_defined_id [String] User Defined ID # # @param verification_method [Symbol, :UNVERIFIED] Verification Method # Account Type # # @see Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified#type module Type extend Lithic::Internal::Type::Enum CHECKING = :CHECKING SAVINGS = :SAVINGS # @!method self.values # @return [Array<Symbol>] end end # @!method self.variants # @return [Array(Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified, Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified, Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest)] end |