Class: Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/lithic/models/external_bank_account_create_params.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, country:, currency:, financial_account_token:, owner:, owner_type:, routing_number:, type:, verification_method:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_enforcement: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest for more details.

Parameters:

  • account_number (String)

    Account Number

  • country (String)

    The country that the bank account is located in using ISO 3166-1. We will only a

  • currency (String)

    currency of the external account 3-character alphabetic ISO 4217 code

  • financial_account_token (String)

    The financial account token of the operating account to fund the micro deposits

  • owner (String)

    Legal Name of the business or individual who owns the external account. This wil

  • owner_type (Symbol, Lithic::Models::OwnerType)

    Owner Type

  • routing_number (String)

    Routing Number

  • type (Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest::Type)

    Account Type

  • verification_method (Symbol, Lithic::Models::VerificationMethod)

    Verification Method

  • account_token (String) (defaults to: nil)

    Indicates which Lithic account the external account is associated with. For exte

  • address (Lithic::Models::ExternalBankAccountAddress) (defaults to: nil)

    Address

  • company_id (String) (defaults to: nil)

    Optional field that helps identify bank accounts in receipts

  • dob (Date) (defaults to: nil)

    Date of Birth of the Individual that owns the external bank account

  • doing_business_as (String) (defaults to: nil)

    Doing Business As

  • name (String) (defaults to: nil)

    The nickname for this External Bank Account

  • user_defined_id (String) (defaults to: nil)

    User Defined ID

  • verification_enforcement (Boolean) (defaults to: nil)


# File 'lib/lithic/models/external_bank_account_create_params.rb', line 137

Instance Attribute Details

#account_numberString

Account Number

Returns:

  • (String)


35
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 35

required :account_number, String

#account_tokenString?

Indicates which Lithic account the external account is associated with. For external accounts that are associated with the program, account_token field returned will be null

Returns:

  • (String, nil)


94
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 94

optional :account_token, String

#addressLithic::Models::ExternalBankAccountAddress?

Address



100
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 100

optional :address, -> { Lithic::ExternalBankAccountAddress }

#company_idString?

Optional field that helps identify bank accounts in receipts

Returns:

  • (String, nil)


106
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 106

optional :company_id, String

#countryString

The country that the bank account is located in using ISO 3166-1. We will only accept USA bank accounts e.g., USA

Returns:

  • (String)


42
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 42

required :country, String

#currencyString

currency of the external account 3-character alphabetic ISO 4217 code

Returns:

  • (String)


48
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 48

required :currency, String

#dobDate?

Date of Birth of the Individual that owns the external bank account

Returns:

  • (Date, nil)


112
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 112

optional :dob, Date

#doing_business_asString?

Doing Business As

Returns:

  • (String, nil)


118
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 118

optional :doing_business_as, String

#financial_account_tokenString

The financial account token of the operating account to fund the micro deposits

Returns:

  • (String)


54
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 54

required :financial_account_token, String

#nameString?

The nickname for this External Bank Account

Returns:

  • (String, nil)


124
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 124

optional :name, String

#ownerString

Legal Name of the business or individual who owns the external account. This will appear in statements

Returns:

  • (String)


61
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 61

required :owner, String

#owner_typeSymbol, Lithic::Models::OwnerType

Owner Type

Returns:



67
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 67

required :owner_type, enum: -> { Lithic::OwnerType }

#routing_numberString

Routing Number

Returns:

  • (String)


73
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 73

required :routing_number, String

#typeSymbol, Lithic::Models::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest::Type

Account Type



79
80
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 79

required :type,
enum: -> { Lithic::ExternalBankAccountCreateParams::Body::BankVerifiedCreateBankAccountAPIRequest::Type }

#user_defined_idString?

User Defined ID

Returns:

  • (String, nil)


130
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 130

optional :user_defined_id, String

#verification_enforcementBoolean?

Returns:

  • (Boolean, nil)


135
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 135

optional :verification_enforcement, Lithic::Internal::Type::Boolean

#verification_methodSymbol, Lithic::Models::VerificationMethod

Verification Method



86
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 86

required :verification_method, enum: -> { Lithic::VerificationMethod }