Class: Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/external_bank_account_create_params.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, country:, currency:, owner:, owner_type:, routing_number:, type:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_method: :EXTERNALLY_VERIFIED) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified for more details.

Parameters:

  • account_number (String)

    Account Number

  • country (String)

    The country that the bank account is located in using ISO 3166-1. We will only a

  • currency (String)

    currency of the external account 3-character alphabetic ISO 4217 code

  • owner (String)

    Legal Name of the business or individual who owns the external account. This wil

  • owner_type (Symbol, Lithic::Models::OwnerType)

    Owner Type

  • routing_number (String)

    Routing Number

  • type (Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type)

    Account Type

  • account_token (String) (defaults to: nil)

    Indicates which Lithic account the external account is associated with. For exte

  • address (Lithic::Models::ExternalBankAccountAddress) (defaults to: nil)

    Address

  • company_id (String) (defaults to: nil)

    Optional field that helps identify bank accounts in receipts

  • dob (Date) (defaults to: nil)

    Date of Birth of the Individual that owns the external bank account

  • doing_business_as (String) (defaults to: nil)

    Doing Business As

  • name (String) (defaults to: nil)

    The nickname for this External Bank Account

  • user_defined_id (String) (defaults to: nil)

    User Defined ID

  • verification_method (Symbol, :EXTERNALLY_VERIFIED) (defaults to: :EXTERNALLY_VERIFIED)

    Verification Method



# File 'lib/lithic/models/external_bank_account_create_params.rb', line 285

Instance Attribute Details

#account_numberString

Account Number

Returns:

  • (String)


195
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 195

required :account_number, String

#account_tokenString?

Indicates which Lithic account the external account is associated with. For external accounts that are associated with the program, account_token field returned will be null

Returns:

  • (String, nil)


247
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 247

optional :account_token, String

#addressLithic::Models::ExternalBankAccountAddress?

Address



253
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 253

optional :address, -> { Lithic::ExternalBankAccountAddress }

#company_idString?

Optional field that helps identify bank accounts in receipts

Returns:

  • (String, nil)


259
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 259

optional :company_id, String

#countryString

The country that the bank account is located in using ISO 3166-1. We will only accept USA bank accounts e.g., USA

Returns:

  • (String)


202
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 202

required :country, String

#currencyString

currency of the external account 3-character alphabetic ISO 4217 code

Returns:

  • (String)


208
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 208

required :currency, String

#dobDate?

Date of Birth of the Individual that owns the external bank account

Returns:

  • (Date, nil)


265
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 265

optional :dob, Date

#doing_business_asString?

Doing Business As

Returns:

  • (String, nil)


271
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 271

optional :doing_business_as, String

#nameString?

The nickname for this External Bank Account

Returns:

  • (String, nil)


277
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 277

optional :name, String

#ownerString

Legal Name of the business or individual who owns the external account. This will appear in statements

Returns:

  • (String)


215
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 215

required :owner, String

#owner_typeSymbol, Lithic::Models::OwnerType

Owner Type

Returns:



221
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 221

required :owner_type, enum: -> { Lithic::OwnerType }

#routing_numberString

Routing Number

Returns:

  • (String)


227
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 227

required :routing_number, String

#typeSymbol, Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type

Account Type



233
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 233

required :type, enum: -> { Lithic::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type }

#user_defined_idString?

User Defined ID

Returns:

  • (String, nil)


283
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 283

optional :user_defined_id, String

#verification_methodSymbol, :EXTERNALLY_VERIFIED

Verification Method

Returns:

  • (Symbol, :EXTERNALLY_VERIFIED)


239
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 239

required :verification_method, const: :EXTERNALLY_VERIFIED