Class: Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified
- Defined in:
- lib/lithic/models/external_bank_account_create_params.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#account_number ⇒ String
Account Number.
-
#account_token ⇒ String?
Indicates which Lithic account the external account is associated with.
-
#address ⇒ Lithic::Models::ExternalBankAccountAddress?
Address.
-
#company_id ⇒ String?
Optional field that helps identify bank accounts in receipts.
-
#country ⇒ String
The country that the bank account is located in using ISO 3166-1.
-
#currency ⇒ String
currency of the external account 3-character alphabetic ISO 4217 code.
-
#dob ⇒ Date?
Date of Birth of the Individual that owns the external bank account.
-
#doing_business_as ⇒ String?
Doing Business As.
-
#name ⇒ String?
The nickname for this External Bank Account.
-
#owner ⇒ String
Legal Name of the business or individual who owns the external account.
-
#owner_type ⇒ Symbol, Lithic::Models::OwnerType
Owner Type.
-
#routing_number ⇒ String
Routing Number.
-
#type ⇒ Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified::Type
Account Type.
-
#user_defined_id ⇒ String?
User Defined ID.
-
#verification_method ⇒ Symbol, :UNVERIFIED
Verification Method.
Instance Method Summary collapse
-
#initialize(account_number:, country:, currency:, owner:, owner_type:, routing_number:, type:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_method: :UNVERIFIED) ⇒ Object
constructor
Some parameter documentations has been truncated, see Unverified for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number:, country:, currency:, owner:, owner_type:, routing_number:, type:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_method: :UNVERIFIED) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified for more details.
|
|
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 429
|
Instance Attribute Details
#account_number ⇒ String
Account Number
339 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 339 required :account_number, String |
#account_token ⇒ String?
Indicates which Lithic account the external account is associated with. For external accounts that are associated with the program, account_token field returned will be null
391 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 391 optional :account_token, String |
#address ⇒ Lithic::Models::ExternalBankAccountAddress?
Address
397 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 397 optional :address, -> { Lithic::ExternalBankAccountAddress } |
#company_id ⇒ String?
Optional field that helps identify bank accounts in receipts
403 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 403 optional :company_id, String |
#country ⇒ String
The country that the bank account is located in using ISO 3166-1. We will only accept USA bank accounts e.g., USA
346 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 346 required :country, String |
#currency ⇒ String
currency of the external account 3-character alphabetic ISO 4217 code
352 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 352 required :currency, String |
#dob ⇒ Date?
Date of Birth of the Individual that owns the external bank account
409 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 409 optional :dob, Date |
#doing_business_as ⇒ String?
Doing Business As
415 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 415 optional :doing_business_as, String |
#name ⇒ String?
The nickname for this External Bank Account
421 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 421 optional :name, String |
#owner ⇒ String
Legal Name of the business or individual who owns the external account. This will appear in statements
359 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 359 required :owner, String |
#owner_type ⇒ Symbol, Lithic::Models::OwnerType
Owner Type
365 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 365 required :owner_type, enum: -> { Lithic::OwnerType } |
#routing_number ⇒ String
Routing Number
371 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 371 required :routing_number, String |
#type ⇒ Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::Unverified::Type
Account Type
377 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 377 required :type, enum: -> { Lithic::ExternalBankAccountCreateParams::Body::Unverified::Type } |
#user_defined_id ⇒ String?
User Defined ID
427 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 427 optional :user_defined_id, String |
#verification_method ⇒ Symbol, :UNVERIFIED
Verification Method
383 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 383 required :verification_method, const: :UNVERIFIED |