Class: Lithic::Models::ExternalBankAccountListParams
Overview
Defined Under Namespace
Modules: AccountType, State, VerificationState
Instance Attribute Summary collapse
#request_options
Class Method Summary
collapse
Instance Method Summary
collapse
dump_request
included
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
65
|
# File 'sig/lithic/models/external_bank_account_list_params.rbs', line 65
def initialize: (
|
Instance Attribute Details
#account_token ⇒ String?
13
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 13
optional :account_token, String
|
18
19
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 18
optional :account_types,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::ExternalBankAccountListParams::AccountType] }
|
#countries ⇒ Array<String>?
24
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 24
optional :countries, Lithic::Internal::Type::ArrayOf[String]
|
#ending_before ⇒ String?
A cursor representing an item's token before which a page of results should end.
Used to retrieve the previous page of results before this item.
31
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 31
optional :ending_before, String
|
36
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 36
optional :owner_types, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::OwnerType] }
|
#page_size ⇒ Integer?
Page size (for pagination).
42
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 42
optional :page_size, Integer
|
#starting_after ⇒ String?
A cursor representing an item's token after which a page of results should
begin. Used to retrieve the next page of results after this item.
49
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 49
optional :starting_after, String
|
54
55
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 54
optional :states,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::ExternalBankAccountListParams::State] }
|
60
61
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 60
optional :verification_states,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::ExternalBankAccountListParams::VerificationState] }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/lithic/models/external_bank_account_list_params.rb', line 93
|
Instance Method Details
#to_hash ⇒ {
78
|
# File 'sig/lithic/models/external_bank_account_list_params.rbs', line 78
def to_hash: -> {
|