Class: Lithic::Models::ExternalBankAccountSetVerificationMethodParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/external_bank_account_set_verification_method_params.rb

Overview

Defined Under Namespace

Modules: VerificationMethod

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_bank_account_token:, verification_method:, financial_account_token: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ExternalBankAccountSetVerificationMethodParams for more details.

Parameters:



# File 'lib/lithic/models/external_bank_account_set_verification_method_params.rb', line 29

Instance Attribute Details

#external_bank_account_tokenString

Returns:

  • (String)


13
# File 'lib/lithic/models/external_bank_account_set_verification_method_params.rb', line 13

required :external_bank_account_token, String

#financial_account_tokenString?

The financial account token of the operating account to fund the micro deposits. Required when verification_method is MICRO_DEPOSIT or PRENOTE.

Returns:

  • (String, nil)


27
# File 'lib/lithic/models/external_bank_account_set_verification_method_params.rb', line 27

optional :financial_account_token, String

#verification_methodSymbol, Lithic::Models::ExternalBankAccountSetVerificationMethodParams::VerificationMethod

The verification method to set for the external bank account



19
20
# File 'lib/lithic/models/external_bank_account_set_verification_method_params.rb', line 19

required :verification_method,
enum: -> { Lithic::ExternalBankAccountSetVerificationMethodParams::VerificationMethod }