Class: Lithic::Models::ExternalPaymentCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ExternalPaymentCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/external_payment_create_params.rb
Overview
Defined Under Namespace
Modules: Category, PaymentType, ProgressTo
Instance Attribute Summary collapse
- #amount ⇒ Integer
- #category ⇒ Symbol, Lithic::Models::ExternalPaymentCreateParams::Category
- #effective_date ⇒ Date
- #financial_account_token ⇒ String
- #memo ⇒ String?
- #payment_type ⇒ Symbol, Lithic::Models::ExternalPaymentCreateParams::PaymentType
- #progress_to ⇒ Symbol, ...
-
#token ⇒ String?
Customer-provided token that will serve as an idempotency token.
- #user_defined_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Lithic::Internal::Type::BaseModel
Instance Attribute Details
#amount ⇒ Integer
13 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 13 required :amount, Integer |
#category ⇒ Symbol, Lithic::Models::ExternalPaymentCreateParams::Category
18 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 18 required :category, enum: -> { Lithic::ExternalPaymentCreateParams::Category } |
#effective_date ⇒ Date
23 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 23 required :effective_date, Date |
#financial_account_token ⇒ String
28 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 28 required :financial_account_token, String |
#memo ⇒ String?
45 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 45 optional :memo, String |
#payment_type ⇒ Symbol, Lithic::Models::ExternalPaymentCreateParams::PaymentType
33 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 33 required :payment_type, enum: -> { Lithic::ExternalPaymentCreateParams::PaymentType } |
#progress_to ⇒ Symbol, ...
50 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 50 optional :progress_to, enum: -> { Lithic::ExternalPaymentCreateParams::ProgressTo } |
#token ⇒ String?
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
40 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 40 optional :token, String |
#user_defined_id ⇒ String?
55 |
# File 'lib/lithic/models/external_payment_create_params.rb', line 55 optional :user_defined_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/external_payment_create_params.rb', line 91
|