Class: Lithic::Models::FinancialAccounts::CreditConfigurationUpdateParams::AutoCollectionConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::FinancialAccounts::CreditConfigurationUpdateParams::AutoCollectionConfiguration
- Defined in:
- lib/lithic/models/financial_accounts/credit_configuration_update_params.rb,
sig/lithic/models/financial_accounts/credit_configuration_update_params.rbs
Instance Attribute Summary collapse
-
#auto_collection_enabled ⇒ Boolean?
If auto collection is enabled for this account.
Instance Method Summary collapse
-
#initialize(auto_collection_enabled: nil) ⇒ AutoCollectionConfiguration
constructor
A new instance of AutoCollectionConfiguration.
- #to_hash ⇒ { auto_collection_enabled: bool }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(auto_collection_enabled: nil) ⇒ AutoCollectionConfiguration
Returns a new instance of AutoCollectionConfiguration.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/lithic/models/financial_accounts/credit_configuration_update_params.rb', line 59 class AutoCollectionConfiguration < Lithic::Internal::Type::BaseModel # @!attribute auto_collection_enabled # If auto collection is enabled for this account # # @return [Boolean, nil] optional :auto_collection_enabled, Lithic::Internal::Type::Boolean # @!method initialize(auto_collection_enabled: nil) # @param auto_collection_enabled [Boolean] If auto collection is enabled for this account end |
Instance Attribute Details
#auto_collection_enabled ⇒ Boolean?
If auto collection is enabled for this account
64 |
# File 'lib/lithic/models/financial_accounts/credit_configuration_update_params.rb', line 64 optional :auto_collection_enabled, Lithic::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ { auto_collection_enabled: bool }
72 |
# File 'sig/lithic/models/financial_accounts/credit_configuration_update_params.rbs', line 72
def to_hash: -> { auto_collection_enabled: bool }
|