Class: Lithic::Models::FinancialAccounts::FinancialAccountsInterestTierSchedule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/financial_accounts/interest_tier_schedule.rb

Overview

Direct Known Subclasses

InterestTierScheduleCreateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credit_product_token:, effective_date:, penalty_rates: nil, tier_name: nil, tier_rates: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::FinancialAccounts::FinancialAccountsInterestTierSchedule for more details.

Entry in the Tier Schedule of an account

Parameters:

  • credit_product_token (String)

    Globally unique identifier for a credit product

  • effective_date (Date)

    Date the tier should be effective in YYYY-MM-DD format

  • penalty_rates (Object) (defaults to: nil)

    Custom rates per category for penalties

  • tier_name (String) (defaults to: nil)

    Name of a tier contained in the credit product. Mutually exclusive with tier_rat

  • tier_rates (Object) (defaults to: nil)

    Custom rates per category. Mutually exclusive with tier_name



# File 'lib/lithic/models/financial_accounts/interest_tier_schedule.rb', line 39

Instance Attribute Details

#credit_product_tokenString

Globally unique identifier for a credit product

Returns:

  • (String)


12
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule.rb', line 12

required :credit_product_token, String

#effective_dateDate

Date the tier should be effective in YYYY-MM-DD format

Returns:

  • (Date)


18
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule.rb', line 18

required :effective_date, Date

#penalty_ratesObject?

Custom rates per category for penalties

Returns:

  • (Object, nil)


24
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule.rb', line 24

optional :penalty_rates, Lithic::Internal::Type::Unknown

#tier_nameString?

Name of a tier contained in the credit product. Mutually exclusive with tier_rates

Returns:

  • (String, nil)


31
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule.rb', line 31

optional :tier_name, String

#tier_ratesObject?

Custom rates per category. Mutually exclusive with tier_name

Returns:

  • (Object, nil)


37
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule.rb', line 37

optional :tier_rates, Lithic::Internal::Type::Unknown