Class: Lithic::Models::FinancialAccounts::InstallmentPlan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/financial_accounts/installment_plan.rb,
sig/lithic/models/financial_accounts/installment_plan.rbs

Overview

See Also:

  • Lithic::Resources::FinancialAccounts::InstallmentPlans#retrieve

Defined Under Namespace

Modules: SourceType, State Classes: Installment

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, amount_details:, date:) ⇒ Object

Parameters:



# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 271

Instance Attribute Details

#closed_at ⇒ Date?

Date the plan was paid off or cancelled, or null while it is still open

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


18
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 18

required :closed_at, Date, nil?: true

#created ⇒ Time

Timestamp of when the installment plan was created

Parameters:

  • value (Time)

Returns:

  • (Time)


24
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 24

required :created, Time

#fee_amount ⇒ Integer

Enrollment fee charged when the plan was created in cents

Parameters:

  • value (Integer)

Returns:

  • (Integer)


30
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 30

required :fee_amount, Integer

#financial_account_token ⇒ String

Globally unique identifier for a financial account

Parameters:

  • value (String)

Returns:

  • (String)


36
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 36

required :financial_account_token, String

#installment_plan_total ⇒ Integer

Total owed on the plan in cents, the principal amount plus the enrollment fee

Parameters:

  • value (Integer)

Returns:

  • (Integer)


42
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 42

required :installment_plan_total, Integer

#installments ⇒ Array<Lithic::Models::FinancialAccounts::InstallmentPlan::Installment>

Installments that make up the plan, oldest first

Parameters:

  • value (::Array[Lithic::FinancialAccounts::InstallmentPlan::Installment])

Returns:



48
49
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 48

required :installments,
-> { Lithic::Internal::Type::ArrayOf[Lithic::FinancialAccounts::InstallmentPlan::Installment] }

#installments_outstanding ⇒ Integer

Number of installments that still carry a balance

Parameters:

  • value (Integer)

Returns:

  • (Integer)


55
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 55

required :installments_outstanding, Integer

#installments_paid ⇒ Integer

Number of installments that have been paid off

Parameters:

  • value (Integer)

Returns:

  • (Integer)


61
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 61

required :installments_paid, Integer

#num_installments ⇒ Integer

Number of installments the plan is broken into

Parameters:

  • value (Integer)

Returns:

  • (Integer)


67
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 67

required :num_installments, Integer

#principal_amount ⇒ Integer

Balance the plan was opened on in cents, excluding the enrollment fee

Parameters:

  • value (Integer)

Returns:

  • (Integer)


73
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 73

required :principal_amount, Integer

#source_amounts ⇒ Lithic::Models::FinancialAccounts::TransactionCategoryBalances?

Balance the plan was opened on, broken out by category, or null if it was not recorded

Parameters:

  • value (Lithic::FinancialAccounts::TransactionCategoryBalances, nil)

Returns:



80
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 80

required :source_amounts, -> { Lithic::FinancialAccounts::TransactionCategoryBalances }, nil?: true

#source_id ⇒ String

Identifier of the record the plan was opened from, such as the closing statement for an unpaid balance

Parameters:

  • value (String)

Returns:

  • (String)


87
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 87

required :source_id, String

#source_type ⇒ Symbol, Lithic::Models::FinancialAccounts::InstallmentPlan::SourceType

Parameters:

  • value (Lithic::Models::FinancialAccounts::InstallmentPlan::source_type)

Returns:



92
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 92

required :source_type, enum: -> { Lithic::FinancialAccounts::InstallmentPlan::SourceType }

#start_date ⇒ Date

Date the plan was created

Parameters:

  • value (Date)

Returns:

  • (Date)


98
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 98

required :start_date, Date

#state ⇒ Symbol, Lithic::Models::FinancialAccounts::InstallmentPlan::State

State of the installment plan. A plan is REBUILD_IN_PROGRESS while its loan tapes are being rebuilt, during which its payment totals are being recomputed and should not be treated as final

Parameters:

  • value (Lithic::Models::FinancialAccounts::InstallmentPlan::state)

Returns:



106
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 106

required :state, enum: -> { Lithic::FinancialAccounts::InstallmentPlan::State }

#token ⇒ String

Globally unique identifier for an installment plan

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 12

required :token, String

#total_paid ⇒ Integer

Amount paid towards the plan to date in cents

Parameters:

  • value (Integer)

Returns:

  • (Integer)


112
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 112

required :total_paid, Integer

#updated ⇒ Time

Timestamp of when the installment plan was updated

Parameters:

  • value (Time)

Returns:

  • (Time)


118
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 118

required :updated, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 287

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


84
# File 'sig/lithic/models/financial_accounts/installment_plan.rbs', line 84

def to_hash: -> {