Class: Lithic::Models::FinancialAccounts::InstallmentPlan::Installment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/financial_accounts/installment_plan.rb,
sig/lithic/models/financial_accounts/installment_plan.rbs

Defined Under Namespace

Classes: Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, closed_at:, created:, fee_amount:, financial_account_token:, installment_plan_total:, installments:, installments_outstanding:, installments_paid:, num_installments:, principal_amount:, source_amounts:, source_id:, source_type:, start_date:, state:, total_paid:, updated:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::FinancialAccounts::InstallmentPlan for more details.

Parameters:

  • token (String) —

    Globally unique identifier for an installment plan

  • closed_at (Date, nil) —

    Date the plan was paid off or cancelled, or null while it is still open

  • created (Time) —

    Timestamp of when the installment plan was created

  • fee_amount (Integer) —

    Enrollment fee charged when the plan was created in cents

  • financial_account_token (String) —

    Globally unique identifier for a financial account

  • installment_plan_total (Integer) —

    Total owed on the plan in cents, the principal amount plus the enrollment fee

  • installments (Array<Lithic::Models::FinancialAccounts::InstallmentPlan::Installment>) —

    Installments that make up the plan, oldest first

  • installments_outstanding (Integer) —

    Number of installments that still carry a balance

  • installments_paid (Integer) —

    Number of installments that have been paid off

  • num_installments (Integer) —

    Number of installments the plan is broken into

  • principal_amount (Integer) —

    Balance the plan was opened on in cents, excluding the enrollment fee

  • source_amounts (Lithic::Models::FinancialAccounts::TransactionCategoryBalances, nil) —

    Balance the plan was opened on, broken out by category, or null if it was not re

  • source_id (String) —

    Identifier of the record the plan was opened from, such as the closing statement

  • source_type (Symbol, Lithic::Models::FinancialAccounts::InstallmentPlan::SourceType)
  • start_date (Date) —

    Date the plan was created

  • state (Symbol, Lithic::Models::FinancialAccounts::InstallmentPlan::State) —

    State of the installment plan. A plan is REBUILD_IN_PROGRESS while its loan tape

  • total_paid (Integer) —

    Amount paid towards the plan to date in cents

  • updated (Time) —

    Timestamp of when the installment plan was updated



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 160

class Installment < Lithic::Internal::Type::BaseModel
  # @!attribute amount_due
  #   Amount the installment was opened for in cents
  #
  #   @return [Integer]
  required :amount_due, Integer

  # @!attribute amount_due_details
  #
  #   @return [Lithic::Models::FinancialAccounts::TransactionCategoryBalances]
  required :amount_due_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances }

  # @!attribute amount_outstanding
  #   Amount still owed on the installment in cents
  #
  #   @return [Integer]
  required :amount_outstanding, Integer

  # @!attribute amount_outstanding_details
  #
  #   @return [Lithic::Models::FinancialAccounts::TransactionCategoryBalances]
  required :amount_outstanding_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances }

  # @!attribute amount_paid
  #   Amount paid towards the installment in cents
  #
  #   @return [Integer]
  required :amount_paid, Integer

  # @!attribute amount_paid_details
  #
  #   @return [Lithic::Models::FinancialAccounts::TransactionCategoryBalances]
  required :amount_paid_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances }

  # @!attribute date_assessed
  #   Date the installment was actually assessed onto the account, or null if it has
  #   not been assessed yet
  #
  #   @return [Date, nil]
  required :date_assessed, Date, nil?: true

  # @!attribute due_date
  #   Date the installment is scheduled to be assessed onto the account
  #
  #   @return [Date]
  required :due_date, Date

  # @!attribute installment_num
  #   Position of this installment within the plan, starting at 0
  #
  #   @return [Integer]
  required :installment_num, Integer

  # @!attribute payment_due_date
  #   Date the installment must be paid by before it is considered past due
  #
  #   @return [Date]
  required :payment_due_date, Date

  # @!attribute payments
  #   Payments applied to this installment, oldest first
  #
  #   @return [Array<Lithic::Models::FinancialAccounts::InstallmentPlan::Installment::Payment>]
  required :payments,
           -> { Lithic::Internal::Type::ArrayOf[Lithic::FinancialAccounts::InstallmentPlan::Installment::Payment] }

  # @!method initialize(amount_due:, amount_due_details:, amount_outstanding:, amount_outstanding_details:, amount_paid:, amount_paid_details:, date_assessed:, due_date:, installment_num:, payment_due_date:, payments:)
  #   Some parameter documentations has been truncated, see
  #   {Lithic::Models::FinancialAccounts::InstallmentPlan::Installment} for more
  #   details.
  #
  #   @param amount_due [Integer] Amount the installment was opened for in cents
  #
  #   @param amount_due_details [Lithic::Models::FinancialAccounts::TransactionCategoryBalances]
  #
  #   @param amount_outstanding [Integer] Amount still owed on the installment in cents
  #
  #   @param amount_outstanding_details [Lithic::Models::FinancialAccounts::TransactionCategoryBalances]
  #
  #   @param amount_paid [Integer] Amount paid towards the installment in cents
  #
  #   @param amount_paid_details [Lithic::Models::FinancialAccounts::TransactionCategoryBalances]
  #
  #   @param date_assessed [Date, nil] Date the installment was actually assessed onto the account, or null if it has n
  #
  #   @param due_date [Date] Date the installment is scheduled to be assessed onto the account
  #
  #   @param installment_num [Integer] Position of this installment within the plan, starting at 0
  #
  #   @param payment_due_date [Date] Date the installment must be paid by before it is considered past due
  #
  #   @param payments [Array<Lithic::Models::FinancialAccounts::InstallmentPlan::Installment::Payment>] Payments applied to this installment, oldest first

  class Payment < Lithic::Internal::Type::BaseModel
    # @!attribute amount
    #   Amount applied to the installment in cents
    #
    #   @return [Integer]
    required :amount, Integer

    # @!attribute amount_details
    #
    #   @return [Lithic::Models::FinancialAccounts::TransactionCategoryBalances]
    required :amount_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances }

    # @!attribute date
    #   Date the payment was applied to the installment
    #
    #   @return [Date]
    required :date, Date

    # @!method initialize(amount:, amount_details:, date:)
    #   @param amount [Integer] Amount applied to the installment in cents
    #
    #   @param amount_details [Lithic::Models::FinancialAccounts::TransactionCategoryBalances]
    #
    #   @param date [Date] Date the payment was applied to the installment
  end
end

Instance Attribute Details

#amount_due ⇒ Integer

Amount the installment was opened for in cents

Parameters:

  • value (Integer)

Returns:

  • (Integer)


165
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 165

required :amount_due, Integer

#amount_due_details ⇒ Lithic::Models::FinancialAccounts::TransactionCategoryBalances

Parameters:

  • value (Lithic::FinancialAccounts::TransactionCategoryBalances)

Returns:



170
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 170

required :amount_due_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances }

#amount_outstanding ⇒ Integer

Amount still owed on the installment in cents

Parameters:

  • value (Integer)

Returns:

  • (Integer)


176
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 176

required :amount_outstanding, Integer

#amount_outstanding_details ⇒ Lithic::Models::FinancialAccounts::TransactionCategoryBalances

Parameters:

  • value (Lithic::FinancialAccounts::TransactionCategoryBalances)

Returns:



181
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 181

required :amount_outstanding_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances }

#amount_paid ⇒ Integer

Amount paid towards the installment in cents

Parameters:

  • value (Integer)

Returns:

  • (Integer)


187
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 187

required :amount_paid, Integer

#amount_paid_details ⇒ Lithic::Models::FinancialAccounts::TransactionCategoryBalances

Parameters:

  • value (Lithic::FinancialAccounts::TransactionCategoryBalances)

Returns:



192
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 192

required :amount_paid_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances }

#date_assessed ⇒ Date?

Date the installment was actually assessed onto the account, or null if it has not been assessed yet

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


199
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 199

required :date_assessed, Date, nil?: true

#due_date ⇒ Date

Date the installment is scheduled to be assessed onto the account

Parameters:

  • value (Date)

Returns:

  • (Date)


205
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 205

required :due_date, Date

#installment_num ⇒ Integer

Position of this installment within the plan, starting at 0

Parameters:

  • value (Integer)

Returns:

  • (Integer)


211
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 211

required :installment_num, Integer

#payment_due_date ⇒ Date

Date the installment must be paid by before it is considered past due

Parameters:

  • value (Date)

Returns:

  • (Date)


217
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 217

required :payment_due_date, Date

#payments ⇒ Array<Lithic::Models::FinancialAccounts::InstallmentPlan::Installment::Payment>

Payments applied to this installment, oldest first

Parameters:

  • value (::Array[Lithic::FinancialAccounts::InstallmentPlan::Installment::Payment])

Returns:



223
224
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 223

required :payments,
-> { Lithic::Internal::Type::ArrayOf[Lithic::FinancialAccounts::InstallmentPlan::Installment::Payment] }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


157
# File 'sig/lithic/models/financial_accounts/installment_plan.rbs', line 157

def to_hash: -> {