Class: Lithic::Models::FinancialAccounts::InstallmentPlan::Installment::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::FinancialAccounts::InstallmentPlan::Installment::Payment
- Defined in:
- lib/lithic/models/financial_accounts/installment_plan.rb,
sig/lithic/models/financial_accounts/installment_plan.rbs
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Amount applied to the installment in cents.
- #amount_details ⇒ Lithic::Models::FinancialAccounts::TransactionCategoryBalances
-
#date ⇒ Date
Date the payment was applied to the installment.
Instance Method Summary collapse
-
#initialize(amount_due:, amount_due_details:, amount_outstanding:, amount_outstanding_details:, amount_paid:, amount_paid_details:, date_assessed:, due_date:, installment_num:, payment_due_date:, payments:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Lithic::Models::FinancialAccounts::InstallmentPlan::Installment for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount_due:, amount_due_details:, amount_outstanding:, amount_outstanding_details:, amount_paid:, amount_paid_details:, date_assessed:, due_date:, installment_num:, payment_due_date:, payments:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::FinancialAccounts::InstallmentPlan::Installment for more details.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 253 class Payment < Lithic::Internal::Type::BaseModel # @!attribute amount # Amount applied to the installment in cents # # @return [Integer] required :amount, Integer # @!attribute amount_details # # @return [Lithic::Models::FinancialAccounts::TransactionCategoryBalances] required :amount_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances } # @!attribute date # Date the payment was applied to the installment # # @return [Date] required :date, Date # @!method initialize(amount:, amount_details:, date:) # @param amount [Integer] Amount applied to the installment in cents # # @param amount_details [Lithic::Models::FinancialAccounts::TransactionCategoryBalances] # # @param date [Date] Date the payment was applied to the installment end |
Instance Attribute Details
#amount ⇒ Integer
Amount applied to the installment in cents
258 |
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 258 required :amount, Integer |
#amount_details ⇒ Lithic::Models::FinancialAccounts::TransactionCategoryBalances
263 |
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 263 required :amount_details, -> { Lithic::FinancialAccounts::TransactionCategoryBalances } |
#date ⇒ Date
Date the payment was applied to the installment
269 |
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 269 required :date, Date |
Instance Method Details
#to_hash ⇒ {
191 |
# File 'sig/lithic/models/financial_accounts/installment_plan.rbs', line 191
def to_hash: -> {
|