Module: Lithic::Models::FinancialAccounts::InstallmentPlan::State
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/financial_accounts/installment_plan.rb,
sig/lithic/models/financial_accounts/installment_plan.rbs
Overview
State of the installment plan. A plan is REBUILD_IN_PROGRESS while its loan tapes are being rebuilt, during which its payment totals are being recomputed and should not be treated as final
Constant Summary collapse
- PENDING =
:PENDING- ACTIVE =
:ACTIVE- REBUILD_IN_PROGRESS =
:REBUILD_IN_PROGRESS- FULLY_PAID =
:FULLY_PAID- CANCELLED =
:CANCELLED
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/financial_accounts/installment_plan.rb', line 305
|
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::FinancialAccounts::InstallmentPlan::state]
222 |
# File 'sig/lithic/models/financial_accounts/installment_plan.rbs', line 222 def self?.values: -> ::Array[Lithic::Models::FinancialAccounts::InstallmentPlan::state] |