Class: Lithic::Models::FinancialAccounts::InterestTierScheduleUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(financial_account_token:, effective_date:, penalty_rates: nil, tier_name: nil, tier_rates: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::FinancialAccounts::InterestTierScheduleUpdateParams for more details.

Parameters:

  • financial_account_token (String)
  • effective_date (Date)
  • penalty_rates (Object) (defaults to: nil)

    Custom rates per category for penalties

  • tier_name (String) (defaults to: nil)

    Name of a tier contained in the credit product. Mutually exclusive with tier_rat

  • tier_rates (Object) (defaults to: nil)

    Custom rates per category. Mutually exclusive with tier_name

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 40

Instance Attribute Details

#effective_dateDate

Returns:

  • (Date)


19
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 19

required :effective_date, Date

#financial_account_tokenString

Returns:

  • (String)


14
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 14

required :financial_account_token, String

#penalty_ratesObject?

Custom rates per category for penalties

Returns:

  • (Object, nil)


25
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 25

optional :penalty_rates, Lithic::Internal::Type::Unknown

#tier_nameString?

Name of a tier contained in the credit product. Mutually exclusive with tier_rates

Returns:

  • (String, nil)


32
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 32

optional :tier_name, String

#tier_ratesObject?

Custom rates per category. Mutually exclusive with tier_name

Returns:

  • (Object, nil)


38
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 38

optional :tier_rates, Lithic::Internal::Type::Unknown