Class: Lithic::Models::FinancialAccounts::LoanTape

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/financial_accounts/loan_tape.rb,
sig/lithic/models/financial_accounts/loan_tape.rbs

Overview

See Also:

  • Lithic::Resources::FinancialAccounts::LoanTapes#retrieve

Defined Under Namespace

Classes: AccountStanding, Balances, InterestDetails, MinimumPaymentBalance, PaymentAllocation, PreviousStatementBalance

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(fee_details:, fees:, interest:, interest_details:, principal:, principal_details:) ⇒ Object

Parameters:



# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 141

Instance Attribute Details

#account_standingLithic::Models::FinancialAccounts::LoanTape::AccountStanding

Parameters:

  • value (Lithic::FinancialAccounts::LoanTape::AccountStanding)

Returns:



17
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 17

required :account_standing, -> { Lithic::FinancialAccounts::LoanTape::AccountStanding }

#available_creditInteger

Amount of credit available to spend in cents

Parameters:

  • value (Integer)

Returns:

  • (Integer)


23
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 23

required :available_credit, Integer

#balancesLithic::Models::FinancialAccounts::LoanTape::Balances

Parameters:

  • value (Lithic::FinancialAccounts::LoanTape::Balances)

Returns:



28
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 28

required :balances, -> { Lithic::FinancialAccounts::LoanTape::Balances }

#createdTime

Timestamp of when the loan tape was created

Parameters:

  • value (Time)

Returns:

  • (Time)


34
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 34

required :created, Time

#credit_limitInteger

For prepay accounts, this is the minimum prepay balance that must be maintained. For charge card accounts, this is the maximum credit balance extended by a lender

Parameters:

  • value (Integer)

Returns:

  • (Integer)


42
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 42

required :credit_limit, Integer

#credit_product_tokenString

Globally unique identifier for a credit product

Parameters:

  • value (String)

Returns:

  • (String)


48
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 48

required :credit_product_token, String

#dateDate

Date of transactions that this loan tape covers

Parameters:

  • value (Date)

Returns:

  • (Date)


54
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 54

required :date, Date

#day_of_periodInteger?

Day of the billing period that this loan tape covers, starting at 1

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


133
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 133

optional :day_of_period, Integer, nil?: true

#day_totalsLithic::Models::StatementTotals



59
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 59

required :day_totals, -> { Lithic::StatementTotals }

#ending_balanceInteger

Balance at the end of the day

Parameters:

  • value (Integer)

Returns:

  • (Integer)


65
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 65

required :ending_balance, Integer

#excess_creditsInteger

Excess credits in the form of provisional credits, payments, or purchase refunds. If positive, the account is in net credit state with no outstanding balances. An overpayment could land an account in this state

Parameters:

  • value (Integer)

Returns:

  • (Integer)


73
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 73

required :excess_credits, Integer

#financial_account_tokenString

Globally unique identifier for a financial account

Parameters:

  • value (String)

Returns:

  • (String)


79
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 79

required :financial_account_token, String

#interest_detailsLithic::Models::FinancialAccounts::LoanTape::InterestDetails?

Parameters:

  • value (Lithic::FinancialAccounts::LoanTape::InterestDetails, nil)

Returns:



84
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 84

required :interest_details, -> { Lithic::FinancialAccounts::LoanTape::InterestDetails }, nil?: true

#minimum_payment_balanceLithic::Models::FinancialAccounts::LoanTape::MinimumPaymentBalance

Parameters:

  • value (Lithic::FinancialAccounts::LoanTape::MinimumPaymentBalance)

Returns:



89
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 89

required :minimum_payment_balance, -> { Lithic::FinancialAccounts::LoanTape::MinimumPaymentBalance }

#payment_allocationLithic::Models::FinancialAccounts::LoanTape::PaymentAllocation

Parameters:

  • value (Lithic::FinancialAccounts::LoanTape::PaymentAllocation)

Returns:



94
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 94

required :payment_allocation, -> { Lithic::FinancialAccounts::LoanTape::PaymentAllocation }

#period_totalsLithic::Models::StatementTotals



99
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 99

required :period_totals, -> { Lithic::StatementTotals }

#previous_statement_balanceLithic::Models::FinancialAccounts::LoanTape::PreviousStatementBalance

Parameters:

  • value (Lithic::FinancialAccounts::LoanTape::PreviousStatementBalance)

Returns:



104
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 104

required :previous_statement_balance, -> { Lithic::FinancialAccounts::LoanTape::PreviousStatementBalance }

#starting_balanceInteger

Balance at the start of the day

Parameters:

  • value (Integer)

Returns:

  • (Integer)


110
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 110

required :starting_balance, Integer

#tierString?

Interest tier to which this account belongs to

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


139
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 139

optional :tier, String, nil?: true

#tokenString

Globally unique identifier for a loan tape

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 12

required :token, String

#updatedTime

Timestamp of when the loan tape was updated

Parameters:

  • value (Time)

Returns:

  • (Time)


116
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 116

required :updated, Time

#versionInteger

Version number of the loan tape. This starts at 1

Parameters:

  • value (Integer)

Returns:

  • (Integer)


122
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 122

required :version, Integer

#ytd_totalsLithic::Models::StatementTotals



127
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 127

required :ytd_totals, -> { Lithic::StatementTotals }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 325

Instance Method Details

#to_hash{

Returns:

  • ({)


104
# File 'sig/lithic/models/financial_accounts/loan_tape.rbs', line 104

def to_hash: -> {