Class: Lithic::Models::FinancialAccounts::LoanTapeRebuildConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/financial_accounts/loan_tape_rebuild_configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(rebuild_needed:, last_rebuild: nil, rebuild_from: nil) ⇒ Object

Configuration for building loan tapes

Parameters:

  • rebuild_needed (Boolean)

    Whether the account’s loan tapes need to be rebuilt or not

  • last_rebuild (Date) (defaults to: nil)

    The date for which the account’s loan tapes were last rebuilt

  • rebuild_from (Date) (defaults to: nil)

    Date from which to start rebuilding from if the account requires a rebuild



# File 'lib/lithic/models/financial_accounts/loan_tape_rebuild_configuration.rb', line 25

Instance Attribute Details

#last_rebuildDate?

The date for which the account’s loan tapes were last rebuilt

Returns:

  • (Date, nil)


17
# File 'lib/lithic/models/financial_accounts/loan_tape_rebuild_configuration.rb', line 17

optional :last_rebuild, Date

#rebuild_fromDate?

Date from which to start rebuilding from if the account requires a rebuild

Returns:

  • (Date, nil)


23
# File 'lib/lithic/models/financial_accounts/loan_tape_rebuild_configuration.rb', line 23

optional :rebuild_from, Date

#rebuild_neededBoolean

Whether the account’s loan tapes need to be rebuilt or not

Returns:

  • (Boolean)


11
# File 'lib/lithic/models/financial_accounts/loan_tape_rebuild_configuration.rb', line 11

required :rebuild_needed, Lithic::Internal::Type::Boolean