Class: Lithic::Models::FinancialAccounts::Statement::PayoffDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/financial_accounts/statement.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(minimum_payment_months:, minimum_payment_total:, payoff_period_length_months:, payoff_period_monthly_payment_amount:, payoff_period_payment_total:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::FinancialAccounts::Statement::PayoffDetails for more details.

Details on number and size of payments to pay off balance

Parameters:

  • minimum_payment_months (String)

    The number of months it would take to pay off the balance in full by only paying

  • minimum_payment_total (String)

    The sum of all interest and principal paid, in cents, when only paying minimum m

  • payoff_period_length_months (Integer, nil)

    Number of months to full pay off

  • payoff_period_monthly_payment_amount (Integer, nil)

    The amount needed to be paid, in cents, each month in order to pay off current b

  • payoff_period_payment_total (Integer, nil)

    The sum of all interest and principal paid, in cents, when paying off in the pay



# File 'lib/lithic/models/financial_accounts/statement.rb', line 462

Instance Attribute Details

#minimum_payment_monthsString

The number of months it would take to pay off the balance in full by only paying the minimum payment. “NA” will signal negative or zero amortization

Returns:

  • (String)


433
# File 'lib/lithic/models/financial_accounts/statement.rb', line 433

required :minimum_payment_months, String

#minimum_payment_totalString

The sum of all interest and principal paid, in cents, when only paying minimum monthly payment. “NA” will signal negative or zero amortization

Returns:

  • (String)


440
# File 'lib/lithic/models/financial_accounts/statement.rb', line 440

required :minimum_payment_total, String

#payoff_period_length_monthsInteger?

Number of months to full pay off

Returns:

  • (Integer, nil)


446
# File 'lib/lithic/models/financial_accounts/statement.rb', line 446

required :payoff_period_length_months, Integer, nil?: true

#payoff_period_monthly_payment_amountInteger?

The amount needed to be paid, in cents, each month in order to pay off current balance in the payoff period

Returns:

  • (Integer, nil)


453
# File 'lib/lithic/models/financial_accounts/statement.rb', line 453

required :payoff_period_monthly_payment_amount, Integer, nil?: true

#payoff_period_payment_totalInteger?

The sum of all interest and principal paid, in cents, when paying off in the payoff period

Returns:

  • (Integer, nil)


460
# File 'lib/lithic/models/financial_accounts/statement.rb', line 460

required :payoff_period_payment_total, Integer, nil?: true