Class: Lithic::Models::FinancialEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/financial_event.rb

Defined Under Namespace

Modules: Result, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token: nil, amount: nil, created: nil, result: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::FinancialEvent for more details.

Financial Event

Parameters:

  • token (String) (defaults to: nil)

    Globally unique identifier.

  • amount (Integer) (defaults to: nil)

    Amount of the financial event that has been settled in the currency’s smallest u

  • created (Time) (defaults to: nil)

    Date and time when the financial event occurred. UTC time zone.

  • result (Symbol, Lithic::Models::FinancialEvent::Result) (defaults to: nil)

    APPROVED financial events were successful while DECLINED financial events were d

  • type (Symbol, Lithic::Models::FinancialEvent::Type) (defaults to: nil)


# File 'lib/lithic/models/financial_event.rb', line 37

Instance Attribute Details

#amountInteger?

Amount of the financial event that has been settled in the currency’s smallest unit (e.g., cents).

Returns:

  • (Integer, nil)


17
# File 'lib/lithic/models/financial_event.rb', line 17

optional :amount, Integer

#createdTime?

Date and time when the financial event occurred. UTC time zone.

Returns:

  • (Time, nil)


23
# File 'lib/lithic/models/financial_event.rb', line 23

optional :created, Time

#resultSymbol, ...

APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.

Returns:



30
# File 'lib/lithic/models/financial_event.rb', line 30

optional :result, enum: -> { Lithic::FinancialEvent::Result }

#tokenString?

Globally unique identifier.

Returns:

  • (String, nil)


10
# File 'lib/lithic/models/financial_event.rb', line 10

optional :token, String

#typeSymbol, ...

Returns:



35
# File 'lib/lithic/models/financial_event.rb', line 35

optional :type, enum: -> { Lithic::FinancialEvent::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/financial_event.rb', line 63