Module: Lithic::Models::Fraud::TransactionRetrieveResponse::FraudStatus

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/fraud/transaction_retrieve_response.rb,
sig/lithic/models/fraud/transaction_retrieve_response.rbs

Overview

The fraud status of the transaction, string (enum) supporting the following values:

  • SUSPECTED_FRAUD: The transaction is suspected to be fraudulent, but this hasn’t been confirmed.
  • FRAUDULENT: The transaction is confirmed to be fraudulent. A transaction may immediately be moved into this state, or be graduated into this state from the SUSPECTED_FRAUD state.
  • NOT_FRAUDULENT: The transaction is (explicitly) marked as not fraudulent. A transaction may immediately be moved into this state, or be graduated into this state from the SUSPECTED_FRAUD state.
  • NO_REPORTED_FRAUD: Indicates that no fraud report exists for the transaction. It is the default state for transactions that have not been analyzed or associated with any known fraudulent activity.

See Also:

  • Lithic::Models::Fraud::TransactionRetrieveResponse#fraud_status

Constant Summary collapse

SUSPECTED_FRAUD =

Returns:

  • (:SUSPECTED_FRAUD)
:SUSPECTED_FRAUD
FRAUDULENT =

Returns:

  • (:FRAUDULENT)
:FRAUDULENT
NOT_FRAUDULENT =

Returns:

  • (:NOT_FRAUDULENT)
:NOT_FRAUDULENT
NO_REPORTED_FRAUD =

Returns:

  • (:NO_REPORTED_FRAUD)
:NO_REPORTED_FRAUD

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Lithic::Models::Fraud::TransactionRetrieveResponse::fraud_status]

Returns:

  • (::Array[Lithic::Models::Fraud::TransactionRetrieveResponse::fraud_status])


66
# File 'sig/lithic/models/fraud/transaction_retrieve_response.rbs', line 66

def self?.values: -> ::Array[Lithic::Models::Fraud::TransactionRetrieveResponse::fraud_status]