Class: Lithic::Models::Hold
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Hold
- Defined in:
- lib/lithic/models/hold.rb
Overview
Defined Under Namespace
Modules: Family, Result, Status
Instance Attribute Summary collapse
-
#created ⇒ Time
ISO 8601 timestamp of when the transaction was created.
- #currency ⇒ String?
- #events ⇒ Array<Lithic::Models::HoldEvent>?
-
#expiration_datetime ⇒ Time?
When the hold will auto-expire if not resolved.
-
#family ⇒ Symbol, ...
HOLD - Hold Transaction.
- #financial_account_token ⇒ String?
-
#pending_amount ⇒ Integer?
Current pending amount (0 when resolved).
- #result ⇒ Symbol, ...
-
#status ⇒ Symbol, Lithic::Models::Hold::Status
Status of a hold transaction.
-
#token ⇒ String
Unique identifier for the transaction.
-
#updated ⇒ Time
ISO 8601 timestamp of when the transaction was last updated.
- #user_defined_id ⇒ String?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, created:, status:, updated:, currency: nil, events: nil, expiration_datetime: nil, family: nil, financial_account_token: nil, pending_amount: nil, result: nil, user_defined_id: nil) ⇒ Object
constructor
A hold transaction representing reserved funds on a financial account.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, created:, status:, updated:, currency: nil, events: nil, expiration_datetime: nil, family: nil, financial_account_token: nil, pending_amount: nil, result: nil, user_defined_id: nil) ⇒ Object
A hold transaction representing reserved funds on a financial account. Holds move funds from available to pending balance in anticipation of future payments. They can be resolved via settlement (linked to payment), manual release, or expiration.
|
|
# File 'lib/lithic/models/hold.rb', line 74
|
Instance Attribute Details
#created ⇒ Time
ISO 8601 timestamp of when the transaction was created
17 |
# File 'lib/lithic/models/hold.rb', line 17 required :created, Time |
#currency ⇒ String?
34 |
# File 'lib/lithic/models/hold.rb', line 34 optional :currency, String |
#events ⇒ Array<Lithic::Models::HoldEvent>?
39 |
# File 'lib/lithic/models/hold.rb', line 39 optional :events, -> { Lithic::Internal::Type::ArrayOf[Lithic::HoldEvent] } |
#expiration_datetime ⇒ Time?
When the hold will auto-expire if not resolved
45 |
# File 'lib/lithic/models/hold.rb', line 45 optional :expiration_datetime, Time, nil?: true |
#family ⇒ Symbol, ...
HOLD - Hold Transaction
51 |
# File 'lib/lithic/models/hold.rb', line 51 optional :family, enum: -> { Lithic::Hold::Family } |
#financial_account_token ⇒ String?
56 |
# File 'lib/lithic/models/hold.rb', line 56 optional :financial_account_token, String |
#pending_amount ⇒ Integer?
Current pending amount (0 when resolved)
62 |
# File 'lib/lithic/models/hold.rb', line 62 optional :pending_amount, Integer |
#result ⇒ Symbol, ...
67 |
# File 'lib/lithic/models/hold.rb', line 67 optional :result, enum: -> { Lithic::Hold::Result } |
#status ⇒ Symbol, Lithic::Models::Hold::Status
Status of a hold transaction
23 |
# File 'lib/lithic/models/hold.rb', line 23 required :status, enum: -> { Lithic::Hold::Status } |
#token ⇒ String
Unique identifier for the transaction
11 |
# File 'lib/lithic/models/hold.rb', line 11 required :token, String |
#updated ⇒ Time
ISO 8601 timestamp of when the transaction was last updated
29 |
# File 'lib/lithic/models/hold.rb', line 29 required :updated, Time |
#user_defined_id ⇒ String?
72 |
# File 'lib/lithic/models/hold.rb', line 72 optional :user_defined_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/hold.rb', line 119
|