Class: Lithic::Models::HoldEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::HoldEvent
- Defined in:
- lib/lithic/models/hold_event.rb
Defined Under Namespace
Modules: DetailedResult, Result, Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Amount in cents.
- #created ⇒ Time
- #detailed_results ⇒ Array<Symbol, Lithic::Models::HoldEvent::DetailedResult>
- #memo ⇒ String?
- #result ⇒ Symbol, Lithic::Models::HoldEvent::Result
-
#settling_transaction_token ⇒ String?
Transaction token of the payment that settled this hold (only populated for HOLD_SETTLED events).
- #token ⇒ String
-
#type ⇒ Symbol, Lithic::Models::HoldEvent::Type
Type of hold lifecycle event.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Lithic::Internal::Type::BaseModel
Instance Attribute Details
#amount ⇒ Integer
Amount in cents
15 |
# File 'lib/lithic/models/hold_event.rb', line 15 required :amount, Integer |
#created ⇒ Time
20 |
# File 'lib/lithic/models/hold_event.rb', line 20 required :created, Time |
#detailed_results ⇒ Array<Symbol, Lithic::Models::HoldEvent::DetailedResult>
25 26 |
# File 'lib/lithic/models/hold_event.rb', line 25 required :detailed_results, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::HoldEvent::DetailedResult] } |
#memo ⇒ String?
31 |
# File 'lib/lithic/models/hold_event.rb', line 31 required :memo, String, nil?: true |
#result ⇒ Symbol, Lithic::Models::HoldEvent::Result
36 |
# File 'lib/lithic/models/hold_event.rb', line 36 required :result, enum: -> { Lithic::HoldEvent::Result } |
#settling_transaction_token ⇒ String?
Transaction token of the payment that settled this hold (only populated for HOLD_SETTLED events)
43 |
# File 'lib/lithic/models/hold_event.rb', line 43 required :settling_transaction_token, String, nil?: true |
#token ⇒ String
9 |
# File 'lib/lithic/models/hold_event.rb', line 9 required :token, String |
#type ⇒ Symbol, Lithic::Models::HoldEvent::Type
Type of hold lifecycle event
49 |
# File 'lib/lithic/models/hold_event.rb', line 49 required :type, enum: -> { Lithic::HoldEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/hold_event.rb', line 79
|