Class: Lithic::Models::KYB::BusinessEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::KYB::BusinessEntity
- Defined in:
- lib/lithic/models/kyb.rb,
sig/lithic/models/kyb.rbs
Overview
Instance Attribute Summary collapse
-
#address ⇒ Lithic::Models::Address
Business's physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
#dba_business_name ⇒ String?
Any name that the business operates under that is not its legal business name (if applicable).
-
#government_id ⇒ String
Government-issued identification number.
-
#legal_business_name ⇒ String
Legal (formal) business name.
-
#parent_company ⇒ String?
Parent company name (if applicable).
-
#phone_numbers ⇒ Array<String>
One or more of the business's phone number(s), entered as a list in E.164 format.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
148 |
# File 'sig/lithic/models/kyb.rbs', line 148
def initialize: (
|
Instance Attribute Details
#address ⇒ Lithic::Models::Address
Business's physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
189 |
# File 'lib/lithic/models/kyb.rb', line 189 required :address, -> { Lithic::Address } |
#dba_business_name ⇒ String?
Any name that the business operates under that is not its legal business name (if applicable).
217 |
# File 'lib/lithic/models/kyb.rb', line 217 optional :dba_business_name, String |
#government_id ⇒ String
Government-issued identification number. US Federal Employer Identification Numbers (EIN) are currently supported, entered as full nine-digits, with or without hyphens.
197 |
# File 'lib/lithic/models/kyb.rb', line 197 required :government_id, String |
#legal_business_name ⇒ String
Legal (formal) business name.
203 |
# File 'lib/lithic/models/kyb.rb', line 203 required :legal_business_name, String |
#parent_company ⇒ String?
Parent company name (if applicable).
223 |
# File 'lib/lithic/models/kyb.rb', line 223 optional :parent_company, String |
#phone_numbers ⇒ Array<String>
One or more of the business's phone number(s), entered as a list in E.164 format.
210 |
# File 'lib/lithic/models/kyb.rb', line 210 required :phone_numbers, Lithic::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
157 |
# File 'sig/lithic/models/kyb.rbs', line 157
def to_hash: -> {
|