Class: Lithic::Models::ManagementOperationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/management_operation_create_params.rb,
sig/lithic/models/management_operation_create_params.rbs

Overview

See Also:

  • Lithic::Resources::ManagementOperations#create

Defined Under Namespace

Modules: Category, Direction, EventType, OnClosedAccount

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



57
# File 'sig/lithic/models/management_operation_create_params.rbs', line 57

def initialize: (

Instance Attribute Details

#amountInteger

Parameters:

  • value (Integer)

Returns:

  • (Integer)


13
# File 'lib/lithic/models/management_operation_create_params.rb', line 13

required :amount, Integer

#categorySymbol, Lithic::Models::ManagementOperationCreateParams::Category

Parameters:

  • value (Lithic::Models::ManagementOperationCreateParams::category)

Returns:



18
# File 'lib/lithic/models/management_operation_create_params.rb', line 18

required :category, enum: -> { Lithic::ManagementOperationCreateParams::Category }

#directionSymbol, Lithic::Models::ManagementOperationCreateParams::Direction

Parameters:

  • value (Lithic::Models::ManagementOperationCreateParams::direction)

Returns:



23
# File 'lib/lithic/models/management_operation_create_params.rb', line 23

required :direction, enum: -> { Lithic::ManagementOperationCreateParams::Direction }

#effective_dateDate

Parameters:

  • value (Date)

Returns:

  • (Date)


28
# File 'lib/lithic/models/management_operation_create_params.rb', line 28

required :effective_date, Date

#event_typeSymbol, Lithic::Models::ManagementOperationCreateParams::EventType

Parameters:

  • value (Lithic::Models::ManagementOperationCreateParams::event_type)

Returns:



33
# File 'lib/lithic/models/management_operation_create_params.rb', line 33

required :event_type, enum: -> { Lithic::ManagementOperationCreateParams::EventType }

#financial_account_tokenString

Parameters:

  • value (String)

Returns:

  • (String)


38
# File 'lib/lithic/models/management_operation_create_params.rb', line 38

required :financial_account_token, String

#memoString?

Parameters:

  • (String)

Returns:

  • (String, nil)


50
# File 'lib/lithic/models/management_operation_create_params.rb', line 50

optional :memo, String

#on_closed_accountSymbol, ...

What to do if the financial account is closed when posting an operation



56
# File 'lib/lithic/models/management_operation_create_params.rb', line 56

optional :on_closed_account, enum: -> { Lithic::ManagementOperationCreateParams::OnClosedAccount }

#subtypeString?

Parameters:

  • (String)

Returns:

  • (String, nil)


61
# File 'lib/lithic/models/management_operation_create_params.rb', line 61

optional :subtype, String

#tokenString?

Customer-provided token that will serve as an idempotency token. This token will become the transaction token.

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/lithic/models/management_operation_create_params.rb', line 45

optional :token, String

#user_defined_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


66
# File 'lib/lithic/models/management_operation_create_params.rb', line 66

optional :user_defined_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/management_operation_create_params.rb', line 105

Instance Method Details

#to_hash{

Returns:

  • ({)


72
# File 'sig/lithic/models/management_operation_create_params.rbs', line 72

def to_hash: -> {