Class: Lithic::Models::NonPCICard::Funding

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/non_pci_card.rb,
sig/lithic/models/non_pci_card.rbs

Overview

See Also:

  • Lithic::Models::NonPCICard#funding

Defined Under Namespace

Modules: State, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, created:, last_four:, state:, type:, account_name: nil, nickname: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::NonPCICard::Funding for more details.

Funding account for a card

accoun

Parameters:

  • token (String)

    A globally unique identifier for this FundingAccount.

  • created (Time)

    An RFC 3339 string representing when this funding source was added to the Lithic

  • last_four (String)

    The last 4 digits of the account (e.g. bank account, debit card) associated with

  • state (Symbol, Lithic::Models::NonPCICard::Funding::State)

    State of funding source. Funding source states: * ENABLED - The funding

  • type (Symbol, Lithic::Models::NonPCICard::Funding::Type)

    Types of funding source: _ DEPOSITORY_CHECKING - Bank checking account. _ `DEP

  • account_name (String) (defaults to: nil)

    Account name identifying the funding source. This may be null.

  • nickname (String, nil) (defaults to: nil)

    The nickname given to the FundingAccount or null if it has no nickname.



# File 'lib/lithic/models/non_pci_card.rb', line 335

Instance Attribute Details

#account_nameString?

Account name identifying the funding source. This may be null.

Parameters:

  • (String)

Returns:

  • (String, nil)


327
# File 'lib/lithic/models/non_pci_card.rb', line 327

optional :account_name, String

#createdTime

An RFC 3339 string representing when this funding source was added to the Lithic account. This may be null. UTC time zone.

Parameters:

  • value (Time)

Returns:

  • (Time)


298
# File 'lib/lithic/models/non_pci_card.rb', line 298

required :created, Time

#last_fourString

The last 4 digits of the account (e.g. bank account, debit card) associated with this FundingAccount. This may be null.

Parameters:

  • value (String)

Returns:

  • (String)


305
# File 'lib/lithic/models/non_pci_card.rb', line 305

required :last_four, String

#nicknameString?

The nickname given to the FundingAccount or null if it has no nickname.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


333
# File 'lib/lithic/models/non_pci_card.rb', line 333

optional :nickname, String, nil?: true

#stateSymbol, Lithic::Models::NonPCICard::Funding::State

State of funding source. Funding source states: _ ENABLED - The funding account is available to use for card creation and transactions. _ PENDING - The funding account is still being verified e.g. bank micro-deposits verification. * DELETED - The founding account has been deleted.

Parameters:

  • value (Lithic::Models::NonPCICard::Funding::state)

Returns:



314
# File 'lib/lithic/models/non_pci_card.rb', line 314

required :state, enum: -> { Lithic::NonPCICard::Funding::State }

#tokenString

A globally unique identifier for this FundingAccount.

Parameters:

  • value (String)

Returns:

  • (String)


291
# File 'lib/lithic/models/non_pci_card.rb', line 291

required :token, String

#typeSymbol, Lithic::Models::NonPCICard::Funding::Type

Types of funding source: _ DEPOSITORY_CHECKING - Bank checking account. _ DEPOSITORY_SAVINGS - Bank savings account.

Parameters:

  • value (Lithic::Models::NonPCICard::Funding::type_)

Returns:



321
# File 'lib/lithic/models/non_pci_card.rb', line 321

required :type, enum: -> { Lithic::NonPCICard::Funding::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/non_pci_card.rb', line 369

Instance Method Details

#to_hash{

Returns:

  • ({)


193
# File 'sig/lithic/models/non_pci_card.rbs', line 193

def to_hash: -> {