Module: Lithic::Models::NonPCICard::State
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/non_pci_card.rb,
sig/lithic/models/non_pci_card.rbs
Overview
Card state values: _ CLOSED - Card will no longer approve authorizations.
Closing a card cannot be undone. _ OPEN - Card will approve authorizations (if
they match card and account parameters). _ PAUSED - Card will decline
authorizations, but can be resumed at a later time. _ PENDING_FULFILLMENT -
The initial state for cards of type PHYSICAL. The card is provisioned pending
manufacturing and fulfillment. Cards in this state can accept authorizations for
e-commerce purchases, but not for "Card Present" purchases where the physical
card itself is present. * PENDING_ACTIVATION - At regular intervals, cards of
type PHYSICAL in state PENDING_FULFILLMENT are sent to the card production
warehouse and updated to state PENDING_ACTIVATION. Similar to
PENDING_FULFILLMENT, cards in this state can be used for e-commerce
transactions or can be added to mobile wallets. API clients should update the
card's state to OPEN only after the cardholder confirms receipt of the card.
In sandbox, the same daily batch fulfillment occurs, but no cards are actually
manufactured.
Constant Summary collapse
- CLOSED =
:CLOSED- OPEN =
:OPEN- PAUSED =
:PAUSED- PENDING_ACTIVATION =
:PENDING_ACTIVATION- PENDING_FULFILLMENT =
:PENDING_FULFILLMENT
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::NonPCICard::state]
251 |
# File 'sig/lithic/models/non_pci_card.rbs', line 251
def self?.values: -> ::Array[Lithic::Models::NonPCICard::state]
|