Module: Lithic::Models::NonPCICard::Type

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/non_pci_card.rb,
sig/lithic/models/non_pci_card.rbs

Overview

Card types: _ VIRTUAL - Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled). _ PHYSICAL - Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. _ SINGLE_USE - Card is closed upon first successful authorization. _ MERCHANT_LOCKED - Card is locked to the first merchant that successfully authorizes the card. _ UNLOCKED - [Deprecated] Similar behavior to VIRTUAL cards, please use VIRTUAL instead. _ DIGITAL_WALLET - [Deprecated] Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

See Also:

  • Lithic::Models::NonPCICard#type

Constant Summary collapse

MERCHANT_LOCKED =

Returns:

  • (:MERCHANT_LOCKED)
:MERCHANT_LOCKED
PHYSICAL =

Returns:

  • (:PHYSICAL)
:PHYSICAL
SINGLE_USE =

Returns:

  • (:SINGLE_USE)
:SINGLE_USE
VIRTUAL =

Returns:

  • (:VIRTUAL)
:VIRTUAL
UNLOCKED =

Returns:

  • (:UNLOCKED)
:UNLOCKED
DIGITAL_WALLET =

Returns:

  • (:DIGITAL_WALLET)
:DIGITAL_WALLET

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Lithic::Models::NonPCICard::type_]

Returns:

  • (::Array[Lithic::Models::NonPCICard::type_])


272
# File 'sig/lithic/models/non_pci_card.rbs', line 272

def self?.values: -> ::Array[Lithic::Models::NonPCICard::type_]