Class: Lithic::Models::ParsedWebhookEvent::KYBPayload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/parsed_webhook_event.rb,
sig/lithic/models/parsed_webhook_event.rbs

Defined Under Namespace

Modules: EventType Classes: UpdateRequest

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address1:, city:, country:, postal_code:, state:, address2: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ParsedWebhookEvent::KYBPayload::UpdateRequest::ControlPerson::Address for more details.

Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.

Parameters:

  • address1 (String) —

    Valid deliverable address (no PO boxes).

  • city (String) —

    Name of city.

  • country (String) —

    Valid country code. Only USA is currently supported, entered in uppercase ISO 31

  • postal_code (String) —

    Valid postal code. Only USA ZIP codes are currently supported, entered as a five

  • state (String) —

    Valid state code. Only USA state codes are currently supported, entered in upper

  • address2 (String) (defaults to: nil) —

    Unit or apartment number (if applicable).



# File 'lib/lithic/models/parsed_webhook_event.rb', line 206

Instance Attribute Details

#event_type ⇒ Symbol, ...

The type of event that occurred.



176
# File 'lib/lithic/models/parsed_webhook_event.rb', line 176

optional :event_type, enum: -> { Lithic::ParsedWebhookEvent::KYBPayload::EventType }

#external_id ⇒ String?

A user provided id that can be used to link an account holder with an external system

Parameters:

  • (String)

Returns:

  • (String, nil)


183
# File 'lib/lithic/models/parsed_webhook_event.rb', line 183

optional :external_id, String

#naics_code ⇒ String?

6-digit North American Industry Classification System (NAICS) code for the business. Only present if naics_code was included in the update request.

Parameters:

  • (String)

Returns:

  • (String, nil)


190
# File 'lib/lithic/models/parsed_webhook_event.rb', line 190

optional :naics_code, String

#nature_of_business ⇒ String?

Short description of the company's line of business (i.e., what does the company do?). Values longer than 255 characters will be truncated before KYB verification

Parameters:

  • (String)

Returns:

  • (String, nil)


198
# File 'lib/lithic/models/parsed_webhook_event.rb', line 198

optional :nature_of_business, String

#token ⇒ String

The token of the account_holder that was created.

Parameters:

  • value (String)

Returns:

  • (String)


164
# File 'lib/lithic/models/parsed_webhook_event.rb', line 164

required :token, String

#update_request ⇒ Lithic::Models::ParsedWebhookEvent::KYBPayload::UpdateRequest

Original request to update the account holder.

Parameters:

  • value (Lithic::ParsedWebhookEvent::KYBPayload::UpdateRequest)

Returns:



170
# File 'lib/lithic/models/parsed_webhook_event.rb', line 170

required :update_request, -> { Lithic::ParsedWebhookEvent::KYBPayload::UpdateRequest }

#website_url ⇒ String?

Company website URL.

Parameters:

  • (String)

Returns:

  • (String, nil)


204
# File 'lib/lithic/models/parsed_webhook_event.rb', line 204

optional :website_url, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


123
# File 'sig/lithic/models/parsed_webhook_event.rbs', line 123

def to_hash: -> {