Class: Lithic::Models::ParsedWebhookEvent::KYBPayload::UpdateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/parsed_webhook_event.rb,
sig/lithic/models/parsed_webhook_event.rbs

Overview

See Also:

  • Lithic::Models::ParsedWebhookEvent::KYBPayload#update_request

Defined Under Namespace

Classes: BeneficialOwnerIndividual, ControlPerson

Constant Summary collapse

Lithic =

Returns:

  • (:KYBBusinessEntity)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address1:, city:, country:, postal_code:, state:, address2: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ParsedWebhookEvent::KYBPayload::UpdateRequest::BeneficialOwnerIndividual::Address for more details.

Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.

Parameters:

  • address1 (String) —

    Valid deliverable address (no PO boxes).

  • city (String) —

    Name of city.

  • country (String) —

    Valid country code. Only USA is currently supported, entered in uppercase ISO 31

  • postal_code (String) —

    Valid postal code. Only USA ZIP codes are currently supported, entered as a five

  • state (String) —

    Valid state code. Only USA state codes are currently supported, entered in upper

  • address2 (String) (defaults to: nil) —

    Unit or apartment number (if applicable).



# File 'lib/lithic/models/parsed_webhook_event.rb', line 371

Instance Attribute Details

#beneficial_owner_individuals ⇒ Array<Lithic::Models::ParsedWebhookEvent::KYBPayload::UpdateRequest::BeneficialOwnerIndividual>?

You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See FinCEN requirements (Section I) for more background on individuals that should be included.



237
238
# File 'lib/lithic/models/parsed_webhook_event.rb', line 237

optional :beneficial_owner_individuals,
-> { Lithic::Internal::Type::ArrayOf[Lithic::ParsedWebhookEvent::KYBPayload::UpdateRequest::BeneficialOwnerIndividual] }

#business_entity ⇒ Lithic::Models::KYBBusinessEntity?

Information for business for which the account is being opened and KYB is being run.



245
# File 'lib/lithic/models/parsed_webhook_event.rb', line 245

optional :business_entity, -> { Lithic::KYBBusinessEntity }

#control_person ⇒ Lithic::Models::ParsedWebhookEvent::KYBPayload::UpdateRequest::ControlPerson?

An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.



258
# File 'lib/lithic/models/parsed_webhook_event.rb', line 258

optional :control_person, -> { Lithic::ParsedWebhookEvent::KYBPayload::UpdateRequest::ControlPerson }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


165
# File 'sig/lithic/models/parsed_webhook_event.rbs', line 165

def to_hash: -> {