Class: Lithic::Models::ParsedWebhookEvent::LegacyPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ParsedWebhookEvent::LegacyPayload
- Defined in:
- lib/lithic/models/parsed_webhook_event.rb
Defined Under Namespace
Modules: EventType
Instance Attribute Summary collapse
-
#business_account_token ⇒ String?
If applicable, represents the business account token associated with the account_holder.
-
#created ⇒ Time?
When the account_holder updated event was created.
-
#email ⇒ String?
If updated, the newly updated email associated with the account_holder otherwise the existing email is provided.
-
#event_type ⇒ Symbol, ...
The type of event that occurred.
-
#external_id ⇒ String?
If applicable, represents the external_id associated with the account_holder.
-
#first_name ⇒ String?
If applicable, represents the account_holder’s first name.
-
#last_name ⇒ String?
If applicable, represents the account_holder’s last name.
-
#legal_business_name ⇒ String?
If applicable, represents the account_holder’s business name.
-
#phone_number ⇒ String?
If updated, the newly updated phone_number associated with the account_holder otherwise the existing phone_number is provided.
-
#token ⇒ String
The token of the account_holder that was created.
Instance Method Summary collapse
-
#initialize(token:, business_account_token: nil, created: nil, email: nil, event_type: nil, external_id: nil, first_name: nil, last_name: nil, legal_business_name: nil, phone_number: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LegacyPayload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, business_account_token: nil, created: nil, email: nil, event_type: nil, external_id: nil, first_name: nil, last_name: nil, legal_business_name: nil, phone_number: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::ParsedWebhookEvent::LegacyPayload for more details.
Legacy payload for an updated account holder.
|
|
# File 'lib/lithic/models/parsed_webhook_event.rb', line 774
|
Instance Attribute Details
#business_account_token ⇒ String?
If applicable, represents the business account token associated with the account_holder.
722 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 722 optional :business_account_token, String, nil?: true |
#created ⇒ Time?
When the account_holder updated event was created
728 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 728 optional :created, Time |
#email ⇒ String?
If updated, the newly updated email associated with the account_holder otherwise the existing email is provided.
735 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 735 optional :email, String |
#event_type ⇒ Symbol, ...
The type of event that occurred.
741 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 741 optional :event_type, enum: -> { Lithic::ParsedWebhookEvent::LegacyPayload::EventType } |
#external_id ⇒ String?
If applicable, represents the external_id associated with the account_holder.
747 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 747 optional :external_id, String, nil?: true |
#first_name ⇒ String?
If applicable, represents the account_holder’s first name.
753 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 753 optional :first_name, String |
#last_name ⇒ String?
If applicable, represents the account_holder’s last name.
759 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 759 optional :last_name, String |
#legal_business_name ⇒ String?
If applicable, represents the account_holder’s business name.
765 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 765 optional :legal_business_name, String |
#phone_number ⇒ String?
If updated, the newly updated phone_number associated with the account_holder otherwise the existing phone_number is provided.
772 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 772 optional :phone_number, String |
#token ⇒ String
The token of the account_holder that was created.
715 |
# File 'lib/lithic/models/parsed_webhook_event.rb', line 715 required :token, String |