Class: Lithic::Models::Payment::Event

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/payment.rb,
sig/lithic/models/payment.rbs

Defined Under Namespace

Modules: DetailedResult, Result, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, amount:, created:, result:, type:, detailed_results: nil, external_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Payment::Event for more details.

Note: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related fields below are a preview. To learn more, contact your customer success manager.

Payment Event

Parameters:

  • token (String)

    Globally unique identifier.

  • amount (Integer)

    Amount of the financial event that has been settled in the currency's smallest u

  • created (Time)

    Date and time when the financial event occurred. UTC time zone.

  • result (Symbol, Lithic::Models::Payment::Event::Result)

    APPROVED financial events were successful while DECLINED financial events were d

  • type (Symbol, Lithic::Models::Payment::Event::Type)

    Note: Inbound wire transfers are coming soon (availability varies by partner ban

  • detailed_results (Array<Symbol, Lithic::Models::Payment::Event::DetailedResult>) (defaults to: nil)

    More detailed reasons for the event

  • external_id (String, nil) (defaults to: nil)

    Payment event external ID. For ACH transactions, this is the ACH trace number.



# File 'lib/lithic/models/payment.rb', line 369

Instance Attribute Details

#amountInteger

Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


265
# File 'lib/lithic/models/payment.rb', line 265

required :amount, Integer

#createdTime

Date and time when the financial event occurred. UTC time zone.

Parameters:

  • value (Time)

Returns:

  • (Time)


271
# File 'lib/lithic/models/payment.rb', line 271

required :created, Time

#detailed_resultsArray<Symbol, Lithic::Models::Payment::Event::DetailedResult>?

More detailed reasons for the event

Returns:



356
357
# File 'lib/lithic/models/payment.rb', line 356

optional :detailed_results,
-> { Lithic::Internal::Type::ArrayOf[enum: Lithic::Payment::Event::DetailedResult] }

#external_idString?

Payment event external ID. For ACH transactions, this is the ACH trace number. For inbound wire transfers, this is the IMAD (Input Message Accountability Data). For stablecoin payments, this is the on-chain transaction hash of the transfer; it is present on events that reflect on-chain activity and null on internal lifecycle events.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


367
# File 'lib/lithic/models/payment.rb', line 367

optional :external_id, String, nil?: true

#resultSymbol, Lithic::Models::Payment::Event::Result

APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.

Parameters:

  • value (Lithic::Models::Payment::Event::result)

Returns:



278
# File 'lib/lithic/models/payment.rb', line 278

required :result, enum: -> { Lithic::Payment::Event::Result }

#tokenString

Globally unique identifier.

Parameters:

  • value (String)

Returns:

  • (String)


258
# File 'lib/lithic/models/payment.rb', line 258

required :token, String

#typeSymbol, Lithic::Models::Payment::Event::Type

Note: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related event types below are a preview. To learn more, contact your customer success manager.

Event types:

ACH events:

  • ACH_ORIGINATION_INITIATED - ACH origination received and pending approval/release from an ACH hold.
  • ACH_ORIGINATION_REVIEWED - ACH origination has completed the review process.
  • ACH_ORIGINATION_CANCELLED - ACH origination has been cancelled.
  • ACH_ORIGINATION_PROCESSED - ACH origination has been processed and sent to the Federal Reserve.
  • ACH_ORIGINATION_SETTLED - ACH origination has settled.
  • ACH_ORIGINATION_RELEASED - ACH origination released from pending to available balance.
  • ACH_ORIGINATION_REJECTED - ACH origination was rejected and not sent to the Federal Reserve.
  • ACH_RECEIPT_PROCESSED - ACH receipt pending release from an ACH holder.
  • ACH_RECEIPT_SETTLED - ACH receipt funds have settled.
  • ACH_RECEIPT_RELEASED - ACH receipt released from pending to available balance.
  • ACH_RECEIPT_RELEASED_EARLY - ACH receipt released early from pending to available balance.
  • ACH_RETURN_INITIATED - ACH initiated return for an ACH receipt.
  • ACH_RETURN_PROCESSED - ACH receipt returned by the Receiving Depository Financial Institution.
  • ACH_RETURN_SETTLED - ACH return settled by the Receiving Depository Financial Institution.
  • ACH_RETURN_REJECTED - ACH return was rejected by the Receiving Depository Financial Institution.

Wire transfer events:

  • WIRE_TRANSFER_INBOUND_RECEIVED - Inbound wire transfer received from the Federal Reserve and pending release to available balance.
  • WIRE_TRANSFER_INBOUND_SETTLED - Inbound wire transfer funds released from pending to available balance.
  • WIRE_TRANSFER_INBOUND_BLOCKED - Inbound wire transfer blocked and funds frozen for regulatory review.

Wire return events:

  • WIRE_RETURN_OUTBOUND_INITIATED - Outbound wire return initiated to return funds from an inbound wire transfer.
  • WIRE_RETURN_OUTBOUND_SENT - Outbound wire return sent to the Federal Reserve and pending acceptance.
  • WIRE_RETURN_OUTBOUND_SETTLED - Outbound wire return accepted by the Federal Reserve and funds returned to sender.
  • WIRE_RETURN_OUTBOUND_REJECTED - Outbound wire return rejected by the Federal Reserve.

Stablecoin events:

  • STABLECOIN_RECEIVED - Stablecoin pay-in received on-chain and pending release to available balance.
  • STABLECOIN_INITIATED - Stablecoin withdrawal initiated, with the funds placed on hold.
  • STABLECOIN_REVIEWED - Stablecoin pay-in or withdrawal has completed the review process.
  • STABLECOIN_SENT - Stablecoin withdrawal accepted for on-chain submission to the destination address, and pending confirmation.
  • STABLECOIN_SETTLED - Stablecoin pay-in funds released to available balance, or stablecoin withdrawal confirmed on-chain.
  • STABLECOIN_REJECTED - Stablecoin withdrawal failed and the hold placed at initiation has been reversed.

Parameters:

  • value (Lithic::Models::Payment::Event::type_)

Returns:



350
# File 'lib/lithic/models/payment.rb', line 350

required :type, enum: -> { Lithic::Payment::Event::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/payment.rb', line 403

Instance Method Details

#to_hash{

Returns:

  • ({)


250
# File 'sig/lithic/models/payment.rbs', line 250

def to_hash: -> {