Class: Lithic::Models::Payment::MethodAttributes::WireMethodAttributes

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/payment.rb,
sig/lithic/models/payment.rbs

Defined Under Namespace

Modules: WireNetwork

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(wire_message_type:, wire_network:, creditor: nil, debtor: nil, message_id: nil, remittance_information: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Payment::MethodAttributes::WireMethodAttributes for more details.

Parameters:



# File 'lib/lithic/models/payment.rb', line 697

Instance Attribute Details

#creditor ⇒ Lithic::Models::WirePartyDetails?



677
# File 'lib/lithic/models/payment.rb', line 677

optional :creditor, -> { Lithic::WirePartyDetails }

#debtor ⇒ Lithic::Models::WirePartyDetails?



682
# File 'lib/lithic/models/payment.rb', line 682

optional :debtor, -> { Lithic::WirePartyDetails }

#message_id ⇒ String?

Point to point reference identifier, as assigned by the instructing party, used for tracking the message through the Fedwire system

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


689
# File 'lib/lithic/models/payment.rb', line 689

optional :message_id, String, nil?: true

#remittance_information ⇒ String?

Payment details or invoice reference

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


695
# File 'lib/lithic/models/payment.rb', line 695

optional :remittance_information, String, nil?: true

#wire_message_type ⇒ String?

Type of wire message

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


666
# File 'lib/lithic/models/payment.rb', line 666

required :wire_message_type, String, nil?: true

#wire_network ⇒ Symbol, Lithic::Models::Payment::MethodAttributes::WireMethodAttributes::WireNetwork

Type of wire transfer

Parameters:

  • value (Lithic::Models::Payment::MethodAttributes::WireMethodAttributes::wire_network)

Returns:



672
# File 'lib/lithic/models/payment.rb', line 672

required :wire_network, enum: -> { Lithic::Payment::MethodAttributes::WireMethodAttributes::WireNetwork }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


498
# File 'sig/lithic/models/payment.rbs', line 498

def to_hash: -> {