Class: Lithic::Models::PaymentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/payment_create_params.rb,
sig/lithic/models/payment_create_params.rbs

Overview

See Also:

  • Lithic::Resources::Payments#create

Defined Under Namespace

Modules: Method, Type Classes: Hold, MethodAttributes

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



52
# File 'sig/lithic/models/payment_create_params.rbs', line 52

def initialize: (

Instance Attribute Details

#amountInteger

Parameters:

  • value (Integer)

Returns:

  • (Integer)


13
# File 'lib/lithic/models/payment_create_params.rb', line 13

required :amount, Integer

#external_bank_account_tokenString

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/lithic/models/payment_create_params.rb', line 18

required :external_bank_account_token, String

#financial_account_tokenString

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/lithic/models/payment_create_params.rb', line 23

required :financial_account_token, String

#holdLithic::Models::PaymentCreateParams::Hold?

Optional hold to settle when this payment is initiated.



51
# File 'lib/lithic/models/payment_create_params.rb', line 51

optional :hold, -> { Lithic::PaymentCreateParams::Hold }

#memoString?

Parameters:

  • (String)

Returns:

  • (String, nil)


56
# File 'lib/lithic/models/payment_create_params.rb', line 56

optional :memo, String

#method_Symbol, Lithic::Models::PaymentCreateParams::Method

Parameters:

  • value (Lithic::Models::PaymentCreateParams::method_)

Returns:



28
# File 'lib/lithic/models/payment_create_params.rb', line 28

required :method_, enum: -> { Lithic::PaymentCreateParams::Method }, api_name: :method

#method_attributesLithic::Models::PaymentCreateParams::MethodAttributes

Parameters:

  • value (Lithic::PaymentCreateParams::MethodAttributes)

Returns:



33
# File 'lib/lithic/models/payment_create_params.rb', line 33

required :method_attributes, -> { Lithic::PaymentCreateParams::MethodAttributes }

#tokenString?

Customer-provided token that will serve as an idempotency token. This token will become the transaction token.

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/lithic/models/payment_create_params.rb', line 45

optional :token, String

#typeSymbol, Lithic::Models::PaymentCreateParams::Type

Parameters:

  • value (Lithic::Models::PaymentCreateParams::type_)

Returns:



38
# File 'lib/lithic/models/payment_create_params.rb', line 38

required :type, enum: -> { Lithic::PaymentCreateParams::Type }

#user_defined_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


61
# File 'lib/lithic/models/payment_create_params.rb', line 61

optional :user_defined_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/payment_create_params.rb', line 95

Instance Method Details

#to_hash{

Returns:

  • ({)


66
# File 'sig/lithic/models/payment_create_params.rbs', line 66

def to_hash: -> {