Class: Lithic::Models::PaymentCreateStablecoinParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/payment_create_stablecoin_params.rb,
sig/lithic/models/payment_create_stablecoin_params.rbs

Overview

See Also:

  • Lithic::Resources::Payments#create_stablecoin

Defined Under Namespace

Modules: Type Classes: Hold

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, blockchain_recipient_token:, financial_account_token:, type:, token: nil, hold: nil, memo: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::PaymentCreateStablecoinParams for more details.

Parameters:

  • amount (Integer) —

    Payout amount in cents

  • blockchain_recipient_token (String) —

    Token of the blockchain recipient to send the payout to. The recipient must be i

  • financial_account_token (String) —

    Token of the financial account the payout is funded from

  • type (Symbol, Lithic::Models::PaymentCreateStablecoinParams::Type) —

    Direction of the payment. Stablecoin supports payouts only

  • token (String) (defaults to: nil) —

    Customer-provided token that will serve as an idempotency token. This token will

  • hold (Lithic::Models::PaymentCreateStablecoinParams::Hold) (defaults to: nil) —

    Optional hold to settle when this payout is initiated

  • memo (String) (defaults to: nil) —

    Memo recorded on the payout. Defaults to Stablecoin payout on <chain> when omi

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 55

Instance Attribute Details

#amount ⇒ Integer

Payout amount in cents

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14
# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 14

required :amount, Integer

#blockchain_recipient_token ⇒ String

Token of the blockchain recipient to send the payout to. The recipient must be in the ENABLED verification state

Parameters:

  • value (String)

Returns:

  • (String)


21
# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 21

required :blockchain_recipient_token, String

#financial_account_token ⇒ String

Token of the financial account the payout is funded from

Parameters:

  • value (String)

Returns:

  • (String)


27
# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 27

required :financial_account_token, String

#hold ⇒ Lithic::Models::PaymentCreateStablecoinParams::Hold?

Optional hold to settle when this payout is initiated



46
# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 46

optional :hold, -> { Lithic::PaymentCreateStablecoinParams::Hold }

#memo ⇒ String?

Memo recorded on the payout. Defaults to Stablecoin payout on <chain> when omitted

Parameters:

  • (String)

Returns:

  • (String, nil)


53
# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 53

optional :memo, String

#token ⇒ String?

Customer-provided token that will serve as an idempotency token. This token will become the transaction token

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 40

optional :token, String

#type ⇒ Symbol, Lithic::Models::PaymentCreateStablecoinParams::Type

Direction of the payment. Stablecoin supports payouts only

Parameters:

  • value (Lithic::Models::PaymentCreateStablecoinParams::type_)

Returns:



33
# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 33

required :type, enum: -> { Lithic::PaymentCreateStablecoinParams::Type }

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 81

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


52
# File 'sig/lithic/models/payment_create_stablecoin_params.rbs', line 52

def to_hash: -> {