Class: Lithic::Models::PaymentCreateStablecoinParams::Hold

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/payment_create_stablecoin_params.rb,
sig/lithic/models/payment_create_stablecoin_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:) ⇒ Hold

Optional hold to settle when this payout is initiated

Parameters:

  • token (String) —

    Token of the hold to settle when this payout is initiated

  • token: (String)


# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 92

Instance Attribute Details

#token ⇒ String

Token of the hold to settle when this payout is initiated

Parameters:

  • value (String)

Returns:

  • (String)


90
# File 'lib/lithic/models/payment_create_stablecoin_params.rb', line 90

required :token, String

Instance Method Details

#to_hash ⇒ { token: String }

Returns:

  • ({ token: String })


80
# File 'sig/lithic/models/payment_create_stablecoin_params.rbs', line 80

def to_hash: -> { token: String }