Module: Lithic::Models::PaymentRetryParams::Method

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/payment_retry_params.rb,
sig/lithic/models/payment_retry_params.rbs

Overview

Settlement speed to retry the payment at. Defaults to the original payment's method. An ACH_SAME_DAY retry is rejected if the payment is for $1,000,000.00 or more, or if it is submitted after the same day ACH cutoff

Constant Summary collapse

ACH_NEXT_DAY =

Returns:

  • (:ACH_NEXT_DAY)
:ACH_NEXT_DAY
ACH_SAME_DAY =

Returns:

  • (:ACH_SAME_DAY)
:ACH_SAME_DAY

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/payment_retry_params.rb', line 42


Instance Method Details

#self?.values ⇒ ::Array[Lithic::Models::PaymentRetryParams::method_]

Returns:

  • (::Array[Lithic::Models::PaymentRetryParams::method_])


42
# File 'sig/lithic/models/payment_retry_params.rbs', line 42

def self?.values: -> ::Array[Lithic::Models::PaymentRetryParams::method_]