Class: Lithic::Models::SettlementDetail

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/settlement_detail.rb

Defined Under Namespace

Modules: Network, Type Classes: OtherFeesDetails

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(isa: nil) ⇒ Object

The total gross amount of other fees by type.

Parameters:

  • isa (Integer) (defaults to: nil)


# File 'lib/lithic/models/settlement_detail.rb', line 145

Instance Attribute Details

#account_tokenString

Globally unique identifier denoting the account that the associated transaction occurred on.

Returns:

  • (String)


17
# File 'lib/lithic/models/settlement_detail.rb', line 17

required :account_token, String

#card_program_tokenString

Globally unique identifier denoting the card program that the associated transaction occurred on.

Returns:

  • (String)


24
# File 'lib/lithic/models/settlement_detail.rb', line 24

required :card_program_token, String

#card_tokenString

Globally unique identifier denoting the card that the associated transaction occurred on.

Returns:

  • (String)


31
# File 'lib/lithic/models/settlement_detail.rb', line 31

required :card_token, String

#createdTime

Date and time when the transaction first occurred. UTC time zone.

Returns:

  • (Time)


37
# File 'lib/lithic/models/settlement_detail.rb', line 37

required :created, Time

#currencyString

Three-character alphabetic ISO 4217 code.

Returns:

  • (String)


43
# File 'lib/lithic/models/settlement_detail.rb', line 43

required :currency, String

#disputes_gross_amountInteger

The total gross amount of disputes settlements.

Returns:

  • (Integer)


49
# File 'lib/lithic/models/settlement_detail.rb', line 49

required :disputes_gross_amount, Integer

#event_tokensArray<String>

Array of globally unique identifiers for the financial events that comprise this settlement. Use these tokens to access detailed event-level information.

Returns:

  • (Array<String>)


56
# File 'lib/lithic/models/settlement_detail.rb', line 56

required :event_tokens, Lithic::Internal::Type::ArrayOf[String]

#fee_descriptionString?

Network’s description of a fee, only present on records with type ‘FEE`.

Returns:

  • (String, nil)


143
# File 'lib/lithic/models/settlement_detail.rb', line 143

optional :fee_description, String

#institutionString

The most granular ID the network settles with (e.g., ICA for Mastercard, FTSRE for Visa).

Returns:

  • (String)


63
# File 'lib/lithic/models/settlement_detail.rb', line 63

required :institution, String

#interchange_fee_extended_precisionInteger

The total amount of interchange in six-digit extended precision.

Returns:

  • (Integer)


69
# File 'lib/lithic/models/settlement_detail.rb', line 69

required :interchange_fee_extended_precision, Integer

#interchange_gross_amountInteger

The total amount of interchange.

Returns:

  • (Integer)


75
# File 'lib/lithic/models/settlement_detail.rb', line 75

required :interchange_gross_amount, Integer

#networkSymbol, Lithic::Models::SettlementDetail::Network

Card network where the transaction took place.



81
# File 'lib/lithic/models/settlement_detail.rb', line 81

required :network, enum: -> { Lithic::SettlementDetail::Network }

#other_fees_detailsLithic::Models::SettlementDetail::OtherFeesDetails

The total gross amount of other fees by type.



87
# File 'lib/lithic/models/settlement_detail.rb', line 87

required :other_fees_details, -> { Lithic::SettlementDetail::OtherFeesDetails }

#other_fees_gross_amountInteger

Total amount of gross other fees outside of interchange.

Returns:

  • (Integer)


93
# File 'lib/lithic/models/settlement_detail.rb', line 93

required :other_fees_gross_amount, Integer

#report_dateString

Date of when the report was first generated.

Returns:

  • (String)


99
# File 'lib/lithic/models/settlement_detail.rb', line 99

required :report_date, String

#settlement_dateString

Date of when money movement is triggered for the transaction. One exception applies - for Mastercard dual message settlement, this is the settlement advisement date, which is distinct from the date of money movement.

Returns:

  • (String)


107
# File 'lib/lithic/models/settlement_detail.rb', line 107

required :settlement_date, String

#tokenString

Globally unique identifier denoting the Settlement Detail.

Returns:

  • (String)


10
# File 'lib/lithic/models/settlement_detail.rb', line 10

required :token, String

#transaction_tokenString

Globally unique identifier denoting the associated transaction. For settlement records with type ‘CLEARING`, `FINANCIAL`, or `NON-FINANCIAL`, this references a card transaction token. For settlement records with type `CHARGEBACK`, `REPRESENTMENT`, `PREARBITRATION`, `ARBITRATION`, or `COLLABORATION`, this references the dispute transaction token. May be null for certain settlement types.

Returns:

  • (String)


118
# File 'lib/lithic/models/settlement_detail.rb', line 118

required :transaction_token, String

#transactions_gross_amountInteger

The total amount of settlement impacting transactions (excluding interchange, fees, and disputes).

Returns:

  • (Integer)


125
# File 'lib/lithic/models/settlement_detail.rb', line 125

required :transactions_gross_amount, Integer

#typeSymbol, Lithic::Models::SettlementDetail::Type

The type of settlement record.



131
# File 'lib/lithic/models/settlement_detail.rb', line 131

required :type, enum: -> { Lithic::SettlementDetail::Type }

#updatedTime

Date and time when the transaction first occurred. UTC time zone.

Returns:

  • (Time)


137
# File 'lib/lithic/models/settlement_detail.rb', line 137

required :updated, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/settlement_detail.rb', line 204