Class: Lithic::Models::SettlementReport
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::SettlementReport
- Defined in:
- lib/lithic/models/settlement_report.rb,
sig/lithic/models/settlement_report.rbs
Direct Known Subclasses
Instance Attribute Summary collapse
-
#created ⇒ Time
Date and time when the transaction first occurred.
- #currency ⇒ String deprecated Deprecated.
- #details ⇒ Array<Lithic::Models::SettlementSummaryDetails>
- #disputes_gross_amount ⇒ Integer deprecated Deprecated.
- #interchange_gross_amount ⇒ Integer deprecated Deprecated.
-
#is_complete ⇒ Boolean
Indicates that all data expected on the given report date is available.
- #other_fees_gross_amount ⇒ Integer deprecated Deprecated.
-
#report_date ⇒ String
Date of when the report was first generated.
- #settled_net_amount ⇒ Integer deprecated Deprecated.
- #transactions_gross_amount ⇒ Integer deprecated Deprecated.
-
#updated ⇒ Time
Date and time when the transaction first occurred.
Instance Method Summary collapse
-
#initialize(created:, currency:, details:, disputes_gross_amount:, interchange_gross_amount:, is_complete:, other_fees_gross_amount:, report_date:, settled_net_amount:, transactions_gross_amount:, updated:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SettlementReport for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created:, currency:, details:, disputes_gross_amount:, interchange_gross_amount:, is_complete:, other_fees_gross_amount:, report_date:, settled_net_amount:, transactions_gross_amount:, updated:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::SettlementReport for more details.
|
|
# File 'lib/lithic/models/settlement_report.rb', line 98
|
Instance Attribute Details
#created ⇒ Time
Date and time when the transaction first occurred. UTC time zone.
10 |
# File 'lib/lithic/models/settlement_report.rb', line 10 required :created, Time |
#currency ⇒ String
3-character alphabetic ISO 4217 code. (This field is deprecated and will be removed in a future version of the API.)
19 |
# File 'lib/lithic/models/settlement_report.rb', line 19 required :currency, String |
#details ⇒ Array<Lithic::Models::SettlementSummaryDetails>
24 |
# File 'lib/lithic/models/settlement_report.rb', line 24 required :details, -> { Lithic::Internal::Type::ArrayOf[Lithic::SettlementSummaryDetails] } |
#disputes_gross_amount ⇒ Integer
The total gross amount of disputes settlements. (This field is deprecated and
will be removed in a future version of the API. To compute total amounts, Lithic
recommends that customers sum the relevant settlement amounts found within
details.)
35 |
# File 'lib/lithic/models/settlement_report.rb', line 35 required :disputes_gross_amount, Integer |
#interchange_gross_amount ⇒ Integer
The total amount of interchange. (This field is deprecated and will be removed
in a future version of the API. To compute total amounts, Lithic recommends that
customers sum the relevant settlement amounts found within details.)
45 |
# File 'lib/lithic/models/settlement_report.rb', line 45 required :interchange_gross_amount, Integer |
#is_complete ⇒ Boolean
Indicates that all data expected on the given report date is available.
51 |
# File 'lib/lithic/models/settlement_report.rb', line 51 required :is_complete, Lithic::Internal::Type::Boolean |
#other_fees_gross_amount ⇒ Integer
Total amount of gross other fees outside of interchange. (This field is
deprecated and will be removed in a future version of the API. To compute total
amounts, Lithic recommends that customers sum the relevant settlement amounts
found within details.)
62 |
# File 'lib/lithic/models/settlement_report.rb', line 62 required :other_fees_gross_amount, Integer |
#report_date ⇒ String
Date of when the report was first generated.
68 |
# File 'lib/lithic/models/settlement_report.rb', line 68 required :report_date, String |
#settled_net_amount ⇒ Integer
The total net amount of cash moved. (net value of settled_gross_amount,
interchange, fees). (This field is deprecated and will be removed in a future
version of the API. To compute total amounts, Lithic recommends that customers
sum the relevant settlement amounts found within details.)
79 |
# File 'lib/lithic/models/settlement_report.rb', line 79 required :settled_net_amount, Integer |
#transactions_gross_amount ⇒ Integer
The total amount of settlement impacting transactions (excluding interchange,
fees, and disputes). (This field is deprecated and will be removed in a future
version of the API. To compute total amounts, Lithic recommends that customers
sum the relevant settlement amounts found within details.)
90 |
# File 'lib/lithic/models/settlement_report.rb', line 90 required :transactions_gross_amount, Integer |
#updated ⇒ Time
Date and time when the transaction first occurred. UTC time zone.
96 |
# File 'lib/lithic/models/settlement_report.rb', line 96 required :updated, Time |
Instance Method Details
#to_hash ⇒ {
55 |
# File 'sig/lithic/models/settlement_report.rbs', line 55
def to_hash: -> {
|