Class: Lithic::Models::ThreeDS::AuthenticationSimulateOtpEntryParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/three_ds/authentication_simulate_otp_entry_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, otp:, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ThreeDS::AuthenticationSimulateOtpEntryParams for more details.

Parameters:

  • token (String)

    A unique token returned as part of a /v1/three_ds_authentication/simulate call t

  • otp (String)

    The OTP entered by the cardholder

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/three_ds/authentication_simulate_otp_entry_params.rb', line 24

Instance Attribute Details

#otpString

The OTP entered by the cardholder

Returns:

  • (String)


22
# File 'lib/lithic/models/three_ds/authentication_simulate_otp_entry_params.rb', line 22

required :otp, String

#tokenString

A unique token returned as part of a /v1/three_ds_authentication/simulate call that resulted in PENDING_CHALLENGE authentication result.

Returns:

  • (String)


16
# File 'lib/lithic/models/three_ds/authentication_simulate_otp_entry_params.rb', line 16

required :token, String