Class: Lithic::Models::ThreeDS::AuthenticationSimulateParams::Merchant

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/three_ds/authentication_simulate_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(merchant:, pan:, transaction:, card_expiry_check: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ThreeDS::AuthenticationSimulateParams for more details.

Parameters:



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/lithic/models/three_ds/authentication_simulate_params.rb', line 50

class Merchant < Lithic::Internal::Type::BaseModel
  # @!attribute id
  #   Unique identifier to identify the payment card acceptor. Corresponds to
  #   `merchant_acceptor_id` in authorization.
  #
  #   @return [String]
  required :id, String

  # @!attribute country
  #   Country of the address provided by the cardholder in ISO 3166-1 alpha-3 format
  #   (e.g. USA)
  #
  #   @return [String]
  required :country, String

  # @!attribute mcc
  #   Merchant category code for the transaction to be simulated. A four-digit number
  #   listed in ISO 18245. Supported merchant category codes can be found
  #   [here](https://docs.lithic.com/docs/transactions#merchant-category-codes-mccs).
  #
  #   @return [String]
  required :mcc, String

  # @!attribute name
  #   Merchant descriptor, corresponds to `descriptor` in authorization. If CHALLENGE
  #   keyword is included, Lithic will trigger a challenge.
  #
  #   @return [String]
  required :name, String

  # @!method initialize(id:, country:, mcc:, name:)
  #   Some parameter documentations has been truncated, see
  #   {Lithic::Models::ThreeDS::AuthenticationSimulateParams::Merchant} for more
  #   details.
  #
  #   Merchant information for the simulated transaction
  #
  #   @param id [String] Unique identifier to identify the payment card acceptor. Corresponds to `merchan
  #
  #   @param country [String] Country of the address provided by the cardholder in ISO 3166-1 alpha-3 format (
  #
  #   @param mcc [String] Merchant category code for the transaction to be simulated. A four-digit number
  #
  #   @param name [String] Merchant descriptor, corresponds to `descriptor` in authorization. If CHALLENGE
end

Instance Attribute Details

#countryString

Country of the address provided by the cardholder in ISO 3166-1 alpha-3 format (e.g. USA)

Returns:

  • (String)


63
# File 'lib/lithic/models/three_ds/authentication_simulate_params.rb', line 63

required :country, String

#idString

Unique identifier to identify the payment card acceptor. Corresponds to ‘merchant_acceptor_id` in authorization.

Returns:

  • (String)


56
# File 'lib/lithic/models/three_ds/authentication_simulate_params.rb', line 56

required :id, String

#mccString

Merchant category code for the transaction to be simulated. A four-digit number listed in ISO 18245. Supported merchant category codes can be found [here](docs.lithic.com/docs/transactions#merchant-category-codes-mccs).

Returns:

  • (String)


71
# File 'lib/lithic/models/three_ds/authentication_simulate_params.rb', line 71

required :mcc, String

#nameString

Merchant descriptor, corresponds to ‘descriptor` in authorization. If CHALLENGE keyword is included, Lithic will trigger a challenge.

Returns:

  • (String)


78
# File 'lib/lithic/models/three_ds/authentication_simulate_params.rb', line 78

required :name, String