Class: Lithic::Models::ThreeDSAuthentication::AdditionalData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs

Overview

See Also:

  • Lithic::Models::ThreeDSAuthentication#additional_data

Defined Under Namespace

Modules: NetworkDecision

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(network_decision: nil, network_risk_score: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ThreeDSAuthentication::AdditionalData for more details.

Object containing additional data about the 3DS request that is beyond the EMV 3DS standard spec (e.g., specific fields that only certain card networks send but are not required across all 3DS requests).

Parameters:



# File 'lib/lithic/models/three_ds_authentication.rb', line 802

Instance Attribute Details

#network_decision ⇒ Symbol, ...

Mastercard only: Indicates whether the network would have considered the authentication request to be low risk or not.

Parameters:

  • value (Lithic::Models::ThreeDSAuthentication::AdditionalData::network_decision, nil)

Returns:



790
791
792
# File 'lib/lithic/models/three_ds_authentication.rb', line 790

optional :network_decision,
enum: -> { Lithic::ThreeDSAuthentication::AdditionalData::NetworkDecision },
nil?: true

#network_risk_score ⇒ Integer?

Mastercard only: Assessment by the network of the authentication risk level, with a higher value indicating a higher amount of risk. Permitted values: Integer between 0-950, in increments of 50.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


800
# File 'lib/lithic/models/three_ds_authentication.rb', line 800

optional :network_risk_score, Integer, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


553
# File 'sig/lithic/models/three_ds_authentication.rbs', line 553

def to_hash: -> {