Class: Lithic::Models::ThreeDSAuthentication::Cardholder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ThreeDSAuthentication::Cardholder
- Defined in:
- lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs
Overview
Defined Under Namespace
Modules: AddressOnFileMatch Classes: BillingAddress, ShippingAddress
Instance Attribute Summary collapse
-
#address_match ⇒ Boolean?
Indicates whether the shipping address and billing address provided by the cardholder are the same.
-
#address_on_file_match ⇒ Symbol, ...
Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists.
-
#billing_address ⇒ Lithic::Models::ThreeDSAuthentication::Cardholder::BillingAddress?
Object containing data on the billing address provided during the transaction.
-
#email ⇒ String?
Email address that is either provided by the cardholder or is on file with the merchant in a 3RI request.
-
#name ⇒ String?
Name of the cardholder.
-
#phone_number_home ⇒ String?
Home phone number in E.164 format provided by the cardholder.
-
#phone_number_mobile ⇒ String?
Mobile/cell phone number in E.164 format provided by the cardholder.
-
#phone_number_work ⇒ String?
Work phone number in E.164 format provided by the cardholder.
-
#shipping_address ⇒ Lithic::Models::ThreeDSAuthentication::Cardholder::ShippingAddress?
Object containing data on the shipping address provided during the transaction.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(address1: nil, address2: nil, address3: nil, city: nil, country: nil, postal_code: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BillingAddress for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address1: nil, address2: nil, address3: nil, city: nil, country: nil, postal_code: nil) ⇒ Object
Some parameter documentations has been truncated, see BillingAddress for more details.
Object containing data on the billing address provided during the transaction.
|
|
# File 'lib/lithic/models/three_ds_authentication.rb', line 335
|
Instance Attribute Details
#address_match ⇒ Boolean?
Indicates whether the shipping address and billing address provided by the
cardholder are the same. This value - and assessment of whether the addresses
match - is provided directly in the 3DS request and is not determined by Lithic.
Maps to EMV 3DS field addrMatch.
277 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 277 optional :address_match, Lithic::Internal::Type::Boolean, nil?: true |
#address_on_file_match ⇒ Symbol, ...
Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
286 287 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 286 optional :address_on_file_match, enum: -> { Lithic::ThreeDSAuthentication::Cardholder::AddressOnFileMatch } |
#billing_address ⇒ Lithic::Models::ThreeDSAuthentication::Cardholder::BillingAddress?
Object containing data on the billing address provided during the transaction.
293 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 293 optional :billing_address, -> { Lithic::ThreeDSAuthentication::Cardholder::BillingAddress } |
#email ⇒ String?
Email address that is either provided by the cardholder or is on file with the
merchant in a 3RI request. Maps to EMV 3DS field email.
300 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 300 optional :email, String, nil?: true |
#name ⇒ String?
Name of the cardholder. Maps to EMV 3DS field cardholderName.
306 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 306 optional :name, String, nil?: true |
#phone_number_home ⇒ String?
Home phone number in E.164 format provided by the cardholder. Maps to EMV 3DS
fields homePhone.cc and homePhone.subscriber.
313 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 313 optional :phone_number_home, String, nil?: true |
#phone_number_mobile ⇒ String?
Mobile/cell phone number in E.164 format provided by the cardholder. Maps to EMV
3DS fields mobilePhone.cc and mobilePhone.subscriber.
320 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 320 optional :phone_number_mobile, String, nil?: true |
#phone_number_work ⇒ String?
Work phone number in E.164 format provided by the cardholder. Maps to EMV 3DS
fields workPhone.cc and workPhone.subscriber.
327 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 327 optional :phone_number_work, String, nil?: true |
#shipping_address ⇒ Lithic::Models::ThreeDSAuthentication::Cardholder::ShippingAddress?
Object containing data on the shipping address provided during the transaction.
333 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 333 optional :shipping_address, -> { Lithic::ThreeDSAuthentication::Cardholder::ShippingAddress } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/three_ds_authentication.rb', line 374
|
Instance Method Details
#to_hash ⇒ {
213 |
# File 'sig/lithic/models/three_ds_authentication.rbs', line 213
def to_hash: -> {
|