Class: Lithic::Models::ThreeDSAuthentication::Cardholder::BillingAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs

Overview

See Also:

  • Lithic::Models::ThreeDSAuthentication::Cardholder#billing_address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



267
# File 'sig/lithic/models/three_ds_authentication.rbs', line 267

def initialize: (

Instance Attribute Details

#address1 ⇒ String?

First line of the street address provided by the cardholder.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


384
# File 'lib/lithic/models/three_ds_authentication.rb', line 384

optional :address1, String, nil?: true

#address2 ⇒ String?

Second line of the street address provided by the cardholder.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


390
# File 'lib/lithic/models/three_ds_authentication.rb', line 390

optional :address2, String, nil?: true

#address3 ⇒ String?

Third line of the street address provided by the cardholder.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


396
# File 'lib/lithic/models/three_ds_authentication.rb', line 396

optional :address3, String, nil?: true

#city ⇒ String?

City of the address provided by the cardholder.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


402
# File 'lib/lithic/models/three_ds_authentication.rb', line 402

optional :city, String, nil?: true

#country ⇒ String?

Country of the address provided by the cardholder in ISO 3166-1 alpha-3 format (e.g. USA)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


409
# File 'lib/lithic/models/three_ds_authentication.rb', line 409

optional :country, String, nil?: true

#postal_code ⇒ String?

Postal code (e.g., ZIP code) of the address provided by the cardholder

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


415
# File 'lib/lithic/models/three_ds_authentication.rb', line 415

optional :postal_code, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


276
# File 'sig/lithic/models/three_ds_authentication.rbs', line 276

def to_hash: -> {