Class: Lithic::Models::ThreeDSAuthentication::ChallengeMetadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs

Overview

See Also:

  • Lithic::Models::ThreeDSAuthentication#challenge_metadata

Defined Under Namespace

Modules: MethodType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(method_type:, status:, phone_number: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ThreeDSAuthentication::ChallengeMetadata for more details.

Metadata about the challenge method and delivery. Only present when a challenge is triggered.

Parameters:



# File 'lib/lithic/models/three_ds_authentication.rb', line 1048

Instance Attribute Details

#method_typeSymbol, Lithic::Models::ThreeDSAuthentication::ChallengeMetadata::MethodType

The type of challenge method used for authentication.

Parameters:

  • value (Lithic::Models::ThreeDSAuthentication::ChallengeMetadata::method_type)

Returns:



1019
# File 'lib/lithic/models/three_ds_authentication.rb', line 1019

required :method_type, enum: -> { Lithic::ThreeDSAuthentication::ChallengeMetadata::MethodType }

#phone_numberString?

The phone number used for delivering the OTP. Relevant only for SMS_OTP method.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1046
# File 'lib/lithic/models/three_ds_authentication.rb', line 1046

optional :phone_number, String, nil?: true

#statusSymbol, Lithic::Models::ThreeDSAuthentication::ChallengeMetadata::Status

Indicates the status of the challenge

  • SUCCESS - Cardholder completed the challenge successfully
  • PENDING - Challenge was issued to the cardholder and was not completed yet
  • SMS_DELIVERY_FAILED - Lithic confirmed undeliverability of the SMS to the provided phone number. Relevant only for SMS_OTP method
  • CARDHOLDER_TIMEOUT - Cardholder failed to complete the challenge within the given challenge TTL
  • CANCELED_VIA_CHALLENGE_UI - Cardholder canceled the challenge by selecting "cancel" on the challenge UI
  • CANCELED_OOB - Cardholder canceled the challenge out of band
  • ATTEMPTS_EXCEEDED - Cardholder failed the challenge by either entering an incorrect OTP more than the allowed number of times or requesting a new OTP more than the allowed number of times
  • ABORTED - Merchant aborted authentication after a challenge was requested
  • ERROR - The challenge failed for a reason different than those documented

Parameters:

  • value (Lithic::Models::ThreeDSAuthentication::ChallengeMetadata::status)

Returns:



1040
# File 'lib/lithic/models/three_ds_authentication.rb', line 1040

required :status, enum: -> { Lithic::ThreeDSAuthentication::ChallengeMetadata::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/three_ds_authentication.rb', line 1070

Instance Method Details

#to_hash{

Returns:

  • ({)


730
# File 'sig/lithic/models/three_ds_authentication.rbs', line 730

def to_hash: -> {