Class: Lithic::Models::ThreeDSAuthentication::Merchant::RiskIndicator
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ThreeDSAuthentication::Merchant::RiskIndicator
- Defined in:
- lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs
Overview
Defined Under Namespace
Modules: DeliveryTimeFrame, OrderAvailability, ReorderItems, ShippingMethod
Instance Attribute Summary collapse
-
#delivery_email_address ⇒ String?
In transactions with electronic delivery, email address to which merchandise is delivered.
-
#delivery_time_frame ⇒ Symbol, ...
The delivery time frame for the merchandise.
-
#gift_card_amount ⇒ Integer?
In prepaid or gift card purchase transactions, purchase amount total in major units (e.g., a purchase of USD $205.10 would be 205).
-
#gift_card_count ⇒ Integer?
In prepaid or gift card purchase transactions, count of individual prepaid or gift cards/codes purchased.
-
#gift_card_currency ⇒ String?
In prepaid or gift card purchase transactions, currency code of the gift card.
-
#order_availability ⇒ Symbol, ...
Indicates whether the purchase is for merchandise that is available now or at a future date.
-
#pre_order_available_date ⇒ Time?
In pre-order purchase transactions, the expected date that the merchandise will be available.
-
#reorder_items ⇒ Symbol, ...
Indicates whether the cardholder is reordering previously purchased merchandise.
-
#shipping_method ⇒ Symbol, ...
Shipping method that the cardholder chose for the transaction.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(delivery_email_address: nil, delivery_time_frame: nil, gift_card_amount: nil, gift_card_count: nil, gift_card_currency: nil, order_availability: nil, pre_order_available_date: nil, reorder_items: nil, shipping_method: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RiskIndicator for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(delivery_email_address: nil, delivery_time_frame: nil, gift_card_amount: nil, gift_card_count: nil, gift_card_currency: nil, order_availability: nil, pre_order_available_date: nil, reorder_items: nil, shipping_method: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::ThreeDSAuthentication::Merchant::RiskIndicator for more details.
Object containing additional data indicating additional risk factors related to the e-commerce transaction.
|
|
# File 'lib/lithic/models/three_ds_authentication.rb', line 636
|
Instance Attribute Details
#delivery_email_address ⇒ String?
In transactions with electronic delivery, email address to which merchandise is
delivered. Maps to EMV 3DS field deliveryEmailAddress.
565 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 565 optional :delivery_email_address, String, nil?: true |
#delivery_time_frame ⇒ Symbol, ...
The delivery time frame for the merchandise. Maps to EMV 3DS field
deliveryTimeframe.
572 573 574 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 572 optional :delivery_time_frame, enum: -> { Lithic::ThreeDSAuthentication::Merchant::RiskIndicator::DeliveryTimeFrame }, nil?: true |
#gift_card_amount ⇒ Integer?
In prepaid or gift card purchase transactions, purchase amount total in major
units (e.g., a purchase of USD $205.10 would be 205). Maps to EMV 3DS field
giftCardAmount.
582 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 582 optional :gift_card_amount, Integer, nil?: true |
#gift_card_count ⇒ Integer?
In prepaid or gift card purchase transactions, count of individual prepaid or
gift cards/codes purchased. Maps to EMV 3DS field giftCardCount.
589 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 589 optional :gift_card_count, Integer, nil?: true |
#gift_card_currency ⇒ String?
In prepaid or gift card purchase transactions, currency code of the gift card.
Maps to EMV 3DS field giftCardCurr. Permitted values: ISO 4217 three-character
currency code (e.g., USD).
597 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 597 optional :gift_card_currency, String, nil?: true |
#order_availability ⇒ Symbol, ...
Indicates whether the purchase is for merchandise that is available now or at a
future date. Maps to EMV 3DS field preOrderPurchaseInd.
604 605 606 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 604 optional :order_availability, enum: -> { Lithic::ThreeDSAuthentication::Merchant::RiskIndicator::OrderAvailability }, nil?: true |
#pre_order_available_date ⇒ Time?
In pre-order purchase transactions, the expected date that the merchandise will
be available. Maps to EMV 3DS field preOrderDate. Permitted values: Date
string in the ISO 8601 format yyyy-MM-dd'T'hh:mm:ssZ
614 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 614 optional :pre_order_available_date, Time, nil?: true |
#reorder_items ⇒ Symbol, ...
Indicates whether the cardholder is reordering previously purchased merchandise.
Maps to EMV 3DS field reorderItemsInd.
621 622 623 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 621 optional :reorder_items, enum: -> { Lithic::ThreeDSAuthentication::Merchant::RiskIndicator::ReorderItems }, nil?: true |
#shipping_method ⇒ Symbol, ...
Shipping method that the cardholder chose for the transaction. If purchase
includes one or more item, this indicator is used for the physical goods; if the
purchase only includes digital goods, this indicator is used to describe the
most expensive item purchased. Maps to EMV 3DS field shipIndicator.
632 633 634 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 632 optional :shipping_method, enum: -> { Lithic::ThreeDSAuthentication::Merchant::RiskIndicator::ShippingMethod }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/three_ds_authentication.rb', line 674
|
Instance Method Details
#to_hash ⇒ {
416 |
# File 'sig/lithic/models/three_ds_authentication.rbs', line 416
def to_hash: -> {
|