Module: Lithic::Models::ThreeDSAuthentication::Merchant::RiskIndicator::ShippingMethod

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs

Overview

Shipping method that the cardholder chose for the transaction. If purchase includes one or more item, this indicator is used for the physical goods; if the purchase only includes digital goods, this indicator is used to describe the most expensive item purchased. Maps to EMV 3DS field shipIndicator.

See Also:

  • Lithic::Models::ThreeDSAuthentication::Merchant::RiskIndicator#shipping_method

Constant Summary collapse

DIGITAL_GOODS =

Returns:

  • (:DIGITAL_GOODS)
:DIGITAL_GOODS
LOCKER_DELIVERY =

Returns:

  • (:LOCKER_DELIVERY)
:LOCKER_DELIVERY
OTHER =

Returns:

  • (:OTHER)
:OTHER
PICK_UP_AND_GO_DELIVERY =

Returns:

  • (:PICK_UP_AND_GO_DELIVERY)
:PICK_UP_AND_GO_DELIVERY
SHIP_TO_BILLING_ADDRESS =

Returns:

  • (:SHIP_TO_BILLING_ADDRESS)
:SHIP_TO_BILLING_ADDRESS
SHIP_TO_NON_BILLING_ADDRESS =

Returns:

  • (:SHIP_TO_NON_BILLING_ADDRESS)
:SHIP_TO_NON_BILLING_ADDRESS
SHIP_TO_OTHER_VERIFIED_ADDRESS =

Returns:

  • (:SHIP_TO_OTHER_VERIFIED_ADDRESS)
:SHIP_TO_OTHER_VERIFIED_ADDRESS
SHIP_TO_STORE =

Returns:

  • (:SHIP_TO_STORE)
:SHIP_TO_STORE
TRAVEL_AND_EVENT_TICKETS =

Returns:

  • (:TRAVEL_AND_EVENT_TICKETS)
:TRAVEL_AND_EVENT_TICKETS

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Lithic::Models::ThreeDSAuthentication::Merchant::RiskIndicator::shipping_method]

Returns:

  • (::Array[Lithic::Models::ThreeDSAuthentication::Merchant::RiskIndicator::shipping_method])


492
# File 'sig/lithic/models/three_ds_authentication.rbs', line 492

def self?.values: -> ::Array[Lithic::Models::ThreeDSAuthentication::Merchant::RiskIndicator::shipping_method]