Class: Lithic::Models::ThreeDSAuthentication::Transaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs

Overview

See Also:

  • Lithic::Models::ThreeDSAuthentication#transaction

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, cardholder_amount:, currency:, currency_exponent:, date_time:, type:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::ThreeDSAuthentication::Transaction for more details.

Object containing data about the e-commerce transaction for which the merchant is requesting authentication.

Parameters:

  • amount (Float) —

    Amount of the purchase in minor units of currency with all punctuation removed.

  • cardholder_amount (Float, nil) —

    Approximate amount of the purchase in minor units of cardholder currency. Derive

  • currency (String) —

    Currency of the purchase. Maps to EMV 3DS field purchaseCurrency. Permitted va

  • currency_exponent (Float) —

    Minor units of currency, as specified in ISO 4217 currency exponent. Maps to EMV

  • date_time (Time) —

    Date and time when the authentication was generated by the merchant/acquirer's 3

  • type (Symbol, Lithic::Models::ThreeDSAuthentication::Transaction::Type, nil) —

    Type of the transaction for which a 3DS authentication request is occurring. Map



# File 'lib/lithic/models/three_ds_authentication.rb', line 1346

Instance Attribute Details

#amount ⇒ Float

Amount of the purchase in minor units of currency with all punctuation removed. Maps to EMV 3DS field purchaseAmount.

Parameters:

  • value (Float)

Returns:

  • (Float)


1308
# File 'lib/lithic/models/three_ds_authentication.rb', line 1308

required :amount, Float

#cardholder_amount ⇒ Float?

Approximate amount of the purchase in minor units of cardholder currency. Derived from amount using a daily conversion rate.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


1315
# File 'lib/lithic/models/three_ds_authentication.rb', line 1315

required :cardholder_amount, Float, nil?: true

#currency ⇒ String

Currency of the purchase. Maps to EMV 3DS field purchaseCurrency. Permitted values: ISO 4217 three-character currency code (e.g., USD).

Parameters:

  • value (String)

Returns:

  • (String)


1322
# File 'lib/lithic/models/three_ds_authentication.rb', line 1322

required :currency, String

#currency_exponent ⇒ Float

Minor units of currency, as specified in ISO 4217 currency exponent. Maps to EMV 3DS field purchaseExponent.

Parameters:

  • value (Float)

Returns:

  • (Float)


1329
# File 'lib/lithic/models/three_ds_authentication.rb', line 1329

required :currency_exponent, Float

#date_time ⇒ Time

Date and time when the authentication was generated by the merchant/acquirer's 3DS server. Maps to EMV 3DS field purchaseDate. Permitted values: Date string in the ISO 8601 format yyyy-MM-dd'T'hh:mm:ssZ.

Parameters:

  • value (Time)

Returns:

  • (Time)


1337
# File 'lib/lithic/models/three_ds_authentication.rb', line 1337

required :date_time, Time

#type ⇒ Symbol, ...

Type of the transaction for which a 3DS authentication request is occurring. Maps to EMV 3DS field transType.

Parameters:

  • value (Lithic::Models::ThreeDSAuthentication::Transaction::type_, nil)

Returns:



1344
# File 'lib/lithic/models/three_ds_authentication.rb', line 1344

required :type, enum: -> { Lithic::ThreeDSAuthentication::Transaction::Type }, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


958
# File 'sig/lithic/models/three_ds_authentication.rbs', line 958

def to_hash: -> {