Class: Lithic::Models::TokenInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/token_info.rb,
sig/lithic/models/token_info.rbs

Defined Under Namespace

Modules: WalletType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(wallet_type:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::TokenInfo for more details.

Parameters:



# File 'lib/lithic/models/token_info.rb', line 15

Instance Attribute Details

#wallet_typeSymbol, Lithic::Models::TokenInfo::WalletType

The wallet_type field will indicate the source of the token. Possible token sources include digital wallets (Apple, Google, or Samsung Pay), merchant tokenization, and “other” sources like in-flight commerce. Masterpass is not currently supported and is included for future use.

Parameters:

  • value (Lithic::Models::TokenInfo::wallet_type)

Returns:



13
# File 'lib/lithic/models/token_info.rb', line 13

required :wallet_type, enum: -> { Lithic::TokenInfo::WalletType }

Instance Method Details

#to_hash{ wallet_type: Lithic::Models::TokenInfo::wallet_type }

Returns:

  • ({ wallet_type: Lithic::Models::TokenInfo::wallet_type })


12
# File 'sig/lithic/models/token_info.rbs', line 12

def to_hash: -> { wallet_type: Lithic::Models::TokenInfo::wallet_type }