Module: Lithic::Models::TokenInfo::WalletType

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/token_info.rb,
sig/lithic/models/token_info.rbs

Overview

The wallet_type field will indicate the source of the token. Possible token sources include digital wallets (Apple, Google, or Samsung Pay), merchant tokenization, and “other” sources like in-flight commerce. Masterpass is not currently supported and is included for future use.

See Also:

  • Lithic::Models::TokenInfo#wallet_type

Constant Summary collapse

APPLE_PAY =

Returns:

  • (:APPLE_PAY)
:APPLE_PAY
GOOGLE_PAY =

Returns:

  • (:GOOGLE_PAY)
:GOOGLE_PAY
MASTERPASS =

Returns:

  • (:MASTERPASS)
:MASTERPASS
MERCHANT =

Returns:

  • (:MERCHANT)
:MERCHANT
OTHER =

Returns:

  • (:OTHER)
:OTHER
SAMSUNG_PAY =

Returns:

  • (:SAMSUNG_PAY)
:SAMSUNG_PAY

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/token_info.rb', line 37

Instance Method Details

#self?.values::Array[Lithic::Models::TokenInfo::wallet_type]

Returns:

  • (::Array[Lithic::Models::TokenInfo::wallet_type])


32
# File 'sig/lithic/models/token_info.rbs', line 32

def self?.values: -> ::Array[Lithic::Models::TokenInfo::wallet_type]