Class: Lithic::Models::Tokenization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/tokenization.rb,
sig/lithic/models/tokenization.rbs

Overview

See Also:

  • Lithic::Resources::Tokenizations#retrieve

Defined Under Namespace

Modules: Status, TokenRequestorName, TokenizationChannel Classes: Event

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, account_token:, card_token:, created_at:, dpan:, status:, token_requestor_name:, token_unique_reference:, tokenization_channel:, updated_at:, device_id: nil, digital_card_art_token: nil, events: nil, payment_account_reference_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Tokenization for more details.

Parameters:

  • token (String)

    Globally unique identifier for a Tokenization

  • account_token (String)

    The account token associated with the card being tokenized.

  • card_token (String)

    The card token associated with the card being tokenized.

  • created_at (Time)

    Date and time when the tokenization first occurred. UTC time zone.

  • dpan (String, nil)

    The dynamic pan assigned to the token by the network.

  • status (Symbol, Lithic::Models::Tokenization::Status)

    The status of the tokenization request

  • token_requestor_name (Symbol, String, Lithic::Models::Tokenization::TokenRequestorName)

    The entity that requested the tokenization. For digital wallets, this will be on

  • token_unique_reference (String)

    The network's unique reference for the tokenization.

  • tokenization_channel (Symbol, Lithic::Models::Tokenization::TokenizationChannel)

    The channel through which the tokenization was made.

  • updated_at (Time)

    Latest date and time when the tokenization was updated. UTC time zone.

  • device_id (String, nil) (defaults to: nil)

    The device identifier associated with the tokenization.

  • digital_card_art_token (String, nil) (defaults to: nil)

    Specifies the digital card art displayed in the user's digital wallet after toke

  • events (Array<Lithic::Models::Tokenization::Event>) (defaults to: nil)

    A list of events related to the tokenization.

  • payment_account_reference_id (String, nil) (defaults to: nil)

    The network's unique reference for the card that is tokenized.



# File 'lib/lithic/models/tokenization.rb', line 96

Instance Attribute Details

#account_tokenString

The account token associated with the card being tokenized.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/lithic/models/tokenization.rb', line 17

required :account_token, String

#card_tokenString

The card token associated with the card being tokenized.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/lithic/models/tokenization.rb', line 23

required :card_token, String

#created_atTime

Date and time when the tokenization first occurred. UTC time zone.

Parameters:

  • value (Time)

Returns:

  • (Time)


29
# File 'lib/lithic/models/tokenization.rb', line 29

required :created_at, Time

#device_idString?

The device identifier associated with the tokenization.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


73
# File 'lib/lithic/models/tokenization.rb', line 73

optional :device_id, String, nil?: true

#digital_card_art_tokenString?

Specifies the digital card art displayed in the user's digital wallet after tokenization. This will be null if the tokenization was created without an associated digital card art. See Flexible Card Art Guide.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


82
# File 'lib/lithic/models/tokenization.rb', line 82

optional :digital_card_art_token, String, nil?: true

#dpanString?

The dynamic pan assigned to the token by the network.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


35
# File 'lib/lithic/models/tokenization.rb', line 35

required :dpan, String, nil?: true

#eventsArray<Lithic::Models::Tokenization::Event>?

A list of events related to the tokenization.

Returns:



88
# File 'lib/lithic/models/tokenization.rb', line 88

optional :events, -> { Lithic::Internal::Type::ArrayOf[Lithic::Tokenization::Event] }

#payment_account_reference_idString?

The network's unique reference for the card that is tokenized.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


94
# File 'lib/lithic/models/tokenization.rb', line 94

optional :payment_account_reference_id, String, nil?: true

#statusSymbol, Lithic::Models::Tokenization::Status

The status of the tokenization request

Parameters:

  • value (Lithic::Models::Tokenization::status)

Returns:



41
# File 'lib/lithic/models/tokenization.rb', line 41

required :status, enum: -> { Lithic::Tokenization::Status }

#tokenString

Globally unique identifier for a Tokenization

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/lithic/models/tokenization.rb', line 11

required :token, String

#token_requestor_nameSymbol, ...

The entity that requested the tokenization. For digital wallets, this will be one of the defined wallet types. For merchant tokenizations, this will be a free-form merchant name string.

Parameters:

  • value (Lithic::Models::Tokenization::token_requestor_name)

Returns:



49
# File 'lib/lithic/models/tokenization.rb', line 49

required :token_requestor_name, union: -> { Lithic::Tokenization::TokenRequestorName }

#token_unique_referenceString

The network's unique reference for the tokenization.

Parameters:

  • value (String)

Returns:

  • (String)


55
# File 'lib/lithic/models/tokenization.rb', line 55

required :token_unique_reference, String

#tokenization_channelSymbol, Lithic::Models::Tokenization::TokenizationChannel

The channel through which the tokenization was made.

Parameters:

  • value (Lithic::Models::Tokenization::tokenization_channel)

Returns:



61
# File 'lib/lithic/models/tokenization.rb', line 61

required :tokenization_channel, enum: -> { Lithic::Tokenization::TokenizationChannel }

#updated_atTime

Latest date and time when the tokenization was updated. UTC time zone.

Parameters:

  • value (Time)

Returns:

  • (Time)


67
# File 'lib/lithic/models/tokenization.rb', line 67

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/tokenization.rb', line 142

Instance Method Details

#to_hash{

Returns:

  • ({)


71
# File 'sig/lithic/models/tokenization.rbs', line 71

def to_hash: -> {