Class: Lithic::Models::Transaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb

Overview

Defined Under Namespace

Modules: Network, Result, Status Classes: Amounts, Avs, Event, Merchant, Pos, ServiceLocation

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, postal_code:, state:, street_address:) ⇒ Object

Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.

Parameters:

  • city (String, nil)

    City of service location.

  • country (String, nil)

    Country code of service location, ISO 3166-1 alpha-3.

  • postal_code (String, nil)

    Postal code of service location.

  • state (String, nil)

    State/province code of service location, ISO 3166-2.

  • street_address (String, nil)

    Street address of service location.



# File 'lib/lithic/models/transaction.rb', line 197

Instance Attribute Details

#account_tokenString

The token for the account associated with this transaction.

Returns:

  • (String)


17
# File 'lib/lithic/models/transaction.rb', line 17

required :account_token, String

#acquirer_feeInteger?

Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.

Returns:

  • (Integer, nil)


25
# File 'lib/lithic/models/transaction.rb', line 25

required :acquirer_fee, Integer, nil?: true

#acquirer_reference_numberString?

Deprecated.

Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing. This field has been deprecated in favor of the ‘acquirer_reference_number` that resides in the event-level `network_info`.

Returns:

  • (String, nil)


35
# File 'lib/lithic/models/transaction.rb', line 35

required :acquirer_reference_number, String, nil?: true

#amountInteger

Deprecated.

When the transaction is pending, this represents the authorization amount of the transaction in the anticipated settlement currency. Once the transaction has settled, this field represents the settled amount in the settlement currency.

Returns:

  • (Integer)


45
# File 'lib/lithic/models/transaction.rb', line 45

required :amount, Integer

#amountsLithic::Models::Transaction::Amounts



50
# File 'lib/lithic/models/transaction.rb', line 50

required :amounts, -> { Lithic::Transaction::Amounts }

#authorization_amountInteger?

Deprecated.

The authorization amount of the transaction in the anticipated settlement currency.

Returns:

  • (Integer, nil)


59
# File 'lib/lithic/models/transaction.rb', line 59

required :authorization_amount, Integer, nil?: true

#authorization_codeString?

A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks.

Returns:

  • (String, nil)


66
# File 'lib/lithic/models/transaction.rb', line 66

required :authorization_code, String, nil?: true

#avsLithic::Models::Transaction::Avs?



71
# File 'lib/lithic/models/transaction.rb', line 71

required :avs, -> { Lithic::Transaction::Avs }, nil?: true

#card_tokenString

Token for the card used in this transaction.

Returns:

  • (String)


77
# File 'lib/lithic/models/transaction.rb', line 77

required :card_token, String

#cardholder_authenticationLithic::Models::CardholderAuthentication?



82
# File 'lib/lithic/models/transaction.rb', line 82

required :cardholder_authentication, -> { Lithic::CardholderAuthentication }, nil?: true

#createdTime

Date and time when the transaction first occurred. UTC time zone.

Returns:

  • (Time)


88
# File 'lib/lithic/models/transaction.rb', line 88

required :created, Time

#eventsArray<Lithic::Models::Transaction::Event>?

Returns:



195
# File 'lib/lithic/models/transaction.rb', line 195

optional :events, -> { Lithic::Internal::Type::ArrayOf[Lithic::Transaction::Event] }

#financial_account_tokenString?

Returns:

  • (String, nil)


93
# File 'lib/lithic/models/transaction.rb', line 93

required :financial_account_token, String, nil?: true

#merchantLithic::Models::Transaction::Merchant

Merchant information including full location details.



99
# File 'lib/lithic/models/transaction.rb', line 99

required :merchant, -> { Lithic::Transaction::Merchant }

#merchant_amountInteger?

Deprecated.

Analogous to the ‘amount’, but in the merchant currency.

Returns:

  • (Integer, nil)


107
# File 'lib/lithic/models/transaction.rb', line 107

required :merchant_amount, Integer, nil?: true

#merchant_authorization_amountInteger?

Deprecated.

Analogous to the ‘authorization_amount’, but in the merchant currency.

Returns:

  • (Integer, nil)


115
# File 'lib/lithic/models/transaction.rb', line 115

required :merchant_authorization_amount, Integer, nil?: true

#merchant_currencyString

Deprecated.

3-character alphabetic ISO 4217 code for the local currency of the transaction.

Returns:

  • (String)


123
# File 'lib/lithic/models/transaction.rb', line 123

required :merchant_currency, String

#networkSymbol, ...

Card network of the authorization. Value is ‘UNKNOWN` when Lithic cannot determine the network code from the upstream provider.

Returns:



130
# File 'lib/lithic/models/transaction.rb', line 130

required :network, enum: -> { Lithic::Transaction::Network }, nil?: true

#network_risk_scoreInteger?

Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.

Returns:

  • (Integer, nil)


140
# File 'lib/lithic/models/transaction.rb', line 140

required :network_risk_score, Integer, nil?: true

#posLithic::Models::Transaction::Pos



145
# File 'lib/lithic/models/transaction.rb', line 145

required :pos, -> { Lithic::Transaction::Pos }

#resultSymbol, Lithic::Models::Transaction::Result



150
# File 'lib/lithic/models/transaction.rb', line 150

required :result, enum: -> { Lithic::Transaction::Result }

#service_locationLithic::Models::Transaction::ServiceLocation?

Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.



158
# File 'lib/lithic/models/transaction.rb', line 158

required :service_location, -> { Lithic::Transaction::ServiceLocation }, nil?: true

#settled_amountInteger

Deprecated.

The settled amount of the transaction in the settlement currency.

Returns:

  • (Integer)


166
# File 'lib/lithic/models/transaction.rb', line 166

required :settled_amount, Integer

#statusSymbol, Lithic::Models::Transaction::Status

Status of the transaction.



172
# File 'lib/lithic/models/transaction.rb', line 172

required :status, enum: -> { Lithic::Transaction::Status }

#tagsHash{Symbol=>String}

Key-value pairs for tagging resources. Tags allow you to associate arbitrary metadata with a resource for your own purposes.

Returns:

  • (Hash{Symbol=>String})


179
# File 'lib/lithic/models/transaction.rb', line 179

required :tags, Lithic::Internal::Type::HashOf[String]

#tokenString

Globally unique identifier.

Returns:

  • (String)


11
# File 'lib/lithic/models/transaction.rb', line 11

required :token, String

#token_infoLithic::Models::TokenInfo?

Returns:



184
# File 'lib/lithic/models/transaction.rb', line 184

required :token_info, -> { Lithic::TokenInfo }, nil?: true

#updatedTime

Date and time when the transaction last updated. UTC time zone.

Returns:

  • (Time)


190
# File 'lib/lithic/models/transaction.rb', line 190

required :updated, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/transaction.rb', line 443