Class: Lithic::Models::Transaction::Amounts::Cardholder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs

Overview

See Also:

  • Lithic::Models::Transaction::Amounts#cardholder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



199
# File 'sig/lithic/models/transaction.rbs', line 199

def initialize: (

Instance Attribute Details

#amountInteger

The estimated settled amount of the transaction in the cardholder billing currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


292
# File 'lib/lithic/models/transaction.rb', line 292

required :amount, Integer

#conversion_rateString

The exchange rate used to convert the merchant amount to the cardholder billing amount.

Parameters:

  • value (String)

Returns:

  • (String)


299
# File 'lib/lithic/models/transaction.rb', line 299

required :conversion_rate, String

#currencyString

3-character alphabetic ISO 4217 currency

Parameters:

  • value (String)

Returns:

  • (String)


305
# File 'lib/lithic/models/transaction.rb', line 305

required :currency, String

Instance Method Details

#to_hash{

Returns:

  • ({)


205
# File 'sig/lithic/models/transaction.rbs', line 205

def to_hash: -> {