Class: Lithic::Models::Transaction::Event::Amounts::Cardholder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs

Overview

See Also:

  • Lithic::Models::Transaction::Event::Amounts#cardholder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



799
# File 'sig/lithic/models/transaction.rbs', line 799

def initialize: (

Instance Attribute Details

#amountInteger

Amount of the event in the cardholder billing currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


935
# File 'lib/lithic/models/transaction.rb', line 935

required :amount, Integer

#conversion_rateString

Exchange rate used to convert the merchant amount to the cardholder billing amount.

Parameters:

  • value (String)

Returns:

  • (String)


942
# File 'lib/lithic/models/transaction.rb', line 942

required :conversion_rate, String

#currencyString

3-character alphabetic ISO 4217 currency

Parameters:

  • value (String)

Returns:

  • (String)


948
# File 'lib/lithic/models/transaction.rb', line 948

required :currency, String

Instance Method Details

#to_hash{

Returns:

  • ({)


805
# File 'sig/lithic/models/transaction.rbs', line 805

def to_hash: -> {