Class: Lithic::Models::Transaction::Event::NetworkInfo::Acquirer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs

Overview

See Also:

  • Lithic::Models::Transaction::Event::NetworkInfo#acquirer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



1026
# File 'sig/lithic/models/transaction.rbs', line 1026

def initialize: (

Instance Attribute Details

#acquirer_reference_number ⇒ String?

Identifier assigned by the acquirer, applicable to dual-message transactions only. The acquirer reference number (ARN) is only populated once a transaction has been cleared, and it is not available in all transactions (such as automated fuel dispenser transactions). A single transaction can contain multiple ARNs if the merchant sends multiple clearings.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1141
# File 'lib/lithic/models/transaction.rb', line 1141

required :acquirer_reference_number, String, nil?: true

#retrieval_reference_number ⇒ String?

Identifier assigned by the acquirer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1147
# File 'lib/lithic/models/transaction.rb', line 1147

required :retrieval_reference_number, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1031
# File 'sig/lithic/models/transaction.rbs', line 1031

def to_hash: -> {