Class: Lithic::Models::Transaction::Event::NetworkInfo::Amex
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Transaction::Event::NetworkInfo::Amex
- Defined in:
- lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#original_transaction_id ⇒ String?
Identifier assigned by American Express.
-
#transaction_id ⇒ String?
Identifier assigned by American Express to link original messages to subsequent messages.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1043 |
# File 'sig/lithic/models/transaction.rbs', line 1043
def initialize: (
|
Instance Attribute Details
#original_transaction_id ⇒ String?
Identifier assigned by American Express. Matches the transaction_id of a prior
related event. May be populated in incremental authorizations (authorization
requests that augment a previously authorized amount), authorization advices,
financial authorizations, and clearings.
1166 |
# File 'lib/lithic/models/transaction.rb', line 1166 required :original_transaction_id, String, nil?: true |
#transaction_id ⇒ String?
Identifier assigned by American Express to link original messages to subsequent messages. Guaranteed by American Express to be unique for each original authorization and financial authorization.
1174 |
# File 'lib/lithic/models/transaction.rb', line 1174 required :transaction_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
1048 |
# File 'sig/lithic/models/transaction.rbs', line 1048
def to_hash: -> {
|