Class: Lithic::Models::Transaction::Event::NetworkInfo::Mastercard

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs

Overview

See Also:

  • Lithic::Models::Transaction::Event::NetworkInfo#mastercard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



1073
# File 'sig/lithic/models/transaction.rbs', line 1073

def initialize: (

Instance Attribute Details

#banknet_reference_number ⇒ String?

Identifier assigned by Mastercard. Guaranteed by Mastercard to be unique for any transaction within a specific financial network on any processing day.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1193
# File 'lib/lithic/models/transaction.rb', line 1193

required :banknet_reference_number, String, nil?: true

#original_banknet_reference_number ⇒ String?

Identifier assigned by Mastercard. Matches the banknet_reference_number of a prior related event. May be populated in authorization reversals, incremental authorizations (authorization requests that augment a previously authorized amount), automated fuel dispenser authorization advices and clearings, and financial authorizations. If the original banknet reference number contains all zeroes, then no actual reference number could be found by the network or acquirer. If Mastercard converts a transaction from dual-message to single-message, such as for certain ATM transactions, it will populate the original banknet reference number in the resulting financial authorization with the banknet reference number of the initial authorization, which Lithic does not receive.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1209
# File 'lib/lithic/models/transaction.rb', line 1209

required :original_banknet_reference_number, String, nil?: true

#original_switch_serial_number ⇒ String?

Identifier assigned by Mastercard. Matches the switch_serial_number of a prior related event. May be populated in returns and return reversals. Applicable to single-message transactions only.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1217
# File 'lib/lithic/models/transaction.rb', line 1217

required :original_switch_serial_number, String, nil?: true

#switch_serial_number ⇒ String?

Identifier assigned by Mastercard, applicable to single-message transactions only.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1224
# File 'lib/lithic/models/transaction.rb', line 1224

required :switch_serial_number, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1080
# File 'sig/lithic/models/transaction.rbs', line 1080

def to_hash: -> {