Class: Lithic::Models::Transaction::Event::NetworkInfo::Visa

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs

Overview

See Also:

  • Lithic::Models::Transaction::Event::NetworkInfo#visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



1096
# File 'sig/lithic/models/transaction.rbs', line 1096

def initialize: (

Instance Attribute Details

#original_transaction_id ⇒ String?

Identifier assigned by Visa. Matches the transaction_id of a prior related event. May be populated in incremental authorizations (authorization requests that augment a previously authorized amount), authorization advices, financial authorizations, and clearings.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1248
# File 'lib/lithic/models/transaction.rb', line 1248

required :original_transaction_id, String, nil?: true

#transaction_id ⇒ String?

Identifier assigned by Visa to link original messages to subsequent messages. Guaranteed by Visa to be unique for each original authorization and financial authorization.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1256
# File 'lib/lithic/models/transaction.rb', line 1256

required :transaction_id, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1101
# File 'sig/lithic/models/transaction.rbs', line 1101

def to_hash: -> {