Class: Lithic::Models::Transaction::Event::RuleResult

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs

Defined Under Namespace

Modules: Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(auth_rule_token:, explanation:, name:, result:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Transaction::Event::RuleResult for more details.

Parameters:

  • auth_rule_token (String, nil) —

    The Auth Rule Token associated with the rule from which the decline originated.

  • explanation (String, nil) —

    A human-readable explanation outlining the motivation for the rule's decline.

  • name (String, nil) —

    The name for the rule, if any was configured.

  • result (Symbol, Lithic::Models::Transaction::Event::RuleResult::Result) —

    The detailed_result associated with this rule's decline.



# File 'lib/lithic/models/transaction.rb', line 1330

Instance Attribute Details

#auth_rule_token ⇒ String?

The Auth Rule Token associated with the rule from which the decline originated. If this is set to null, then the decline was not associated with a customer-configured Auth Rule. This may happen in cases where a transaction is declined due to a Lithic-configured security or compliance rule, for example.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1310
# File 'lib/lithic/models/transaction.rb', line 1310

required :auth_rule_token, String, nil?: true

#explanation ⇒ String?

A human-readable explanation outlining the motivation for the rule's decline.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1316
# File 'lib/lithic/models/transaction.rb', line 1316

required :explanation, String, nil?: true

#name ⇒ String?

The name for the rule, if any was configured.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1322
# File 'lib/lithic/models/transaction.rb', line 1322

required :name, String, nil?: true

#result ⇒ Symbol, Lithic::Models::Transaction::Event::RuleResult::Result

The detailed_result associated with this rule's decline.

Parameters:

  • value (Lithic::Models::Transaction::Event::RuleResult::result)

Returns:



1328
# File 'lib/lithic/models/transaction.rb', line 1328

required :result, enum: -> { Lithic::Transaction::Event::RuleResult::Result }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1191
# File 'sig/lithic/models/transaction.rbs', line 1191

def to_hash: -> {