Class: Lithic::Models::Transaction::Pos::Terminal

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Operator, PinCapability, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(attended:, card_retention_capable:, on_premise:, operator:, partial_approval_capable:, pin_capability:, type:, acceptor_terminal_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::Transaction::Pos::Terminal for more details.

Parameters:

  • attended (Boolean)

    True if a clerk is present at the sale.

  • card_retention_capable (Boolean)

    True if the terminal is capable of retaining the card.

  • on_premise (Boolean)

    True if the sale was made at the place of business (vs. mobile).

  • operator (Symbol, Lithic::Models::Transaction::Pos::Terminal::Operator)

    The person that is designated to swipe the card

  • partial_approval_capable (Boolean)

    True if the terminal is capable of partial approval. Partial approval is when pa

  • pin_capability (Symbol, Lithic::Models::Transaction::Pos::Terminal::PinCapability)

    Status of whether the POS is able to accept PINs

  • type (Symbol, Lithic::Models::Transaction::Pos::Terminal::Type)

    POS Type

  • acceptor_terminal_id (String, nil) (defaults to: nil)

    Uniquely identifies a terminal at the card acceptor location of acquiring instit



# File 'lib/lithic/models/transaction.rb', line 616

Instance Attribute Details

#acceptor_terminal_idString?

Uniquely identifies a terminal at the card acceptor location of acquiring institutions or merchant POS Systems

Returns:

  • (String, nil)


614
# File 'lib/lithic/models/transaction.rb', line 614

optional :acceptor_terminal_id, String, nil?: true

#attendedBoolean

True if a clerk is present at the sale.

Returns:

  • (Boolean)


567
# File 'lib/lithic/models/transaction.rb', line 567

required :attended, Lithic::Internal::Type::Boolean

#card_retention_capableBoolean

True if the terminal is capable of retaining the card.

Returns:

  • (Boolean)


573
# File 'lib/lithic/models/transaction.rb', line 573

required :card_retention_capable, Lithic::Internal::Type::Boolean

#on_premiseBoolean

True if the sale was made at the place of business (vs. mobile).

Returns:

  • (Boolean)


579
# File 'lib/lithic/models/transaction.rb', line 579

required :on_premise, Lithic::Internal::Type::Boolean

#operatorSymbol, Lithic::Models::Transaction::Pos::Terminal::Operator

The person that is designated to swipe the card



585
# File 'lib/lithic/models/transaction.rb', line 585

required :operator, enum: -> { Lithic::Transaction::Pos::Terminal::Operator }

#partial_approval_capableBoolean

True if the terminal is capable of partial approval. Partial approval is when part of a transaction is approved and another payment must be used for the remainder. Example scenario: A $40 transaction is attempted on a prepaid card with a $25 balance. If partial approval is enabled, $25 can be authorized, at which point the POS will prompt the user for an additional payment of $15.

Returns:

  • (Boolean)


595
# File 'lib/lithic/models/transaction.rb', line 595

required :partial_approval_capable, Lithic::Internal::Type::Boolean

#pin_capabilitySymbol, Lithic::Models::Transaction::Pos::Terminal::PinCapability

Status of whether the POS is able to accept PINs



601
# File 'lib/lithic/models/transaction.rb', line 601

required :pin_capability, enum: -> { Lithic::Transaction::Pos::Terminal::PinCapability }

#typeSymbol, Lithic::Models::Transaction::Pos::Terminal::Type

POS Type



607
# File 'lib/lithic/models/transaction.rb', line 607

required :type, enum: -> { Lithic::Transaction::Pos::Terminal::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/transaction.rb', line 647