Class: Lithic::Models::TransactionMonitoring::CaseActivityEntry

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction_monitoring/case_activity_entry.rb,
sig/lithic/models/transaction_monitoring/case_activity_entry.rbs

Overview

See Also:

  • Lithic::Resources::TransactionMonitoring::Cases#list_activity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, actor_token:, created:, entry_type:, new_value:, previous_value:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::CaseActivityEntry for more details.

A single entry in a case's activity feed

Parameters:

  • token (String)

    Globally unique identifier for the activity entry

  • actor_token (String, nil)

    Identifier of the actor that produced the activity entry

  • created (Time)

    Date and time at which the activity entry was created

  • entry_type (Symbol, Lithic::Models::TransactionMonitoring::CaseActivityType)

    The case field that changed, or the action that was taken, in an activity entry:

  • new_value (String, nil)

    New value of the changed field, when applicable

  • previous_value (String, nil)

    Previous value of the changed field, when applicable



# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 54

Instance Attribute Details

#actor_tokenString?

Identifier of the actor that produced the activity entry

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


18
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 18

required :actor_token, String, nil?: true

#createdTime

Date and time at which the activity entry was created

Parameters:

  • value (Time)

Returns:

  • (Time)


24
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 24

required :created, Time

#entry_typeSymbol, Lithic::Models::TransactionMonitoring::CaseActivityType

The case field that changed, or the action that was taken, in an activity entry:

  • STATUS - The case status changed
  • TITLE - The case title changed
  • ASSIGNED_TO - The case assignee changed
  • RESOLUTION_OUTCOME - The resolution outcome was set or changed
  • RESOLUTION_NOTES - The resolution notes were set or changed
  • TAGS - The case tags changed
  • PRIORITY - The case priority changed
  • COMMENT - A comment was added or edited
  • FILE - A file was attached to the case

Parameters:

  • value (Lithic::Models::TransactionMonitoring::case_activity_type)

Returns:



40
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 40

required :entry_type, enum: -> { Lithic::TransactionMonitoring::CaseActivityType }

#new_valueString?

New value of the changed field, when applicable

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


46
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 46

required :new_value, String, nil?: true

#previous_valueString?

Previous value of the changed field, when applicable

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


52
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 52

required :previous_value, String, nil?: true

#tokenString

Globally unique identifier for the activity entry

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 12

required :token, String

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/lithic/models/transaction_monitoring/case_activity_entry.rbs', line 36

def to_hash: -> {