Class: Lithic::Models::TransactionMonitoring::CaseCard
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::CaseCard
- Defined in:
- lib/lithic/models/transaction_monitoring/case_card.rb
Instance Attribute Summary collapse
-
#account_token ⇒ String
Token of the account the card belongs to.
-
#card_token ⇒ String
Token of the card.
-
#transaction_count ⇒ Integer
Number of the card’s transactions associated with the case.
Instance Method Summary collapse
-
#initialize(account_token:, card_token:, transaction_count:) ⇒ Object
constructor
Summary of a card’s involvement in a case, aggregated across the case’s transactions.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_token:, card_token:, transaction_count:) ⇒ Object
Summary of a card’s involvement in a case, aggregated across the case’s transactions
|
|
# File 'lib/lithic/models/transaction_monitoring/case_card.rb', line 25
|
Instance Attribute Details
#account_token ⇒ String
Token of the account the card belongs to
11 |
# File 'lib/lithic/models/transaction_monitoring/case_card.rb', line 11 required :account_token, String |
#card_token ⇒ String
Token of the card
17 |
# File 'lib/lithic/models/transaction_monitoring/case_card.rb', line 17 required :card_token, String |
#transaction_count ⇒ Integer
Number of the card’s transactions associated with the case
23 |
# File 'lib/lithic/models/transaction_monitoring/case_card.rb', line 23 required :transaction_count, Integer |