Class: Lithic::Models::TransactionMonitoring::CaseEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::CaseEntity
- Defined in:
- lib/lithic/models/transaction_monitoring/case_entity.rb
Defined Under Namespace
Modules: EntityType
Instance Attribute Summary collapse
-
#entity_token ⇒ String
Globally unique identifier for the associated entity.
-
#entity_type ⇒ Symbol, Lithic::Models::TransactionMonitoring::CaseEntity::EntityType
The type of entity a case is associated with:.
Instance Method Summary collapse
-
#initialize(entity_token:, entity_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CaseEntity for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(entity_token:, entity_type:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::CaseEntity for more details.
The entity a case is associated with
|
|
# File 'lib/lithic/models/transaction_monitoring/case_entity.rb', line 22
|
Instance Attribute Details
#entity_token ⇒ String
Globally unique identifier for the associated entity
11 |
# File 'lib/lithic/models/transaction_monitoring/case_entity.rb', line 11 required :entity_token, String |
#entity_type ⇒ Symbol, Lithic::Models::TransactionMonitoring::CaseEntity::EntityType
The type of entity a case is associated with:
-
‘CARD` - The case is associated with a card
-
‘ACCOUNT` - The case is associated with an account
20 |
# File 'lib/lithic/models/transaction_monitoring/case_entity.rb', line 20 required :entity_type, enum: -> { Lithic::TransactionMonitoring::CaseEntity::EntityType } |