Class: Lithic::Models::TransactionMonitoring::CaseListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/transaction_monitoring/case_list_params.rb,
sig/lithic/models/transaction_monitoring/case_list_params.rbs

Overview

See Also:

  • Lithic::Resources::TransactionMonitoring::Cases#list

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_token: nil, assignee: nil, begin_: nil, card_token: nil, end_: nil, ending_before: nil, entity_token: nil, page_size: nil, queue_token: nil, rule_token: nil, sort_by: nil, starting_after: nil, status: nil, transaction_token: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::CaseListParams for more details.

Parameters:

  • account_token (String) (defaults to: nil) —

    Only return cases that include transactions on the provided account.

  • assignee (String) (defaults to: nil) —

    Only return cases assigned to the provided value. Pass an empty string to return

  • begin_ (Time) (defaults to: nil) —

    Date string in RFC 3339 format. Only entries created after the specified time wi

  • card_token (String) (defaults to: nil) —

    Only return cases that include transactions on the provided card.

  • end_ (Time) (defaults to: nil) —

    Date string in RFC 3339 format. Only entries created before the specified time w

  • ending_before (String) (defaults to: nil) —

    A cursor representing an item's token before which a page of results should end.

  • entity_token (String) (defaults to: nil) —

    Only return cases associated with the provided entity. Accepts a card, account,

  • page_size (Integer) (defaults to: nil) —

    Page size (for pagination).

  • queue_token (String) (defaults to: nil) —

    Only return cases belonging to the provided queue.

  • rule_token (String) (defaults to: nil) —

    Only return cases triggered by the provided transaction monitoring rule.

  • sort_by (Symbol, Lithic::Models::TransactionMonitoring::CaseSortOrder) (defaults to: nil) —

    Sort order for the returned cases.

  • starting_after (String) (defaults to: nil) —

    A cursor representing an item's token after which a page of results should begin

  • status (Symbol, Lithic::Models::TransactionMonitoring::CaseStatus) (defaults to: nil) —

    Only return cases with the provided status.

  • transaction_token (String) (defaults to: nil) —

    Only return cases that include the provided transaction.

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 102

Instance Attribute Details

#account_token ⇒ String?

Only return cases that include transactions on the provided account.

Parameters:

  • (String)

Returns:

  • (String, nil)


15
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 15

optional :account_token, String

#assignee ⇒ String?

Only return cases assigned to the provided value. Pass an empty string to return only unassigned cases.

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 22

optional :assignee, String

#begin_ ⇒ Time?

Date string in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


29
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 29

optional :begin_, Time

#card_token ⇒ String?

Only return cases that include transactions on the provided card.

Parameters:

  • (String)

Returns:

  • (String, nil)


35
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 35

optional :card_token, String

#end_ ⇒ Time?

Date string in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


42
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 42

optional :end_, Time

#ending_before ⇒ String?

A cursor representing an item's token before which a page of results should end. Used to retrieve the previous page of results before this item.

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 49

optional :ending_before, String

#entity_token ⇒ String?

Only return cases associated with the provided entity. Accepts a card, account, or financial account token. Cases with a PROGRAM entity have no entity token and are never returned by this filter.

Parameters:

  • (String)

Returns:

  • (String, nil)


57
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 57

optional :entity_token, String

#page_size ⇒ Integer?

Page size (for pagination).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


63
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 63

optional :page_size, Integer

#queue_token ⇒ String?

Only return cases belonging to the provided queue.

Parameters:

  • (String)

Returns:

  • (String, nil)


69
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 69

optional :queue_token, String

#rule_token ⇒ String?

Only return cases triggered by the provided transaction monitoring rule.

Parameters:

  • (String)

Returns:

  • (String, nil)


75
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 75

optional :rule_token, String

#sort_by ⇒ Symbol, ...

Sort order for the returned cases.



81
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 81

optional :sort_by, enum: -> { Lithic::TransactionMonitoring::CaseSortOrder }

#starting_after ⇒ String?

A cursor representing an item's token after which a page of results should begin. Used to retrieve the next page of results after this item.

Parameters:

  • (String)

Returns:

  • (String, nil)


88
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 88

optional :starting_after, String

#status ⇒ Symbol, ...

Only return cases with the provided status.



94
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 94

optional :status, enum: -> { Lithic::TransactionMonitoring::CaseStatus }

#transaction_token ⇒ String?

Only return cases that include the provided transaction.

Parameters:

  • (String)

Returns:

  • (String, nil)


100
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 100

optional :transaction_token, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


105
# File 'sig/lithic/models/transaction_monitoring/case_list_params.rbs', line 105

def to_hash: -> {