Module: Lithic::Models::TransactionMonitoring::CaseTransaction

Extended by:
Internal::Type::Union
Defined in:
lib/lithic/models/transaction_monitoring/case_transaction.rb,
sig/lithic/models/transaction_monitoring/case_transaction.rbs

Overview

A single transaction associated with a case. The category field identifies whether this is a card transaction or a payment transaction.

See Also:

  • Lithic::Resources::TransactionMonitoring::Cases#list_transactions

Defined Under Namespace

Classes: CardCaseTransaction, PaymentCaseTransaction

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(token:, account_token:, added_at:, card_token:, transaction_created_at:, category: :CARD) ⇒ Object

A card transaction associated with a case

Parameters:

  • token (String)

    Globally unique identifier for the card transaction

  • account_token (String)

    Token of the account the transaction belongs to

  • added_at (Time)

    Date and time at which the transaction was added to the case

  • card_token (String)

    Token of the card the transaction was made on

  • transaction_created_at (Time)

    Date and time at which the transaction was created

  • category (Symbol, :CARD) (defaults to: :CARD)


# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 57

#self?.variants::Array[Lithic::Models::TransactionMonitoring::case_transaction]

Returns:

  • (::Array[Lithic::Models::TransactionMonitoring::case_transaction])


97
# File 'sig/lithic/models/transaction_monitoring/case_transaction.rbs', line 97

def self?.variants: -> ::Array[Lithic::Models::TransactionMonitoring::case_transaction]