Class: Lithic::Models::TransactionMonitoring::CaseTransaction::CardCaseTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::CaseTransaction::CardCaseTransaction
- Defined in:
- lib/lithic/models/transaction_monitoring/case_transaction.rb,
sig/lithic/models/transaction_monitoring/case_transaction.rbs
Instance Attribute Summary collapse
-
#account_token ⇒ String
Token of the account the transaction belongs to.
-
#added_at ⇒ Time
Date and time at which the transaction was added to the case.
-
#card_token ⇒ String
Token of the card the transaction was made on.
- #category ⇒ Symbol, :CARD
-
#token ⇒ String
Globally unique identifier for the card transaction.
-
#transaction_created_at ⇒ Time
Date and time at which the transaction was created.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
34 |
# File 'sig/lithic/models/transaction_monitoring/case_transaction.rbs', line 34
def initialize: (
|
Instance Attribute Details
#account_token ⇒ String
Token of the account the transaction belongs to
32 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 32 required :account_token, String |
#added_at ⇒ Time
Date and time at which the transaction was added to the case
38 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 38 required :added_at, Time |
#card_token ⇒ String
Token of the card the transaction was made on
44 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 44 required :card_token, String |
#category ⇒ Symbol, :CARD
49 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 49 required :category, const: :CARD |
#token ⇒ String
Globally unique identifier for the card transaction
26 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 26 required :token, String |
#transaction_created_at ⇒ Time
Date and time at which the transaction was created
55 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 55 required :transaction_created_at, Time |
Instance Method Details
#to_hash ⇒ {
43 |
# File 'sig/lithic/models/transaction_monitoring/case_transaction.rbs', line 43
def to_hash: -> {
|