Class: Lithic::Models::TransactionMonitoring::CaseTransaction::PaymentCaseTransaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction_monitoring/case_transaction.rb,
sig/lithic/models/transaction_monitoring/case_transaction.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, added_at:, financial_account_token:, transaction_created_at:, account_token: nil, category: :PAYMENT) ⇒ Object

A payment (ACH) transaction associated with a case

Parameters:

  • token (String)

    Globally unique identifier for the payment transaction

  • added_at (Time)

    Date and time at which the transaction was added to the case

  • financial_account_token (String)

    Token of the financial account the payment belongs to

  • transaction_created_at (Time)

    Date and time at which the transaction was created

  • account_token (String) (defaults to: nil)

    Token of the account the payment belongs to, if applicable

  • category (Symbol, :PAYMENT) (defaults to: :PAYMENT)


# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 109

Instance Attribute Details

#account_tokenString?

Token of the account the payment belongs to, if applicable

Parameters:

  • (String)

Returns:

  • (String, nil)


107
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 107

optional :account_token, String

#added_atTime

Date and time at which the transaction was added to the case

Parameters:

  • value (Time)

Returns:

  • (Time)


84
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 84

required :added_at, Time

#categorySymbol, :PAYMENT

Parameters:

  • value (:PAYMENT)

Returns:

  • (Symbol, :PAYMENT)


89
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 89

required :category, const: :PAYMENT

#financial_account_tokenString

Token of the financial account the payment belongs to

Parameters:

  • value (String)

Returns:

  • (String)


95
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 95

required :financial_account_token, String

#tokenString

Globally unique identifier for the payment transaction

Parameters:

  • value (String)

Returns:

  • (String)


78
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 78

required :token, String

#transaction_created_atTime

Date and time at which the transaction was created

Parameters:

  • value (Time)

Returns:

  • (Time)


101
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 101

required :transaction_created_at, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


87
# File 'sig/lithic/models/transaction_monitoring/case_transaction.rbs', line 87

def to_hash: -> {