Class: Lithic::Models::TransactionMonitoring::CaseUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/transaction_monitoring/case_update_params.rb,
sig/lithic/models/transaction_monitoring/case_update_params.rbs

Overview

See Also:

  • Lithic::Resources::TransactionMonitoring::Cases#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(case_token:, actor_token: nil, assignee: nil, priority: nil, resolution: nil, resolution_notes: nil, sla_deadline: nil, status: nil, tags: nil, title: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::CaseUpdateParams for more details.

Parameters:

  • case_token (String)
  • actor_token (String) (defaults to: nil)

    Optional client-provided identifier for the actor performing this action,

  • assignee (String, nil) (defaults to: nil)

    New assignee for the case, or null to unassign

  • priority (Symbol, Lithic::Models::TransactionMonitoring::CasePriority) (defaults to: nil)

    Priority level of a case, controlling queue ordering and SLA urgency

  • resolution (String) (defaults to: nil)

    Resolution to record on the case. Must be one of the

  • resolution_notes (String) (defaults to: nil)

    Notes describing the resolution

  • sla_deadline (Time, nil) (defaults to: nil)

    New SLA deadline for the case, or null to clear it

  • status (Symbol, Lithic::Models::TransactionMonitoring::CaseStatus) (defaults to: nil)

    Status of a case as it progresses through the review workflow:

  • tags (Hash{Symbol=>String}) (defaults to: nil)

    Arbitrary key-value metadata to set on the case

  • title (String, nil) (defaults to: nil)

    New title for the case, or null to clear it

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 82

Instance Attribute Details

#actor_tokenString?

Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. This value is supplied by the client (for example, your own internal user ID) and is not authenticated by Lithic

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 22

optional :actor_token, String

#assigneeString?

New assignee for the case, or null to unassign

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


28
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 28

optional :assignee, String, nil?: true

#case_tokenString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 14

required :case_token, String

#prioritySymbol, ...

Priority level of a case, controlling queue ordering and SLA urgency



34
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 34

optional :priority, enum: -> { Lithic::TransactionMonitoring::CasePriority }

#resolutionString?

Resolution to record on the case. Must be one of the allowed_resolutions configured on the case's queue, otherwise the request is rejected with a 400

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 41

optional :resolution, String

#resolution_notesString?

Notes describing the resolution

Parameters:

  • (String)

Returns:

  • (String, nil)


47
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 47

optional :resolution_notes, String

#sla_deadlineTime?

New SLA deadline for the case, or null to clear it

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


53
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 53

optional :sla_deadline, Time, nil?: true

#statusSymbol, ...

Status of a case as it progresses through the review workflow:

  • OPEN - The case has been created and is still collecting matching transactions
  • ASSIGNED - An analyst has been assigned and transaction collection has stopped
  • IN_REVIEW - The case is actively being investigated
  • ESCALATED - The case has been reviewed and requires additional oversight
  • RESOLVED - A determination has been made and a resolution recorded
  • CLOSED - The case is finalized


68
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 68

optional :status, enum: -> { Lithic::TransactionMonitoring::CaseStatus }

#tagsHash{Symbol=>String}?

Arbitrary key-value metadata to set on the case

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


74
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 74

optional :tags, Lithic::Internal::Type::HashOf[String]

#titleString?

New title for the case, or null to clear it

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


80
# File 'lib/lithic/models/transaction_monitoring/case_update_params.rb', line 80

optional :title, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


73
# File 'sig/lithic/models/transaction_monitoring/case_update_params.rbs', line 73

def to_hash: -> {