Class: Lithic::Models::TransactionMonitoring::Cases::CaseFile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::Cases::CaseFile
- Defined in:
- lib/lithic/models/transaction_monitoring/cases/case_file.rb,
sig/lithic/models/transaction_monitoring/cases/case_file.rbs
Overview
Instance Attribute Summary collapse
-
#created ⇒ Time
Date and time at which the file record was created.
-
#download_url ⇒ String?
Presigned URL the client uses to download the file.
-
#download_url_expires ⇒ Time?
Date and time at which the download URL expires.
-
#failure_reason ⇒ String?
Reason the file was rejected, when applicable.
-
#mime_type ⇒ String?
MIME type of the file, available once the file is ready.
-
#name ⇒ String
Name of the file.
-
#size_bytes ⇒ Integer?
Size of the file in bytes, available once the file is ready.
-
#status ⇒ Symbol, Lithic::Models::TransactionMonitoring::Cases::FileStatus
Lifecycle status of a case file:.
-
#token ⇒ String
Globally unique identifier for the file.
-
#updated ⇒ Time
Date and time at which the file record was last updated.
-
#upload_constraints ⇒ Lithic::Models::TransactionMonitoring::Cases::UploadConstraints?
Constraints applied to a file upload, returned alongside the upload URL so clients can validate before uploading.
-
#upload_url ⇒ String?
Presigned URL the client uses to upload the file.
-
#upload_url_expires ⇒ Time?
Date and time at which the upload URL expires.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
51 |
# File 'sig/lithic/models/transaction_monitoring/cases/case_file.rbs', line 51
def initialize: (
|
Instance Attribute Details
#created ⇒ Time
Date and time at which the file record was created
19 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 19 required :created, Time |
#download_url ⇒ String?
Presigned URL the client uses to download the file
25 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 25 required :download_url, String, nil?: true |
#download_url_expires ⇒ Time?
Date and time at which the download URL expires
31 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 31 required :download_url_expires, Time, nil?: true |
#failure_reason ⇒ String?
Reason the file was rejected, when applicable
37 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 37 required :failure_reason, String, nil?: true |
#mime_type ⇒ String?
MIME type of the file, available once the file is ready
43 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 43 required :mime_type, String, nil?: true |
#name ⇒ String
Name of the file
49 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 49 required :name, String |
#size_bytes ⇒ Integer?
Size of the file in bytes, available once the file is ready
55 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 55 required :size_bytes, Integer, nil?: true |
#status ⇒ Symbol, Lithic::Models::TransactionMonitoring::Cases::FileStatus
Lifecycle status of a case file:
PENDING- An upload URL has been issued and the file is awaiting uploadREADY- The file has been uploaded and validated; a download URL is availableREJECTED- File validation failed; seefailure_reasonfor details
66 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 66 required :status, enum: -> { Lithic::TransactionMonitoring::Cases::FileStatus } |
#token ⇒ String
Globally unique identifier for the file
13 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 13 required :token, String |
#updated ⇒ Time
Date and time at which the file record was last updated
72 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 72 required :updated, Time |
#upload_constraints ⇒ Lithic::Models::TransactionMonitoring::Cases::UploadConstraints?
Constraints applied to a file upload, returned alongside the upload URL so clients can validate before uploading
79 80 81 82 83 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 79 required :upload_constraints, -> { Lithic::TransactionMonitoring::Cases::UploadConstraints }, nil?: true |
#upload_url ⇒ String?
Presigned URL the client uses to upload the file
89 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 89 required :upload_url, String, nil?: true |
#upload_url_expires ⇒ Time?
Date and time at which the upload URL expires
95 |
# File 'lib/lithic/models/transaction_monitoring/cases/case_file.rb', line 95 required :upload_url_expires, Time, nil?: true |
Instance Method Details
#to_hash ⇒ {
67 |
# File 'sig/lithic/models/transaction_monitoring/cases/case_file.rbs', line 67
def to_hash: -> {
|