Class: Lithic::Models::TransactionMonitoring::Cases::CommentUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::Cases::CommentUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/transaction_monitoring/cases/comment_update_params.rb
Overview
Instance Attribute Summary collapse
-
#actor_token ⇒ String?
Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry.
- #case_token ⇒ String
-
#comment ⇒ String
New text of the comment.
- #comment_token ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(case_token:, comment_token:, comment:, actor_token: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CommentUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(case_token:, comment_token:, comment:, actor_token: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::Cases::CommentUpdateParams for more details.
|
|
# File 'lib/lithic/models/transaction_monitoring/cases/comment_update_params.rb', line 36
|
Instance Attribute Details
#actor_token ⇒ String?
Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. This value is supplied by the client (for example, your own internal user ID) and is not authenticated by Lithic
34 |
# File 'lib/lithic/models/transaction_monitoring/cases/comment_update_params.rb', line 34 optional :actor_token, String |
#case_token ⇒ String
15 |
# File 'lib/lithic/models/transaction_monitoring/cases/comment_update_params.rb', line 15 required :case_token, String |
#comment ⇒ String
New text of the comment
26 |
# File 'lib/lithic/models/transaction_monitoring/cases/comment_update_params.rb', line 26 required :comment, String |
#comment_token ⇒ String
20 |
# File 'lib/lithic/models/transaction_monitoring/cases/comment_update_params.rb', line 20 required :comment_token, String |