Class: Lithic::Models::TransactionMonitoring::Cases::UploadConstraints
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::Cases::UploadConstraints
- Defined in:
- lib/lithic/models/transaction_monitoring/cases/upload_constraints.rb
Instance Attribute Summary collapse
-
#accepted_mime_types ⇒ Array<String>
MIME types accepted for the upload.
-
#max_size_bytes ⇒ Integer
Maximum accepted file size, in bytes.
Instance Method Summary collapse
-
#initialize(accepted_mime_types:, max_size_bytes:) ⇒ Object
constructor
Constraints applied to a file upload, returned alongside the upload URL so clients can validate before uploading.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(accepted_mime_types:, max_size_bytes:) ⇒ Object
Constraints applied to a file upload, returned alongside the upload URL so clients can validate before uploading
|
|
# File 'lib/lithic/models/transaction_monitoring/cases/upload_constraints.rb', line 20
|
Instance Attribute Details
#accepted_mime_types ⇒ Array<String>
MIME types accepted for the upload
12 |
# File 'lib/lithic/models/transaction_monitoring/cases/upload_constraints.rb', line 12 required :accepted_mime_types, Lithic::Internal::Type::ArrayOf[String] |
#max_size_bytes ⇒ Integer
Maximum accepted file size, in bytes
18 |
# File 'lib/lithic/models/transaction_monitoring/cases/upload_constraints.rb', line 18 required :max_size_bytes, Integer |