Class: Lithic::Models::TransactionMonitoring::MonitoringCase

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction_monitoring/monitoring_case.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, assignee:, collection_stopped:, created:, entity:, pending_transactions:, priority:, queue_token:, resolution:, resolution_notes:, resolved:, rule_token:, sla_deadline:, status:, tags:, title:, updated:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::MonitoringCase for more details.

A transaction monitoring case

Parameters:

  • token (String)

    Globally unique identifier for the case

  • assignee (String, nil)

    Identifier of the user the case is currently assigned to

  • collection_stopped (Time, nil)

    Date and time at which transaction collection stopped for the case

  • created (Time)

    Date and time at which the case was created

  • entity (Lithic::Models::TransactionMonitoring::CaseEntity, nil)

    The entity a case is associated with

  • pending_transactions (Boolean)

    Whether the case still has transaction scopes pending resolution

  • priority (Symbol, Lithic::Models::TransactionMonitoring::CasePriority)

    Priority level of a case, controlling queue ordering and SLA urgency

  • queue_token (String)

    Token of the queue the case belongs to

  • resolution (Symbol, Lithic::Models::TransactionMonitoring::ResolutionOutcome, nil)

    Outcome recorded when a case is resolved:

  • resolution_notes (String, nil)

    Free-form notes describing the resolution

  • resolved (Time, nil)

    Date and time at which the case was resolved

  • rule_token (String, nil)

    Token of the transaction monitoring rule that triggered the case

  • sla_deadline (Time, nil)

    Deadline by which the case is expected to be resolved

  • status (Symbol, Lithic::Models::TransactionMonitoring::CaseStatus)

    Status of a case as it progresses through the review workflow:

  • tags (Hash{Symbol=>String})

    Arbitrary key-value metadata associated with the case

  • title (String, nil)

    Short, human-readable summary of the case

  • updated (Time)

    Date and time at which the case was last updated



# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 126

Instance Attribute Details

#assigneeString?

Identifier of the user the case is currently assigned to

Returns:

  • (String, nil)


18
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 18

required :assignee, String, nil?: true

#collection_stoppedTime?

Date and time at which transaction collection stopped for the case

Returns:

  • (Time, nil)


24
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 24

required :collection_stopped, Time, nil?: true

#createdTime

Date and time at which the case was created

Returns:

  • (Time)


30
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 30

required :created, Time

#entityLithic::Models::TransactionMonitoring::CaseEntity?

The entity a case is associated with



36
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 36

required :entity, -> { Lithic::TransactionMonitoring::CaseEntity }, nil?: true

#pending_transactionsBoolean

Whether the case still has transaction scopes pending resolution

Returns:

  • (Boolean)


42
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 42

required :pending_transactions, Lithic::Internal::Type::Boolean

#prioritySymbol, Lithic::Models::TransactionMonitoring::CasePriority

Priority level of a case, controlling queue ordering and SLA urgency



48
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 48

required :priority, enum: -> { Lithic::TransactionMonitoring::CasePriority }

#queue_tokenString

Token of the queue the case belongs to

Returns:

  • (String)


54
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 54

required :queue_token, String

#resolutionSymbol, ...

Outcome recorded when a case is resolved:

  • ‘CONFIRMED_FRAUD` - The reviewed activity was confirmed to be fraudulent

  • ‘SUSPICIOUS_ACTIVITY` - The activity is suspicious but not confirmed fraud

  • ‘FALSE_POSITIVE` - The activity was legitimate and the alert was a false positive

  • ‘NO_ACTION_REQUIRED` - No further action is required

  • ‘ESCALATED_EXTERNAL` - The case was escalated to an external party



67
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 67

required :resolution, enum: -> { Lithic::TransactionMonitoring::ResolutionOutcome }, nil?: true

#resolution_notesString?

Free-form notes describing the resolution

Returns:

  • (String, nil)


73
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 73

required :resolution_notes, String, nil?: true

#resolvedTime?

Date and time at which the case was resolved

Returns:

  • (Time, nil)


79
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 79

required :resolved, Time, nil?: true

#rule_tokenString?

Token of the transaction monitoring rule that triggered the case

Returns:

  • (String, nil)


85
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 85

required :rule_token, String, nil?: true

#sla_deadlineTime?

Deadline by which the case is expected to be resolved

Returns:

  • (Time, nil)


91
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 91

required :sla_deadline, Time, nil?: true

#statusSymbol, Lithic::Models::TransactionMonitoring::CaseStatus

Status of a case as it progresses through the review workflow:

  • ‘OPEN` - The case has been created and is still collecting matching transactions

  • ‘ASSIGNED` - An analyst has been assigned and transaction collection has stopped

  • ‘IN_REVIEW` - The case is actively being investigated

  • ‘ESCALATED` - The case has been reviewed and requires additional oversight

  • ‘RESOLVED` - A determination has been made and a resolution recorded

  • ‘CLOSED` - The case is finalized



106
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 106

required :status, enum: -> { Lithic::TransactionMonitoring::CaseStatus }

#tagsHash{Symbol=>String}

Arbitrary key-value metadata associated with the case

Returns:

  • (Hash{Symbol=>String})


112
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 112

required :tags, Lithic::Internal::Type::HashOf[String]

#titleString?

Short, human-readable summary of the case

Returns:

  • (String, nil)


118
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 118

required :title, String, nil?: true

#tokenString

Globally unique identifier for the case

Returns:

  • (String)


12
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 12

required :token, String

#updatedTime

Date and time at which the case was last updated

Returns:

  • (Time)


124
# File 'lib/lithic/models/transaction_monitoring/monitoring_case.rb', line 124

required :updated, Time