Class: Lithic::Models::TransactionMonitoring::Queue

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction_monitoring/queue.rb

Overview

Defined Under Namespace

Classes: CaseCounts

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, case_counts:, created:, description:, name:, updated:) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::Queue for more details.

A queue that groups transaction monitoring cases for review

Parameters:

  • token (String)

    Globally unique identifier for the queue

  • case_counts (Lithic::Models::TransactionMonitoring::Queue::CaseCounts)

    Number of cases in the queue, broken down by status. A status is omitted

  • created (Time)

    Date and time at which the queue was created

  • description (String, nil)

    Optional description of the queue

  • name (String)

    Human-readable name of the queue

  • updated (Time)

    Date and time at which the queue was last updated



# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 45

Instance Attribute Details

#case_countsLithic::Models::TransactionMonitoring::Queue::CaseCounts

Number of cases in the queue, broken down by status. A status is omitted when the queue has no cases in that status



19
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 19

required :case_counts, -> { Lithic::TransactionMonitoring::Queue::CaseCounts }

#createdTime

Date and time at which the queue was created

Returns:

  • (Time)


25
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 25

required :created, Time

#descriptionString?

Optional description of the queue

Returns:

  • (String, nil)


31
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 31

required :description, String, nil?: true

#nameString

Human-readable name of the queue

Returns:

  • (String)


37
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 37

required :name, String

#tokenString

Globally unique identifier for the queue

Returns:

  • (String)


12
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 12

required :token, String

#updatedTime

Date and time at which the queue was last updated

Returns:

  • (Time)


43
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 43

required :updated, Time