Class: Lithic::Models::TransactionMonitoring::QueueCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::QueueCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/transaction_monitoring/queue_create_params.rb,
sig/lithic/models/transaction_monitoring/queue_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#allowed_resolutions ⇒ Array<String>?
Resolutions that can be recorded on cases in this queue.
-
#description ⇒ String?
Optional description of the queue.
-
#name ⇒ String
Human-readable name of the queue.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(name:, allowed_resolutions: nil, description: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see QueueCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, allowed_resolutions: nil, description: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::QueueCreateParams for more details.
|
|
# File 'lib/lithic/models/transaction_monitoring/queue_create_params.rb', line 31
|
Instance Attribute Details
#allowed_resolutions ⇒ Array<String>?
Resolutions that can be recorded on cases in this queue. Omit or send null to
use the default list. Values are free-form labels and must be non-empty and
unique
23 |
# File 'lib/lithic/models/transaction_monitoring/queue_create_params.rb', line 23 optional :allowed_resolutions, Lithic::Internal::Type::ArrayOf[String], nil?: true |
#description ⇒ String?
Optional description of the queue
29 |
# File 'lib/lithic/models/transaction_monitoring/queue_create_params.rb', line 29 optional :description, String, nil?: true |
#name ⇒ String
Human-readable name of the queue
15 |
# File 'lib/lithic/models/transaction_monitoring/queue_create_params.rb', line 15 required :name, String |
Instance Method Details
#to_hash ⇒ {
29 |
# File 'sig/lithic/models/transaction_monitoring/queue_create_params.rbs', line 29
def to_hash: -> {
|