Module: Lithic::Models::TransactionSimulateAuthorizationParams::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/transaction_simulate_authorization_params.rb,
sig/lithic/models/transaction_simulate_authorization_params.rbs

Overview

Type of event to simulate.

  • AUTHORIZATION is a dual message purchase authorization, meaning a subsequent clearing step is required to settle the transaction.
  • BALANCE_INQUIRY is a $0 authorization requesting the balance held on the card, and is most often observed when a cardholder requests to view a card's balance at an ATM.
  • CREDIT_AUTHORIZATION is a dual message request from a merchant to authorize a refund, meaning a subsequent clearing step is required to settle the transaction.
  • FINANCIAL_AUTHORIZATION is a single message request from a merchant to debit funds immediately (such as an ATM withdrawal), and no subsequent clearing is required to settle the transaction.
  • FINANCIAL_CREDIT_AUTHORIZATION is a single message request from a merchant to credit funds immediately, and no subsequent clearing is required to settle the transaction.

Constant Summary collapse

AUTHORIZATION =

Returns:

  • (:AUTHORIZATION)
:AUTHORIZATION
BALANCE_INQUIRY =

Returns:

  • (:BALANCE_INQUIRY)
:BALANCE_INQUIRY
CREDIT_AUTHORIZATION =

Returns:

  • (:CREDIT_AUTHORIZATION)
:CREDIT_AUTHORIZATION
FINANCIAL_AUTHORIZATION =

Returns:

  • (:FINANCIAL_AUTHORIZATION)
:FINANCIAL_AUTHORIZATION
FINANCIAL_CREDIT_AUTHORIZATION =

Returns:

  • (:FINANCIAL_CREDIT_AUTHORIZATION)
:FINANCIAL_CREDIT_AUTHORIZATION

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/transaction_simulate_authorization_params.rb', line 170

Instance Method Details

#self?.values::Array[Lithic::Models::TransactionSimulateAuthorizationParams::status]

Returns:

  • (::Array[Lithic::Models::TransactionSimulateAuthorizationParams::status])


123
# File 'sig/lithic/models/transaction_simulate_authorization_params.rbs', line 123

def self?.values: -> ::Array[Lithic::Models::TransactionSimulateAuthorizationParams::status]