Class: Lithic::Resources::FinancialAccounts::LoanTapeConfiguration
- Inherits:
-
Object
- Object
- Lithic::Resources::FinancialAccounts::LoanTapeConfiguration
- Defined in:
- lib/lithic/resources/financial_accounts/loan_tape_configuration.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ LoanTapeConfiguration
constructor
private
A new instance of LoanTapeConfiguration.
-
#retrieve(financial_account_token, request_options: {}) ⇒ Lithic::Models::FinancialAccounts::FinancialAccountsLoanTapeConfiguration
Get the loan tape configuration for a given financial account.
Constructor Details
#initialize(client:) ⇒ LoanTapeConfiguration
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of LoanTapeConfiguration.
30 31 32 |
# File 'lib/lithic/resources/financial_accounts/loan_tape_configuration.rb', line 30 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(financial_account_token, request_options: {}) ⇒ Lithic::Models::FinancialAccounts::FinancialAccountsLoanTapeConfiguration
Get the loan tape configuration for a given financial account.
18 19 20 21 22 23 24 25 |
# File 'lib/lithic/resources/financial_accounts/loan_tape_configuration.rb', line 18 def retrieve(financial_account_token, params = {}) @client.request( method: :get, path: ["v1/financial_accounts/%1$s/loan_tape_configuration", financial_account_token], model: Lithic::FinancialAccounts::FinancialAccountsLoanTapeConfiguration, options: params[:request_options] ) end |