Class: Lithic::Models::Account
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Account
- Defined in:
- lib/lithic/models/account.rb,
sig/lithic/models/account.rbs
Overview
Defined Under Namespace
Modules: State, Substatus Classes: AccountHolder, SpendLimit, VerificationAddress
Instance Attribute Summary collapse
- #account_holder ⇒ Lithic::Models::Account::AccountHolder?
- #auth_rule_tokens ⇒ Array<String>? deprecated Deprecated.
-
#cardholder_currency ⇒ String?
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
#comment ⇒ String?
Additional context or information related to the account.
-
#created ⇒ Time?
Timestamp of when the account was created.
-
#spend_limit ⇒ Lithic::Models::Account::SpendLimit
Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account.
-
#state ⇒ Symbol, Lithic::Models::Account::State
Account state:.
-
#substatus ⇒ Symbol, ...
Account state substatus values:.
-
#token ⇒ String
Globally unique identifier for the account.
- #verification_address ⇒ Lithic::Models::Account::VerificationAddress? deprecated Deprecated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, business_account_token:, email:, phone_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountHolder for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, business_account_token:, email:, phone_number:) ⇒ Object
Some parameter documentations has been truncated, see AccountHolder for more details.
|
|
# File 'lib/lithic/models/account.rb', line 113
|
Instance Attribute Details
#account_holder ⇒ Lithic::Models::Account::AccountHolder?
50 |
# File 'lib/lithic/models/account.rb', line 50 optional :account_holder, -> { Lithic::Account::AccountHolder } |
#auth_rule_tokens ⇒ Array<String>?
List of identifiers for the Auth Rule(s) that are applied on the account. This
field is deprecated and will no longer be populated in the account_holder
object. The key will be removed from the schema in a future release. Use the
/auth_rules endpoints to fetch Auth Rule information instead.
61 |
# File 'lib/lithic/models/account.rb', line 61 optional :auth_rule_tokens, Lithic::Internal::Type::ArrayOf[String] |
#cardholder_currency ⇒ String?
3-character alphabetic ISO 4217 code for the currency of the cardholder.
67 |
# File 'lib/lithic/models/account.rb', line 67 optional :cardholder_currency, String |
#comment ⇒ String?
Additional context or information related to the account.
73 |
# File 'lib/lithic/models/account.rb', line 73 optional :comment, String |
#created ⇒ Time?
Timestamp of when the account was created.
19 |
# File 'lib/lithic/models/account.rb', line 19 required :created, Time, nil?: true |
#spend_limit ⇒ Lithic::Models::Account::SpendLimit
Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.
29 |
# File 'lib/lithic/models/account.rb', line 29 required :spend_limit, -> { Lithic::Account::SpendLimit } |
#state ⇒ Symbol, Lithic::Models::Account::State
Account state:
ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are unable to be transitioned toACTIVEorPAUSEDstates. Accounts can be manually set toCLOSED, or this can be done by Lithic due to failure to pass KYB/KYC or for risk/compliance reasons. Please contact support.lithic.com if you believe this was done by mistake.
45 |
# File 'lib/lithic/models/account.rb', line 45 required :state, enum: -> { Lithic::Account::State } |
#substatus ⇒ Symbol, ...
Account state substatus values:
FRAUD_IDENTIFIED- The account has been recognized as being created or used with stolen or fabricated identity information, encompassing both true identity theft and synthetic identities.SUSPICIOUS_ACTIVITY- The account has exhibited suspicious behavior, such as unauthorized access or fraudulent transactions, necessitating further investigation.RISK_VIOLATION- The account has been involved in deliberate misuse by the legitimate account holder. Examples include disputing valid transactions without cause, falsely claiming non-receipt of goods, or engaging in intentional bust-out schemes to exploit account services.END_USER_REQUEST- The account holder has voluntarily requested the closure of the account for personal reasons. This encompasses situations such as bankruptcy, other financial considerations, or the account holder's death.ISSUER_REQUEST- The issuer has initiated the closure of the account due to business strategy, risk management, inactivity, product changes, regulatory concerns, or violations of terms and conditions.NOT_ACTIVE- The account has not had any transactions or payment activity within a specified period. This status applies to accounts that are paused or closed due to inactivity.INTERNAL_REVIEW- The account is temporarily paused pending further internal review. In future implementations, this status may prevent clients from activating the account via APIs until the review is completed.OTHER- The reason for the account's current status does not fall into any of the above categories. A comment should be provided to specify the particular reason.
105 |
# File 'lib/lithic/models/account.rb', line 105 optional :substatus, enum: -> { Lithic::Account::Substatus }, nil?: true |
#token ⇒ String
Globally unique identifier for the account. This is the same as the account_token returned by the enroll endpoint. If using this parameter, do not include pagination.
13 |
# File 'lib/lithic/models/account.rb', line 13 required :token, String |
#verification_address ⇒ Lithic::Models::Account::VerificationAddress?
111 |
# File 'lib/lithic/models/account.rb', line 111 optional :verification_address, -> { Lithic::Account::VerificationAddress } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/account.rb', line 191
|
Instance Method Details
#to_hash ⇒ {
65 |
# File 'sig/lithic/models/account.rbs', line 65
def to_hash: -> {
|