Module: Lithic::Models::Account::State
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/account.rb,
sig/lithic/models/account.rbs
Overview
Account state:
ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are unable to be transitioned toACTIVEorPAUSEDstates. Accounts can be manually set toCLOSED, or this can be done by Lithic due to failure to pass KYB/KYC or for risk/compliance reasons. Please contact support.lithic.com if you believe this was done by mistake.
Constant Summary collapse
- ACTIVE =
:ACTIVE- PAUSED =
:PAUSED- CLOSED =
:CLOSED
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::Account::state]
105 |
# File 'sig/lithic/models/account.rbs', line 105
def self?.values: -> ::Array[Lithic::Models::Account::state]
|