Class: Lithic::Models::AccountHolder::BeneficialOwnerIndividual
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolder::BeneficialOwnerIndividual
- Defined in:
- lib/lithic/models/account_holder.rb
Instance Attribute Summary collapse
-
#address ⇒ Lithic::Models::Address
Individual’s current address.
-
#dob ⇒ String
Individual’s date of birth, as an RFC 3339 date.
-
#email ⇒ String
Individual’s email address.
-
#entity_token ⇒ String
Globally unique identifier for the entity.
-
#first_name ⇒ String
Individual’s first name, as it appears on government-issued identity documents.
-
#last_name ⇒ String
Individual’s last name, as it appears on government-issued identity documents.
-
#phone_number ⇒ String
Individual’s phone number, entered in E.164 format.
Instance Method Summary collapse
-
#initialize(token:, created:, account_token: nil, beneficial_owner_individuals: nil, business_account_token: nil, business_entity: nil, control_person: nil, email: nil, exemption_type: nil, external_id: nil, individual: nil, naics_code: nil, nature_of_business: nil, phone_number: nil, required_documents: nil, status: nil, status_reasons: nil, user_type: nil, verification_application: nil, website_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Lithic::Models::AccountHolder for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, created:, account_token: nil, beneficial_owner_individuals: nil, business_account_token: nil, business_entity: nil, control_person: nil, email: nil, exemption_type: nil, external_id: nil, individual: nil, naics_code: nil, nature_of_business: nil, phone_number: nil, required_documents: nil, status: nil, status_reasons: nil, user_type: nil, verification_application: nil, website_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AccountHolder for more details.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/lithic/models/account_holder.rb', line 206 class BeneficialOwnerIndividual < Lithic::Internal::Type::BaseModel # @!attribute address # Individual's current address # # @return [Lithic::Models::Address] required :address, -> { Lithic::Address } # @!attribute dob # Individual's date of birth, as an RFC 3339 date. # # @return [String] required :dob, String # @!attribute email # Individual's email address. # # @return [String] required :email, String # @!attribute entity_token # Globally unique identifier for the entity. # # @return [String] required :entity_token, String # @!attribute first_name # Individual's first name, as it appears on government-issued identity documents. # # @return [String] required :first_name, String # @!attribute last_name # Individual's last name, as it appears on government-issued identity documents. # # @return [String] required :last_name, String # @!attribute phone_number # Individual's phone number, entered in E.164 format. # # @return [String] required :phone_number, String # @!method initialize(address:, dob:, email:, entity_token:, first_name:, last_name:, phone_number:) # Information about an individual associated with an account holder. A subset of # the information provided via KYC. For example, we do not return the government # id. # # @param address [Lithic::Models::Address] Individual's current address # # @param dob [String] Individual's date of birth, as an RFC 3339 date. # # @param email [String] Individual's email address. # # @param entity_token [String] Globally unique identifier for the entity. # # @param first_name [String] Individual's first name, as it appears on government-issued identity documents. # # @param last_name [String] Individual's last name, as it appears on government-issued identity documents. # # @param phone_number [String] Individual's phone number, entered in E.164 format. end |
Instance Attribute Details
#address ⇒ Lithic::Models::Address
Individual’s current address
211 |
# File 'lib/lithic/models/account_holder.rb', line 211 required :address, -> { Lithic::Address } |
#dob ⇒ String
Individual’s date of birth, as an RFC 3339 date.
217 |
# File 'lib/lithic/models/account_holder.rb', line 217 required :dob, String |
#email ⇒ String
Individual’s email address.
223 |
# File 'lib/lithic/models/account_holder.rb', line 223 required :email, String |
#entity_token ⇒ String
Globally unique identifier for the entity.
229 |
# File 'lib/lithic/models/account_holder.rb', line 229 required :entity_token, String |
#first_name ⇒ String
Individual’s first name, as it appears on government-issued identity documents.
235 |
# File 'lib/lithic/models/account_holder.rb', line 235 required :first_name, String |
#last_name ⇒ String
Individual’s last name, as it appears on government-issued identity documents.
241 |
# File 'lib/lithic/models/account_holder.rb', line 241 required :last_name, String |
#phone_number ⇒ String
Individual’s phone number, entered in E.164 format.
247 |
# File 'lib/lithic/models/account_holder.rb', line 247 required :phone_number, String |