Class: Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest
- Defined in:
- lib/lithic/models/account_holder_update_params.rb
Defined Under Namespace
Classes: BeneficialOwnerIndividual, BusinessEntity, ControlPerson
Instance Attribute Summary collapse
-
#beneficial_owner_individuals ⇒ Array<Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::BeneficialOwnerIndividual>?
You must submit a list of all direct and indirect individuals with 25% or more ownership in the company.
-
#business_entity ⇒ Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::BusinessEntity?
Information for business for which the account is being opened and KYB is being run.
-
#control_person ⇒ Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::ControlPerson?
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer).
-
#external_id ⇒ String?
A user provided id that can be used to link an account holder with an external system.
-
#naics_code ⇒ String?
6-digit North American Industry Classification System (NAICS) code for the business.
-
#nature_of_business ⇒ String?
Short description of the company’s line of business (i.e., what does the company do?).
-
#website_url ⇒ String?
Company website URL.
Instance Method Summary collapse
-
#initialize(entity_token:, address: nil, dba_business_name: nil, government_id: nil, legal_business_name: nil, parent_company: nil, phone_numbers: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BusinessEntity for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(entity_token:, address: nil, dba_business_name: nil, government_id: nil, legal_business_name: nil, parent_company: nil, phone_numbers: nil) ⇒ Object
Some parameter documentations has been truncated, see BusinessEntity for more details.
Information for business for which the account is being opened and KYB is being run.
|
|
# File 'lib/lithic/models/account_holder_update_params.rb', line 179
|
Instance Attribute Details
#beneficial_owner_individuals ⇒ Array<Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::BeneficialOwnerIndividual>?
You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See [FinCEN requirements](www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf) (Section I) for more background on individuals that should be included.
51 52 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 51 optional :beneficial_owner_individuals, -> { Lithic::Internal::Type::ArrayOf[Lithic::AccountHolderUpdateParams::Body::KYBPatchRequest::BeneficialOwnerIndividual] } |
#business_entity ⇒ Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::BusinessEntity?
Information for business for which the account is being opened and KYB is being run.
59 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 59 optional :business_entity, -> { Lithic::AccountHolderUpdateParams::Body::KYBPatchRequest::BusinessEntity } |
#control_person ⇒ Lithic::Models::AccountHolderUpdateParams::Body::KYBPatchRequest::ControlPerson?
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See [FinCEN requirements](www.fincen.gov/sites/default/files/shared/CDD_Rev6.7_Sept_2017_Certificate.pdf) (Section II) for more background.
72 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 72 optional :control_person, -> { Lithic::AccountHolderUpdateParams::Body::KYBPatchRequest::ControlPerson } |
#external_id ⇒ String?
A user provided id that can be used to link an account holder with an external system
79 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 79 optional :external_id, String |
#naics_code ⇒ String?
6-digit North American Industry Classification System (NAICS) code for the business.
86 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 86 optional :naics_code, String |
#nature_of_business ⇒ String?
Short description of the company’s line of business (i.e., what does the company do?). Values longer than 255 characters will be truncated before KYB verification
94 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 94 optional :nature_of_business, String |
#website_url ⇒ String?
Company website URL.
100 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 100 optional :website_url, String |