Class: Lithic::Models::AccountHolderUpdateParams::Body::PatchRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolderUpdateParams::Body::PatchRequest
- Defined in:
- lib/lithic/models/account_holder_update_params.rb
Instance Attribute Summary collapse
-
#address ⇒ Lithic::Models::AddressUpdate?
Allowed for: KYC-Exempt, BYO-KYC, BYO-KYB.
-
#business_account_token ⇒ String?
Allowed for: KYC-Exempt, BYO-KYC.
-
#email ⇒ String?
Allowed for all Account Holders.
-
#first_name ⇒ String?
Allowed for KYC-Exempt, BYO-KYC.
-
#last_name ⇒ String?
Allowed for KYC-Exempt, BYO-KYC.
-
#legal_business_name ⇒ String?
Allowed for BYO-KYB.
-
#phone_number ⇒ String?
Allowed for all Account Holders.
Instance Method Summary collapse
-
#initialize(address: nil, business_account_token: nil, email: nil, first_name: nil, last_name: nil, legal_business_name: nil, phone_number: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PatchRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address: nil, business_account_token: nil, email: nil, first_name: nil, last_name: nil, legal_business_name: nil, phone_number: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AccountHolderUpdateParams::Body::PatchRequest for more details.
The legacy request for updating an account holder.
|
|
# File 'lib/lithic/models/account_holder_update_params.rb', line 521
|
Instance Attribute Details
#address ⇒ Lithic::Models::AddressUpdate?
Allowed for: KYC-Exempt, BYO-KYC, BYO-KYB.
478 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 478 optional :address, -> { Lithic::AddressUpdate } |
#business_account_token ⇒ String?
Allowed for: KYC-Exempt, BYO-KYC. The token of the business account to which the account holder is associated.
485 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 485 optional :business_account_token, String |
#email ⇒ String?
Allowed for all Account Holders. Account holder’s email address. The primary purpose of this field is for cardholder identification and verification during the digital wallet tokenization process.
493 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 493 optional :email, String |
#first_name ⇒ String?
Allowed for KYC-Exempt, BYO-KYC. Account holder’s first name.
499 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 499 optional :first_name, String |
#last_name ⇒ String?
Allowed for KYC-Exempt, BYO-KYC. Account holder’s last name.
505 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 505 optional :last_name, String |
#legal_business_name ⇒ String?
Allowed for BYO-KYB. Legal business name of the account holder.
511 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 511 optional :legal_business_name, String |
#phone_number ⇒ String?
Allowed for all Account Holders. Account holder’s phone number, entered in E.164 format. The primary purpose of this field is for cardholder identification and verification during the digital wallet tokenization process.
519 |
# File 'lib/lithic/models/account_holder_update_params.rb', line 519 optional :phone_number, String |