Class: Lithic::Models::AccountHolders::AccountHolderEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolders::AccountHolderEntity
- Defined in:
- lib/lithic/models/account_holders/account_holder_entity.rb
Overview
Defined Under Namespace
Modules: Status, Type Classes: Address
Instance Attribute Summary collapse
-
#account_holder_token ⇒ String
Globally unique identifier for the account holder.
-
#address ⇒ Lithic::Models::AccountHolders::AccountHolderEntity::Address
Individual’s current address.
-
#dob ⇒ String?
Individual’s date of birth, as an RFC 3339 date.
-
#email ⇒ String?
Individual’s email address.
-
#first_name ⇒ String?
Individual’s first name, as it appears on government-issued identity documents.
-
#last_name ⇒ String?
Individual’s last name, as it appears on government-issued identity documents.
-
#phone_number ⇒ String?
Individual’s phone number, entered in E.164 format.
-
#status ⇒ Symbol, Lithic::Models::AccountHolders::AccountHolderEntity::Status
The status of the entity.
-
#token ⇒ String
Globally unique identifier for the entity.
-
#type ⇒ Symbol, Lithic::Models::AccountHolders::AccountHolderEntity::Type
The type of entity.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(address1:, city:, country:, postal_code:, state:, address2: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address1:, city:, country:, postal_code:, state:, address2: nil) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
Individual’s current address
|
|
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 68
|
Instance Attribute Details
#account_holder_token ⇒ String
Globally unique identifier for the account holder
18 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 18 required :account_holder_token, String |
#address ⇒ Lithic::Models::AccountHolders::AccountHolderEntity::Address
Individual’s current address
24 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 24 required :address, -> { Lithic::AccountHolders::AccountHolderEntity::Address } |
#dob ⇒ String?
Individual’s date of birth, as an RFC 3339 date
30 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 30 required :dob, String, nil?: true |
#email ⇒ String?
Individual’s email address
36 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 36 required :email, String, nil?: true |
#first_name ⇒ String?
Individual’s first name, as it appears on government-issued identity documents
42 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 42 required :first_name, String, nil?: true |
#last_name ⇒ String?
Individual’s last name, as it appears on government-issued identity documents
48 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 48 required :last_name, String, nil?: true |
#phone_number ⇒ String?
Individual’s phone number, entered in E.164 format
54 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 54 required :phone_number, String, nil?: true |
#status ⇒ Symbol, Lithic::Models::AccountHolders::AccountHolderEntity::Status
The status of the entity
60 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 60 required :status, enum: -> { Lithic::AccountHolders::AccountHolderEntity::Status } |
#token ⇒ String
Globally unique identifier for the entity
12 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 12 required :token, String |
#type ⇒ Symbol, Lithic::Models::AccountHolders::AccountHolderEntity::Type
The type of entity
66 |
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 66 required :type, enum: -> { Lithic::AccountHolders::AccountHolderEntity::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/account_holders/account_holder_entity.rb', line 162
|