Class: Lithic::Models::AccountHolders::EntityCreateParams::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolders::EntityCreateParams::Address
- Defined in:
- lib/lithic/models/account_holders/entity_create_params.rb
Instance Attribute Summary collapse
-
#address1 ⇒ String
Valid deliverable address (no PO boxes).
-
#address2 ⇒ String?
Unit or apartment number (if applicable).
-
#city ⇒ String
Name of city.
-
#country ⇒ String
Valid country code.
-
#postal_code ⇒ String
Valid postal code.
-
#state ⇒ String
Valid state code.
Instance Method Summary collapse
-
#initialize(account_holder_token:, address:, dob:, email:, first_name:, government_id:, last_name:, phone_number:, type:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see Lithic::Models::AccountHolders::EntityCreateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_holder_token:, address:, dob:, email:, first_name:, government_id:, last_name:, phone_number:, type:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AccountHolders::EntityCreateParams for more details.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 93 class Address < Lithic::Internal::Type::BaseModel # @!attribute address1 # Valid deliverable address (no PO boxes). # # @return [String] required :address1, String # @!attribute city # Name of city. # # @return [String] required :city, String # @!attribute country # Valid country code. Only USA is currently supported, entered in uppercase ISO # 3166-1 alpha-3 three-character format. # # @return [String] required :country, String # @!attribute postal_code # Valid postal code. Only USA ZIP codes are currently supported, entered as a # five-digit ZIP or nine-digit ZIP+4. # # @return [String] required :postal_code, String # @!attribute state # Valid state code. Only USA state codes are currently supported, entered in # uppercase ISO 3166-2 two-character format. # # @return [String] required :state, String # @!attribute address2 # Unit or apartment number (if applicable). # # @return [String, nil] optional :address2, String # @!method initialize(address1:, city:, country:, postal_code:, state:, address2: nil) # Some parameter documentations has been truncated, see # {Lithic::Models::AccountHolders::EntityCreateParams::Address} for more details. # # Individual's current address - PO boxes, UPS drops, and FedEx drops are not # acceptable; APO/FPO are acceptable. Only USA addresses are currently supported. # # @param address1 [String] Valid deliverable address (no PO boxes). # # @param city [String] Name of city. # # @param country [String] Valid country code. Only USA is currently supported, entered in uppercase ISO 31 # # @param postal_code [String] Valid postal code. Only USA ZIP codes are currently supported, entered as a five # # @param state [String] Valid state code. Only USA state codes are currently supported, entered in upper # # @param address2 [String] Unit or apartment number (if applicable). end |
Instance Attribute Details
#address1 ⇒ String
Valid deliverable address (no PO boxes).
98 |
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 98 required :address1, String |
#address2 ⇒ String?
Unit or apartment number (if applicable).
131 |
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 131 optional :address2, String |
#city ⇒ String
Name of city.
104 |
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 104 required :city, String |
#country ⇒ String
Valid country code. Only USA is currently supported, entered in uppercase ISO 3166-1 alpha-3 three-character format.
111 |
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 111 required :country, String |
#postal_code ⇒ String
Valid postal code. Only USA ZIP codes are currently supported, entered as a five-digit ZIP or nine-digit ZIP+4.
118 |
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 118 required :postal_code, String |
#state ⇒ String
Valid state code. Only USA state codes are currently supported, entered in uppercase ISO 3166-2 two-character format.
125 |
# File 'lib/lithic/models/account_holders/entity_create_params.rb', line 125 required :state, String |