Class: Lithic::Models::AccountHolders::EntityCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AccountHolders::EntityCreateResponse
- Defined in:
- lib/lithic/models/account_holders/entity_create_response.rb
Overview
Defined Under Namespace
Modules: Status, StatusReason
Instance Attribute Summary collapse
-
#account_holder_token ⇒ String
Globally unique identifier for the account holder.
-
#created ⇒ Time
Timestamp of when the entity was created.
-
#required_documents ⇒ Array<Lithic::Models::RequiredDocument>
A list of documents required for the entity to be approved.
-
#status ⇒ Symbol, Lithic::Models::AccountHolders::EntityCreateResponse::Status
Entity verification status.
-
#status_reasons ⇒ Array<Symbol, Lithic::Models::AccountHolders::EntityCreateResponse::StatusReason>
Reason for the evaluation status.
-
#token ⇒ String
Globally unique identifier for the entity.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, account_holder_token:, created:, required_documents:, status:, status_reasons:) ⇒ Object
constructor
Response body for creating a new beneficial owner or replacing the control person entity on an existing KYB account holder.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, account_holder_token:, created:, required_documents:, status:, status_reasons:) ⇒ Object
Response body for creating a new beneficial owner or replacing the control person entity on an existing KYB account holder.
|
|
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 45
|
Instance Attribute Details
#account_holder_token ⇒ String
Globally unique identifier for the account holder
18 |
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 18 required :account_holder_token, String |
#created ⇒ Time
Timestamp of when the entity was created
24 |
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 24 required :created, Time |
#required_documents ⇒ Array<Lithic::Models::RequiredDocument>
A list of documents required for the entity to be approved
30 |
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 30 required :required_documents, -> { Lithic::Internal::Type::ArrayOf[Lithic::RequiredDocument] } |
#status ⇒ Symbol, Lithic::Models::AccountHolders::EntityCreateResponse::Status
Entity verification status
36 |
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 36 required :status, enum: -> { Lithic::Models::AccountHolders::EntityCreateResponse::Status } |
#status_reasons ⇒ Array<Symbol, Lithic::Models::AccountHolders::EntityCreateResponse::StatusReason>
Reason for the evaluation status
42 43 |
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 42 required :status_reasons, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::Models::AccountHolders::EntityCreateResponse::StatusReason] } |
#token ⇒ String
Globally unique identifier for the entity
12 |
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 12 required :token, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/account_holders/entity_create_response.rb', line 72
|