Class: Lithic::Models::AccountUpdateParams::VerificationAddress
Deprecated
Overview
Instance Attribute Summary collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address1: nil, address2: nil, city: nil, country: nil, postal_code: nil, state: nil) ⇒ Object
Address used during Address Verification Service (AVS) checks during transactions if enabled via Auth Rules. This field is deprecated as AVS checks are no longer supported by Auth Rules. The field will be removed from the schema in a future release.
|
# File 'lib/lithic/models/account_update_params.rb', line 205
|
Instance Attribute Details
#address1 ⇒ String?
178
|
# File 'lib/lithic/models/account_update_params.rb', line 178
optional :address1, String
|
#address2 ⇒ String?
183
|
# File 'lib/lithic/models/account_update_params.rb', line 183
optional :address2, String
|
#city ⇒ String?
188
|
# File 'lib/lithic/models/account_update_params.rb', line 188
optional :city, String
|
#country ⇒ String?
193
|
# File 'lib/lithic/models/account_update_params.rb', line 193
optional :country, String
|
#postal_code ⇒ String?
198
|
# File 'lib/lithic/models/account_update_params.rb', line 198
optional :postal_code, String
|
#state ⇒ String?
203
|
# File 'lib/lithic/models/account_update_params.rb', line 203
optional :state, String
|