Module: Lithic::Models::AuthRules::AuthRule::DraftVersion::State
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/auth_rules/auth_rule.rb
Overview
The state of the draft version. Most rules are created synchronously and the state is immediately ‘SHADOWING`. Rules backed by TypeScript code are compiled asynchronously — the state starts as `PENDING` and transitions to `SHADOWING` on success or `ERROR` on failure.
-
‘PENDING`: Compilation of the rule is in progress (TypeScript rules only).
-
‘SHADOWING`: The draft version is ready and evaluating in shadow mode alongside the current active version. It can be promoted to the active version.
-
‘ERROR`: Compilation of the rule failed. Check the `error` field for details.
Constant Summary collapse
- PENDING =
:PENDING- SHADOWING =
:SHADOWING- ERROR =
:ERROR
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info