Class: Lithic::Models::AuthRules::AuthRuleCondition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::AuthRuleCondition
- Defined in:
- lib/lithic/models/auth_rules/auth_rule_condition.rb,
sig/lithic/models/auth_rules/auth_rule_condition.rbs
Instance Attribute Summary collapse
-
#attribute ⇒ Symbol, Lithic::Models::AuthRules::ConditionalAttribute
The attribute to target.
-
#operation ⇒ Symbol, Lithic::Models::AuthRules::ConditionalOperation
The operation to apply to the attribute.
-
#value ⇒ String, ...
A regex string, to be used with
MATCHESorDOES_NOT_MATCH.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
20 |
# File 'sig/lithic/models/auth_rules/auth_rule_condition.rbs', line 20
def initialize: (
|
Instance Attribute Details
#attribute ⇒ Symbol, Lithic::Models::AuthRules::ConditionalAttribute
The attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.LIABILITY_SHIFT: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values areNONE,3DS_AUTHENTICATED, orTOKEN_AUTHENTICATED.PAN_ENTRY_MODE: The method by which the cardholder's primary account number (PAN) was entered. Valid values areAUTO_ENTRY,BAR_CODE,CONTACTLESS,ECOMMERCE,ERROR_KEYED,ERROR_MAGNETIC_STRIPE,ICC,KEY_ENTERED,MAGNETIC_STRIPE,MANUAL,OCR,SECURE_CARDLESS,UNSPECIFIED,UNKNOWN,CREDENTIAL_ON_FILE, orECOMMERCE.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.RISK_SCORE: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.CARD_TRANSACTION_COUNT_15M: The number of transactions on the card in the trailing 15 minutes before the authorization.CARD_TRANSACTION_COUNT_1H: The number of transactions on the card in the trailing hour up and until the authorization.CARD_TRANSACTION_COUNT_24H: The number of transactions on the card in the trailing 24 hours up and until the authorization.CARD_STATE: The current state of the card associated with the transaction. Valid values areCLOSED,OPEN,PAUSED,PENDING_ACTIVATION,PENDING_FULFILLMENT.PIN_ENTERED: Indicates whether a PIN was entered during the transaction. Valid values areTRUE,FALSE.PIN_STATUS: The current state of card's PIN. Valid values areNOT_SET,OK,BLOCKED.WALLET_TYPE: For transactions using a digital wallet token, indicates the source of the token. Valid values areAPPLE_PAY,GOOGLE_PAY,SAMSUNG_PAY,MASTERPASS,MERCHANT,OTHER,NONE.ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values areMATCH,MATCH_ADDRESS_ONLY,MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.
60 |
# File 'lib/lithic/models/auth_rules/auth_rule_condition.rb', line 60 required :attribute, enum: -> { Lithic::AuthRules::ConditionalAttribute } |
#operation ⇒ Symbol, Lithic::Models::AuthRules::ConditionalOperation
The operation to apply to the attribute
66 |
# File 'lib/lithic/models/auth_rules/auth_rule_condition.rb', line 66 required :operation, enum: -> { Lithic::AuthRules::ConditionalOperation } |
#value ⇒ String, ...
A regex string, to be used with MATCHES or DOES_NOT_MATCH
72 |
# File 'lib/lithic/models/auth_rules/auth_rule_condition.rb', line 72 required :value, union: -> { Lithic::AuthRules::ConditionalValue } |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/lithic/models/auth_rules/auth_rule_condition.rbs', line 26
def to_hash: -> {
|