Class: Lithic::Models::AuthRules::CardTransactionUpdateAction::TagAction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::CardTransactionUpdateAction::TagAction
- Defined in:
- lib/lithic/models/auth_rules/card_transaction_update_action.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#key ⇒ String
The key of the tag to apply to the transaction.
-
#type ⇒ Symbol, Lithic::Models::AuthRules::CardTransactionUpdateAction::TagAction::Type
Tag the transaction with key-value metadata.
-
#value ⇒ String
The value of the tag to apply to the transaction.
Instance Method Summary collapse
- #initialize(key:, type:, value:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key:, type:, value:) ⇒ Object
|
|
# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 32
|
Instance Attribute Details
#key ⇒ String
The key of the tag to apply to the transaction
18 |
# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 18 required :key, String |
#type ⇒ Symbol, Lithic::Models::AuthRules::CardTransactionUpdateAction::TagAction::Type
Tag the transaction with key-value metadata
24 |
# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 24 required :type, enum: -> { Lithic::AuthRules::CardTransactionUpdateAction::TagAction::Type } |
#value ⇒ String
The value of the tag to apply to the transaction
30 |
# File 'lib/lithic/models/auth_rules/card_transaction_update_action.rb', line 30 required :value, String |