Class: Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition
- Defined in:
- lib/lithic/models/auth_rules/conditional_ach_payment_update_action_parameters.rb
Defined Under Namespace
Modules: Attribute
Instance Attribute Summary collapse
-
#attribute ⇒ Symbol, Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition::Attribute
The attribute to target.
-
#operation ⇒ Symbol, Lithic::Models::AuthRules::ConditionalOperation
The operation to apply to the attribute.
-
#value ⇒ String, ...
A regex string, to be used with ‘MATCHES` or `DOES_NOT_MATCH`.
Instance Method Summary collapse
-
#initialize(attribute:, operation:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Condition for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attribute:, operation:, value:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition for more details.
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/lithic/models/auth_rules/conditional_ach_payment_update_action_parameters.rb', line 24 class Condition < Lithic::Internal::Type::BaseModel # @!attribute attribute # The attribute to target. # # The following attributes may be targeted: # # - `TRANSACTION_AMOUNT`: The total amount of the ACH payment in minor units # (cents), calculated as the sum of the settled and pending amounts. Use an # integer value. # - `SEC_CODE`: Standard Entry Class code indicating the type of ACH transaction. # Valid values include PPD (Prearranged Payment and Deposit Entry), CCD # (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL # (Telephone-Initiated Entry), and others. # - `RETURN_REASON_CODE`: NACHA return reason code associated with the payment # (for example, `R01`). # - `ACCOUNT_AGE`: The age of the account in seconds at the time of the payment. # Use an integer value. For programs where Lithic does not manage or retain # account holder data, this attribute does not evaluate. # - `EXTERNAL_BANK_ACCOUNT_AGE`: The age of the external bank account in seconds # at the time of the payment. Use an integer value. # - `EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD`: The method used to verify the # external bank account. Valid values are `MANUAL`, `MICRO_DEPOSIT`, `PRENOTE`, # `EXTERNALLY_VERIFIED`, or `UNVERIFIED`. # - `EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE`: The verification state of the # external bank account. Valid values are `PENDING`, `ENABLED`, # `FAILED_VERIFICATION`, or `INSUFFICIENT_FUNDS`. # - `EXTERNAL_BANK_ACCOUNT_OWNER_TYPE`: The owner type of the external bank # account. Valid values are `INDIVIDUAL` or `BUSINESS`. # - `ACH_EVENT_TYPE`: The type of ACH payment event being evaluated. Valid values # include `ACH_ORIGINATION_INITIATED`, `ACH_ORIGINATION_REVIEWED`, # `ACH_ORIGINATION_CANCELLED`, `ACH_ORIGINATION_PROCESSED`, # `ACH_ORIGINATION_SETTLED`, `ACH_ORIGINATION_RELEASED`, # `ACH_ORIGINATION_REJECTED`, `ACH_RECEIPT_PROCESSED`, `ACH_RECEIPT_SETTLED`, # `ACH_RECEIPT_RELEASED`, `ACH_RECEIPT_RELEASED_EARLY`, `ACH_RETURN_INITIATED`, # `ACH_RETURN_PROCESSED`, `ACH_RETURN_SETTLED`, and `ACH_RETURN_REJECTED`. # # @return [Symbol, Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition::Attribute] required :attribute, enum: -> { Lithic::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition::Attribute } # @!attribute operation # The operation to apply to the attribute # # @return [Symbol, Lithic::Models::AuthRules::ConditionalOperation] required :operation, enum: -> { Lithic::AuthRules::ConditionalOperation } # @!attribute value # A regex string, to be used with `MATCHES` or `DOES_NOT_MATCH` # # @return [String, Integer, Float, Array<String>, Time] required :value, union: -> { Lithic::AuthRules::ConditionalValue } # @!method initialize(attribute:, operation:, value:) # Some parameter documentations has been truncated, see # {Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition} # for more details. # # @param attribute [Symbol, Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition::Attribute] The attribute to target. # # @param operation [Symbol, Lithic::Models::AuthRules::ConditionalOperation] The operation to apply to the attribute # # @param value [String, Integer, Float, Array<String>, Time] A regex string, to be used with `MATCHES` or `DOES_NOT_MATCH` # The attribute to target. # # The following attributes may be targeted: # # - `TRANSACTION_AMOUNT`: The total amount of the ACH payment in minor units # (cents), calculated as the sum of the settled and pending amounts. Use an # integer value. # - `SEC_CODE`: Standard Entry Class code indicating the type of ACH transaction. # Valid values include PPD (Prearranged Payment and Deposit Entry), CCD # (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL # (Telephone-Initiated Entry), and others. # - `RETURN_REASON_CODE`: NACHA return reason code associated with the payment # (for example, `R01`). # - `ACCOUNT_AGE`: The age of the account in seconds at the time of the payment. # Use an integer value. For programs where Lithic does not manage or retain # account holder data, this attribute does not evaluate. # - `EXTERNAL_BANK_ACCOUNT_AGE`: The age of the external bank account in seconds # at the time of the payment. Use an integer value. # - `EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD`: The method used to verify the # external bank account. Valid values are `MANUAL`, `MICRO_DEPOSIT`, `PRENOTE`, # `EXTERNALLY_VERIFIED`, or `UNVERIFIED`. # - `EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE`: The verification state of the # external bank account. Valid values are `PENDING`, `ENABLED`, # `FAILED_VERIFICATION`, or `INSUFFICIENT_FUNDS`. # - `EXTERNAL_BANK_ACCOUNT_OWNER_TYPE`: The owner type of the external bank # account. Valid values are `INDIVIDUAL` or `BUSINESS`. # - `ACH_EVENT_TYPE`: The type of ACH payment event being evaluated. Valid values # include `ACH_ORIGINATION_INITIATED`, `ACH_ORIGINATION_REVIEWED`, # `ACH_ORIGINATION_CANCELLED`, `ACH_ORIGINATION_PROCESSED`, # `ACH_ORIGINATION_SETTLED`, `ACH_ORIGINATION_RELEASED`, # `ACH_ORIGINATION_REJECTED`, `ACH_RECEIPT_PROCESSED`, `ACH_RECEIPT_SETTLED`, # `ACH_RECEIPT_RELEASED`, `ACH_RECEIPT_RELEASED_EARLY`, `ACH_RETURN_INITIATED`, # `ACH_RETURN_PROCESSED`, `ACH_RETURN_SETTLED`, and `ACH_RETURN_REJECTED`. # # @see Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition#attribute module Attribute extend Lithic::Internal::Type::Enum TRANSACTION_AMOUNT = :TRANSACTION_AMOUNT SEC_CODE = :SEC_CODE RETURN_REASON_CODE = :RETURN_REASON_CODE ACCOUNT_AGE = :ACCOUNT_AGE EXTERNAL_BANK_ACCOUNT_AGE = :EXTERNAL_BANK_ACCOUNT_AGE EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD = :EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE = :EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE EXTERNAL_BANK_ACCOUNT_OWNER_TYPE = :EXTERNAL_BANK_ACCOUNT_OWNER_TYPE ACH_EVENT_TYPE = :ACH_EVENT_TYPE # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#attribute ⇒ Symbol, Lithic::Models::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition::Attribute
The attribute to target.
The following attributes may be targeted:
-
‘TRANSACTION_AMOUNT`: The total amount of the ACH payment in minor units (cents), calculated as the sum of the settled and pending amounts. Use an integer value.
-
‘SEC_CODE`: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.
-
‘RETURN_REASON_CODE`: NACHA return reason code associated with the payment (for example, `R01`).
-
‘ACCOUNT_AGE`: The age of the account in seconds at the time of the payment. Use an integer value. For programs where Lithic does not manage or retain account holder data, this attribute does not evaluate.
-
‘EXTERNAL_BANK_ACCOUNT_AGE`: The age of the external bank account in seconds at the time of the payment. Use an integer value.
-
‘EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD`: The method used to verify the external bank account. Valid values are `MANUAL`, `MICRO_DEPOSIT`, `PRENOTE`, `EXTERNALLY_VERIFIED`, or `UNVERIFIED`.
-
‘EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE`: The verification state of the external bank account. Valid values are `PENDING`, `ENABLED`, `FAILED_VERIFICATION`, or `INSUFFICIENT_FUNDS`.
-
‘EXTERNAL_BANK_ACCOUNT_OWNER_TYPE`: The owner type of the external bank account. Valid values are `INDIVIDUAL` or `BUSINESS`.
-
‘ACH_EVENT_TYPE`: The type of ACH payment event being evaluated. Valid values include `ACH_ORIGINATION_INITIATED`, `ACH_ORIGINATION_REVIEWED`, `ACH_ORIGINATION_CANCELLED`, `ACH_ORIGINATION_PROCESSED`, `ACH_ORIGINATION_SETTLED`, `ACH_ORIGINATION_RELEASED`, `ACH_ORIGINATION_REJECTED`, `ACH_RECEIPT_PROCESSED`, `ACH_RECEIPT_SETTLED`, `ACH_RECEIPT_RELEASED`, `ACH_RECEIPT_RELEASED_EARLY`, `ACH_RETURN_INITIATED`, `ACH_RETURN_PROCESSED`, `ACH_RETURN_SETTLED`, and `ACH_RETURN_REJECTED`.
61 62 |
# File 'lib/lithic/models/auth_rules/conditional_ach_payment_update_action_parameters.rb', line 61 required :attribute, enum: -> { Lithic::AuthRules::ConditionalACHPaymentUpdateActionParameters::Condition::Attribute } |
#operation ⇒ Symbol, Lithic::Models::AuthRules::ConditionalOperation
The operation to apply to the attribute
68 |
# File 'lib/lithic/models/auth_rules/conditional_ach_payment_update_action_parameters.rb', line 68 required :operation, enum: -> { Lithic::AuthRules::ConditionalOperation } |