Module: Lithic::Models::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Attribute

Extended by:
Internal::Type::Enum
Defined in:
lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb

Overview

The attribute to target.

The following attributes may be targeted:

  • ‘MCC`: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.

  • ‘COUNTRY`: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.

  • ‘CURRENCY`: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.

  • ‘MERCHANT_ID`: Unique alphanumeric identifier for the payment card acceptor (merchant).

  • ‘DESCRIPTOR`: Short description of card acceptor.

  • ‘TRANSACTION_AMOUNT`: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder. Use an integer value.

  • ‘RISK_SCORE`: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x. Use an integer value.

  • ‘TRANSACTION_STATUS`: The status of the transaction. Valid values are `PENDING`, `VOIDED`, `SETTLING`, `SETTLED`, `BOUNCED`, `RETURNED`, `DECLINED`, `EXPIRED`.

  • ‘LAST_EVENT_TYPE`: The type of the most recent event on the transaction. Valid values are `AUTHORIZATION`, `AUTHORIZATION_ADVICE`, `AUTHORIZATION_EXPIRY`, `AUTHORIZATION_REVERSAL`, `BALANCE_INQUIRY`, `CLEARING`, `CORRECTION_CREDIT`, `CORRECTION_DEBIT`, `CREDIT_AUTHORIZATION`, `CREDIT_AUTHORIZATION_ADVICE`, `FINANCIAL_AUTHORIZATION`, `FINANCIAL_CREDIT_AUTHORIZATION`, `RETURN`, `RETURN_REVERSAL`.

  • ‘LIABILITY_SHIFT`: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values are `NONE`, `3DS_AUTHENTICATED`, or `TOKEN_AUTHENTICATED`.

  • ‘PAN_ENTRY_MODE`: The method by which the cardholder’s primary account number (PAN) was entered. Valid values are ‘AUTO_ENTRY`, `BAR_CODE`, `CONTACTLESS`, `ECOMMERCE`, `ERROR_KEYED`, `ERROR_MAGNETIC_STRIPE`, `ICC`, `KEY_ENTERED`, `MAGNETIC_STRIPE`, `MANUAL`, `OCR`, `SECURE_CARDLESS`, `UNSPECIFIED`, `UNKNOWN`, or `CREDENTIAL_ON_FILE`.

  • ‘WALLET_TYPE`: For transactions using a digital wallet token, indicates the source of the token. Valid values are `APPLE_PAY`, `GOOGLE_PAY`, `SAMSUNG_PAY`, `MASTERPASS`, `MERCHANT`, `OTHER`, `NONE`.

  • ‘CARD_AGE`: The age of the card in seconds at the time of the transaction. Use an integer value.

  • ‘ACCOUNT_AGE`: The age of the account in seconds at the time of the transaction. Use an integer value. For programs where Lithic does not manage or retain account holder data, this attribute does not evaluate.

  • ‘SPEND_VELOCITY_COUNT`: The number of transactions matching the specified filters within the given period. Requires `parameters` with `scope`, `period`, and optional `filters`. Use an integer value.

  • ‘SPEND_VELOCITY_AMOUNT`: The total spend amount (in cents) of transactions matching the specified filters within the given period. Requires `parameters` with `scope`, `period`, and optional `filters`. Use an integer value.

See Also:

Constant Summary collapse

MCC =
:MCC
COUNTRY =
:COUNTRY
CURRENCY =
:CURRENCY
MERCHANT_ID =
:MERCHANT_ID
DESCRIPTOR =
:DESCRIPTOR
TRANSACTION_AMOUNT =
:TRANSACTION_AMOUNT
RISK_SCORE =
:RISK_SCORE
TRANSACTION_STATUS =
:TRANSACTION_STATUS
LAST_EVENT_TYPE =
:LAST_EVENT_TYPE
LIABILITY_SHIFT =
:LIABILITY_SHIFT
PAN_ENTRY_MODE =
:PAN_ENTRY_MODE
WALLET_TYPE =
:WALLET_TYPE
CARD_AGE =
:CARD_AGE
ACCOUNT_AGE =
:ACCOUNT_AGE
SPEND_VELOCITY_COUNT =
:SPEND_VELOCITY_COUNT
SPEND_VELOCITY_AMOUNT =
:SPEND_VELOCITY_AMOUNT

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info