Class: Lithic::Models::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Parameters
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Parameters
- Defined in:
- lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb
Overview
Defined Under Namespace
Modules: Scope
Instance Attribute Summary collapse
- #filters ⇒ Lithic::Models::AuthRules::SpendVelocityFilters?
-
#period ⇒ Lithic::Models::AuthRules::VelocityLimitPeriod::TrailingWindowObject, ...
The time period over which to calculate the spend velocity.
-
#scope ⇒ Symbol, ...
The entity scope to evaluate the attribute against.
Instance Method Summary collapse
-
#initialize(filters: nil, period: nil, scope: nil) ⇒ Object
constructor
Additional parameters for spend velocity attributes.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filters: nil, period: nil, scope: nil) ⇒ Object
Additional parameters for spend velocity attributes. Required when ‘attribute` is `SPEND_VELOCITY_COUNT` or `SPEND_VELOCITY_AMOUNT`. Not used for other attributes.
|
|
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 215
|
Instance Attribute Details
#filters ⇒ Lithic::Models::AuthRules::SpendVelocityFilters?
200 |
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 200 optional :filters, -> { Lithic::AuthRules::SpendVelocityFilters } |
#period ⇒ Lithic::Models::AuthRules::VelocityLimitPeriod::TrailingWindowObject, ...
The time period over which to calculate the spend velocity.
206 |
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 206 optional :period, union: -> { Lithic::AuthRules::VelocityLimitPeriod } |
#scope ⇒ Symbol, ...
The entity scope to evaluate the attribute against.
212 213 |
# File 'lib/lithic/models/auth_rules/conditional_card_transaction_update_action_parameters.rb', line 212 optional :scope, enum: -> { Lithic::AuthRules::ConditionalCardTransactionUpdateActionParameters::Condition::Parameters::Scope } |