Class: Lithic::Models::AuthRules::ReportStats
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::ReportStats
- Defined in:
- lib/lithic/models/auth_rules/report_stats.rb
Defined Under Namespace
Modules: State Classes: Example
Instance Attribute Summary collapse
-
#action_counts ⇒ Hash{Symbol=>Integer}
A mapping of action types to the number of times that action was returned by this version during the relevant period.
-
#examples ⇒ Array<Lithic::Models::AuthRules::ReportStats::Example>
Example events and their outcomes for this version.
-
#state ⇒ Symbol, Lithic::Models::AuthRules::ReportStats::State
The evaluation mode of this version during the reported period.
-
#version ⇒ Integer
The rule version number.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization, Lithic::Models::AuthRules::ReportStats::Example::Action::ChallengeActionAuthorization, Lithic::Models::AuthRules::ReportStats::Example::Action::ResultAuthentication3DSAction, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization, Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction, Lithic::Models::AuthRules::ReportStats::Example::Action::ApproveActionACH, Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction)
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Lithic::Internal::Type::BaseModel
Instance Attribute Details
#action_counts ⇒ Hash{Symbol=>Integer}
A mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn’t trigger any action, it’s counted under NO_ACTION key.
14 |
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 14 required :action_counts, Lithic::Internal::Type::HashOf[Integer] |
#examples ⇒ Array<Lithic::Models::AuthRules::ReportStats::Example>
Example events and their outcomes for this version.
20 |
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 20 required :examples, -> { Lithic::Internal::Type::ArrayOf[Lithic::AuthRules::ReportStats::Example] } |
#state ⇒ Symbol, Lithic::Models::AuthRules::ReportStats::State
The evaluation mode of this version during the reported period.
26 |
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 26 required :state, enum: -> { Lithic::AuthRules::ReportStats::State } |
#version ⇒ Integer
The rule version number.
32 |
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 32 required :version, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 491
|
.variants ⇒ Array(Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization, Lithic::Models::AuthRules::ReportStats::Example::Action::ChallengeActionAuthorization, Lithic::Models::AuthRules::ReportStats::Example::Action::ResultAuthentication3DSAction, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization, Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction, Lithic::Models::AuthRules::ReportStats::Example::Action::ApproveActionACH, Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction)
|
|
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 496
|