Module: Lithic::Models::AuthRules::ReportStats::Example::Action
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/lithic/models/auth_rules/report_stats.rb
Defined Under Namespace
Classes: ApproveActionACH, ChallengeActionAuthorization, DeclineActionAuthorization, DeclineActionTokenization, RequireTfaAction, ResultAuthentication3DSAction, ReturnAction
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 191
|
Instance Method Details
#initialize(actions:, event_token:, timestamp:, transaction_token: nil) ⇒ Object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/lithic/models/auth_rules/report_stats.rb', line 81 module Action extend Lithic::Internal::Type::Union variant -> { Lithic::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization } variant -> { Lithic::AuthRules::ReportStats::Example::Action::ChallengeActionAuthorization } variant -> { Lithic::AuthRules::ReportStats::Example::Action::ResultAuthentication3DSAction } variant -> { Lithic::AuthRules::ReportStats::Example::Action::DeclineActionTokenization } variant -> { Lithic::AuthRules::ReportStats::Example::Action::RequireTfaAction } variant -> { Lithic::AuthRules::ReportStats::Example::Action::ApproveActionACH } variant -> { Lithic::AuthRules::ReportStats::Example::Action::ReturnAction } class DeclineActionAuthorization < Lithic::Internal::Type::BaseModel # @!attribute code # The detailed result code explaining the specific reason for the decline # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Code] required :code, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Code } # @!attribute type # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Type] required :type, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Type } # @!method initialize(code:, type:) # @param code [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Code] The detailed result code explaining the specific reason for the decline # # @param type [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization::Type] # The detailed result code explaining the specific reason for the decline # # @see Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization#code module Code extend Lithic::Internal::Type::Enum ACCOUNT_DAILY_SPEND_LIMIT_EXCEEDED = :ACCOUNT_DAILY_SPEND_LIMIT_EXCEEDED ACCOUNT_DELINQUENT = :ACCOUNT_DELINQUENT ACCOUNT_INACTIVE = :ACCOUNT_INACTIVE ACCOUNT_LIFETIME_SPEND_LIMIT_EXCEEDED = :ACCOUNT_LIFETIME_SPEND_LIMIT_EXCEEDED ACCOUNT_MONTHLY_SPEND_LIMIT_EXCEEDED = :ACCOUNT_MONTHLY_SPEND_LIMIT_EXCEEDED ACCOUNT_PAUSED = :ACCOUNT_PAUSED ACCOUNT_UNDER_REVIEW = :ACCOUNT_UNDER_REVIEW ADDRESS_INCORRECT = :ADDRESS_INCORRECT APPROVED = :APPROVED AUTH_RULE_ALLOWED_COUNTRY = :AUTH_RULE_ALLOWED_COUNTRY AUTH_RULE_ALLOWED_MCC = :AUTH_RULE_ALLOWED_MCC AUTH_RULE_BLOCKED_COUNTRY = :AUTH_RULE_BLOCKED_COUNTRY AUTH_RULE_BLOCKED_MCC = :AUTH_RULE_BLOCKED_MCC AUTH_RULE = :AUTH_RULE CARD_CLOSED = :CARD_CLOSED CARD_CRYPTOGRAM_VALIDATION_FAILURE = :CARD_CRYPTOGRAM_VALIDATION_FAILURE CARD_EXPIRED = :CARD_EXPIRED CARD_EXPIRY_DATE_INCORRECT = :CARD_EXPIRY_DATE_INCORRECT CARD_INVALID = :CARD_INVALID CARD_NOT_ACTIVATED = :CARD_NOT_ACTIVATED CARD_PAUSED = :CARD_PAUSED CARD_PIN_INCORRECT = :CARD_PIN_INCORRECT CARD_RESTRICTED = :CARD_RESTRICTED CARD_SECURITY_CODE_INCORRECT = :CARD_SECURITY_CODE_INCORRECT CARD_SPEND_LIMIT_EXCEEDED = :CARD_SPEND_LIMIT_EXCEEDED CONTACT_CARD_ISSUER = :CONTACT_CARD_ISSUER CUSTOMER_ASA_TIMEOUT = :CUSTOMER_ASA_TIMEOUT CUSTOM_ASA_RESULT = :CUSTOM_ASA_RESULT DECLINED = :DECLINED DO_NOT_HONOR = :DO_NOT_HONOR DRIVER_NUMBER_INVALID = :DRIVER_NUMBER_INVALID FORMAT_ERROR = :FORMAT_ERROR INSUFFICIENT_FUNDING_SOURCE_BALANCE = :INSUFFICIENT_FUNDING_SOURCE_BALANCE INSUFFICIENT_FUNDS = :INSUFFICIENT_FUNDS LITHIC_SYSTEM_ERROR = :LITHIC_SYSTEM_ERROR LITHIC_SYSTEM_RATE_LIMIT = :LITHIC_SYSTEM_RATE_LIMIT MALFORMED_ASA_RESPONSE = :MALFORMED_ASA_RESPONSE MERCHANT_INVALID = :MERCHANT_INVALID MERCHANT_LOCKED_CARD_ATTEMPTED_ELSEWHERE = :MERCHANT_LOCKED_CARD_ATTEMPTED_ELSEWHERE MERCHANT_NOT_PERMITTED = :MERCHANT_NOT_PERMITTED OVER_REVERSAL_ATTEMPTED = :OVER_REVERSAL_ATTEMPTED PIN_BLOCKED = :PIN_BLOCKED PROGRAM_CARD_SPEND_LIMIT_EXCEEDED = :PROGRAM_CARD_SPEND_LIMIT_EXCEEDED PROGRAM_SUSPENDED = :PROGRAM_SUSPENDED PROGRAM_USAGE_RESTRICTION = :PROGRAM_USAGE_RESTRICTION REVERSAL_UNMATCHED = :REVERSAL_UNMATCHED SECURITY_VIOLATION = :SECURITY_VIOLATION SINGLE_USE_CARD_REATTEMPTED = :SINGLE_USE_CARD_REATTEMPTED SUSPECTED_FRAUD = :SUSPECTED_FRAUD TRANSACTION_INVALID = :TRANSACTION_INVALID TRANSACTION_NOT_PERMITTED_TO_ACQUIRER_OR_TERMINAL = :TRANSACTION_NOT_PERMITTED_TO_ACQUIRER_OR_TERMINAL TRANSACTION_NOT_PERMITTED_TO_ISSUER_OR_CARDHOLDER = :TRANSACTION_NOT_PERMITTED_TO_ISSUER_OR_CARDHOLDER TRANSACTION_PREVIOUSLY_COMPLETED = :TRANSACTION_PREVIOUSLY_COMPLETED UNAUTHORIZED_MERCHANT = :UNAUTHORIZED_MERCHANT VEHICLE_NUMBER_INVALID = :VEHICLE_NUMBER_INVALID CARDHOLDER_CHALLENGED = :CARDHOLDER_CHALLENGED CARDHOLDER_CHALLENGE_FAILED = :CARDHOLDER_CHALLENGE_FAILED # @!method self.values # @return [Array<Symbol>] end # @see Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization#type module Type extend Lithic::Internal::Type::Enum DECLINE = :DECLINE # @!method self.values # @return [Array<Symbol>] end end class ChallengeActionAuthorization < Lithic::Internal::Type::BaseModel # @!attribute type # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ChallengeActionAuthorization::Type] required :type, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::ChallengeActionAuthorization::Type } # @!method initialize(type:) # @param type [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ChallengeActionAuthorization::Type] # @see Lithic::Models::AuthRules::ReportStats::Example::Action::ChallengeActionAuthorization#type module Type extend Lithic::Internal::Type::Enum CHALLENGE = :CHALLENGE # @!method self.values # @return [Array<Symbol>] end end class ResultAuthentication3DSAction < Lithic::Internal::Type::BaseModel # @!attribute type # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ResultAuthentication3DSAction::Type] required :type, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::ResultAuthentication3DSAction::Type } # @!method initialize(type:) # @param type [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ResultAuthentication3DSAction::Type] # @see Lithic::Models::AuthRules::ReportStats::Example::Action::ResultAuthentication3DSAction#type module Type extend Lithic::Internal::Type::Enum DECLINE = :DECLINE CHALLENGE = :CHALLENGE # @!method self.values # @return [Array<Symbol>] end end class DeclineActionTokenization < Lithic::Internal::Type::BaseModel # @!attribute type # Decline the tokenization request # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization::Type] required :type, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::DeclineActionTokenization::Type } # @!attribute reason # Reason code for declining the tokenization request # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization::Reason, nil] optional :reason, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::DeclineActionTokenization::Reason } # @!method initialize(type:, reason: nil) # @param type [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization::Type] Decline the tokenization request # # @param reason [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization::Reason] Reason code for declining the tokenization request # Decline the tokenization request # # @see Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization#type module Type extend Lithic::Internal::Type::Enum DECLINE = :DECLINE # @!method self.values # @return [Array<Symbol>] end # Reason code for declining the tokenization request # # @see Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization#reason module Reason extend Lithic::Internal::Type::Enum ACCOUNT_SCORE_1 = :ACCOUNT_SCORE_1 DEVICE_SCORE_1 = :DEVICE_SCORE_1 ALL_WALLET_DECLINE_REASONS_PRESENT = :ALL_WALLET_DECLINE_REASONS_PRESENT WALLET_RECOMMENDED_DECISION_RED = :WALLET_RECOMMENDED_DECISION_RED CVC_MISMATCH = :CVC_MISMATCH CARD_EXPIRY_MONTH_MISMATCH = :CARD_EXPIRY_MONTH_MISMATCH CARD_EXPIRY_YEAR_MISMATCH = :CARD_EXPIRY_YEAR_MISMATCH CARD_INVALID_STATE = :CARD_INVALID_STATE CUSTOMER_RED_PATH = :CUSTOMER_RED_PATH INVALID_CUSTOMER_RESPONSE = :INVALID_CUSTOMER_RESPONSE NETWORK_FAILURE = :NETWORK_FAILURE GENERIC_DECLINE = :GENERIC_DECLINE DIGITAL_CARD_ART_REQUIRED = :DIGITAL_CARD_ART_REQUIRED # @!method self.values # @return [Array<Symbol>] end end class RequireTfaAction < Lithic::Internal::Type::BaseModel # @!attribute type # Require two-factor authentication for the tokenization request # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction::Type] required :type, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::RequireTfaAction::Type } # @!attribute reason # Reason code for requiring two-factor authentication # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction::Reason, nil] optional :reason, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::RequireTfaAction::Reason } # @!method initialize(type:, reason: nil) # @param type [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction::Type] Require two-factor authentication for the tokenization request # # @param reason [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction::Reason] Reason code for requiring two-factor authentication # Require two-factor authentication for the tokenization request # # @see Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction#type module Type extend Lithic::Internal::Type::Enum REQUIRE_TFA = :REQUIRE_TFA # @!method self.values # @return [Array<Symbol>] end # Reason code for requiring two-factor authentication # # @see Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction#reason module Reason extend Lithic::Internal::Type::Enum WALLET_RECOMMENDED_TFA = :WALLET_RECOMMENDED_TFA SUSPICIOUS_ACTIVITY = :SUSPICIOUS_ACTIVITY DEVICE_RECENTLY_LOST = :DEVICE_RECENTLY_LOST TOO_MANY_RECENT_ATTEMPTS = :TOO_MANY_RECENT_ATTEMPTS TOO_MANY_RECENT_TOKENS = :TOO_MANY_RECENT_TOKENS TOO_MANY_DIFFERENT_CARDHOLDERS = :TOO_MANY_DIFFERENT_CARDHOLDERS OUTSIDE_HOME_TERRITORY = :OUTSIDE_HOME_TERRITORY HAS_SUSPENDED_TOKENS = :HAS_SUSPENDED_TOKENS HIGH_RISK = :HIGH_RISK ACCOUNT_SCORE_LOW = :ACCOUNT_SCORE_LOW DEVICE_SCORE_LOW = :DEVICE_SCORE_LOW CARD_STATE_TFA = :CARD_STATE_TFA HARDCODED_TFA = :HARDCODED_TFA CUSTOMER_RULE_TFA = :CUSTOMER_RULE_TFA DEVICE_HOST_CARD_EMULATION = :DEVICE_HOST_CARD_EMULATION # @!method self.values # @return [Array<Symbol>] end end class ApproveActionACH < Lithic::Internal::Type::BaseModel # @!attribute type # Approve the ACH transaction # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ApproveActionACH::Type] required :type, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::ApproveActionACH::Type } # @!method initialize(type:) # @param type [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ApproveActionACH::Type] Approve the ACH transaction # Approve the ACH transaction # # @see Lithic::Models::AuthRules::ReportStats::Example::Action::ApproveActionACH#type module Type extend Lithic::Internal::Type::Enum APPROVE = :APPROVE # @!method self.values # @return [Array<Symbol>] end end class ReturnAction < Lithic::Internal::Type::BaseModel # @!attribute code # NACHA return code to use when returning the transaction. Note that the list of # available return codes is subject to an allowlist configured at the program # level # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction::Code] required :code, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::ReturnAction::Code } # @!attribute type # Return the ACH transaction # # @return [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction::Type] required :type, enum: -> { Lithic::AuthRules::ReportStats::Example::Action::ReturnAction::Type } # @!method initialize(code:, type:) # Some parameter documentations has been truncated, see # {Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction} for more # details. # # @param code [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction::Code] NACHA return code to use when returning the transaction. Note that the list of a # # @param type [Symbol, Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction::Type] Return the ACH transaction # NACHA return code to use when returning the transaction. Note that the list of # available return codes is subject to an allowlist configured at the program # level # # @see Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction#code module Code extend Lithic::Internal::Type::Enum R01 = :R01 R02 = :R02 R03 = :R03 R04 = :R04 R05 = :R05 R06 = :R06 R07 = :R07 R08 = :R08 R09 = :R09 R10 = :R10 R11 = :R11 R12 = :R12 R13 = :R13 R14 = :R14 R15 = :R15 R16 = :R16 R17 = :R17 R18 = :R18 R19 = :R19 R20 = :R20 R21 = :R21 R22 = :R22 R23 = :R23 R24 = :R24 R25 = :R25 R26 = :R26 R27 = :R27 R28 = :R28 R29 = :R29 R30 = :R30 R31 = :R31 R32 = :R32 R33 = :R33 R34 = :R34 R35 = :R35 R36 = :R36 R37 = :R37 R38 = :R38 R39 = :R39 R40 = :R40 R41 = :R41 R42 = :R42 R43 = :R43 R44 = :R44 R45 = :R45 R46 = :R46 R47 = :R47 R50 = :R50 R51 = :R51 R52 = :R52 R53 = :R53 R61 = :R61 R62 = :R62 R67 = :R67 R68 = :R68 R69 = :R69 R70 = :R70 R71 = :R71 R72 = :R72 R73 = :R73 R74 = :R74 R75 = :R75 R76 = :R76 R77 = :R77 R80 = :R80 R81 = :R81 R82 = :R82 R83 = :R83 R84 = :R84 R85 = :R85 # @!method self.values # @return [Array<Symbol>] end # Return the ACH transaction # # @see Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction#type module Type extend Lithic::Internal::Type::Enum RETURN = :RETURN # @!method self.values # @return [Array<Symbol>] end end # @!method self.variants # @return [Array(Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionAuthorization, Lithic::Models::AuthRules::ReportStats::Example::Action::ChallengeActionAuthorization, Lithic::Models::AuthRules::ReportStats::Example::Action::ResultAuthentication3DSAction, Lithic::Models::AuthRules::ReportStats::Example::Action::DeclineActionTokenization, Lithic::Models::AuthRules::ReportStats::Example::Action::RequireTfaAction, Lithic::Models::AuthRules::ReportStats::Example::Action::ApproveActionACH, Lithic::Models::AuthRules::ReportStats::Example::Action::ReturnAction)] end |