Module: Lithic::Models::AuthRules::RuleFeature
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/lithic/models/auth_rules/rule_feature.rb,
sig/lithic/models/auth_rules/rule_feature.rbs
Overview
A feature made available to the rule. The name field is the variable name used
in the rule function signature. The type field determines which data the
feature provides to the rule at evaluation time.
AUTHORIZATION: The authorization request being evaluated. Only available for AUTHORIZATION event stream rules.AUTHENTICATION: The 3DS authentication request being evaluated. Only available for THREE_DS_AUTHENTICATION event stream rules.TOKENIZATION: The tokenization request being evaluated. Only available for TOKENIZATION event stream rules.ACH_RECEIPT: The ACH receipt being evaluated. Only available for ACH_CREDIT_RECEIPT and ACH_DEBIT_RECEIPT event stream rules.CARD_TRANSACTION: The card transaction being evaluated. Only available for CARD_TRANSACTION_UPDATE event stream rules.ACH_PAYMENT: The ACH payment being evaluated. Only available for ACH_PAYMENT_UPDATE event stream rules.EXTERNAL_BANK_ACCOUNT: The external bank account tied to the ACH payment being evaluated. Only available for ACH_PAYMENT_UPDATE event stream rules.CARD: The card associated with the event. Available for AUTHORIZATION, THREE_DS_AUTHENTICATION, and CARD_TRANSACTION_UPDATE event stream rules.ACCOUNT_HOLDER: The account holder associated with the event. Available for AUTHORIZATION, THREE_DS_AUTHENTICATION, CARD_TRANSACTION_UPDATE, and ACH_PAYMENT_UPDATE event stream rules.IP_METADATA: IP address metadata for the request. Available for THREE_DS_AUTHENTICATION event stream rules.SPEND_VELOCITY: Spend velocity data for the card or account. Requiresscope,period, and optionallyfiltersto configure the velocity calculation. Available for AUTHORIZATION and CARD_TRANSACTION_UPDATE event stream rules.PAYMENT_VELOCITY: ACH payment velocity data, aggregated over the given scope. Requiresscope,period, and optionallyfiltersto configure the velocity calculation. Available for ACH_PAYMENT_UPDATE event stream rules.CONSECUTIVE_DECLINES: The number of consecutive declined transactions since the last approval for the card or account. Requiresscope. Available for AUTHORIZATION and CARD_TRANSACTION_UPDATE event stream rules.ACH_PAYMENT_HISTORY: Windowed settled-amount statistics derived from the financial account's ACH payment history. Requiresscope. Available for ACH_PAYMENT_UPDATE event stream rules.TRANSACTION_HISTORY_SIGNALS: Behavioral feature state derived from the entity's transaction history. Requiresscopeto specify whether to load card, account, or business account history. Available for AUTHORIZATION and CARD_TRANSACTION_UPDATE event stream rules.
Defined Under Namespace
Classes: ACHPaymentFeature, ACHPaymentHistoryFeature, ACHReceiptFeature, AccountHolderFeature, AuthenticationFeature, AuthorizationFeature, CardFeature, CardTransactionFeature, ConsecutiveDeclinesFeature, ExternalBankAccountFeature, IPMetadataFeature, PaymentVelocityFeature, SpendVelocityFeature, TokenizationFeature, TransactionHistorySignalsFeature
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Lithic::Models::AuthRules::RuleFeature::AuthorizationFeature, Lithic::Models::AuthRules::RuleFeature::AuthenticationFeature, Lithic::Models::AuthRules::RuleFeature::TokenizationFeature, Lithic::Models::AuthRules::RuleFeature::ACHReceiptFeature, Lithic::Models::AuthRules::RuleFeature::CardTransactionFeature, Lithic::Models::AuthRules::RuleFeature::ACHPaymentFeature, Lithic::Models::AuthRules::RuleFeature::ExternalBankAccountFeature, Lithic::Models::AuthRules::RuleFeature::CardFeature, Lithic::Models::AuthRules::RuleFeature::AccountHolderFeature, Lithic::Models::AuthRules::RuleFeature::IPMetadataFeature, Lithic::Models::AuthRules::RuleFeature::SpendVelocityFeature, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature, Lithic::Models::AuthRules::RuleFeature::TransactionHistorySignalsFeature, Lithic::Models::AuthRules::RuleFeature::ConsecutiveDeclinesFeature, Lithic::Models::AuthRules::RuleFeature::ACHPaymentHistoryFeature)
Instance Method Summary collapse
- #initialize(name: nil, type: :IP_METADATA) ⇒ Object
- #self?.variants ⇒ ::Array[Lithic::Models::AuthRules::rule_feature]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 310
|
.variants ⇒ Array(Lithic::Models::AuthRules::RuleFeature::AuthorizationFeature, Lithic::Models::AuthRules::RuleFeature::AuthenticationFeature, Lithic::Models::AuthRules::RuleFeature::TokenizationFeature, Lithic::Models::AuthRules::RuleFeature::ACHReceiptFeature, Lithic::Models::AuthRules::RuleFeature::CardTransactionFeature, Lithic::Models::AuthRules::RuleFeature::ACHPaymentFeature, Lithic::Models::AuthRules::RuleFeature::ExternalBankAccountFeature, Lithic::Models::AuthRules::RuleFeature::CardFeature, Lithic::Models::AuthRules::RuleFeature::AccountHolderFeature, Lithic::Models::AuthRules::RuleFeature::IPMetadataFeature, Lithic::Models::AuthRules::RuleFeature::SpendVelocityFeature, Lithic::Models::AuthRules::RuleFeature::PaymentVelocityFeature, Lithic::Models::AuthRules::RuleFeature::TransactionHistorySignalsFeature, Lithic::Models::AuthRules::RuleFeature::ConsecutiveDeclinesFeature, Lithic::Models::AuthRules::RuleFeature::ACHPaymentHistoryFeature)
|
|
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 606
|
Instance Method Details
#initialize(name: nil, type: :IP_METADATA) ⇒ Object
|
|
# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 93
|
#self?.variants ⇒ ::Array[Lithic::Models::AuthRules::rule_feature]
494 |
# File 'sig/lithic/models/auth_rules/rule_feature.rbs', line 494
def self?.variants: -> ::Array[Lithic::Models::AuthRules::rule_feature]
|