Module: Lithic::Models::AuthRules::RuleFeature

Extended by:
Internal::Type::Union
Defined in:
lib/lithic/models/auth_rules/rule_feature.rb

Overview

A feature made available to the rule. The ‘name` field is the variable name used in the rule function signature. The `type` field determines which data the feature provides to the rule at evaluation time.

  • ‘AUTHORIZATION`: The authorization request being evaluated. Only available for AUTHORIZATION event stream rules.

  • ‘AUTHENTICATION`: The 3DS authentication request being evaluated. Only available for THREE_DS_AUTHENTICATION event stream rules.

  • ‘TOKENIZATION`: The tokenization request being evaluated. Only available for TOKENIZATION event stream rules.

  • ‘ACH_RECEIPT`: The ACH receipt being evaluated. Only available for ACH_CREDIT_RECEIPT and ACH_DEBIT_RECEIPT event stream rules.

  • ‘CARD`: The card associated with the event. Available for AUTHORIZATION and THREE_DS_AUTHENTICATION event stream rules.

  • ‘ACCOUNT_HOLDER`: The account holder associated with the card. Available for AUTHORIZATION and THREE_DS_AUTHENTICATION event stream rules.

  • ‘IP_METADATA`: IP address metadata for the request. Available for THREE_DS_AUTHENTICATION event stream rules.

  • ‘SPEND_VELOCITY`: Spend velocity data for the card or account. Requires `scope`, `period`, and optionally `filters` to configure the velocity calculation. Available for AUTHORIZATION event stream rules.

Defined Under Namespace

Classes: ACHReceiptFeature, AccountHolderFeature, AuthenticationFeature, AuthorizationFeature, CardFeature, IPMetadataFeature, SpendVelocityFeature, TokenizationFeature

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(name: nil, type: :IP_METADATA) ⇒ Object

Parameters:

  • name (String) (defaults to: nil)

    The variable name for this feature in the rule function signature

  • type (Symbol, :IP_METADATA) (defaults to: :IP_METADATA)


# File 'lib/lithic/models/auth_rules/rule_feature.rb', line 58