Class: Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_create_params.rb

Defined Under Namespace

Modules: Parameters, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_tokens:, parameters:, type:, event_stream: nil, name: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule for more details.



# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 205

Instance Attribute Details

#card_tokensArray<String>

Card tokens to which the Auth Rule applies.

Returns:

  • (Array<String>)


165
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 165

required :card_tokens, Lithic::Internal::Type::ArrayOf[String]

#event_streamSymbol, ...

The event stream during which the rule will be evaluated.

Returns:



197
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 197

optional :event_stream, enum: -> { Lithic::AuthRules::EventStream }

#nameString?

Auth Rule Name

Returns:

  • (String, nil)


203
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 203

optional :name, String, nil?: true

#typeSymbol, Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule::Type

The type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate ‘event_stream` field.

  • ‘CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead. AUTHORIZATION event stream.

  • ‘VELOCITY_LIMIT`: AUTHORIZATION event stream.

  • ‘MERCHANT_LOCK`: AUTHORIZATION event stream.

  • ‘CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, or CARD_TRANSACTION_UPDATE event stream.

  • ‘TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, or CARD_TRANSACTION_UPDATE event stream.



191
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 191

required :type, enum: -> { Lithic::AuthRules::V2CreateParams::Body::CardLevelRule::Type }