Class: Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule
- Defined in:
- lib/lithic/models/auth_rules/v2_create_params.rb
Defined Under Namespace
Modules: Parameters, Type
Instance Attribute Summary collapse
-
#card_tokens ⇒ Array<String>
Card tokens to which the Auth Rule applies.
-
#event_stream ⇒ Symbol, ...
The event stream during which the rule will be evaluated.
-
#name ⇒ String?
Auth Rule Name.
-
#parameters ⇒ Lithic::Models::AuthRules::ConditionalBlockParameters, ...
Parameters for the Auth Rule.
-
#type ⇒ Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule::Type
The type of Auth Rule.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(card_tokens:, parameters:, type:, event_stream: nil, name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardLevelRule for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(card_tokens:, parameters:, type:, event_stream: nil, name: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule for more details.
|
|
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 200
|
Instance Attribute Details
#card_tokens ⇒ Array<String>
Card tokens to which the Auth Rule applies.
161 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 161 required :card_tokens, Lithic::Internal::Type::ArrayOf[String] |
#event_stream ⇒ Symbol, ...
The event stream during which the rule will be evaluated.
192 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 192 optional :event_stream, enum: -> { Lithic::AuthRules::EventStream } |
#name ⇒ String?
Auth Rule Name
198 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 198 optional :name, String, nil?: true |
#parameters ⇒ Lithic::Models::AuthRules::ConditionalBlockParameters, ...
Parameters for the Auth Rule
167 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 167 required :parameters, union: -> { Lithic::AuthRules::V2CreateParams::Body::CardLevelRule::Parameters } |
#type ⇒ Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::CardLevelRule::Type
The type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate ‘event_stream` field.
-
‘CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead. AUTHORIZATION event stream.
-
‘VELOCITY_LIMIT`: AUTHORIZATION event stream.
-
‘MERCHANT_LOCK`: AUTHORIZATION event stream.
-
‘CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, or CARD_TRANSACTION_UPDATE event stream.
-
‘TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
186 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 186 required :type, enum: -> { Lithic::AuthRules::V2CreateParams::Body::CardLevelRule::Type } |
Class Method Details
.variants ⇒ Array(Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::ConditionalCardTransactionUpdateActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters)
|
|
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 241
|