Class: Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule
- Defined in:
- lib/lithic/models/auth_rules/v2_create_params.rb
Defined Under Namespace
Modules: Parameters, Type
Instance Attribute Summary collapse
-
#event_stream ⇒ Symbol, ...
The event stream during which the rule will be evaluated.
-
#excluded_account_tokens ⇒ Array<String>?
Account tokens to which the Auth Rule does not apply.
-
#excluded_business_account_tokens ⇒ Array<String>?
Business account tokens to which the Auth Rule does not apply.
-
#excluded_card_tokens ⇒ Array<String>?
Card tokens to which the Auth Rule does not apply.
-
#name ⇒ String?
Auth Rule Name.
-
#parameters ⇒ Lithic::Models::AuthRules::ConditionalBlockParameters, ...
Parameters for the Auth Rule.
-
#program_level ⇒ Boolean
Whether the Auth Rule applies to all authorizations on the card program.
-
#type ⇒ Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule::Type
The type of Auth Rule.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(parameters:, program_level:, type:, event_stream: nil, excluded_account_tokens: nil, excluded_business_account_tokens: nil, excluded_card_tokens: nil, name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProgramLevelRule for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(parameters:, program_level:, type:, event_stream: nil, excluded_account_tokens: nil, excluded_business_account_tokens: nil, excluded_card_tokens: nil, name: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule for more details.
|
|
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 328
|
Instance Attribute Details
#event_stream ⇒ Symbol, ...
The event stream during which the rule will be evaluated.
302 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 302 optional :event_stream, enum: -> { Lithic::AuthRules::EventStream } |
#excluded_account_tokens ⇒ Array<String>?
Account tokens to which the Auth Rule does not apply.
308 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 308 optional :excluded_account_tokens, Lithic::Internal::Type::ArrayOf[String] |
#excluded_business_account_tokens ⇒ Array<String>?
Business account tokens to which the Auth Rule does not apply.
314 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 314 optional :excluded_business_account_tokens, Lithic::Internal::Type::ArrayOf[String] |
#excluded_card_tokens ⇒ Array<String>?
Card tokens to which the Auth Rule does not apply.
320 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 320 optional :excluded_card_tokens, Lithic::Internal::Type::ArrayOf[String] |
#name ⇒ String?
Auth Rule Name
326 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 326 optional :name, String, nil?: true |
#parameters ⇒ Lithic::Models::AuthRules::ConditionalBlockParameters, ...
Parameters for the Auth Rule
272 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 272 required :parameters, union: -> { Lithic::AuthRules::V2CreateParams::Body::ProgramLevelRule::Parameters } |
#program_level ⇒ Boolean
Whether the Auth Rule applies to all authorizations on the card program.
278 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 278 required :program_level, Lithic::Internal::Type::Boolean |
#type ⇒ Symbol, Lithic::Models::AuthRules::V2CreateParams::Body::ProgramLevelRule::Type
The type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate ‘event_stream` field.
-
‘CONDITIONAL_BLOCK`: Deprecated. Use `CONDITIONAL_ACTION` instead. AUTHORIZATION event stream.
-
‘VELOCITY_LIMIT`: AUTHORIZATION event stream.
-
‘MERCHANT_LOCK`: AUTHORIZATION event stream.
-
‘CONDITIONAL_ACTION`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
-
‘TYPESCRIPT_CODE`: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
296 |
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 296 required :type, enum: -> { Lithic::AuthRules::V2CreateParams::Body::ProgramLevelRule::Type } |
Class Method Details
.variants ⇒ Array(Lithic::Models::AuthRules::ConditionalBlockParameters, Lithic::Models::AuthRules::VelocityLimitParams, Lithic::Models::AuthRules::MerchantLockParameters, Lithic::Models::AuthRules::Conditional3DSActionParameters, Lithic::Models::AuthRules::ConditionalAuthorizationActionParameters, Lithic::Models::AuthRules::ConditionalACHActionParameters, Lithic::Models::AuthRules::ConditionalTokenizationActionParameters, Lithic::Models::AuthRules::TypescriptCodeParameters)
|
|
# File 'lib/lithic/models/auth_rules/v2_create_params.rb', line 373
|