Class: Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult
- Defined in:
- lib/lithic/models/auth_rules/v2_list_results_response.rb
Defined Under Namespace
Modules: Action, EventStream, Mode
Instance Attribute Summary collapse
-
#actions ⇒ Array<Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction>
Actions returned by the rule evaluation.
-
#auth_rule_token ⇒ String
The Auth Rule token.
-
#evaluation_time ⇒ Time
Timestamp of the rule evaluation.
-
#event_stream ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::EventStream
The event stream during which the rule was evaluated.
-
#event_token ⇒ String
Token of the event that triggered the evaluation.
-
#mode ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Mode
The state of the Auth Rule.
-
#rule_version ⇒ Integer
Version of the rule that was evaluated.
-
#token ⇒ String
Globally unique identifier for the evaluation.
-
#transaction_token ⇒ String?
The token of the transaction that triggered the rule evaluation.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction)
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Lithic::Internal::Type::BaseModel
Instance Attribute Details
#actions ⇒ Array<Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction>
Actions returned by the rule evaluation
618 619 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 618 required :actions, -> { Lithic::Internal::Type::ArrayOf[union: Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action] } |
#auth_rule_token ⇒ String
The Auth Rule token
625 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 625 required :auth_rule_token, String |
#evaluation_time ⇒ Time
Timestamp of the rule evaluation
631 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 631 required :evaluation_time, Time |
#event_stream ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::EventStream
The event stream during which the rule was evaluated
637 638 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 637 required :event_stream, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::EventStream } |
#event_token ⇒ String
Token of the event that triggered the evaluation
644 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 644 required :event_token, String |
#mode ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Mode
The state of the Auth Rule
650 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 650 required :mode, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Mode } |
#rule_version ⇒ Integer
Version of the rule that was evaluated
656 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 656 required :rule_version, Integer |
#token ⇒ String
Globally unique identifier for the evaluation
612 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 612 required :token, String |
#transaction_token ⇒ String?
The token of the transaction that triggered the rule evaluation
662 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 662 required :transaction_token, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 847
|
.variants ⇒ Array(Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ApproveActionACH, Lithic::Models::AuthRules::V2ListResultsResponse::ACHResult::Action::ReturnAction)
|
|
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 852
|