Class: Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/v2_list_results_response.rb

Defined Under Namespace

Modules: Mode Classes: Action

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Lithic::Internal::Type::BaseModel

Instance Attribute Details

#actionsArray<Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action>

Actions returned by the rule evaluation



270
271
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 270

required :actions,
-> { Lithic::Internal::Type::ArrayOf[Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Action] }

#auth_rule_tokenString

The Auth Rule token

Returns:

  • (String)


277
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 277

required :auth_rule_token, String

#evaluation_timeTime

Timestamp of the rule evaluation

Returns:

  • (Time)


283
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 283

required :evaluation_time, Time

#event_streamSymbol, :THREE_DS_AUTHENTICATION

The event stream during which the rule was evaluated

Returns:

  • (Symbol, :THREE_DS_AUTHENTICATION)


289
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 289

required :event_stream, const: :THREE_DS_AUTHENTICATION

#event_tokenString

Token of the event that triggered the evaluation

Returns:

  • (String)


295
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 295

required :event_token, String

#modeSymbol, Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Mode

The state of the Auth Rule



301
302
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 301

required :mode,
enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::Authentication3DSResult::Mode }

#rule_versionInteger

Version of the rule that was evaluated

Returns:

  • (Integer)


308
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 308

required :rule_version, Integer

#tokenString

Globally unique identifier for the evaluation

Returns:

  • (String)


264
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 264

required :token, String

#transaction_tokenString?

The token of the transaction that triggered the rule evaluation

Returns:

  • (String, nil)


314
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 314

required :transaction_token, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 360