Class: Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult
- Defined in:
- lib/lithic/models/auth_rules/v2_list_results_response.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#actions ⇒ Array<Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction>
Actions returned by the rule evaluation.
-
#auth_rule_token ⇒ String
The Auth Rule token.
-
#evaluation_time ⇒ Time
Timestamp of the rule evaluation.
-
#event_stream ⇒ Symbol, :TOKENIZATION
The event stream during which the rule was evaluated.
-
#event_token ⇒ String
Token of the event that triggered the evaluation.
-
#mode ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Mode
The state of the Auth Rule.
-
#rule_version ⇒ Integer
Version of the rule that was evaluated.
-
#token ⇒ String
Globally unique identifier for the evaluation.
-
#transaction_token ⇒ String?
The token of the transaction that triggered the rule evaluation.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction)
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Lithic::Internal::Type::BaseModel
Instance Attribute Details
#actions ⇒ Array<Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction>
Actions returned by the rule evaluation
386 387 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 386 required :actions, -> { Lithic::Internal::Type::ArrayOf[union: Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action] } |
#auth_rule_token ⇒ String
The Auth Rule token
393 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 393 required :auth_rule_token, String |
#evaluation_time ⇒ Time
Timestamp of the rule evaluation
399 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 399 required :evaluation_time, Time |
#event_stream ⇒ Symbol, :TOKENIZATION
The event stream during which the rule was evaluated
405 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 405 required :event_stream, const: :TOKENIZATION |
#event_token ⇒ String
Token of the event that triggered the evaluation
411 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 411 required :event_token, String |
#mode ⇒ Symbol, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Mode
The state of the Auth Rule
417 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 417 required :mode, enum: -> { Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Mode } |
#rule_version ⇒ Integer
Version of the rule that was evaluated
423 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 423 required :rule_version, Integer |
#token ⇒ String
Globally unique identifier for the evaluation
380 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 380 required :token, String |
#transaction_token ⇒ String?
The token of the transaction that triggered the rule evaluation
429 |
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 429 required :transaction_token, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 584
|
.variants ⇒ Array(Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::DeclineActionTokenization, Lithic::Models::AuthRules::V2ListResultsResponse::TokenizationResult::Action::RequireTfaAction)
|
|
# File 'lib/lithic/models/auth_rules/v2_list_results_response.rb', line 589
|