Class: Lithic::Models::AuthRules::V2RetrieveReportResponse::DailyStatistic
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2RetrieveReportResponse::DailyStatistic
- Defined in:
- lib/lithic/models/auth_rules/v2_retrieve_report_response.rb
Instance Attribute Summary collapse
-
#date ⇒ Date
The date (UTC) for which the statistics are reported.
-
#versions ⇒ Array<Lithic::Models::AuthRules::ReportStats>
Statistics for each version of the rule that was evaluated during the reported day.
Instance Method Summary collapse
-
#initialize(date:, versions:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DailyStatistic for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(date:, versions:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2RetrieveReportResponse::DailyStatistic for more details.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/lithic/models/auth_rules/v2_retrieve_report_response.rb', line 42 class DailyStatistic < Lithic::Internal::Type::BaseModel # @!attribute date # The date (UTC) for which the statistics are reported. # # @return [Date] required :date, Date # @!attribute versions # Statistics for each version of the rule that was evaluated during the reported # day. # # @return [Array<Lithic::Models::AuthRules::ReportStats>] required :versions, -> { Lithic::Internal::Type::ArrayOf[Lithic::AuthRules::ReportStats] } # @!method initialize(date:, versions:) # Some parameter documentations has been truncated, see # {Lithic::Models::AuthRules::V2RetrieveReportResponse::DailyStatistic} for more # details. # # @param date [Date] The date (UTC) for which the statistics are reported. # # @param versions [Array<Lithic::Models::AuthRules::ReportStats>] Statistics for each version of the rule that was evaluated during the reported d end |
Instance Attribute Details
#date ⇒ Date
The date (UTC) for which the statistics are reported.
47 |
# File 'lib/lithic/models/auth_rules/v2_retrieve_report_response.rb', line 47 required :date, Date |
#versions ⇒ Array<Lithic::Models::AuthRules::ReportStats>
Statistics for each version of the rule that was evaluated during the reported day.
54 |
# File 'lib/lithic/models/auth_rules/v2_retrieve_report_response.rb', line 54 required :versions, -> { Lithic::Internal::Type::ArrayOf[Lithic::AuthRules::ReportStats] } |