Class: Lithic::Models::AuthRules::V2UpdateParams::Body::CardLevelRule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::V2UpdateParams::Body::CardLevelRule
- Defined in:
- lib/lithic/models/auth_rules/v2_update_params.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#card_tokens ⇒ Array<String>?
Card tokens to which the Auth Rule applies.
-
#name ⇒ String?
Auth Rule Name.
-
#state ⇒ Symbol, ...
The desired state of the Auth Rule.
Instance Method Summary collapse
-
#initialize(card_tokens: nil, name: nil, state: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardLevelRule for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(card_tokens: nil, name: nil, state: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::AuthRules::V2UpdateParams::Body::CardLevelRule for more details.
|
|
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 117
|
Instance Attribute Details
#card_tokens ⇒ Array<String>?
Card tokens to which the Auth Rule applies.
99 |
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 99 optional :card_tokens, Lithic::Internal::Type::ArrayOf[String] |
#name ⇒ String?
Auth Rule Name
105 |
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 105 optional :name, String, nil?: true |
#state ⇒ Symbol, ...
The desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
115 |
# File 'lib/lithic/models/auth_rules/v2_update_params.rb', line 115 optional :state, enum: -> { Lithic::AuthRules::V2UpdateParams::Body::CardLevelRule::State } |