Class: Lithic::Models::AuthRules::VelocityLimitFilters

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/auth_rules/velocity_limit_filters.rb

Defined Under Namespace

Modules: IncludePanEntryMode

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Lithic::Internal::Type::BaseModel

Instance Attribute Details

#exclude_countriesArray<String>?

ISO-3166-1 alpha-3 Country Codes to exclude from the velocity calculation. Transactions matching any of the provided will be excluded from the calculated velocity.

Returns:

  • (Array<String>, nil)


13
# File 'lib/lithic/models/auth_rules/velocity_limit_filters.rb', line 13

optional :exclude_countries, Lithic::Internal::Type::ArrayOf[String], nil?: true

#exclude_mccsArray<String>?

Merchant Category Codes to exclude from the velocity calculation. Transactions matching this MCC will be excluded from the calculated velocity.

Returns:

  • (Array<String>, nil)


20
# File 'lib/lithic/models/auth_rules/velocity_limit_filters.rb', line 20

optional :exclude_mccs, Lithic::Internal::Type::ArrayOf[String], nil?: true

#include_countriesArray<String>?

ISO-3166-1 alpha-3 Country Codes to include in the velocity calculation. Transactions not matching any of the provided will not be included in the calculated velocity.

Returns:

  • (Array<String>, nil)


28
# File 'lib/lithic/models/auth_rules/velocity_limit_filters.rb', line 28

optional :include_countries, Lithic::Internal::Type::ArrayOf[String], nil?: true

#include_mccsArray<String>?

Merchant Category Codes to include in the velocity calculation. Transactions not matching this MCC will not be included in the calculated velocity.

Returns:

  • (Array<String>, nil)


35
# File 'lib/lithic/models/auth_rules/velocity_limit_filters.rb', line 35

optional :include_mccs, Lithic::Internal::Type::ArrayOf[String], nil?: true

#include_pan_entry_modesArray<Symbol, Lithic::Models::AuthRules::VelocityLimitFilters::IncludePanEntryMode>?

PAN entry modes to include in the velocity calculation. Transactions not matching any of the provided will not be included in the calculated velocity.



42
43
44
45
46
# File 'lib/lithic/models/auth_rules/velocity_limit_filters.rb', line 42

optional :include_pan_entry_modes,
-> {
  Lithic::Internal::Type::ArrayOf[enum: Lithic::AuthRules::VelocityLimitFilters::IncludePanEntryMode]
},
nil?: true