Class: Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowMonth
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::AuthRules::VelocityLimitPeriod::FixedWindowMonth
- Defined in:
- lib/lithic/models/auth_rules/velocity_limit_period.rb,
sig/lithic/models/auth_rules/velocity_limit_period.rbs
Instance Attribute Summary collapse
-
#day_of_month ⇒ Integer?
The day of the month to start from.
- #type ⇒ Symbol, :MONTH
Instance Method Summary collapse
-
#initialize ⇒ FixedWindowMonth
constructor
A new instance of FixedWindowMonth.
- #to_hash ⇒ { type: :MONTH, day_of_month: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ FixedWindowMonth
Returns a new instance of FixedWindowMonth.
59 |
# File 'sig/lithic/models/auth_rules/velocity_limit_period.rbs', line 59
def initialize: (?day_of_month: Integer, ?type: :MONTH) -> void
|
Instance Attribute Details
#day_of_month ⇒ Integer?
The day of the month to start from. Accepts values from 1 to 31, and will reset at the end of the month if the day exceeds the number of days in the month. Defaults to the 1st of the month if not specified.
97 |
# File 'lib/lithic/models/auth_rules/velocity_limit_period.rb', line 97 optional :day_of_month, Integer |
#type ⇒ Symbol, :MONTH
89 |
# File 'lib/lithic/models/auth_rules/velocity_limit_period.rb', line 89 required :type, const: :MONTH |
Instance Method Details
#to_hash ⇒ { type: :MONTH, day_of_month: Integer }
61 |
# File 'sig/lithic/models/auth_rules/velocity_limit_period.rbs', line 61
def to_hash: -> { type: :MONTH, day_of_month: Integer }
|