Class: Lithic::Models::BlockchainRecipient
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::BlockchainRecipient
- Defined in:
- lib/lithic/models/blockchain_recipient.rb,
sig/lithic/models/blockchain_recipient.rbs
Overview
Defined Under Namespace
Modules: State, VerificationState
Instance Attribute Summary collapse
-
#account_token ⇒ String?
The financial account the blockchain recipient belongs to, or null when the recipient is registered against the program rather than a financial account.
-
#address_tag ⇒ String?
An optional tag or memo used by some chains to identify the destination of a transfer within a shared address.
-
#chain ⇒ String
The blockchain network that the address belongs to.
-
#created ⇒ Time
An ISO 8601 string representing when this blockchain recipient was created.
-
#external_id ⇒ String?
The identifier the recipient is registered under with the payment provider.
-
#name ⇒ String?
The nickname for this blockchain recipient.
-
#owner ⇒ String
Legal name of the business or individual who owns the blockchain address.
-
#owner_type ⇒ Symbol, Lithic::Models::OwnerType
Owner Type.
-
#program_id ⇒ String
Globally unique identifier for the program the blockchain recipient is associated with.
-
#state ⇒ Symbol, Lithic::Models::BlockchainRecipient::State
Account State.
-
#token ⇒ String
A globally unique identifier for this blockchain recipient.
-
#updated ⇒ Time
An ISO 8601 string representing when this blockchain recipient was last updated.
-
#verification_state ⇒ Symbol, Lithic::Models::BlockchainRecipient::VerificationState
Verification State.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, account_token:, address_tag:, chain:, created:, external_id:, name:, owner:, owner_type:, program_id:, state:, updated:, verification_state:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BlockchainRecipient for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, account_token:, address_tag:, chain:, created:, external_id:, name:, owner:, owner_type:, program_id:, state:, updated:, verification_state:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::BlockchainRecipient for more details.
|
|
# File 'lib/lithic/models/blockchain_recipient.rb', line 88
|
Instance Attribute Details
#account_token ⇒ String?
The financial account the blockchain recipient belongs to, or null when the recipient is registered against the program rather than a financial account
18 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 18 required :account_token, String, nil?: true |
#address_tag ⇒ String?
An optional tag or memo used by some chains to identify the destination of a transfer within a shared address
25 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 25 required :address_tag, String, nil?: true |
#chain ⇒ String
The blockchain network that the address belongs to
31 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 31 required :chain, String |
#created ⇒ Time
An ISO 8601 string representing when this blockchain recipient was created
37 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 37 required :created, Time |
#external_id ⇒ String?
The identifier the recipient is registered under with the payment provider
43 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 43 required :external_id, String, nil?: true |
#name ⇒ String?
The nickname for this blockchain recipient
49 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 49 required :name, String, nil?: true |
#owner ⇒ String
Legal name of the business or individual who owns the blockchain address
55 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 55 required :owner, String |
#owner_type ⇒ Symbol, Lithic::Models::OwnerType
Owner Type
61 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 61 required :owner_type, enum: -> { Lithic::OwnerType } |
#program_id ⇒ String
Globally unique identifier for the program the blockchain recipient is associated with
68 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 68 required :program_id, String |
#state ⇒ Symbol, Lithic::Models::BlockchainRecipient::State
Account State
74 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 74 required :state, enum: -> { Lithic::BlockchainRecipient::State } |
#token ⇒ String
A globally unique identifier for this blockchain recipient
11 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 11 required :token, String |
#updated ⇒ Time
An ISO 8601 string representing when this blockchain recipient was last updated
80 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 80 required :updated, Time |
#verification_state ⇒ Symbol, Lithic::Models::BlockchainRecipient::VerificationState
Verification State
86 |
# File 'lib/lithic/models/blockchain_recipient.rb', line 86 required :verification_state, enum: -> { Lithic::BlockchainRecipient::VerificationState } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/blockchain_recipient.rb', line 128
|
Instance Method Details
#to_hash ⇒ {
63 |
# File 'sig/lithic/models/blockchain_recipient.rbs', line 63
def to_hash: -> {
|