Class: Lithic::Models::BlockchainRecipientCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::BlockchainRecipientCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/blockchain_recipient_create_params.rb,
sig/lithic/models/blockchain_recipient_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#account_token ⇒ String
The financial account the blockchain recipient belongs to.
-
#address ⇒ String
The blockchain address funds will be withdrawn to.
-
#address_tag ⇒ String?
An optional tag or memo used by some chains to identify the destination of a transfer within a shared address.
-
#chain ⇒ String
The blockchain network that the address belongs to.
-
#name ⇒ String?
The nickname for this blockchain recipient.
-
#owner ⇒ String
Legal name of the business or individual who owns the blockchain address.
-
#owner_type ⇒ Symbol, Lithic::Models::OwnerType
Owner Type.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_token:, address:, chain:, owner:, owner_type:, address_tag: nil, name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BlockchainRecipientCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_token:, address:, chain:, owner:, owner_type:, address_tag: nil, name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::BlockchainRecipientCreateParams for more details.
|
|
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 53
|
Instance Attribute Details
#account_token ⇒ String
The financial account the blockchain recipient belongs to
14 |
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 14 required :account_token, String |
#address ⇒ String
The blockchain address funds will be withdrawn to
20 |
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 20 required :address, String |
#address_tag ⇒ String?
An optional tag or memo used by some chains to identify the destination of a transfer within a shared address
45 |
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 45 optional :address_tag, String |
#chain ⇒ String
The blockchain network that the address belongs to
26 |
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 26 required :chain, String |
#name ⇒ String?
The nickname for this blockchain recipient
51 |
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 51 optional :name, String |
#owner ⇒ String
Legal name of the business or individual who owns the blockchain address
32 |
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 32 required :owner, String |
#owner_type ⇒ Symbol, Lithic::Models::OwnerType
Owner Type
38 |
# File 'lib/lithic/models/blockchain_recipient_create_params.rb', line 38 required :owner_type, enum: -> { Lithic::OwnerType } |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/lithic/models/blockchain_recipient_create_params.rbs', line 48
def to_hash: -> {
|