Class: Lithic::Models::CardAuthorization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorization
- Defined in:
- lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs
Direct Known Subclasses
Defined Under Namespace
Modules: AccountType, Network, Status, TransactionInitiator Classes: Amounts, Avs, Card, FleetInfo, LatestChallenge, Merchant, NameValidation, NetworkSpecificData, Pos, ServiceLocation
Constant Summary collapse
- Lithic =
Instance Attribute Summary collapse
- #account_type ⇒ Symbol, ...
-
#acquirer_fee ⇒ Integer
Fee (in cents) assessed by the merchant and paid for by the cardholder.
- #amount ⇒ Integer deprecated Deprecated.
-
#amounts ⇒ Lithic::Models::CardAuthorization::Amounts
Structured amounts for this authorization.
- #authorization_amount ⇒ Integer deprecated Deprecated.
- #avs ⇒ Lithic::Models::CardAuthorization::Avs
-
#card ⇒ Lithic::Models::CardAuthorization::Card
Card object in ASA.
- #cardholder_authentication ⇒ Lithic::Models::CardholderAuthentication?
- #cardholder_currency ⇒ String deprecated Deprecated.
-
#cash_amount ⇒ Integer
The amount of cash requested by the cardholder, in the cardholder billing currency's smallest unit.
-
#cashback ⇒ Integer?
Deprecated, use
cash_amount. - #conversion_rate ⇒ Float? deprecated Deprecated.
-
#created ⇒ Time
Date and time when the transaction first occurred in UTC.
-
#event_token ⇒ String?
The event token associated with the authorization.
-
#fleet_info ⇒ Lithic::Models::CardAuthorization::FleetInfo?
Optional Object containing information if the Card is a part of a Fleet managed program.
-
#latest_challenge ⇒ Lithic::Models::CardAuthorization::LatestChallenge?
The latest Authorization Challenge that was issued to the cardholder for this merchant.
-
#merchant ⇒ Lithic::Models::CardAuthorization::Merchant
Merchant information including full location details.
- #merchant_amount ⇒ Integer deprecated Deprecated.
- #merchant_currency ⇒ String deprecated Deprecated.
-
#name_validation ⇒ Lithic::Models::CardAuthorization::NameValidation?
Network name validation data, present when the card network requested name validation for this transaction.
-
#network ⇒ Symbol, ...
Card network of the authorization.
-
#network_risk_score ⇒ Integer?
Network-provided score assessing risk level associated with a given authorization.
-
#network_specific_data ⇒ Lithic::Models::CardAuthorization::NetworkSpecificData?
Contains raw data provided by the card network, including attributes that provide further context about the authorization.
- #pos ⇒ Lithic::Models::CardAuthorization::Pos?
-
#service_location ⇒ Lithic::Models::CardAuthorization::ServiceLocation?
Where the cardholder received the service, when different from the card acceptor location.
- #settled_amount ⇒ Integer deprecated Deprecated.
-
#status ⇒ Symbol, Lithic::Models::CardAuthorization::Status
The type of authorization request that this request is for.
-
#token ⇒ String
The provisional transaction group uuid associated with the authorization.
- #token_info ⇒ Lithic::Models::TokenInfo?
-
#transaction_initiator ⇒ Symbol, Lithic::Models::CardAuthorization::TransactionInitiator
The entity that initiated the transaction.
-
#ttl ⇒ Time?
Deprecated: approximate time-to-live for the authorization.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(business_application_identifier: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkSpecificData::Visa for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(business_application_identifier: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardAuthorization::NetworkSpecificData::Visa for more details.
|
|
# File 'lib/lithic/models/card_authorization.rb', line 245
|
Instance Attribute Details
#account_type ⇒ Symbol, ...
156 |
# File 'lib/lithic/models/card_authorization.rb', line 156 optional :account_type, enum: -> { Lithic::CardAuthorization::AccountType } |
#acquirer_fee ⇒ Integer
Fee (in cents) assessed by the merchant and paid for by the cardholder. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
18 |
# File 'lib/lithic/models/card_authorization.rb', line 18 required :acquirer_fee, Integer |
#amount ⇒ Integer
Deprecated, use amounts. Authorization amount of the transaction (in cents),
including any acquirer fees. The contents of this field are identical to
authorization_amount.
28 |
# File 'lib/lithic/models/card_authorization.rb', line 28 required :amount, Integer |
#amounts ⇒ Lithic::Models::CardAuthorization::Amounts
Structured amounts for this authorization. The cardholder and merchant
amounts reflect the original network authorization values. For programs with
hold adjustments enabled (e.g., automated fuel dispensers or tipping MCCs), the
hold amount may exceed the cardholder and merchant amounts to account for
anticipated final transaction amounts such as tips or fuel fill-ups
38 |
# File 'lib/lithic/models/card_authorization.rb', line 38 required :amounts, -> { Lithic::CardAuthorization::Amounts } |
#authorization_amount ⇒ Integer
Deprecated, use amounts. The base transaction amount (in cents) plus the
acquirer fee field. This is the amount the issuer should authorize against
unless the issuer is paying the acquirer fee on behalf of the cardholder.
48 |
# File 'lib/lithic/models/card_authorization.rb', line 48 required :authorization_amount, Integer |
#avs ⇒ Lithic::Models::CardAuthorization::Avs
53 |
# File 'lib/lithic/models/card_authorization.rb', line 53 required :avs, -> { Lithic::CardAuthorization::Avs } |
#card ⇒ Lithic::Models::CardAuthorization::Card
Card object in ASA
59 |
# File 'lib/lithic/models/card_authorization.rb', line 59 required :card, -> { Lithic::CardAuthorization::Card } |
#cardholder_authentication ⇒ Lithic::Models::CardholderAuthentication?
161 |
# File 'lib/lithic/models/card_authorization.rb', line 161 optional :cardholder_authentication, -> { Lithic::CardholderAuthentication } |
#cardholder_currency ⇒ String
Deprecated, use amounts. 3-character alphabetic ISO 4217 code for cardholder's
billing currency.
68 |
# File 'lib/lithic/models/card_authorization.rb', line 68 required :cardholder_currency, String |
#cash_amount ⇒ Integer
The amount of cash requested by the cardholder, in the cardholder billing currency's smallest unit. For purchase-with-cashback transactions this is the cashback portion only; for ATM transactions this is the full amount. This amount includes all acquirer fees.
If no cash was requested, the value of this field will be 0, and the field will always be present.
80 |
# File 'lib/lithic/models/card_authorization.rb', line 80 required :cash_amount, Integer |
#cashback ⇒ Integer?
Deprecated, use cash_amount.
167 |
# File 'lib/lithic/models/card_authorization.rb', line 167 optional :cashback, Integer |
#conversion_rate ⇒ Float?
Deprecated, use amounts. If the transaction was requested in a currency other
than the settlement currency, this field will be populated to indicate the rate
used to translate the merchant_amount to the amount (i.e., merchant_amount x
conversion_rate = amount). Note that the merchant_amount is in the local
currency and the amount is in the settlement currency.
179 |
# File 'lib/lithic/models/card_authorization.rb', line 179 optional :conversion_rate, Float |
#created ⇒ Time
Date and time when the transaction first occurred in UTC.
86 |
# File 'lib/lithic/models/card_authorization.rb', line 86 required :created, Time |
#event_token ⇒ String?
The event token associated with the authorization. This field is only set for programs enrolled into the beta.
186 |
# File 'lib/lithic/models/card_authorization.rb', line 186 optional :event_token, String |
#fleet_info ⇒ Lithic::Models::CardAuthorization::FleetInfo?
Optional Object containing information if the Card is a part of a Fleet managed program
193 |
# File 'lib/lithic/models/card_authorization.rb', line 193 optional :fleet_info, -> { Lithic::CardAuthorization::FleetInfo }, nil?: true |
#latest_challenge ⇒ Lithic::Models::CardAuthorization::LatestChallenge?
The latest Authorization Challenge that was issued to the cardholder for this merchant.
200 |
# File 'lib/lithic/models/card_authorization.rb', line 200 optional :latest_challenge, -> { Lithic::CardAuthorization::LatestChallenge } |
#merchant ⇒ Lithic::Models::CardAuthorization::Merchant
Merchant information including full location details.
92 |
# File 'lib/lithic/models/card_authorization.rb', line 92 required :merchant, -> { Lithic::CardAuthorization::Merchant } |
#merchant_amount ⇒ Integer
Deprecated, use amounts. The amount that the merchant will receive,
denominated in merchant_currency and in the smallest currency unit. Note the
amount includes acquirer_fee, similar to authorization_amount. It will be
different from authorization_amount if the merchant is taking payment in a
different currency.
104 |
# File 'lib/lithic/models/card_authorization.rb', line 104 required :merchant_amount, Integer |
#merchant_currency ⇒ String
3-character alphabetic ISO 4217 code for the local currency of the transaction.
112 |
# File 'lib/lithic/models/card_authorization.rb', line 112 required :merchant_currency, String |
#name_validation ⇒ Lithic::Models::CardAuthorization::NameValidation?
Network name validation data, present when the card network requested name validation for this transaction. Contains the cardholder name provided by the network and Lithic's computed match result against KYC data on file.
120 |
# File 'lib/lithic/models/card_authorization.rb', line 120 required :name_validation, -> { Lithic::CardAuthorization::NameValidation }, nil?: true |
#network ⇒ Symbol, ...
Card network of the authorization.
206 |
# File 'lib/lithic/models/card_authorization.rb', line 206 optional :network, enum: -> { Lithic::CardAuthorization::Network } |
#network_risk_score ⇒ Integer?
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
216 |
# File 'lib/lithic/models/card_authorization.rb', line 216 optional :network_risk_score, Integer, nil?: true |
#network_specific_data ⇒ Lithic::Models::CardAuthorization::NetworkSpecificData?
Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
227 |
# File 'lib/lithic/models/card_authorization.rb', line 227 optional :network_specific_data, -> { Lithic::CardAuthorization::NetworkSpecificData }, nil?: true |
#pos ⇒ Lithic::Models::CardAuthorization::Pos?
232 |
# File 'lib/lithic/models/card_authorization.rb', line 232 optional :pos, -> { Lithic::CardAuthorization::Pos } |
#service_location ⇒ Lithic::Models::CardAuthorization::ServiceLocation?
Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.
128 |
# File 'lib/lithic/models/card_authorization.rb', line 128 required :service_location, -> { Lithic::CardAuthorization::ServiceLocation }, nil?: true |
#settled_amount ⇒ Integer
Deprecated, use amounts. Amount (in cents) of the transaction that has been
settled, including any acquirer fees.
137 |
# File 'lib/lithic/models/card_authorization.rb', line 137 required :settled_amount, Integer |
#status ⇒ Symbol, Lithic::Models::CardAuthorization::Status
The type of authorization request that this request is for. Note that
CREDIT_AUTHORIZATION and FINANCIAL_CREDIT_AUTHORIZATION is only available to
users with credit decisioning via ASA enabled.
145 |
# File 'lib/lithic/models/card_authorization.rb', line 145 required :status, enum: -> { Lithic::CardAuthorization::Status } |
#token ⇒ String
The provisional transaction group uuid associated with the authorization
10 |
# File 'lib/lithic/models/card_authorization.rb', line 10 required :token, String |
#token_info ⇒ Lithic::Models::TokenInfo?
237 |
# File 'lib/lithic/models/card_authorization.rb', line 237 optional :token_info, -> { Lithic::TokenInfo }, nil?: true |
#transaction_initiator ⇒ Symbol, Lithic::Models::CardAuthorization::TransactionInitiator
The entity that initiated the transaction.
151 |
# File 'lib/lithic/models/card_authorization.rb', line 151 required :transaction_initiator, enum: -> { Lithic::CardAuthorization::TransactionInitiator } |
#ttl ⇒ Time?
Deprecated: approximate time-to-live for the authorization.
243 |
# File 'lib/lithic/models/card_authorization.rb', line 243 optional :ttl, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/card_authorization.rb', line 484
|
Instance Method Details
#to_hash ⇒ {
163 |
# File 'sig/lithic/models/card_authorization.rbs', line 163
def to_hash: -> {
|