Module: Lithic::Models::CardAuthorization::Avs::AddressOnFileMatch
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs
Overview
Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
Constant Summary collapse
- MATCH =
:MATCH- MATCH_ADDRESS_ONLY =
:MATCH_ADDRESS_ONLY- MATCH_ZIP_ONLY =
:MATCH_ZIP_ONLY- MISMATCH =
:MISMATCH- NOT_PRESENT =
:NOT_PRESENT
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::CardAuthorization::Avs::address_on_file_match]
330 |
# File 'sig/lithic/models/card_authorization.rbs', line 330
def self?.values: -> ::Array[Lithic::Models::CardAuthorization::Avs::address_on_file_match]
|