Module: Lithic::Models::CardAuthorization::FleetInfo::FleetRestrictionCode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs
Overview
Code indicating which restrictions, if any, there are on purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis
Constant Summary collapse
- NO_RESTRICTIONS =
:NO_RESTRICTIONS- FUEL_ONLY =
:FUEL_ONLY
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::CardAuthorization::FleetInfo::fleet_restriction_code]
656 |
# File 'sig/lithic/models/card_authorization.rbs', line 656
def self?.values: -> ::Array[Lithic::Models::CardAuthorization::FleetInfo::fleet_restriction_code]
|