Class: Lithic::Models::CardAuthorization::LatestChallenge
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorization::LatestChallenge
- Defined in:
- lib/lithic/models/card_authorization.rb,
sig/lithic/models/card_authorization.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#completed_at ⇒ Time?
The date and time when the Authorization Challenge was completed in UTC.
-
#created ⇒ Time
The date and time when the Authorization Challenge was created in UTC.
-
#method_ ⇒ Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Method
The method used to deliver the challenge to the cardholder.
-
#phone_number ⇒ String?
The phone number used for sending the Authorization Challenge.
-
#status ⇒ Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Status
The status of the Authorization Challenge.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(completed_at:, created:, method_:, phone_number:, status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see LatestChallenge for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, created:, method_:, phone_number:, status:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardAuthorization::LatestChallenge for more details.
The latest Authorization Challenge that was issued to the cardholder for this merchant.
|
|
# File 'lib/lithic/models/card_authorization.rb', line 936
|
Instance Attribute Details
#completed_at ⇒ Time?
The date and time when the Authorization Challenge was completed in UTC. Filled only if the challenge has been completed.
900 |
# File 'lib/lithic/models/card_authorization.rb', line 900 required :completed_at, Time, nil?: true |
#created ⇒ Time
The date and time when the Authorization Challenge was created in UTC
906 |
# File 'lib/lithic/models/card_authorization.rb', line 906 required :created, Time |
#method_ ⇒ Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Method
The method used to deliver the challenge to the cardholder
SMS- Challenge was delivered via SMSOUT_OF_BAND- Challenge was delivered via an out-of-band method
915 |
# File 'lib/lithic/models/card_authorization.rb', line 915 required :method_, enum: -> { Lithic::CardAuthorization::LatestChallenge::Method }, api_name: :method |
#phone_number ⇒ String?
The phone number used for sending the Authorization Challenge. Present only when
the challenge method is SMS.
922 |
# File 'lib/lithic/models/card_authorization.rb', line 922 required :phone_number, String, nil?: true |
#status ⇒ Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Status
The status of the Authorization Challenge
COMPLETED- Challenge was successfully completed by the cardholderDECLINED- Challenge was declined by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
934 |
# File 'lib/lithic/models/card_authorization.rb', line 934 required :status, enum: -> { Lithic::CardAuthorization::LatestChallenge::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/card_authorization.rb', line 965
|
Instance Method Details
#to_hash ⇒ {
688 |
# File 'sig/lithic/models/card_authorization.rbs', line 688
def to_hash: -> {
|