Class: Lithic::Models::CardAuthorization::LatestChallenge

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/card_authorization.rb

Overview

See Also:

Defined Under Namespace

Modules: Method, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(method_:, phone_number:, status:, completed_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardAuthorization::LatestChallenge for more details.

The latest Authorization Challenge that was issued to the cardholder for this merchant.

Parameters:



# File 'lib/lithic/models/card_authorization.rb', line 831

Instance Attribute Details

#completed_atTime?

The date and time when the Authorization Challenge was completed in UTC. Present only if the status is ‘COMPLETED`.

Returns:

  • (Time, nil)


829
# File 'lib/lithic/models/card_authorization.rb', line 829

optional :completed_at, Time

#method_Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Method

The method used to deliver the challenge to the cardholder

  • ‘SMS` - Challenge was delivered via SMS

  • ‘OUT_OF_BAND` - Challenge was delivered via an out-of-band method



803
# File 'lib/lithic/models/card_authorization.rb', line 803

required :method_, enum: -> { Lithic::CardAuthorization::LatestChallenge::Method }, api_name: :method

#phone_numberString?

The phone number used for sending the Authorization Challenge. Present only when the challenge method is ‘SMS`.

Returns:

  • (String, nil)


810
# File 'lib/lithic/models/card_authorization.rb', line 810

required :phone_number, String, nil?: true

#statusSymbol, Lithic::Models::CardAuthorization::LatestChallenge::Status

The status of the Authorization Challenge

  • ‘COMPLETED` - Challenge was successfully completed by the cardholder

  • ‘DECLINED` - Challenge was declined by the cardholder

  • ‘PENDING` - Challenge is still open

  • ‘EXPIRED` - Challenge has expired without being completed

  • ‘ERROR` - There was an error processing the challenge



822
# File 'lib/lithic/models/card_authorization.rb', line 822

required :status, enum: -> { Lithic::CardAuthorization::LatestChallenge::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/card_authorization.rb', line 858