Class: Lithic::Models::CardAuthorization::LatestChallenge
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorization::LatestChallenge
- Defined in:
- lib/lithic/models/card_authorization.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#completed_at ⇒ Time?
The date and time when the Authorization Challenge was completed in UTC.
-
#method_ ⇒ Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Method
The method used to deliver the challenge to the cardholder.
-
#phone_number ⇒ String?
The phone number used for sending the Authorization Challenge.
-
#status ⇒ Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Status
The status of the Authorization Challenge.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(method_:, phone_number:, status:, completed_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LatestChallenge for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(method_:, phone_number:, status:, completed_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardAuthorization::LatestChallenge for more details.
The latest Authorization Challenge that was issued to the cardholder for this merchant.
|
|
# File 'lib/lithic/models/card_authorization.rb', line 831
|
Instance Attribute Details
#completed_at ⇒ Time?
The date and time when the Authorization Challenge was completed in UTC. Present only if the status is ‘COMPLETED`.
829 |
# File 'lib/lithic/models/card_authorization.rb', line 829 optional :completed_at, Time |
#method_ ⇒ Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Method
The method used to deliver the challenge to the cardholder
-
‘SMS` - Challenge was delivered via SMS
-
‘OUT_OF_BAND` - Challenge was delivered via an out-of-band method
803 |
# File 'lib/lithic/models/card_authorization.rb', line 803 required :method_, enum: -> { Lithic::CardAuthorization::LatestChallenge::Method }, api_name: :method |
#phone_number ⇒ String?
The phone number used for sending the Authorization Challenge. Present only when the challenge method is ‘SMS`.
810 |
# File 'lib/lithic/models/card_authorization.rb', line 810 required :phone_number, String, nil?: true |
#status ⇒ Symbol, Lithic::Models::CardAuthorization::LatestChallenge::Status
The status of the Authorization Challenge
-
‘COMPLETED` - Challenge was successfully completed by the cardholder
-
‘DECLINED` - Challenge was declined by the cardholder
-
‘PENDING` - Challenge is still open
-
‘EXPIRED` - Challenge has expired without being completed
-
‘ERROR` - There was an error processing the challenge
822 |
# File 'lib/lithic/models/card_authorization.rb', line 822 required :status, enum: -> { Lithic::CardAuthorization::LatestChallenge::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/card_authorization.rb', line 858
|