Class: Lithic::Models::CardAuthorization::NetworkSpecificData::Mastercard
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorization::NetworkSpecificData::Mastercard
- Defined in:
- lib/lithic/models/card_authorization.rb
Overview
Defined Under Namespace
Classes: OnBehalfServiceResult
Instance Attribute Summary collapse
-
#ecommerce_security_level_indicator ⇒ String?
Indicates the electronic commerce security level and UCAF collection.
-
#on_behalf_service_result ⇒ Array<Lithic::Models::CardAuthorization::NetworkSpecificData::Mastercard::OnBehalfServiceResult>?
The On-behalf Service performed on the transaction and the results.
-
#transaction_type_identifier ⇒ String?
Indicates the type of additional transaction purpose.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Lithic::Internal::Type::BaseModel
Instance Attribute Details
#ecommerce_security_level_indicator ⇒ String?
Indicates the electronic commerce security level and UCAF collection.
931 |
# File 'lib/lithic/models/card_authorization.rb', line 931 optional :ecommerce_security_level_indicator, String, nil?: true |
#on_behalf_service_result ⇒ Array<Lithic::Models::CardAuthorization::NetworkSpecificData::Mastercard::OnBehalfServiceResult>?
The On-behalf Service performed on the transaction and the results. Contains all applicable, on-behalf service results that were performed on a given transaction.
939 940 941 942 943 |
# File 'lib/lithic/models/card_authorization.rb', line 939 optional :on_behalf_service_result, -> { Lithic::Internal::Type::ArrayOf[Lithic::CardAuthorization::NetworkSpecificData::Mastercard::OnBehalfServiceResult] }, nil?: true |
#transaction_type_identifier ⇒ String?
Indicates the type of additional transaction purpose.
949 |
# File 'lib/lithic/models/card_authorization.rb', line 949 optional :transaction_type_identifier, String, nil?: true |