Class: Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/card_authorization_approval_request_webhook_event.rb

Defined Under Namespace

Modules: AccountType, Network, Status, TransactionInitiator Classes: Amounts, Avs, Card, FleetInfo, LatestChallenge, Merchant, NetworkSpecificData, Pos, ServiceLocation

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(business_application_identifier: nil) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::NetworkSpecificData::Visa for more details.

Parameters:

  • business_application_identifier (String, nil) (defaults to: nil)

    Identifies the purpose or category of a transaction, used to classify and proces



# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 246

Instance Attribute Details

#account_typeSymbol, ...



155
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 155

optional :account_type, enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::AccountType }

#acquirer_feeInteger

Fee (in cents) assessed by the merchant and paid for by the cardholder. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.

Returns:

  • (Integer)


18
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 18

required :acquirer_fee, Integer

#amountInteger

Deprecated.

Deprecated, use ‘amounts`. Authorization amount of the transaction (in cents), including any acquirer fees. The contents of this field are identical to `authorization_amount`.

Returns:

  • (Integer)


28
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 28

required :amount, Integer

#amountsLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Amounts

Structured amounts for this authorization. The ‘cardholder` and `merchant` amounts reflect the original network authorization values. For programs with hold adjustments enabled (e.g., automated fuel dispensers or tipping MCCs), the `hold` amount may exceed the `cardholder` and `merchant` amounts to account for anticipated final transaction amounts such as tips or fuel fill-ups



38
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 38

required :amounts, -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Amounts }

#authorization_amountInteger

Deprecated.

Deprecated, use ‘amounts`. The base transaction amount (in cents) plus the acquirer fee field. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.

Returns:

  • (Integer)


48
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 48

required :authorization_amount, Integer

#avsLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Avs



53
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 53

required :avs, -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Avs }

#cardLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Card

Card object in ASA



59
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 59

required :card, -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Card }

#cardholder_authenticationLithic::Models::CardholderAuthentication?



160
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 160

optional :cardholder_authentication, -> { Lithic::CardholderAuthentication }

#cardholder_currencyString

Deprecated.

Deprecated, use ‘amounts`. 3-character alphabetic ISO 4217 code for cardholder’s billing currency.

Returns:

  • (String)


68
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 68

required :cardholder_currency, String

#cash_amountInteger

The portion of the transaction requested as cash back by the cardholder, and does not include any acquirer fees. The amount field includes the purchase amount, the requested cash back amount, and any acquirer fees.

If no cash back was requested, the value of this field will be 0, and the field will always be present.

Returns:

  • (Integer)


79
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 79

required :cash_amount, Integer

#cashbackInteger?

Deprecated, use ‘cash_amount`.

Returns:

  • (Integer, nil)


166
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 166

optional :cashback, Integer

#conversion_rateFloat?

Deprecated.

Deprecated, use ‘amounts`. If the transaction was requested in a currency other than the settlement currency, this field will be populated to indicate the rate used to translate the merchant_amount to the amount (i.e., `merchant_amount` x `conversion_rate` = `amount`). Note that the `merchant_amount` is in the local currency and the amount is in the settlement currency.

Returns:

  • (Float, nil)


178
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 178

optional :conversion_rate, Float

#createdTime

Date and time when the transaction first occurred in UTC.

Returns:

  • (Time)


85
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 85

required :created, Time

#event_tokenString?

The event token associated with the authorization. This field is only set for programs enrolled into the beta.

Returns:

  • (String, nil)


185
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 185

optional :event_token, String

#event_typeSymbol, :"card_authorization.approval_request"

Returns:

  • (Symbol, :"card_authorization.approval_request")


90
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 90

required :event_type, const: :"card_authorization.approval_request"

#fleet_infoLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::FleetInfo?

Optional Object containing information if the Card is a part of a Fleet managed program



192
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 192

optional :fleet_info, -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::FleetInfo }, nil?: true

#latest_challengeLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::LatestChallenge?

The latest Authorization Challenge that was issued to the cardholder for this merchant.



199
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 199

optional :latest_challenge, -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::LatestChallenge }

#merchantLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Merchant

Merchant information including full location details.



96
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 96

required :merchant, -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Merchant }

#merchant_amountInteger

Deprecated.

Deprecated, use ‘amounts`. The amount that the merchant will receive, denominated in `merchant_currency` and in the smallest currency unit. Note the amount includes `acquirer_fee`, similar to `authorization_amount`. It will be different from `authorization_amount` if the merchant is taking payment in a different currency.

Returns:

  • (Integer)


108
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 108

required :merchant_amount, Integer

#merchant_currencyString

Deprecated.

3-character alphabetic ISO 4217 code for the local currency of the transaction.

Returns:

  • (String)


116
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 116

required :merchant_currency, String

#networkSymbol, ...

Card network of the authorization.



205
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 205

optional :network, enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Network }

#network_risk_scoreInteger?

Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.

Returns:

  • (Integer, nil)


215
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 215

optional :network_risk_score, Integer, nil?: true

#network_specific_dataLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::NetworkSpecificData?

Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.



226
227
228
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 226

optional :network_specific_data,
-> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::NetworkSpecificData },
nil?: true

#posLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Pos?



233
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 233

optional :pos, -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Pos }

#service_locationLithic::Models::CardAuthorizationApprovalRequestWebhookEvent::ServiceLocation?

Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.



124
125
126
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 124

required :service_location,
-> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::ServiceLocation },
nil?: true

#settled_amountInteger

Deprecated.

Deprecated, use ‘amounts`. Amount (in cents) of the transaction that has been settled, including any acquirer fees.

Returns:

  • (Integer)


135
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 135

required :settled_amount, Integer

#statusSymbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::Status

The type of authorization request that this request is for. Note that ‘CREDIT_AUTHORIZATION` and `FINANCIAL_CREDIT_AUTHORIZATION` is only available to users with credit decisioning via ASA enabled.



143
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 143

required :status, enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::Status }

#tokenString

The provisional transaction group uuid associated with the authorization

Returns:

  • (String)


10
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 10

required :token, String

#token_infoLithic::Models::TokenInfo?

Returns:



238
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 238

optional :token_info, -> { Lithic::TokenInfo }, nil?: true

#transaction_initiatorSymbol, Lithic::Models::CardAuthorizationApprovalRequestWebhookEvent::TransactionInitiator

The entity that initiated the transaction.



149
150
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 149

required :transaction_initiator,
enum: -> { Lithic::CardAuthorizationApprovalRequestWebhookEvent::TransactionInitiator }

#ttlTime?

Deprecated: approximate time-to-live for the authorization.

Returns:

  • (Time, nil)


244
# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 244

optional :ttl, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/lithic/models/card_authorization_approval_request_webhook_event.rb', line 487