Class: Lithic::Models::CardAuthorizationChallengeResponseWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardAuthorizationChallengeResponseWebhookEvent
- Defined in:
- lib/lithic/models/card_authorization_challenge_response_webhook_event.rb
Defined Under Namespace
Modules: ChallengeMethod, Response
Instance Attribute Summary collapse
-
#card_token ⇒ String?
The token of the card associated with the challenge.
-
#challenge_method ⇒ Symbol, Lithic::Models::CardAuthorizationChallengeResponseWebhookEvent::ChallengeMethod
The method used to deliver the challenge to the cardholder.
-
#completed ⇒ Time?
The timestamp of when the challenge was completed.
-
#created ⇒ Time
The timestamp of when the challenge was created.
-
#event_token ⇒ String
Globally unique identifier for the event.
-
#event_type ⇒ Symbol, :"card_authorization.challenge_response"
Event type.
-
#response ⇒ Symbol, Lithic::Models::CardAuthorizationChallengeResponseWebhookEvent::Response
The cardholder’s response to the challenge.
-
#transaction_token ⇒ String?
The token of the transaction associated with the authorization event being challenged.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(card_token:, challenge_method:, completed:, created:, event_token:, response:, transaction_token:, event_type: :"card_authorization.challenge_response") ⇒ Object
constructor
Some parameter documentations has been truncated, see CardAuthorizationChallengeResponseWebhookEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(card_token:, challenge_method:, completed:, created:, event_token:, response:, transaction_token:, event_type: :"card_authorization.challenge_response") ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardAuthorizationChallengeResponseWebhookEvent for more details.
|
|
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 56
|
Instance Attribute Details
#card_token ⇒ String?
The token of the card associated with the challenge
10 |
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 10 required :card_token, String, nil?: true |
#challenge_method ⇒ Symbol, Lithic::Models::CardAuthorizationChallengeResponseWebhookEvent::ChallengeMethod
The method used to deliver the challenge to the cardholder
16 17 |
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 16 required :challenge_method, enum: -> { Lithic::CardAuthorizationChallengeResponseWebhookEvent::ChallengeMethod } |
#completed ⇒ Time?
The timestamp of when the challenge was completed
23 |
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 23 required :completed, Time, nil?: true |
#created ⇒ Time
The timestamp of when the challenge was created
29 |
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 29 required :created, Time |
#event_token ⇒ String
Globally unique identifier for the event
35 |
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 35 required :event_token, String |
#event_type ⇒ Symbol, :"card_authorization.challenge_response"
Event type
41 |
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 41 required :event_type, const: :"card_authorization.challenge_response" |
#response ⇒ Symbol, Lithic::Models::CardAuthorizationChallengeResponseWebhookEvent::Response
The cardholder’s response to the challenge
47 |
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 47 required :response, enum: -> { Lithic::CardAuthorizationChallengeResponseWebhookEvent::Response } |
#transaction_token ⇒ String?
The token of the transaction associated with the authorization event being challenged
54 |
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 54 required :transaction_token, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/card_authorization_challenge_response_webhook_event.rb', line 85
|