Class: Lithic::Models::CardProvisionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardProvisionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/card_provision_params.rb,
sig/lithic/models/card_provision_params.rbs
Overview
Defined Under Namespace
Modules: DigitalWallet
Instance Attribute Summary collapse
- #card_token ⇒ String
-
#certificate ⇒ String?
Only applicable if
digital_walletisAPPLE_PAY. -
#client_device_id ⇒ String?
Only applicable if
digital_walletisGOOGLE_PAYorSAMSUNG_PAY. -
#client_wallet_account_id ⇒ String?
Only applicable if
digital_walletisGOOGLE_PAYorSAMSUNG_PAY. -
#digital_wallet ⇒ Symbol, ...
Name of digital wallet provider.
-
#nonce ⇒ String?
Only applicable if
digital_walletisAPPLE_PAY. -
#nonce_signature ⇒ String?
Only applicable if
digital_walletisAPPLE_PAY.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(card_token:, certificate: nil, client_device_id: nil, client_wallet_account_id: nil, digital_wallet: nil, nonce: nil, nonce_signature: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardProvisionParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(card_token:, certificate: nil, client_device_id: nil, client_wallet_account_id: nil, digital_wallet: nil, nonce: nil, nonce_signature: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::CardProvisionParams for more details.
|
|
# File 'lib/lithic/models/card_provision_params.rb', line 64
|
Instance Attribute Details
#card_token ⇒ String
13 |
# File 'lib/lithic/models/card_provision_params.rb', line 13 required :card_token, String |
#certificate ⇒ String?
Only applicable if digital_wallet is APPLE_PAY. Omit to receive only
activationData in the response. Apple's public leaf certificate. Base64
encoded in PEM format with headers (-----BEGIN CERTIFICATE-----) and trailers
omitted. Provided by the device's wallet.
22 |
# File 'lib/lithic/models/card_provision_params.rb', line 22 optional :certificate, String |
#client_device_id ⇒ String?
Only applicable if digital_wallet is GOOGLE_PAY or SAMSUNG_PAY. Stable
device identification set by the wallet provider. Required for both wallets
regardless of network, though the value is only used for cards on the Visa
network and is ignored on Amex and Mastercard.
31 |
# File 'lib/lithic/models/card_provision_params.rb', line 31 optional :client_device_id, String |
#client_wallet_account_id ⇒ String?
Only applicable if digital_wallet is GOOGLE_PAY or SAMSUNG_PAY. Consumer
ID that identifies the wallet account holder entity. Required for both wallets
regardless of network, though the value is only used for cards on the Visa
network and is ignored on Amex and Mastercard.
40 |
# File 'lib/lithic/models/card_provision_params.rb', line 40 optional :client_wallet_account_id, String |
#digital_wallet ⇒ Symbol, ...
Name of digital wallet provider.
46 |
# File 'lib/lithic/models/card_provision_params.rb', line 46 optional :digital_wallet, enum: -> { Lithic::CardProvisionParams::DigitalWallet } |
#nonce ⇒ String?
Only applicable if digital_wallet is APPLE_PAY. Omit to receive only
activationData in the response. Base64 cryptographic nonce provided by the
device's wallet.
54 |
# File 'lib/lithic/models/card_provision_params.rb', line 54 optional :nonce, String |
#nonce_signature ⇒ String?
Only applicable if digital_wallet is APPLE_PAY. Omit to receive only
activationData in the response. Base64 cryptographic nonce provided by the
device's wallet.
62 |
# File 'lib/lithic/models/card_provision_params.rb', line 62 optional :nonce_signature, String |
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/lithic/models/card_provision_params.rbs', line 58 def to_hash: -> { |