Class: Lithic::Models::CardUpdatedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::CardUpdatedWebhookEvent
- Defined in:
- lib/lithic/models/card_updated_webhook_event.rb
Instance Attribute Summary collapse
-
#card_token ⇒ String
The token of the card that was updated.
-
#event_type ⇒ Symbol, :"card.updated"
The type of event that occurred.
-
#previous_fields ⇒ Object
The previous values of the fields that were updated.
-
#state ⇒ String
The current state of the card.
Instance Method Summary collapse
- #initialize(card_token:, previous_fields:, state:, event_type: :"card.updated") ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(card_token:, previous_fields:, state:, event_type: :"card.updated") ⇒ Object
|
|
# File 'lib/lithic/models/card_updated_webhook_event.rb', line 30
|
Instance Attribute Details
#card_token ⇒ String
The token of the card that was updated.
10 |
# File 'lib/lithic/models/card_updated_webhook_event.rb', line 10 required :card_token, String |
#event_type ⇒ Symbol, :"card.updated"
The type of event that occurred.
16 |
# File 'lib/lithic/models/card_updated_webhook_event.rb', line 16 required :event_type, const: :"card.updated" |
#previous_fields ⇒ Object
The previous values of the fields that were updated.
22 |
# File 'lib/lithic/models/card_updated_webhook_event.rb', line 22 required :previous_fields, Lithic::Internal::Type::Unknown |
#state ⇒ String
The current state of the card.
28 |
# File 'lib/lithic/models/card_updated_webhook_event.rb', line 28 required :state, String |