Class: Lithic::Models::EmbedViewedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::EmbedViewedWebhookEvent
- Defined in:
- lib/lithic/models/embed_viewed_webhook_event.rb,
sig/lithic/models/embed_viewed_webhook_event.rbs
Defined Under Namespace
Modules: EmbedType Classes: DeviceDetails
Instance Attribute Summary collapse
-
#account_token ⇒ String
The token of the account associated with the card.
-
#card_token ⇒ String
The token of the card whose details were revealed.
-
#device_details ⇒ Lithic::Models::EmbedViewedWebhookEvent::DeviceDetails
Details about the request that revealed the card detail.
-
#embed_type ⇒ Symbol, Lithic::Models::EmbedViewedWebhookEvent::EmbedType
The type of card detail that was revealed.
-
#event_type ⇒ Symbol, :"embed.viewed"
The type of event.
-
#session_id ⇒ String
The identifier shared by webhook events for the same embed session.
Instance Method Summary collapse
-
#initialize(ip_address:) ⇒ Object
constructor
Details about the request that revealed the card detail.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip_address:) ⇒ Object
Details about the request that revealed the card detail
|
|
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 42
|
Instance Attribute Details
#account_token ⇒ String
The token of the account associated with the card
10 |
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 10 required :account_token, String |
#card_token ⇒ String
The token of the card whose details were revealed
16 |
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 16 required :card_token, String |
#device_details ⇒ Lithic::Models::EmbedViewedWebhookEvent::DeviceDetails
Details about the request that revealed the card detail
22 |
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 22 required :device_details, -> { Lithic::EmbedViewedWebhookEvent::DeviceDetails } |
#embed_type ⇒ Symbol, Lithic::Models::EmbedViewedWebhookEvent::EmbedType
The type of card detail that was revealed
28 |
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 28 required :embed_type, enum: -> { Lithic::EmbedViewedWebhookEvent::EmbedType } |
#event_type ⇒ Symbol, :"embed.viewed"
The type of event
34 |
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 34 required :event_type, const: :"embed.viewed" |
#session_id ⇒ String
The identifier shared by webhook events for the same embed session.
40 |
# File 'lib/lithic/models/embed_viewed_webhook_event.rb', line 40 required :session_id, String |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/lithic/models/embed_viewed_webhook_event.rbs', line 35
def to_hash: -> {
|