Class: Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified
- Defined in:
- lib/lithic/models/external_bank_account_create_params.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#account_number ⇒ String
Account Number.
-
#account_token ⇒ String?
Indicates which Lithic account the external account is associated with.
-
#address ⇒ Lithic::Models::ExternalBankAccountAddress?
Address.
-
#company_id ⇒ String?
Optional field that helps identify bank accounts in receipts.
-
#country ⇒ String
The country that the bank account is located in using ISO 3166-1.
-
#currency ⇒ String
currency of the external account 3-character alphabetic ISO 4217 code.
-
#dob ⇒ Date?
Date of Birth of the Individual that owns the external bank account.
-
#doing_business_as ⇒ String?
Doing Business As.
-
#name ⇒ String?
The nickname for this External Bank Account.
-
#owner ⇒ String
Legal Name of the business or individual who owns the external account.
-
#owner_type ⇒ Symbol, Lithic::Models::OwnerType
Owner Type.
-
#routing_number ⇒ String
Routing Number.
-
#type ⇒ Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type
Account Type.
-
#user_defined_id ⇒ String?
User Defined ID.
-
#verification_method ⇒ Symbol, :EXTERNALLY_VERIFIED
Verification Method.
Instance Method Summary collapse
-
#initialize(account_number:, country:, currency:, owner:, owner_type:, routing_number:, type:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_method: :EXTERNALLY_VERIFIED) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternallyVerified for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number:, country:, currency:, owner:, owner_type:, routing_number:, type:, account_token: nil, address: nil, company_id: nil, dob: nil, doing_business_as: nil, name: nil, user_defined_id: nil, verification_method: :EXTERNALLY_VERIFIED) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified for more details.
|
|
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 285
|
Instance Attribute Details
#account_number ⇒ String
Account Number
195 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 195 required :account_number, String |
#account_token ⇒ String?
Indicates which Lithic account the external account is associated with. For external accounts that are associated with the program, account_token field returned will be null
247 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 247 optional :account_token, String |
#address ⇒ Lithic::Models::ExternalBankAccountAddress?
Address
253 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 253 optional :address, -> { Lithic::ExternalBankAccountAddress } |
#company_id ⇒ String?
Optional field that helps identify bank accounts in receipts
259 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 259 optional :company_id, String |
#country ⇒ String
The country that the bank account is located in using ISO 3166-1. We will only accept USA bank accounts e.g., USA
202 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 202 required :country, String |
#currency ⇒ String
currency of the external account 3-character alphabetic ISO 4217 code
208 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 208 required :currency, String |
#dob ⇒ Date?
Date of Birth of the Individual that owns the external bank account
265 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 265 optional :dob, Date |
#doing_business_as ⇒ String?
Doing Business As
271 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 271 optional :doing_business_as, String |
#name ⇒ String?
The nickname for this External Bank Account
277 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 277 optional :name, String |
#owner ⇒ String
Legal Name of the business or individual who owns the external account. This will appear in statements
215 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 215 required :owner, String |
#owner_type ⇒ Symbol, Lithic::Models::OwnerType
Owner Type
221 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 221 required :owner_type, enum: -> { Lithic::OwnerType } |
#routing_number ⇒ String
Routing Number
227 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 227 required :routing_number, String |
#type ⇒ Symbol, Lithic::Models::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type
Account Type
233 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 233 required :type, enum: -> { Lithic::ExternalBankAccountCreateParams::Body::ExternallyVerified::Type } |
#user_defined_id ⇒ String?
User Defined ID
283 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 283 optional :user_defined_id, String |
#verification_method ⇒ Symbol, :EXTERNALLY_VERIFIED
Verification Method
239 |
# File 'lib/lithic/models/external_bank_account_create_params.rb', line 239 required :verification_method, const: :EXTERNALLY_VERIFIED |