Class: Lithic::Models::ExternalBankAccountSetVerificationMethodParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ExternalBankAccountSetVerificationMethodParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/external_bank_account_set_verification_method_params.rb
Overview
Defined Under Namespace
Modules: VerificationMethod
Instance Attribute Summary collapse
- #external_bank_account_token ⇒ String
-
#financial_account_token ⇒ String?
The financial account token of the operating account to fund the micro deposits.
-
#verification_method ⇒ Symbol, Lithic::Models::ExternalBankAccountSetVerificationMethodParams::VerificationMethod
The verification method to set for the external bank account.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(external_bank_account_token:, verification_method:, financial_account_token: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalBankAccountSetVerificationMethodParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_bank_account_token:, verification_method:, financial_account_token: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::ExternalBankAccountSetVerificationMethodParams for more details.
|
|
# File 'lib/lithic/models/external_bank_account_set_verification_method_params.rb', line 29
|
Instance Attribute Details
#external_bank_account_token ⇒ String
13 |
# File 'lib/lithic/models/external_bank_account_set_verification_method_params.rb', line 13 required :external_bank_account_token, String |
#financial_account_token ⇒ String?
The financial account token of the operating account to fund the micro deposits. Required when verification_method is MICRO_DEPOSIT or PRENOTE.
27 |
# File 'lib/lithic/models/external_bank_account_set_verification_method_params.rb', line 27 optional :financial_account_token, String |
#verification_method ⇒ Symbol, Lithic::Models::ExternalBankAccountSetVerificationMethodParams::VerificationMethod
The verification method to set for the external bank account
19 20 |
# File 'lib/lithic/models/external_bank_account_set_verification_method_params.rb', line 19 required :verification_method, enum: -> { Lithic::ExternalBankAccountSetVerificationMethodParams::VerificationMethod } |