Class: Lithic::Models::ExternalBankAccountUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/external_bank_account_update_params.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Lithic::Internal::Type::BaseModel

Instance Attribute Details

#addressLithic::Models::ExternalBankAccountAddress?

Address



19
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 19

optional :address, -> { Lithic::ExternalBankAccountAddress }

#company_idString?

Optional field that helps identify bank accounts in receipts

Returns:

  • (String, nil)


25
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 25

optional :company_id, String

#dobDate?

Date of Birth of the Individual that owns the external bank account

Returns:

  • (Date, nil)


31
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 31

optional :dob, Date

#doing_business_asString?

Doing Business As

Returns:

  • (String, nil)


37
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 37

optional :doing_business_as, String

#external_bank_account_tokenString

Returns:

  • (String)


13
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 13

required :external_bank_account_token, String

#nameString?

The nickname for this External Bank Account

Returns:

  • (String, nil)


43
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 43

optional :name, String

#ownerString?

Legal Name of the business or individual who owns the external account. This will appear in statements

Returns:

  • (String, nil)


50
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 50

optional :owner, String

#owner_typeSymbol, ...

Owner Type

Returns:



56
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 56

optional :owner_type, enum: -> { Lithic::OwnerType }

#typeSymbol, ...



61
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 61

optional :type, enum: -> { Lithic::ExternalBankAccountUpdateParams::Type }

#user_defined_idString?

User Defined ID

Returns:

  • (String, nil)


67
# File 'lib/lithic/models/external_bank_account_update_params.rb', line 67

optional :user_defined_id, String