Class: Lithic::Models::FinancialAccounts::FinancialAccountsOpenToBuy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::FinancialAccounts::FinancialAccountsOpenToBuy
- Defined in:
- lib/lithic/models/financial_accounts/open_to_buy.rb,
sig/lithic/models/financial_accounts/open_to_buy.rbs
Overview
Instance Attribute Summary collapse
-
#open_to_buy ⇒ Integer
Funds available for card spend backed by this Security Account, in the currency's smallest unit (e.g., cents for USD).
-
#summary ⇒ Lithic::Models::FinancialAccounts::OpenToBuySummary
Balances that open to buy is derived from.
Instance Method Summary collapse
-
#initialize(open_to_buy:, summary:) ⇒ Object
constructor
Some parameter documentations has been truncated, see FinancialAccountsOpenToBuy for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(open_to_buy:, summary:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::FinancialAccounts::FinancialAccountsOpenToBuy for more details.
Open to Buy
|
|
# File 'lib/lithic/models/financial_accounts/open_to_buy.rb', line 23
|
Instance Attribute Details
#open_to_buy ⇒ Integer
Funds available for card spend backed by this Security Account, in the
currency's smallest unit (e.g., cents for USD). Equal to the sum of the amounts
in summary, and reaches zero once outstanding spend has consumed all available
funding
15 |
# File 'lib/lithic/models/financial_accounts/open_to_buy.rb', line 15 required :open_to_buy, Integer |
#summary ⇒ Lithic::Models::FinancialAccounts::OpenToBuySummary
Balances that open to buy is derived from
21 |
# File 'lib/lithic/models/financial_accounts/open_to_buy.rb', line 21 required :summary, -> { Lithic::FinancialAccounts::OpenToBuySummary } |
Instance Method Details
#to_hash ⇒ {
20 |
# File 'sig/lithic/models/financial_accounts/open_to_buy.rbs', line 20
def to_hash: -> {
|