Class: Lithic::Models::FinancialAccounts::InterestTierScheduleUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::FinancialAccounts::InterestTierScheduleUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb
Overview
Instance Attribute Summary collapse
- #effective_date ⇒ Date
- #financial_account_token ⇒ String
-
#penalty_rates ⇒ Object?
Custom rates per category for penalties.
-
#tier_name ⇒ String?
Name of a tier contained in the credit product.
-
#tier_rates ⇒ Object?
Custom rates per category.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(financial_account_token:, effective_date:, penalty_rates: nil, tier_name: nil, tier_rates: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see InterestTierScheduleUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(financial_account_token:, effective_date:, penalty_rates: nil, tier_name: nil, tier_rates: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::FinancialAccounts::InterestTierScheduleUpdateParams for more details.
|
|
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 40
|
Instance Attribute Details
#effective_date ⇒ Date
19 |
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 19 required :effective_date, Date |
#financial_account_token ⇒ String
14 |
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 14 required :financial_account_token, String |
#penalty_rates ⇒ Object?
Custom rates per category for penalties
25 |
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 25 optional :penalty_rates, Lithic::Internal::Type::Unknown |
#tier_name ⇒ String?
Name of a tier contained in the credit product. Mutually exclusive with tier_rates
32 |
# File 'lib/lithic/models/financial_accounts/interest_tier_schedule_update_params.rb', line 32 optional :tier_name, String |