Class: Lithic::Models::FinancialAccounts::LoanTape::Balances

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/financial_accounts/loan_tape.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Lithic::Internal::Type::BaseModel

Instance Attribute Details

#dueLithic::Models::FinancialAccounts::CategoryBalances

Amount due for the prior billing cycle. Any amounts not fully paid off on this due date will be considered past due the next day



337
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 337

required :due, -> { Lithic::FinancialAccounts::CategoryBalances }

#next_statement_dueLithic::Models::FinancialAccounts::CategoryBalances

Amount due for the current billing cycle. Any amounts not paid off by early payments or credits will be considered due at the end of the current billing period



345
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 345

required :next_statement_due, -> { Lithic::FinancialAccounts::CategoryBalances }

#past_dueLithic::Models::FinancialAccounts::CategoryBalances

Amount not paid off on previous due dates



351
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 351

required :past_due, -> { Lithic::FinancialAccounts::CategoryBalances }

#past_statements_dueLithic::Models::FinancialAccounts::CategoryBalances

Amount due for the past billing cycles.



357
# File 'lib/lithic/models/financial_accounts/loan_tape.rb', line 357

required :past_statements_due, -> { Lithic::FinancialAccounts::CategoryBalances }