Class: Lithic::Models::FinancialAccounts::Statement::AmountDue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::FinancialAccounts::Statement::AmountDue
- Defined in:
- lib/lithic/models/financial_accounts/statement.rb,
sig/lithic/models/financial_accounts/statement.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Payment due at the end of the billing period in cents.
-
#past_due ⇒ Integer
Amount past due for statement in cents.
Instance Method Summary collapse
-
#initialize ⇒ AmountDue
constructor
A new instance of AmountDue.
- #to_hash ⇒ { amount: Integer, past_due: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ AmountDue
Returns a new instance of AmountDue.
261 |
# File 'sig/lithic/models/financial_accounts/statement.rbs', line 261
def initialize: (amount: Integer, past_due: Integer) -> void
|
Instance Attribute Details
#amount ⇒ Integer
Payment due at the end of the billing period in cents. Negative amount indicates something is owed. If the amount owed is positive there was a net credit. If auto-collections are enabled this is the amount that will be requested on the payment due date
338 |
# File 'lib/lithic/models/financial_accounts/statement.rb', line 338 required :amount, Integer |
#past_due ⇒ Integer
Amount past due for statement in cents
344 |
# File 'lib/lithic/models/financial_accounts/statement.rb', line 344 required :past_due, Integer |
Instance Method Details
#to_hash ⇒ { amount: Integer, past_due: Integer }
263 |
# File 'sig/lithic/models/financial_accounts/statement.rbs', line 263
def to_hash: -> { amount: Integer, past_due: Integer }
|