Class: Lithic::Models::ManagementOperationCreateParams
Overview
Defined Under Namespace
Modules: Category, Direction, EventType, OnClosedAccount
Instance Attribute Summary collapse
#request_options
Class Method Summary
collapse
Instance Method Summary
collapse
dump_request
included
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
57
|
# File 'sig/lithic/models/management_operation_create_params.rbs', line 57
def initialize: (
|
Instance Attribute Details
#amount ⇒ Integer
13
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 13
required :amount, Integer
|
18
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 18
required :category, enum: -> { Lithic::ManagementOperationCreateParams::Category }
|
23
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 23
required :direction, enum: -> { Lithic::ManagementOperationCreateParams::Direction }
|
#effective_date ⇒ Date
28
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 28
required :effective_date, Date
|
33
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 33
required :event_type, enum: -> { Lithic::ManagementOperationCreateParams::EventType }
|
#financial_account_token ⇒ String
38
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 38
required :financial_account_token, String
|
#memo ⇒ String?
50
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 50
optional :memo, String
|
#on_closed_account ⇒ Symbol, ...
What to do if the financial account is closed when posting an operation
56
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 56
optional :on_closed_account, enum: -> { Lithic::ManagementOperationCreateParams::OnClosedAccount }
|
#subtype ⇒ String?
61
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 61
optional :subtype, String
|
#token ⇒ String?
Customer-provided token that will serve as an idempotency token. This token will
become the transaction token.
45
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 45
optional :token, String
|
#user_defined_id ⇒ String?
66
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 66
optional :user_defined_id, String
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/lithic/models/management_operation_create_params.rb', line 105
|
Instance Method Details
#to_hash ⇒ {
72
|
# File 'sig/lithic/models/management_operation_create_params.rbs', line 72
def to_hash: -> {
|