Class: Lithic::Models::NonPCICard::Funding
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::NonPCICard::Funding
- Defined in:
- lib/lithic/models/non_pci_card.rb,
sig/lithic/models/non_pci_card.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#account_name ⇒ String?
Account name identifying the funding source.
-
#created ⇒ Time
An RFC 3339 string representing when this funding source was added to the Lithic account.
-
#last_four ⇒ String
The last 4 digits of the account (e.g. bank account, debit card) associated with this FundingAccount.
-
#nickname ⇒ String?
The nickname given to the
FundingAccountornullif it has no nickname. -
#state ⇒ Symbol, Lithic::Models::NonPCICard::Funding::State
State of funding source.
-
#token ⇒ String
A globally unique identifier for this FundingAccount.
-
#type ⇒ Symbol, Lithic::Models::NonPCICard::Funding::Type
Types of funding source: _
DEPOSITORY_CHECKING- Bank checking account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, created:, last_four:, state:, type:, account_name: nil, nickname: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Funding for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, created:, last_four:, state:, type:, account_name: nil, nickname: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::NonPCICard::Funding for more details.
Funding account for a card
accoun
|
|
# File 'lib/lithic/models/non_pci_card.rb', line 335
|
Instance Attribute Details
#account_name ⇒ String?
Account name identifying the funding source. This may be null.
327 |
# File 'lib/lithic/models/non_pci_card.rb', line 327 optional :account_name, String |
#created ⇒ Time
An RFC 3339 string representing when this funding source was added to the Lithic
account. This may be null. UTC time zone.
298 |
# File 'lib/lithic/models/non_pci_card.rb', line 298 required :created, Time |
#last_four ⇒ String
The last 4 digits of the account (e.g. bank account, debit card) associated with this FundingAccount. This may be null.
305 |
# File 'lib/lithic/models/non_pci_card.rb', line 305 required :last_four, String |
#nickname ⇒ String?
The nickname given to the FundingAccount or null if it has no nickname.
333 |
# File 'lib/lithic/models/non_pci_card.rb', line 333 optional :nickname, String, nil?: true |
#state ⇒ Symbol, Lithic::Models::NonPCICard::Funding::State
State of funding source. Funding source states: _ ENABLED - The funding
account is available to use for card creation and transactions. _ PENDING -
The funding account is still being verified e.g. bank micro-deposits
verification. * DELETED - The founding account has been deleted.
314 |
# File 'lib/lithic/models/non_pci_card.rb', line 314 required :state, enum: -> { Lithic::NonPCICard::Funding::State } |
#token ⇒ String
A globally unique identifier for this FundingAccount.
291 |
# File 'lib/lithic/models/non_pci_card.rb', line 291 required :token, String |
#type ⇒ Symbol, Lithic::Models::NonPCICard::Funding::Type
Types of funding source: _ DEPOSITORY_CHECKING - Bank checking account. _
DEPOSITORY_SAVINGS - Bank savings account.
321 |
# File 'lib/lithic/models/non_pci_card.rb', line 321 required :type, enum: -> { Lithic::NonPCICard::Funding::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/non_pci_card.rb', line 369
|
Instance Method Details
#to_hash ⇒ {
193 |
# File 'sig/lithic/models/non_pci_card.rbs', line 193
def to_hash: -> {
|