Class: Lithic::Models::Payment::Event
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Payment::Event
- Defined in:
- lib/lithic/models/payment.rb,
sig/lithic/models/payment.rbs
Defined Under Namespace
Modules: DetailedResult, Result, Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
#created ⇒ Time
Date and time when the financial event occurred.
-
#detailed_results ⇒ Array<Symbol, Lithic::Models::Payment::Event::DetailedResult>?
More detailed reasons for the event.
-
#external_id ⇒ String?
Payment event external ID.
-
#result ⇒ Symbol, Lithic::Models::Payment::Event::Result
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
#token ⇒ String
Globally unique identifier.
-
#type ⇒ Symbol, Lithic::Models::Payment::Event::Type
Note: Inbound wire transfers are coming soon (availability varies by partner bank).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, amount:, created:, result:, type:, detailed_results: nil, external_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Lithic::Models::Payment::Event for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, amount:, created:, result:, type:, detailed_results: nil, external_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::Payment::Event for more details.
Note: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related fields below are a preview. To learn more, contact your customer success manager.
Payment Event
|
|
# File 'lib/lithic/models/payment.rb', line 342
|
Instance Attribute Details
#amount ⇒ Integer
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
255 |
# File 'lib/lithic/models/payment.rb', line 255 required :amount, Integer |
#created ⇒ Time
Date and time when the financial event occurred. UTC time zone.
261 |
# File 'lib/lithic/models/payment.rb', line 261 required :created, Time |
#detailed_results ⇒ Array<Symbol, Lithic::Models::Payment::Event::DetailedResult>?
More detailed reasons for the event
331 332 |
# File 'lib/lithic/models/payment.rb', line 331 optional :detailed_results, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::Payment::Event::DetailedResult] } |
#external_id ⇒ String?
Payment event external ID. For ACH transactions, this is the ACH trace number. For inbound wire transfers, this is the IMAD (Input Message Accountability Data).
340 |
# File 'lib/lithic/models/payment.rb', line 340 optional :external_id, String, nil?: true |
#result ⇒ Symbol, Lithic::Models::Payment::Event::Result
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
268 |
# File 'lib/lithic/models/payment.rb', line 268 required :result, enum: -> { Lithic::Payment::Event::Result } |
#token ⇒ String
Globally unique identifier.
248 |
# File 'lib/lithic/models/payment.rb', line 248 required :token, String |
#type ⇒ Symbol, Lithic::Models::Payment::Event::Type
Note: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related event types below are a preview. To learn more, contact your customer success manager.
Event types:
ACH events:
ACH_ORIGINATION_INITIATED- ACH origination received and pending approval/release from an ACH hold.ACH_ORIGINATION_REVIEWED- ACH origination has completed the review process.ACH_ORIGINATION_CANCELLED- ACH origination has been cancelled.ACH_ORIGINATION_PROCESSED- ACH origination has been processed and sent to the Federal Reserve.ACH_ORIGINATION_SETTLED- ACH origination has settled.ACH_ORIGINATION_RELEASED- ACH origination released from pending to available balance.ACH_ORIGINATION_REJECTED- ACH origination was rejected and not sent to the Federal Reserve.ACH_RECEIPT_PROCESSED- ACH receipt pending release from an ACH holder.ACH_RECEIPT_SETTLED- ACH receipt funds have settled.ACH_RECEIPT_RELEASED- ACH receipt released from pending to available balance.ACH_RECEIPT_RELEASED_EARLY- ACH receipt released early from pending to available balance.ACH_RETURN_INITIATED- ACH initiated return for an ACH receipt.ACH_RETURN_PROCESSED- ACH receipt returned by the Receiving Depository Financial Institution.ACH_RETURN_SETTLED- ACH return settled by the Receiving Depository Financial Institution.ACH_RETURN_REJECTED- ACH return was rejected by the Receiving Depository Financial Institution.
Wire transfer events:
WIRE_TRANSFER_INBOUND_RECEIVED- Inbound wire transfer received from the Federal Reserve and pending release to available balance.WIRE_TRANSFER_INBOUND_SETTLED- Inbound wire transfer funds released from pending to available balance.WIRE_TRANSFER_INBOUND_BLOCKED- Inbound wire transfer blocked and funds frozen for regulatory review.
Wire return events:
WIRE_RETURN_OUTBOUND_INITIATED- Outbound wire return initiated to return funds from an inbound wire transfer.WIRE_RETURN_OUTBOUND_SENT- Outbound wire return sent to the Federal Reserve and pending acceptance.WIRE_RETURN_OUTBOUND_SETTLED- Outbound wire return accepted by the Federal Reserve and funds returned to sender.WIRE_RETURN_OUTBOUND_REJECTED- Outbound wire return rejected by the Federal Reserve.
325 |
# File 'lib/lithic/models/payment.rb', line 325 required :type, enum: -> { Lithic::Payment::Event::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/payment.rb', line 376
|
Instance Method Details
#to_hash ⇒ {
241 |
# File 'sig/lithic/models/payment.rbs', line 241
def to_hash: -> {
|