Class: Lithic::Models::PaymentCreateParams
Overview
Defined Under Namespace
Modules: Method, Type
Classes: Hold, MethodAttributes
Instance Attribute Summary collapse
#request_options
Class Method Summary
collapse
dump_request
included
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Instance Attribute Details
#amount ⇒ Integer
13
|
# File 'lib/lithic/models/payment_create_params.rb', line 13
required :amount, Integer
|
#external_bank_account_token ⇒ String
18
|
# File 'lib/lithic/models/payment_create_params.rb', line 18
required :external_bank_account_token, String
|
#financial_account_token ⇒ String
23
|
# File 'lib/lithic/models/payment_create_params.rb', line 23
required :financial_account_token, String
|
Optional hold to settle when this payment is initiated.
#memo ⇒ String?
56
|
# File 'lib/lithic/models/payment_create_params.rb', line 56
optional :memo, String
|
28
|
# File 'lib/lithic/models/payment_create_params.rb', line 28
required :method_, enum: -> { Lithic::PaymentCreateParams::Method }, api_name: :method
|
33
|
# File 'lib/lithic/models/payment_create_params.rb', line 33
required :method_attributes, -> { Lithic::PaymentCreateParams::MethodAttributes }
|
#token ⇒ String?
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
45
|
# File 'lib/lithic/models/payment_create_params.rb', line 45
optional :token, String
|
38
|
# File 'lib/lithic/models/payment_create_params.rb', line 38
required :type, enum: -> { Lithic::PaymentCreateParams::Type }
|
#user_defined_id ⇒ String?
61
|
# File 'lib/lithic/models/payment_create_params.rb', line 61
optional :user_defined_id, String
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/lithic/models/payment_create_params.rb', line 95
|