Class: Lithic::Models::ThreeDSAuthentication::Browser
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::ThreeDSAuthentication::Browser
- Defined in:
- lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs
Overview
Instance Attribute Summary collapse
-
#accept_header ⇒ String?
Content of the HTTP accept headers as sent from the cardholder's browser to the 3DS requestor (e.g., merchant or digital wallet).
-
#ip ⇒ String?
IP address of the browser as returned by the HTTP headers to the 3DS requestor (e.g., merchant or digital wallet).
-
#java_enabled ⇒ Boolean?
Indicates whether the cardholder's browser has the ability to execute Java.
-
#javascript_enabled ⇒ Boolean?
Indicates whether the cardholder's browser has the ability to execute JavaScript.
-
#language ⇒ String?
Language of the cardholder's browser as defined in IETF BCP47.
-
#time_zone ⇒ String?
Time zone offset in minutes between UTC and browser local time.
-
#user_agent ⇒ String?
Content of the HTTP user-agent header.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
689 |
# File 'sig/lithic/models/three_ds_authentication.rbs', line 689
def initialize: (
|
Instance Attribute Details
#accept_header ⇒ String?
Content of the HTTP accept headers as sent from the cardholder's browser to the 3DS requestor (e.g., merchant or digital wallet).
948 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 948 optional :accept_header, String, nil?: true |
#ip ⇒ String?
IP address of the browser as returned by the HTTP headers to the 3DS requestor
(e.g., merchant or digital wallet). Maps to EMV 3DS field browserIP.
955 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 955 optional :ip, String, nil?: true |
#java_enabled ⇒ Boolean?
Indicates whether the cardholder's browser has the ability to execute Java. Maps
to EMV 3DS field browserJavaEnabled.
962 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 962 optional :java_enabled, Lithic::Internal::Type::Boolean, nil?: true |
#javascript_enabled ⇒ Boolean?
Indicates whether the cardholder's browser has the ability to execute
JavaScript. Maps to EMV 3DS field browserJavascriptEnabled.
969 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 969 optional :javascript_enabled, Lithic::Internal::Type::Boolean, nil?: true |
#language ⇒ String?
Language of the cardholder's browser as defined in IETF BCP47. Maps to EMV 3DS
field browserLanguage.
976 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 976 optional :language, String, nil?: true |
#time_zone ⇒ String?
Time zone offset in minutes between UTC and browser local time. Maps to EMV 3DS
field browserTz.
983 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 983 optional :time_zone, String, nil?: true |
#user_agent ⇒ String?
Content of the HTTP user-agent header. Maps to EMV 3DS field browserUserAgent.
989 |
# File 'lib/lithic/models/three_ds_authentication.rb', line 989 optional :user_agent, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
699 |
# File 'sig/lithic/models/three_ds_authentication.rbs', line 699
def to_hash: -> {
|