Module: Lithic::Models::ThreeDSAuthentication::ChallengeMetadata::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs
Overview
Indicates the status of the challenge
- SUCCESS - Cardholder completed the challenge successfully
- PENDING - Challenge was issued to the cardholder and was not completed yet
- SMS_DELIVERY_FAILED - Lithic confirmed undeliverability of the SMS to the provided phone number. Relevant only for SMS_OTP method
- CARDHOLDER_TIMEOUT - Cardholder failed to complete the challenge within the given challenge TTL
- CANCELED_VIA_CHALLENGE_UI - Cardholder canceled the challenge by selecting "cancel" on the challenge UI
- CANCELED_OOB - Cardholder canceled the challenge out of band
- ATTEMPTS_EXCEEDED - Cardholder failed the challenge by either entering an incorrect OTP more than the allowed number of times or requesting a new OTP more than the allowed number of times
- ABORTED - Merchant aborted authentication after a challenge was requested
- ERROR - The challenge failed for a reason different than those documented
Constant Summary collapse
- SUCCESS =
:SUCCESS- PENDING =
:PENDING- SMS_DELIVERY_FAILED =
:SMS_DELIVERY_FAILED- CARDHOLDER_TIMEOUT =
:CARDHOLDER_TIMEOUT- CANCELED_VIA_CHALLENGE_UI =
:CANCELED_VIA_CHALLENGE_UI- CANCELED_OOB =
:CANCELED_OOB- ATTEMPTS_EXCEEDED =
:ATTEMPTS_EXCEEDED- ABORTED =
:ABORTED- ERROR =
:ERROR
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::ThreeDSAuthentication::ChallengeMetadata::status]
771 |
# File 'sig/lithic/models/three_ds_authentication.rbs', line 771
def self?.values: -> ::Array[Lithic::Models::ThreeDSAuthentication::ChallengeMetadata::status]
|