Module: Lithic::Models::ThreeDSAuthentication::Psd2Context::LithicExemptionValidation
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs
Overview
Lithic's validation of the acquirer-declared exemption. Absent when no acquirer exemption was declared.
ACCEPTED- Lithic signals support the acquirer's claimREJECTED- Lithic signals contradict the claim, or a required signal is missingNOT_VALIDATED- Exemption was declared but Lithic has no basis to evaluate it; treated asREJECTEDfor challenge purposes
Constant Summary collapse
- ACCEPTED =
:ACCEPTED- REJECTED =
:REJECTED- NOT_VALIDATED =
:NOT_VALIDATED
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::ThreeDSAuthentication::Psd2Context::lithic_exemption_validation]
881 |
# File 'sig/lithic/models/three_ds_authentication.rbs', line 881
def self?.values: -> ::Array[Lithic::Models::ThreeDSAuthentication::Psd2Context::lithic_exemption_validation]
|