Module: Lithic::Models::ThreeDSAuthentication::ThreeRiRequestType
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/three_ds_authentication.rb,
sig/lithic/models/three_ds_authentication.rbs
Overview
Type of 3DS Requestor Initiated (3RI) request — i.e., a 3DS authentication that
takes place at the initiation of the merchant rather than the cardholder. The
most common example of this is where a merchant is authenticating before billing
for a recurring transaction such as a pay TV subscription or a utility bill.
Maps to EMV 3DS field threeRIInd.
Constant Summary collapse
- ACCOUNT_VERIFICATION =
:ACCOUNT_VERIFICATION- ADD_CARD =
:ADD_CARD- BILLING_AGREEMENT =
:BILLING_AGREEMENT- CARD_SECURITY_CODE_STATUS_CHECK =
:CARD_SECURITY_CODE_STATUS_CHECK- DELAYED_SHIPMENT =
:DELAYED_SHIPMENT- DEVICE_BINDING_STATUS_CHECK =
:DEVICE_BINDING_STATUS_CHECK- INSTALLMENT_TRANSACTION =
:INSTALLMENT_TRANSACTION- MAIL_ORDER =
:MAIL_ORDER- MAINTAIN_CARD_INFO =
:MAINTAIN_CARD_INFO- OTHER_PAYMENT =
:OTHER_PAYMENT- RECURRING_TRANSACTION =
:RECURRING_TRANSACTION- SPLIT_PAYMENT =
:SPLIT_PAYMENT- SPLIT_SHIPMENT =
:SPLIT_SHIPMENT- TELEPHONE_ORDER =
:TELEPHONE_ORDER- TOP_UP =
:TOP_UP- TRUST_LIST_STATUS_CHECK =
:TRUST_LIST_STATUS_CHECK
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Lithic::Models::ThreeDSAuthentication::three_ri_request_type]
846 |
# File 'sig/lithic/models/three_ds_authentication.rbs', line 846
def self?.values: -> ::Array[Lithic::Models::ThreeDSAuthentication::three_ri_request_type]
|