Class: Lithic::Models::Tokenization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Tokenization
- Defined in:
- lib/lithic/models/tokenization.rb,
sig/lithic/models/tokenization.rbs
Overview
Defined Under Namespace
Modules: Status, TokenRequestorName, TokenizationChannel Classes: Event
Instance Attribute Summary collapse
-
#account_token ⇒ String
The account token associated with the card being tokenized.
-
#card_token ⇒ String
The card token associated with the card being tokenized.
-
#created_at ⇒ Time
Date and time when the tokenization first occurred.
-
#device_id ⇒ String?
The device identifier associated with the tokenization.
-
#digital_card_art_token ⇒ String?
Specifies the digital card art displayed in the user's digital wallet after tokenization.
-
#dpan ⇒ String?
The dynamic pan assigned to the token by the network.
-
#events ⇒ Array<Lithic::Models::Tokenization::Event>?
A list of events related to the tokenization.
-
#payment_account_reference_id ⇒ String?
The network's unique reference for the card that is tokenized.
-
#status ⇒ Symbol, Lithic::Models::Tokenization::Status
The status of the tokenization request.
-
#token ⇒ String
Globally unique identifier for a Tokenization.
-
#token_requestor_name ⇒ Symbol, ...
The entity that requested the tokenization.
-
#token_unique_reference ⇒ String
The network's unique reference for the tokenization.
-
#tokenization_channel ⇒ Symbol, Lithic::Models::Tokenization::TokenizationChannel
The channel through which the tokenization was made.
-
#updated_at ⇒ Time
Latest date and time when the tokenization was updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(token:, account_token:, card_token:, created_at:, dpan:, status:, token_requestor_name:, token_unique_reference:, tokenization_channel:, updated_at:, device_id: nil, digital_card_art_token: nil, events: nil, payment_account_reference_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Tokenization for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, account_token:, card_token:, created_at:, dpan:, status:, token_requestor_name:, token_unique_reference:, tokenization_channel:, updated_at:, device_id: nil, digital_card_art_token: nil, events: nil, payment_account_reference_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::Tokenization for more details.
|
|
# File 'lib/lithic/models/tokenization.rb', line 96
|
Instance Attribute Details
#account_token ⇒ String
The account token associated with the card being tokenized.
17 |
# File 'lib/lithic/models/tokenization.rb', line 17 required :account_token, String |
#card_token ⇒ String
The card token associated with the card being tokenized.
23 |
# File 'lib/lithic/models/tokenization.rb', line 23 required :card_token, String |
#created_at ⇒ Time
Date and time when the tokenization first occurred. UTC time zone.
29 |
# File 'lib/lithic/models/tokenization.rb', line 29 required :created_at, Time |
#device_id ⇒ String?
The device identifier associated with the tokenization.
73 |
# File 'lib/lithic/models/tokenization.rb', line 73 optional :device_id, String, nil?: true |
#digital_card_art_token ⇒ String?
Specifies the digital card art displayed in the user's digital wallet after tokenization. This will be null if the tokenization was created without an associated digital card art. See Flexible Card Art Guide.
82 |
# File 'lib/lithic/models/tokenization.rb', line 82 optional :digital_card_art_token, String, nil?: true |
#dpan ⇒ String?
The dynamic pan assigned to the token by the network.
35 |
# File 'lib/lithic/models/tokenization.rb', line 35 required :dpan, String, nil?: true |
#events ⇒ Array<Lithic::Models::Tokenization::Event>?
A list of events related to the tokenization.
88 |
# File 'lib/lithic/models/tokenization.rb', line 88 optional :events, -> { Lithic::Internal::Type::ArrayOf[Lithic::Tokenization::Event] } |
#payment_account_reference_id ⇒ String?
The network's unique reference for the card that is tokenized.
94 |
# File 'lib/lithic/models/tokenization.rb', line 94 optional :payment_account_reference_id, String, nil?: true |
#status ⇒ Symbol, Lithic::Models::Tokenization::Status
The status of the tokenization request
41 |
# File 'lib/lithic/models/tokenization.rb', line 41 required :status, enum: -> { Lithic::Tokenization::Status } |
#token ⇒ String
Globally unique identifier for a Tokenization
11 |
# File 'lib/lithic/models/tokenization.rb', line 11 required :token, String |
#token_requestor_name ⇒ Symbol, ...
The entity that requested the tokenization. For digital wallets, this will be one of the defined wallet types. For merchant tokenizations, this will be a free-form merchant name string.
49 |
# File 'lib/lithic/models/tokenization.rb', line 49 required :token_requestor_name, union: -> { Lithic::Tokenization::TokenRequestorName } |
#token_unique_reference ⇒ String
The network's unique reference for the tokenization.
55 |
# File 'lib/lithic/models/tokenization.rb', line 55 required :token_unique_reference, String |
#tokenization_channel ⇒ Symbol, Lithic::Models::Tokenization::TokenizationChannel
The channel through which the tokenization was made.
61 |
# File 'lib/lithic/models/tokenization.rb', line 61 required :tokenization_channel, enum: -> { Lithic::Tokenization::TokenizationChannel } |
#updated_at ⇒ Time
Latest date and time when the tokenization was updated. UTC time zone.
67 |
# File 'lib/lithic/models/tokenization.rb', line 67 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/tokenization.rb', line 142
|
Instance Method Details
#to_hash ⇒ {
71 |
# File 'sig/lithic/models/tokenization.rbs', line 71
def to_hash: -> {
|