Class: Lithic::Models::Transaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Transaction
- Defined in:
- lib/lithic/models/transaction.rb
Overview
Direct Known Subclasses
AccountActivityListResponse::Card, AccountActivityRetrieveTransactionResponse::Card, CardTransactionUpdatedWebhookEvent
Defined Under Namespace
Modules: Network, Result, Status Classes: Amounts, Avs, Event, Merchant, Pos, ServiceLocation
Instance Attribute Summary collapse
-
#account_token ⇒ String
The token for the account associated with this transaction.
-
#acquirer_fee ⇒ Integer?
Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency.
- #acquirer_reference_number ⇒ String? deprecated Deprecated.
- #amount ⇒ Integer deprecated Deprecated.
- #amounts ⇒ Lithic::Models::Transaction::Amounts
- #authorization_amount ⇒ Integer? deprecated Deprecated.
-
#authorization_code ⇒ String?
A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks.
- #avs ⇒ Lithic::Models::Transaction::Avs?
-
#card_token ⇒ String
Token for the card used in this transaction.
- #cardholder_authentication ⇒ Lithic::Models::CardholderAuthentication?
-
#created ⇒ Time
Date and time when the transaction first occurred.
- #events ⇒ Array<Lithic::Models::Transaction::Event>?
- #financial_account_token ⇒ String?
-
#merchant ⇒ Lithic::Models::Transaction::Merchant
Merchant information including full location details.
- #merchant_amount ⇒ Integer? deprecated Deprecated.
- #merchant_authorization_amount ⇒ Integer? deprecated Deprecated.
- #merchant_currency ⇒ String deprecated Deprecated.
-
#network ⇒ Symbol, ...
Card network of the authorization.
-
#network_risk_score ⇒ Integer?
Network-provided score assessing risk level associated with a given authorization.
- #pos ⇒ Lithic::Models::Transaction::Pos
- #result ⇒ Symbol, Lithic::Models::Transaction::Result
-
#service_location ⇒ Lithic::Models::Transaction::ServiceLocation?
Where the cardholder received the service, when different from the card acceptor location.
- #settled_amount ⇒ Integer deprecated Deprecated.
-
#status ⇒ Symbol, Lithic::Models::Transaction::Status
Status of the transaction.
-
#tags ⇒ Hash{Symbol=>String}
Key-value pairs for tagging resources.
-
#token ⇒ String
Globally unique identifier.
- #token_info ⇒ Lithic::Models::TokenInfo?
-
#updated ⇒ Time
Date and time when the transaction last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, country:, postal_code:, state:, street_address:) ⇒ Object
constructor
Where the cardholder received the service, when different from the card acceptor location.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, postal_code:, state:, street_address:) ⇒ Object
Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.
|
|
# File 'lib/lithic/models/transaction.rb', line 197
|
Instance Attribute Details
#account_token ⇒ String
The token for the account associated with this transaction.
17 |
# File 'lib/lithic/models/transaction.rb', line 17 required :account_token, String |
#acquirer_fee ⇒ Integer?
Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
25 |
# File 'lib/lithic/models/transaction.rb', line 25 required :acquirer_fee, Integer, nil?: true |
#acquirer_reference_number ⇒ String?
Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing. This field has been deprecated in favor of the ‘acquirer_reference_number` that resides in the event-level `network_info`.
35 |
# File 'lib/lithic/models/transaction.rb', line 35 required :acquirer_reference_number, String, nil?: true |
#amount ⇒ Integer
When the transaction is pending, this represents the authorization amount of the transaction in the anticipated settlement currency. Once the transaction has settled, this field represents the settled amount in the settlement currency.
45 |
# File 'lib/lithic/models/transaction.rb', line 45 required :amount, Integer |
#amounts ⇒ Lithic::Models::Transaction::Amounts
50 |
# File 'lib/lithic/models/transaction.rb', line 50 required :amounts, -> { Lithic::Transaction::Amounts } |
#authorization_amount ⇒ Integer?
The authorization amount of the transaction in the anticipated settlement currency.
59 |
# File 'lib/lithic/models/transaction.rb', line 59 required :authorization_amount, Integer, nil?: true |
#authorization_code ⇒ String?
A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks.
66 |
# File 'lib/lithic/models/transaction.rb', line 66 required :authorization_code, String, nil?: true |
#avs ⇒ Lithic::Models::Transaction::Avs?
71 |
# File 'lib/lithic/models/transaction.rb', line 71 required :avs, -> { Lithic::Transaction::Avs }, nil?: true |
#card_token ⇒ String
Token for the card used in this transaction.
77 |
# File 'lib/lithic/models/transaction.rb', line 77 required :card_token, String |
#cardholder_authentication ⇒ Lithic::Models::CardholderAuthentication?
82 |
# File 'lib/lithic/models/transaction.rb', line 82 required :cardholder_authentication, -> { Lithic::CardholderAuthentication }, nil?: true |
#created ⇒ Time
Date and time when the transaction first occurred. UTC time zone.
88 |
# File 'lib/lithic/models/transaction.rb', line 88 required :created, Time |
#events ⇒ Array<Lithic::Models::Transaction::Event>?
195 |
# File 'lib/lithic/models/transaction.rb', line 195 optional :events, -> { Lithic::Internal::Type::ArrayOf[Lithic::Transaction::Event] } |
#financial_account_token ⇒ String?
93 |
# File 'lib/lithic/models/transaction.rb', line 93 required :financial_account_token, String, nil?: true |
#merchant ⇒ Lithic::Models::Transaction::Merchant
Merchant information including full location details.
99 |
# File 'lib/lithic/models/transaction.rb', line 99 required :merchant, -> { Lithic::Transaction::Merchant } |
#merchant_amount ⇒ Integer?
Analogous to the ‘amount’, but in the merchant currency.
107 |
# File 'lib/lithic/models/transaction.rb', line 107 required :merchant_amount, Integer, nil?: true |
#merchant_authorization_amount ⇒ Integer?
Analogous to the ‘authorization_amount’, but in the merchant currency.
115 |
# File 'lib/lithic/models/transaction.rb', line 115 required :merchant_authorization_amount, Integer, nil?: true |
#merchant_currency ⇒ String
3-character alphabetic ISO 4217 code for the local currency of the transaction.
123 |
# File 'lib/lithic/models/transaction.rb', line 123 required :merchant_currency, String |
#network ⇒ Symbol, ...
Card network of the authorization. Value is ‘UNKNOWN` when Lithic cannot determine the network code from the upstream provider.
130 |
# File 'lib/lithic/models/transaction.rb', line 130 required :network, enum: -> { Lithic::Transaction::Network }, nil?: true |
#network_risk_score ⇒ Integer?
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
140 |
# File 'lib/lithic/models/transaction.rb', line 140 required :network_risk_score, Integer, nil?: true |
#pos ⇒ Lithic::Models::Transaction::Pos
145 |
# File 'lib/lithic/models/transaction.rb', line 145 required :pos, -> { Lithic::Transaction::Pos } |
#result ⇒ Symbol, Lithic::Models::Transaction::Result
150 |
# File 'lib/lithic/models/transaction.rb', line 150 required :result, enum: -> { Lithic::Transaction::Result } |
#service_location ⇒ Lithic::Models::Transaction::ServiceLocation?
Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.
158 |
# File 'lib/lithic/models/transaction.rb', line 158 required :service_location, -> { Lithic::Transaction::ServiceLocation }, nil?: true |
#settled_amount ⇒ Integer
The settled amount of the transaction in the settlement currency.
166 |
# File 'lib/lithic/models/transaction.rb', line 166 required :settled_amount, Integer |
#status ⇒ Symbol, Lithic::Models::Transaction::Status
Status of the transaction.
172 |
# File 'lib/lithic/models/transaction.rb', line 172 required :status, enum: -> { Lithic::Transaction::Status } |
#tags ⇒ Hash{Symbol=>String}
Key-value pairs for tagging resources. Tags allow you to associate arbitrary metadata with a resource for your own purposes.
179 |
# File 'lib/lithic/models/transaction.rb', line 179 required :tags, Lithic::Internal::Type::HashOf[String] |
#token ⇒ String
Globally unique identifier.
11 |
# File 'lib/lithic/models/transaction.rb', line 11 required :token, String |
#token_info ⇒ Lithic::Models::TokenInfo?
184 |
# File 'lib/lithic/models/transaction.rb', line 184 required :token_info, -> { Lithic::TokenInfo }, nil?: true |
#updated ⇒ Time
Date and time when the transaction last updated. UTC time zone.
190 |
# File 'lib/lithic/models/transaction.rb', line 190 required :updated, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/transaction.rb', line 443
|