Class: Lithic::Models::Transaction::Event
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Transaction::Event
- Defined in:
- lib/lithic/models/transaction.rb
Defined Under Namespace
Modules: AccountType, DetailedResult, EffectivePolarity, Result, Type Classes: Amounts, NetworkInfo, NetworkSpecificData, RuleResult
Instance Attribute Summary collapse
- #account_type ⇒ Symbol, ...
- #amount ⇒ Integer deprecated Deprecated.
- #amounts ⇒ Lithic::Models::Transaction::Event::Amounts
-
#created ⇒ Time
RFC 3339 date and time this event entered the system.
- #detailed_results ⇒ Array<Symbol, Lithic::Models::Transaction::Event::DetailedResult>
-
#effective_polarity ⇒ Symbol, Lithic::Models::Transaction::Event::EffectivePolarity
Indicates whether the transaction event is a credit or debit to the account.
-
#network_info ⇒ Lithic::Models::Transaction::Event::NetworkInfo?
Information provided by the card network in each event.
- #network_specific_data ⇒ Lithic::Models::Transaction::Event::NetworkSpecificData?
- #result ⇒ Symbol, Lithic::Models::Transaction::Event::Result
- #rule_results ⇒ Array<Lithic::Models::Transaction::Event::RuleResult>
-
#token ⇒ String
Transaction event identifier.
-
#type ⇒ Symbol, Lithic::Models::Transaction::Event::Type
Type of transaction event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(original_transaction_id:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkInfo::Visa for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(original_transaction_id:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::Transaction::Event::NetworkInfo::Visa for more details.
|
|
# File 'lib/lithic/models/transaction.rb', line 879
|
Instance Attribute Details
#account_type ⇒ Symbol, ...
872 |
# File 'lib/lithic/models/transaction.rb', line 872 optional :account_type, enum: -> { Lithic::Transaction::Event::AccountType } |
#amount ⇒ Integer
Amount of the event in the settlement currency.
814 |
# File 'lib/lithic/models/transaction.rb', line 814 required :amount, Integer |
#amounts ⇒ Lithic::Models::Transaction::Event::Amounts
819 |
# File 'lib/lithic/models/transaction.rb', line 819 required :amounts, -> { Lithic::Transaction::Event::Amounts } |
#created ⇒ Time
RFC 3339 date and time this event entered the system. UTC time zone.
825 |
# File 'lib/lithic/models/transaction.rb', line 825 required :created, Time |
#detailed_results ⇒ Array<Symbol, Lithic::Models::Transaction::Event::DetailedResult>
830 831 |
# File 'lib/lithic/models/transaction.rb', line 830 required :detailed_results, -> { Lithic::Internal::Type::ArrayOf[enum: Lithic::Transaction::Event::DetailedResult] } |
#effective_polarity ⇒ Symbol, Lithic::Models::Transaction::Event::EffectivePolarity
Indicates whether the transaction event is a credit or debit to the account.
837 |
# File 'lib/lithic/models/transaction.rb', line 837 required :effective_polarity, enum: -> { Lithic::Transaction::Event::EffectivePolarity } |
#network_info ⇒ Lithic::Models::Transaction::Event::NetworkInfo?
Information provided by the card network in each event. This includes common identifiers shared between you, Lithic, the card network and in some cases the acquirer. These identifiers often link together events within the same transaction lifecycle and can be used to locate a particular transaction, such as during processing of disputes. Not all fields are available in all events, and the presence of these fields is dependent on the card network and the event type. If the field is populated by the network, we will pass it through as is unless otherwise specified. Please consult the official network documentation for more details about these fields and how to use them.
851 |
# File 'lib/lithic/models/transaction.rb', line 851 required :network_info, -> { Lithic::Transaction::Event::NetworkInfo }, nil?: true |
#network_specific_data ⇒ Lithic::Models::Transaction::Event::NetworkSpecificData?
877 |
# File 'lib/lithic/models/transaction.rb', line 877 optional :network_specific_data, -> { Lithic::Transaction::Event::NetworkSpecificData } |
#result ⇒ Symbol, Lithic::Models::Transaction::Event::Result
856 |
# File 'lib/lithic/models/transaction.rb', line 856 required :result, enum: -> { Lithic::Transaction::Event::Result } |
#rule_results ⇒ Array<Lithic::Models::Transaction::Event::RuleResult>
861 |
# File 'lib/lithic/models/transaction.rb', line 861 required :rule_results, -> { Lithic::Internal::Type::ArrayOf[Lithic::Transaction::Event::RuleResult] } |
#token ⇒ String
Transaction event identifier.
806 |
# File 'lib/lithic/models/transaction.rb', line 806 required :token, String |
#type ⇒ Symbol, Lithic::Models::Transaction::Event::Type
Type of transaction event
867 |
# File 'lib/lithic/models/transaction.rb', line 867 required :type, enum: -> { Lithic::Transaction::Event::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/transaction.rb', line 1075
|