Class: Lithic::Models::Transaction::Event::NetworkInfo::Acquirer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Transaction::Event::NetworkInfo::Acquirer
- Defined in:
- lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#acquirer_reference_number ⇒ String?
Identifier assigned by the acquirer, applicable to dual-message transactions only.
-
#retrieval_reference_number ⇒ String?
Identifier assigned by the acquirer.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1024 |
# File 'sig/lithic/models/transaction.rbs', line 1024
def initialize: (
|
Instance Attribute Details
#acquirer_reference_number ⇒ String?
Identifier assigned by the acquirer, applicable to dual-message transactions only. The acquirer reference number (ARN) is only populated once a transaction has been cleared, and it is not available in all transactions (such as automated fuel dispenser transactions). A single transaction can contain multiple ARNs if the merchant sends multiple clearings.
1140 |
# File 'lib/lithic/models/transaction.rb', line 1140 required :acquirer_reference_number, String, nil?: true |
#retrieval_reference_number ⇒ String?
Identifier assigned by the acquirer.
1146 |
# File 'lib/lithic/models/transaction.rb', line 1146 required :retrieval_reference_number, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
1029 |
# File 'sig/lithic/models/transaction.rbs', line 1029
def to_hash: -> {
|