Class: Lithic::Models::Transaction::Event::NetworkInfo::Mastercard
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::Transaction::Event::NetworkInfo::Mastercard
- Defined in:
- lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#banknet_reference_number ⇒ String?
Identifier assigned by Mastercard.
-
#original_banknet_reference_number ⇒ String?
Identifier assigned by Mastercard.
-
#original_switch_serial_number ⇒ String?
Identifier assigned by Mastercard.
-
#switch_serial_number ⇒ String?
Identifier assigned by Mastercard, applicable to single-message transactions only.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1071 |
# File 'sig/lithic/models/transaction.rbs', line 1071
def initialize: (
|
Instance Attribute Details
#banknet_reference_number ⇒ String?
Identifier assigned by Mastercard. Guaranteed by Mastercard to be unique for any transaction within a specific financial network on any processing day.
1192 |
# File 'lib/lithic/models/transaction.rb', line 1192 required :banknet_reference_number, String, nil?: true |
#original_banknet_reference_number ⇒ String?
Identifier assigned by Mastercard. Matches the banknet_reference_number of a
prior related event. May be populated in authorization reversals, incremental
authorizations (authorization requests that augment a previously authorized
amount), automated fuel dispenser authorization advices and clearings, and
financial authorizations. If the original banknet reference number contains all
zeroes, then no actual reference number could be found by the network or
acquirer. If Mastercard converts a transaction from dual-message to
single-message, such as for certain ATM transactions, it will populate the
original banknet reference number in the resulting financial authorization with
the banknet reference number of the initial authorization, which Lithic does not
receive.
1208 |
# File 'lib/lithic/models/transaction.rb', line 1208 required :original_banknet_reference_number, String, nil?: true |
#original_switch_serial_number ⇒ String?
Identifier assigned by Mastercard. Matches the switch_serial_number of a prior
related event. May be populated in returns and return reversals. Applicable to
single-message transactions only.
1216 |
# File 'lib/lithic/models/transaction.rb', line 1216 required :original_switch_serial_number, String, nil?: true |
#switch_serial_number ⇒ String?
Identifier assigned by Mastercard, applicable to single-message transactions only.
1223 |
# File 'lib/lithic/models/transaction.rb', line 1223 required :switch_serial_number, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
1078 |
# File 'sig/lithic/models/transaction.rbs', line 1078
def to_hash: -> {
|