Class: Lithic::Models::Transaction::Event::NetworkSpecificData::Mastercard

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction.rb,
sig/lithic/models/transaction.rbs

Overview

See Also:

  • Lithic::Models::Transaction::Event::NetworkSpecificData#mastercard

Defined Under Namespace

Classes: OnBehalfServiceResult

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



1403
# File 'sig/lithic/models/transaction.rbs', line 1403

def initialize: (

Instance Attribute Details

#ecommerce_security_level_indicatorString?

Indicates the electronic commerce security level and UCAF collection.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1468
# File 'lib/lithic/models/transaction.rb', line 1468

required :ecommerce_security_level_indicator, String, nil?: true

#on_behalf_service_resultArray<Lithic::Models::Transaction::Event::NetworkSpecificData::Mastercard::OnBehalfServiceResult>?

The On-behalf Service performed on the transaction and the results. Contains all applicable, on-behalf service results that were performed on a given transaction.

Parameters:

  • value (::Array[Lithic::Transaction::Event::NetworkSpecificData::Mastercard::OnBehalfServiceResult], nil)

Returns:



1476
1477
1478
1479
1480
# File 'lib/lithic/models/transaction.rb', line 1476

required :on_behalf_service_result,
-> {
  Lithic::Internal::Type::ArrayOf[Lithic::Transaction::Event::NetworkSpecificData::Mastercard::OnBehalfServiceResult]
},
nil?: true

#transaction_type_identifierString?

Indicates the type of additional transaction purpose.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1486
# File 'lib/lithic/models/transaction.rb', line 1486

required :transaction_type_identifier, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


1409
# File 'sig/lithic/models/transaction.rbs', line 1409

def to_hash: -> {