Class: Lithic::Models::TransactionMonitoring::CaseActivityEntry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::CaseActivityEntry
- Defined in:
- lib/lithic/models/transaction_monitoring/case_activity_entry.rb,
sig/lithic/models/transaction_monitoring/case_activity_entry.rbs
Overview
Instance Attribute Summary collapse
-
#actor_token ⇒ String?
Identifier of the actor that produced the activity entry.
-
#created ⇒ Time
Date and time at which the activity entry was created.
-
#entry_type ⇒ Symbol, Lithic::Models::TransactionMonitoring::CaseActivityType
The case field that changed, or the action that was taken, in an activity entry:.
-
#new_value ⇒ String?
New value of the changed field, when applicable.
-
#previous_value ⇒ String?
Previous value of the changed field, when applicable.
-
#token ⇒ String
Globally unique identifier for the activity entry.
Instance Method Summary collapse
-
#initialize(token:, actor_token:, created:, entry_type:, new_value:, previous_value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CaseActivityEntry for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, actor_token:, created:, entry_type:, new_value:, previous_value:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::CaseActivityEntry for more details.
A single entry in a case's activity feed
|
|
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 54
|
Instance Attribute Details
#actor_token ⇒ String?
Identifier of the actor that produced the activity entry
18 |
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 18 required :actor_token, String, nil?: true |
#created ⇒ Time
Date and time at which the activity entry was created
24 |
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 24 required :created, Time |
#entry_type ⇒ Symbol, Lithic::Models::TransactionMonitoring::CaseActivityType
The case field that changed, or the action that was taken, in an activity entry:
STATUS- The case status changedTITLE- The case title changedASSIGNED_TO- The case assignee changedRESOLUTION_OUTCOME- The resolution outcome was set or changedRESOLUTION_NOTES- The resolution notes were set or changedTAGS- The case tags changedPRIORITY- The case priority changedCOMMENT- A comment was added or editedFILE- A file was attached to the case
40 |
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 40 required :entry_type, enum: -> { Lithic::TransactionMonitoring::CaseActivityType } |
#new_value ⇒ String?
New value of the changed field, when applicable
46 |
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 46 required :new_value, String, nil?: true |
#previous_value ⇒ String?
Previous value of the changed field, when applicable
52 |
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 52 required :previous_value, String, nil?: true |
#token ⇒ String
Globally unique identifier for the activity entry
12 |
# File 'lib/lithic/models/transaction_monitoring/case_activity_entry.rb', line 12 required :token, String |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/lithic/models/transaction_monitoring/case_activity_entry.rbs', line 36
def to_hash: -> {
|