Class: Lithic::Models::TransactionMonitoring::CaseListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/lithic/models/transaction_monitoring/case_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_token: nil, assignee: nil, begin_: nil, card_token: nil, end_: nil, ending_before: nil, entity_token: nil, page_size: nil, queue_token: nil, rule_token: nil, sort_by: nil, starting_after: nil, status: nil, transaction_token: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::CaseListParams for more details.

Parameters:

  • account_token (String) (defaults to: nil)

    Only return cases that include transactions on the provided account.

  • assignee (String) (defaults to: nil)

    Only return cases assigned to the provided value. Pass an empty string to return

  • begin_ (Time) (defaults to: nil)

    Date string in RFC 3339 format. Only entries created after the specified time wi

  • card_token (String) (defaults to: nil)

    Only return cases that include transactions on the provided card.

  • end_ (Time) (defaults to: nil)

    Date string in RFC 3339 format. Only entries created before the specified time w

  • ending_before (String) (defaults to: nil)

    A cursor representing an item’s token before which a page of results should end.

  • entity_token (String) (defaults to: nil)

    Only return cases associated with the provided entity.

  • page_size (Integer) (defaults to: nil)

    Page size (for pagination).

  • queue_token (String) (defaults to: nil)

    Only return cases belonging to the provided queue.

  • rule_token (String) (defaults to: nil)

    Only return cases triggered by the provided transaction monitoring rule.

  • sort_by (Symbol, Lithic::Models::TransactionMonitoring::CaseSortOrder) (defaults to: nil)

    Sort order for the returned cases.

  • starting_after (String) (defaults to: nil)

    A cursor representing an item’s token after which a page of results should begin

  • status (Symbol, Lithic::Models::TransactionMonitoring::CaseStatus) (defaults to: nil)

    Only return cases with the provided status.

  • transaction_token (String) (defaults to: nil)

    Only return cases that include the provided transaction.

  • request_options (Lithic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 100

Instance Attribute Details

#account_tokenString?

Only return cases that include transactions on the provided account.

Returns:

  • (String, nil)


15
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 15

optional :account_token, String

#assigneeString?

Only return cases assigned to the provided value. Pass an empty string to return only unassigned cases.

Returns:

  • (String, nil)


22
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 22

optional :assignee, String

#begin_Time?

Date string in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.

Returns:

  • (Time, nil)


29
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 29

optional :begin_, Time

#card_tokenString?

Only return cases that include transactions on the provided card.

Returns:

  • (String, nil)


35
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 35

optional :card_token, String

#end_Time?

Date string in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.

Returns:

  • (Time, nil)


42
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 42

optional :end_, Time

#ending_beforeString?

A cursor representing an item’s token before which a page of results should end. Used to retrieve the previous page of results before this item.

Returns:

  • (String, nil)


49
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 49

optional :ending_before, String

#entity_tokenString?

Only return cases associated with the provided entity.

Returns:

  • (String, nil)


55
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 55

optional :entity_token, String

#page_sizeInteger?

Page size (for pagination).

Returns:

  • (Integer, nil)


61
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 61

optional :page_size, Integer

#queue_tokenString?

Only return cases belonging to the provided queue.

Returns:

  • (String, nil)


67
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 67

optional :queue_token, String

#rule_tokenString?

Only return cases triggered by the provided transaction monitoring rule.

Returns:

  • (String, nil)


73
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 73

optional :rule_token, String

#sort_bySymbol, ...

Sort order for the returned cases.



79
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 79

optional :sort_by, enum: -> { Lithic::TransactionMonitoring::CaseSortOrder }

#starting_afterString?

A cursor representing an item’s token after which a page of results should begin. Used to retrieve the next page of results after this item.

Returns:

  • (String, nil)


86
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 86

optional :starting_after, String

#statusSymbol, ...

Only return cases with the provided status.



92
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 92

optional :status, enum: -> { Lithic::TransactionMonitoring::CaseStatus }

#transaction_tokenString?

Only return cases that include the provided transaction.

Returns:

  • (String, nil)


98
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 98

optional :transaction_token, String