Class: Lithic::Models::TransactionMonitoring::CaseListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::CaseListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/lithic/models/transaction_monitoring/case_list_params.rb
Overview
Instance Attribute Summary collapse
-
#account_token ⇒ String?
Only return cases that include transactions on the provided account.
-
#assignee ⇒ String?
Only return cases assigned to the provided value.
-
#begin_ ⇒ Time?
Date string in RFC 3339 format.
-
#card_token ⇒ String?
Only return cases that include transactions on the provided card.
-
#end_ ⇒ Time?
Date string in RFC 3339 format.
-
#ending_before ⇒ String?
A cursor representing an item’s token before which a page of results should end.
-
#entity_token ⇒ String?
Only return cases associated with the provided entity.
-
#page_size ⇒ Integer?
Page size (for pagination).
-
#queue_token ⇒ String?
Only return cases belonging to the provided queue.
-
#rule_token ⇒ String?
Only return cases triggered by the provided transaction monitoring rule.
-
#sort_by ⇒ Symbol, ...
Sort order for the returned cases.
-
#starting_after ⇒ String?
A cursor representing an item’s token after which a page of results should begin.
-
#status ⇒ Symbol, ...
Only return cases with the provided status.
-
#transaction_token ⇒ String?
Only return cases that include the provided transaction.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_token: nil, assignee: nil, begin_: nil, card_token: nil, end_: nil, ending_before: nil, entity_token: nil, page_size: nil, queue_token: nil, rule_token: nil, sort_by: nil, starting_after: nil, status: nil, transaction_token: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CaseListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_token: nil, assignee: nil, begin_: nil, card_token: nil, end_: nil, ending_before: nil, entity_token: nil, page_size: nil, queue_token: nil, rule_token: nil, sort_by: nil, starting_after: nil, status: nil, transaction_token: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::CaseListParams for more details.
|
|
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 100
|
Instance Attribute Details
#account_token ⇒ String?
Only return cases that include transactions on the provided account.
15 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 15 optional :account_token, String |
#assignee ⇒ String?
Only return cases assigned to the provided value. Pass an empty string to return only unassigned cases.
22 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 22 optional :assignee, String |
#begin_ ⇒ Time?
Date string in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.
29 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 29 optional :begin_, Time |
#card_token ⇒ String?
Only return cases that include transactions on the provided card.
35 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 35 optional :card_token, String |
#end_ ⇒ Time?
Date string in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.
42 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 42 optional :end_, Time |
#ending_before ⇒ String?
A cursor representing an item’s token before which a page of results should end. Used to retrieve the previous page of results before this item.
49 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 49 optional :ending_before, String |
#entity_token ⇒ String?
Only return cases associated with the provided entity.
55 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 55 optional :entity_token, String |
#page_size ⇒ Integer?
Page size (for pagination).
61 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 61 optional :page_size, Integer |
#queue_token ⇒ String?
Only return cases belonging to the provided queue.
67 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 67 optional :queue_token, String |
#rule_token ⇒ String?
Only return cases triggered by the provided transaction monitoring rule.
73 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 73 optional :rule_token, String |
#sort_by ⇒ Symbol, ...
Sort order for the returned cases.
79 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 79 optional :sort_by, enum: -> { Lithic::TransactionMonitoring::CaseSortOrder } |
#starting_after ⇒ String?
A cursor representing an item’s token after which a page of results should begin. Used to retrieve the next page of results after this item.
86 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 86 optional :starting_after, String |
#status ⇒ Symbol, ...
Only return cases with the provided status.
92 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 92 optional :status, enum: -> { Lithic::TransactionMonitoring::CaseStatus } |
#transaction_token ⇒ String?
Only return cases that include the provided transaction.
98 |
# File 'lib/lithic/models/transaction_monitoring/case_list_params.rb', line 98 optional :transaction_token, String |