Module: Lithic::Models::TransactionMonitoring::CaseStatus
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/lithic/models/transaction_monitoring/case_status.rb
Overview
Status of a case as it progresses through the review workflow:
-
‘OPEN` - The case has been created and is still collecting matching transactions
-
‘ASSIGNED` - An analyst has been assigned and transaction collection has stopped
-
‘IN_REVIEW` - The case is actively being investigated
-
‘ESCALATED` - The case has been reviewed and requires additional oversight
-
‘RESOLVED` - A determination has been made and a resolution recorded
-
‘CLOSED` - The case is finalized
Constant Summary collapse
- OPEN =
:OPEN- ASSIGNED =
:ASSIGNED- IN_REVIEW =
:IN_REVIEW- ESCALATED =
:ESCALATED- RESOLVED =
:RESOLVED- CLOSED =
:CLOSED
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/lithic/models/transaction_monitoring/case_status.rb', line 26
|