Class: Lithic::Models::TransactionMonitoring::CaseTransaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction_monitoring/case_transaction.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, account_token:, added_at:, card_token:, transaction_created_at:) ⇒ Object

A single transaction associated with a case

Parameters:

  • token (String)

    Globally unique identifier for the transaction

  • account_token (String)

    Token of the account the transaction belongs to

  • added_at (Time)

    Date and time at which the transaction was added to the case

  • card_token (String)

    Token of the card the transaction was made on

  • transaction_created_at (Time)

    Date and time at which the transaction was created



# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 38

Instance Attribute Details

#account_tokenString

Token of the account the transaction belongs to

Returns:

  • (String)


18
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 18

required :account_token, String

#added_atTime

Date and time at which the transaction was added to the case

Returns:

  • (Time)


24
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 24

required :added_at, Time

#card_tokenString

Token of the card the transaction was made on

Returns:

  • (String)


30
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 30

required :card_token, String

#tokenString

Globally unique identifier for the transaction

Returns:

  • (String)


12
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 12

required :token, String

#transaction_created_atTime

Date and time at which the transaction was created

Returns:

  • (Time)


36
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 36

required :transaction_created_at, Time