Class: Lithic::Models::TransactionMonitoring::CaseTransaction::PaymentCaseTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::CaseTransaction::PaymentCaseTransaction
- Defined in:
- lib/lithic/models/transaction_monitoring/case_transaction.rb,
sig/lithic/models/transaction_monitoring/case_transaction.rbs
Instance Attribute Summary collapse
-
#account_token ⇒ String?
Token of the account the payment belongs to, if applicable.
-
#added_at ⇒ Time
Date and time at which the transaction was added to the case.
- #category ⇒ Symbol, :PAYMENT
-
#financial_account_token ⇒ String
Token of the financial account the payment belongs to.
-
#token ⇒ String
Globally unique identifier for the payment transaction.
-
#transaction_created_at ⇒ Time
Date and time at which the transaction was created.
Instance Method Summary collapse
-
#initialize(token:, added_at:, financial_account_token:, transaction_created_at:, account_token: nil, category: :PAYMENT) ⇒ Object
constructor
A payment (ACH) transaction associated with a case.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, added_at:, financial_account_token:, transaction_created_at:, account_token: nil, category: :PAYMENT) ⇒ Object
A payment (ACH) transaction associated with a case
|
|
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 109
|
Instance Attribute Details
#account_token ⇒ String?
Token of the account the payment belongs to, if applicable
107 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 107 optional :account_token, String |
#added_at ⇒ Time
Date and time at which the transaction was added to the case
84 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 84 required :added_at, Time |
#category ⇒ Symbol, :PAYMENT
89 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 89 required :category, const: :PAYMENT |
#financial_account_token ⇒ String
Token of the financial account the payment belongs to
95 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 95 required :financial_account_token, String |
#token ⇒ String
Globally unique identifier for the payment transaction
78 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 78 required :token, String |
#transaction_created_at ⇒ Time
Date and time at which the transaction was created
101 |
# File 'lib/lithic/models/transaction_monitoring/case_transaction.rb', line 101 required :transaction_created_at, Time |
Instance Method Details
#to_hash ⇒ {
87 |
# File 'sig/lithic/models/transaction_monitoring/case_transaction.rbs', line 87
def to_hash: -> {
|