Class: Lithic::Models::TransactionMonitoring::Queue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::Queue
- Defined in:
- lib/lithic/models/transaction_monitoring/queue.rb
Overview
Defined Under Namespace
Classes: CaseCounts
Instance Attribute Summary collapse
-
#case_counts ⇒ Lithic::Models::TransactionMonitoring::Queue::CaseCounts
Number of cases in the queue, broken down by status.
-
#created ⇒ Time
Date and time at which the queue was created.
-
#description ⇒ String?
Optional description of the queue.
-
#name ⇒ String
Human-readable name of the queue.
-
#token ⇒ String
Globally unique identifier for the queue.
-
#updated ⇒ Time
Date and time at which the queue was last updated.
Instance Method Summary collapse
-
#initialize(token:, case_counts:, created:, description:, name:, updated:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Queue for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, case_counts:, created:, description:, name:, updated:) ⇒ Object
Some parameter documentations has been truncated, see Lithic::Models::TransactionMonitoring::Queue for more details.
A queue that groups transaction monitoring cases for review
|
|
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 45
|
Instance Attribute Details
#case_counts ⇒ Lithic::Models::TransactionMonitoring::Queue::CaseCounts
Number of cases in the queue, broken down by status. A status is omitted when the queue has no cases in that status
19 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 19 required :case_counts, -> { Lithic::TransactionMonitoring::Queue::CaseCounts } |
#created ⇒ Time
Date and time at which the queue was created
25 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 25 required :created, Time |
#description ⇒ String?
Optional description of the queue
31 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 31 required :description, String, nil?: true |
#name ⇒ String
Human-readable name of the queue
37 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 37 required :name, String |
#token ⇒ String
Globally unique identifier for the queue
12 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 12 required :token, String |
#updated ⇒ Time
Date and time at which the queue was last updated
43 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 43 required :updated, Time |