Class: Lithic::Models::TransactionMonitoring::Queue::CaseCounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Lithic::Models::TransactionMonitoring::Queue::CaseCounts
- Defined in:
- lib/lithic/models/transaction_monitoring/queue.rb,
sig/lithic/models/transaction_monitoring/queue.rbs
Overview
Instance Attribute Summary collapse
-
#assigned ⇒ Integer?
Number of cases in the queue with status
ASSIGNED. -
#closed ⇒ Integer?
Number of cases in the queue with status
CLOSED. -
#escalated ⇒ Integer?
Number of cases in the queue with status
ESCALATED. -
#in_review ⇒ Integer?
Number of cases in the queue with status
IN_REVIEW. -
#open_ ⇒ Integer?
Number of cases in the queue with status
OPEN. -
#resolved ⇒ Integer?
Number of cases in the queue with status
RESOLVED.
Instance Method Summary collapse
-
#initialize(assigned: nil, closed: nil, escalated: nil, in_review: nil, open_: nil, resolved: nil) ⇒ Object
constructor
Number of cases in the queue, broken down by status.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assigned: nil, closed: nil, escalated: nil, in_review: nil, open_: nil, resolved: nil) ⇒ Object
Number of cases in the queue, broken down by status. A status is omitted when the queue has no cases in that status
|
|
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 101
|
Instance Attribute Details
#assigned ⇒ Integer?
Number of cases in the queue with status ASSIGNED
69 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 69 optional :assigned, Integer, api_name: :ASSIGNED |
#closed ⇒ Integer?
Number of cases in the queue with status CLOSED
75 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 75 optional :closed, Integer, api_name: :CLOSED |
#escalated ⇒ Integer?
Number of cases in the queue with status ESCALATED
81 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 81 optional :escalated, Integer, api_name: :ESCALATED |
#in_review ⇒ Integer?
Number of cases in the queue with status IN_REVIEW
87 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 87 optional :in_review, Integer, api_name: :IN_REVIEW |
#open_ ⇒ Integer?
Number of cases in the queue with status OPEN
93 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 93 optional :open_, Integer, api_name: :OPEN |
#resolved ⇒ Integer?
Number of cases in the queue with status RESOLVED
99 |
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 99 optional :resolved, Integer, api_name: :RESOLVED |
Instance Method Details
#to_hash ⇒ {
89 |
# File 'sig/lithic/models/transaction_monitoring/queue.rbs', line 89
def to_hash: -> {
|