Class: Lithic::Models::TransactionMonitoring::Queue::CaseCounts

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/lithic/models/transaction_monitoring/queue.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(assigned: nil, closed: nil, escalated: nil, in_review: nil, open_: nil, resolved: nil) ⇒ Object

Number of cases in the queue, broken down by status. A status is omitted when the queue has no cases in that status

Parameters:

  • assigned (Integer) (defaults to: nil)

    Number of cases in the queue with status ‘ASSIGNED`

  • closed (Integer) (defaults to: nil)

    Number of cases in the queue with status ‘CLOSED`

  • escalated (Integer) (defaults to: nil)

    Number of cases in the queue with status ‘ESCALATED`

  • in_review (Integer) (defaults to: nil)

    Number of cases in the queue with status ‘IN_REVIEW`

  • open_ (Integer) (defaults to: nil)

    Number of cases in the queue with status ‘OPEN`

  • resolved (Integer) (defaults to: nil)

    Number of cases in the queue with status ‘RESOLVED`



# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 101

Instance Attribute Details

#assignedInteger?

Number of cases in the queue with status ‘ASSIGNED`

Returns:

  • (Integer, nil)


69
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 69

optional :assigned, Integer, api_name: :ASSIGNED

#closedInteger?

Number of cases in the queue with status ‘CLOSED`

Returns:

  • (Integer, nil)


75
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 75

optional :closed, Integer, api_name: :CLOSED

#escalatedInteger?

Number of cases in the queue with status ‘ESCALATED`

Returns:

  • (Integer, nil)


81
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 81

optional :escalated, Integer, api_name: :ESCALATED

#in_reviewInteger?

Number of cases in the queue with status ‘IN_REVIEW`

Returns:

  • (Integer, nil)


87
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 87

optional :in_review, Integer, api_name: :IN_REVIEW

#open_Integer?

Number of cases in the queue with status ‘OPEN`

Returns:

  • (Integer, nil)


93
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 93

optional :open_, Integer, api_name: :OPEN

#resolvedInteger?

Number of cases in the queue with status ‘RESOLVED`

Returns:

  • (Integer, nil)


99
# File 'lib/lithic/models/transaction_monitoring/queue.rb', line 99

optional :resolved, Integer, api_name: :RESOLVED