Class: Lithic::Resources::BlockchainRecipients
- Inherits:
-
Object
- Object
- Lithic::Resources::BlockchainRecipients
- Defined in:
- lib/lithic/resources/blockchain_recipients.rb,
sig/lithic/resources/blockchain_recipients.rbs
Instance Method Summary collapse
-
#create(account_token:, address:, chain:, owner:, owner_type:, address_tag: nil, name: nil, request_options: {}) ⇒ Lithic::Models::BlockchainRecipient
Some parameter documentations has been truncated, see Models::BlockchainRecipientCreateParams for more details.
-
#initialize(client:) ⇒ BlockchainRecipients
constructor
private
A new instance of BlockchainRecipients.
Constructor Details
#initialize(client:) ⇒ BlockchainRecipients
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of BlockchainRecipients.
52 53 54 |
# File 'lib/lithic/resources/blockchain_recipients.rb', line 52 def initialize(client:) @client = client end |
Instance Method Details
#create(account_token:, address:, chain:, owner:, owner_type:, address_tag: nil, name: nil, request_options: {}) ⇒ Lithic::Models::BlockchainRecipient
Some parameter documentations has been truncated, see Models::BlockchainRecipientCreateParams for more details.
Register a blockchain address as a withdrawal destination for a financial account
The recipient is created with a PENDING verification state and cannot receive
a payout until screening of the address completes. Registering an address that
is already registered to the same financial account returns the existing
recipient and its current verification state, rather than creating a second one
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/lithic/resources/blockchain_recipients.rb', line 38 def create(params) parsed, = Lithic::BlockchainRecipientCreateParams.dump_request(params) @client.request( method: :post, path: "v1/blockchain_recipients", body: parsed, model: Lithic::BlockchainRecipient, options: ) end |