Class: Lithic::Resources::CardAuthorizations
- Inherits:
-
Object
- Object
- Lithic::Resources::CardAuthorizations
- Defined in:
- lib/lithic/resources/card_authorizations.rb
Instance Method Summary collapse
-
#challenge_response(event_token, response:, request_options: {}) ⇒ nil
Some parameter documentations has been truncated, see Models::CardAuthorizationChallengeResponseParams for more details.
-
#initialize(client:) ⇒ CardAuthorizations
constructor
private
A new instance of CardAuthorizations.
Constructor Details
#initialize(client:) ⇒ CardAuthorizations
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of CardAuthorizations.
40 41 42 |
# File 'lib/lithic/resources/card_authorizations.rb', line 40 def initialize(client:) @client = client end |
Instance Method Details
#challenge_response(event_token, response:, request_options: {}) ⇒ nil
Some parameter documentations has been truncated, see Models::CardAuthorizationChallengeResponseParams for more details.
Card program’s response to Authorization Challenge. Programs that have Authorization Challenges configured as Out of Band receive a [card_authorization.challenge](docs.lithic.com/reference/post_card-authorization-challenge) webhook when an authorization attempt triggers a challenge. The card program should respond using this endpoint after the cardholder completes the challenge.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/lithic/resources/card_authorizations.rb', line 26 def challenge_response(event_token, params) parsed, = Lithic::CardAuthorizationChallengeResponseParams.dump_request(params) @client.request( method: :post, path: ["v1/card_authorizations/%1$s/challenge_response", event_token], body: parsed, model: NilClass, options: ) end |