Class: Lithic::Resources::FinancialAccounts::InstallmentPlans
- Inherits:
-
Object
- Object
- Lithic::Resources::FinancialAccounts::InstallmentPlans
- Defined in:
- lib/lithic/resources/financial_accounts/installment_plans.rb,
sig/lithic/resources/financial_accounts/installment_plans.rbs
Instance Method Summary collapse
-
#initialize(client:) ⇒ InstallmentPlans
constructor
private
A new instance of InstallmentPlans.
-
#list(financial_account_token, ending_before: nil, page_size: nil, starting_after: nil, state: nil, request_options: {}) ⇒ Lithic::Internal::CursorPage<Lithic::Models::FinancialAccounts::InstallmentPlan>
Some parameter documentations has been truncated, see Models::FinancialAccounts::InstallmentPlanListParams for more details.
-
#retrieve(installment_plan_token, financial_account_token:, request_options: {}) ⇒ Lithic::Models::FinancialAccounts::InstallmentPlan
Get a specific installment plan for a given financial account.
Constructor Details
#initialize(client:) ⇒ InstallmentPlans
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of InstallmentPlans.
76 77 78 |
# File 'lib/lithic/resources/financial_accounts/installment_plans.rb', line 76 def initialize(client:) @client = client end |
Instance Method Details
#list(financial_account_token, ending_before: nil, page_size: nil, starting_after: nil, state: nil, request_options: {}) ⇒ Lithic::Internal::CursorPage<Lithic::Models::FinancialAccounts::InstallmentPlan>
Some parameter documentations has been truncated, see Models::FinancialAccounts::InstallmentPlanListParams for more details.
List the installment plans for a given financial account.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/lithic/resources/financial_accounts/installment_plans.rb', line 60 def list(financial_account_token, params = {}) parsed, = Lithic::FinancialAccounts::InstallmentPlanListParams.dump_request(params) query = Lithic::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["v1/financial_accounts/%1$s/installment_plans", financial_account_token], query: query, page: Lithic::Internal::CursorPage, model: Lithic::FinancialAccounts::InstallmentPlan, options: ) end |
#retrieve(installment_plan_token, financial_account_token:, request_options: {}) ⇒ Lithic::Models::FinancialAccounts::InstallmentPlan
Get a specific installment plan for a given financial account.
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/lithic/resources/financial_accounts/installment_plans.rb', line 20 def retrieve(installment_plan_token, params) parsed, = Lithic::FinancialAccounts::InstallmentPlanRetrieveParams.dump_request(params) financial_account_token = parsed.delete(:financial_account_token) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: [ "v1/financial_accounts/%1$s/installment_plans/%2$s", financial_account_token, installment_plan_token ], model: Lithic::FinancialAccounts::InstallmentPlan, options: ) end |